_antonyms = {
    "способность": "неспособность",
    "ненормальный": "в своем уме",
    "упразднять": "установить",
    "отсутствие": "присутствие",
    "нет на месте": "настоящее время",
    "будущее": "мимо",
    "абсолютный": "относительный",
    "воздерживаться": "акт",
    "абстрактные": "бетон",
    "изобилие": "дефицит",
    "обильный": "дефицитный",
    "принимать": "отклонять",
    "признавать": "отрицать",
    "приемлемо": "неприемлемо",
    "принятие": "отказ",
    "доступной": "недоступный",
    "точный": "неточный",
    "признанный": "непризнанный",
    "знакомство": "незнакомец",
    "акт": "воздерживаться",
    "действие": "в бою",
    "активный": "тихо",
    "сохранившийся": "потухший",
    "шумный": "тихо",
    "мероприятия": "бездеятельность",
    "фактический": "потенциал",
    "добавить": "вычитать",
    "прибавление": "вычитание",
    "адекватный": "неадекватный",
    "имя прилагательное": "основной",
    "допустимый": "недопустимый",
    "для взрослых": "ювенильный",
    "продвижение": "убывать",
    "впереди": "назад",
    "фронт": "задний",
    "травить": "назад",
    "преимущество": "недостаток",
    "утверждение": "неодобрение",
    "утвердительный": "отрицательный",
    "нейтральный": "отрицательный",
    "кормовой": "носовой",
    "возраст": "омолаживать",
    "престарелый": "молодой",
    "агитация": "спокойствие",
    "дать согласие": "не соглашаться",
    "приятный": "неприятный",
    "соглашение": "разногласие",
    "изменено": "без изменений",
    "чередовать": "напротив",
    "любитель": "профессиональный",
    "двусмысленный": "недвусмысленный",
    "дружный": "враждебный",
    "дружелюбный": "недружественный",
    "десантный": "земной",
    "анальный": "пероральный",
    "аналогичный": "непохожий",
    "анализ": "синтез",
    "аналитический": "синтетический",
    "предок": "потомок",
    "угловая": "закругленный",
    "оживлять": "неодушевленный",
    "ответ": "вопрос",
    "антагонистический": "синергистический",
    "предшествующее": "последующий",
    "передний": "задний",
    "антисептик": "септический",
    "появление": "исчезновение",
    "признательность": "амортизация",
    "одобрить": "не одобрять",
    "водный": "изверженный",
    "земной": "небесный",
    "рука": "разоружаться",
    "вооруженный": "безоружный",
    "прибыть": "оставлять",
    "восходить": "сходить",
    "восхождение": "спуск",
    "спящий": "бодрствующий",
    "соизволение": "разногласие",
    "асимметрия": "симметрия",
    "атеизм": "теизм",
    "прикреплять": "отрывать",
    "атака": "защищать",
    "преследовать в судебном порядке": "защищать",
    "внимание": "невнимательность",
    "привлечение": "отталкивание",
    "слышимый": "неслышный",
    "увеличение": "снижение",
    "тетка": "дядя",
    "уполномоченный": "неразрешенный",
    "автоматический": "руководство",
    "избежать": "противостоять",
    "бодрствующий": "спящий",
    "назад": "вперед",
    "убывать": "воск",
    "задний": "передний",
    "задний план": "передний план",
    "задний ход": "лицевой",
    "плохо": "хорошо",
    "зло": "хорошо",
    "негодность": "доброта",
    "сбалансированный": "несбалансированный",
    "медведь": "бык",
    "красивая": "уродливый",
    "красота": "уродство",
    "начать": "конец",
    "начало": "средний",
    "рано": "поздно",
    "вера": "неверие",
    "изгиб": "выпрямлять",
    "доброкачественный": "злокачественный",
    "большой": "маленький",
    "рождение": "смерть",
    "бисексуал": "гомосексуальный",
    "черный": "белый",
    "благословить": "проклятие",
    "благословенный": "проклят",
    "бескровный": "кровавый",
    "кровавый": "бескровный",
    "пятно": "фокус",
    "кипятить": "замерзать",
    "жирный": "робкий",
    "смелость": "робость",
    "заимствовать": "давать в долг",
    "заемщик": "кредитор",
    "дно": "вверх",
    "связанный": "несвязанный",
    "мальчик": "девушка",
    "бойкотировать": "покровительствовать",
    "ломать": "ремонт",
    "ломкий": "неуязвимый",
    "просиять": "темнеть",
    "светлеть": "темнеть",
    "сломанный": "непрерывный",
    "брат": "сестра",
    "бык": "медведь",
    "занятый": "незанятый",
    "работа": "вхолостую",
    "купить": "продавать",
    "спокойный": "штормовой",
    "спокойствие": "агитация",
    "способный": "неспособный",
    "вместимость": "недееспособность",
    "денежные средства": "кредит",
    "дебет": "кредит",
    "центр": "оставил",
    "церебральный": "эмоциональный",
    "определенность": "неопределенность",
    "изменение": "оставаться",
    "отходить": "оставаться",
    "переехать": "оставаться",
    "сменный": "неизменяемый",
    "заряд": "разряд",
    "завербоваться": "разряд",
    "дешево": "дорогая",
    "ура": "жаловаться",
    "веселая": "унылый",
    "ребенок": "родитель",
    "гражданский": "военные",
    "запрос": "утрачивать",
    "ясность": "помутнение",
    "протуберанец": "неясность",
    "прозрачность": "помутнение",
    "чистый": "нечистый",
    "духовенство": "миряне",
    "священник": "неспециалист",
    "закрыть": "открытый",
    "закрыто": "открытый",
    "закрыть": "открытый",
    "близость": "открытость",
    "береговой": "внутренний",
    "последовательный": "бессвязный",
    "холодно": "горячий",
    "обеспечение": "прямой",
    "комедия": "трагедия",
    "комфорт": "дискомфорт",
    "общий": "редкий",
    "совместимый": "несовместимый",
    "компетентность": "некомпетентность",
    "компетентный": "некомпетентный",
    "соревнование": "сотрудничество",
    "жаловаться": "ура",
    "полнота": "пустота",
    "сложный": "просто",
    "соединение": "просто",
    "уступчивый": "дерзкий",
    "усложнять": "упрощать",
    "вогнутый": "выпуклый",
    "тщеславие": "смирение",
    "гордость": "смирение",
    "концентрация": "распределение",
    "концентрический": "эксцентричный",
    "концепция": "неправильное представление",
    "обеспокоенный": "беззаботный",
    "бетон": "абстрактные",
    "подтвердил": "неподтвержденный",
    "противостоять": "избежать",
    "сослагательное наклонение": "разъединяющий",
    "соединять": "отключить",
    "сознание": "беспамятство",
    "консервативный": "либеральный",
    "консервировать": "отходы",
    "внимательный": "невнимательный",
    "консистенция": "несогласованность",
    "согласный": "гласная буква",
    "бросающийся в глаза": "незаметный",
    "конституционная": "неконституционный",
    "потреблять": "воздерживаться",
    "содержание": "недовольство",
    "постоянный": "бег",
    "продолжение": "прекращение",
    "продолжать": "прекращать",
    "непрерывность": "разрыв",
    "непрерывный": "сломанный",
    "контракт": "расширенный",
    "сокращение": "расширение",
    "удобный": "неудобный",
    "обычный": "необычный",
    "сходиться": "расходиться",
    "конвергенция": "дивергенция",
    "сходящийся": "расходящийся",
    "выпуклый": "вогнутый",
    "убежденный": "убедило",
    "круто": "высокая температура",
    "сотрудничество": "соревнование",
    "космополит": "провинциальный",
    "мужество": "трусость",
    "обложка": "раскрывать",
    "завуалированный": "неприкрытый",
    "трусость": "мужество",
    "кредит": "дебет",
    "кредитор": "заемщик",
    "критиковать": "хвалить",
    "плакать": "смех",
    "излечим": "неизлечимый",
    "проклятие": "благословить",
    "проклят": "благословенный",
    "изогнутый": "прямо",
    "порез": "неразрезанный",
    "опасность": "безопасность",
    "опасно": "безопасно",
    "темно": "легкий",
    "темнеть": "светлеть",
    "темнота": "расторопность",
    "инертность": "расторопность",
    "дочь": "сын",
    "день": "ночь",
    "глухой": "слух",
    "смерть": "рождение",
    "должник": "кредитор",
    "порядочность": "непристойность",
    "порядочный": "неприличный",
    "лиственный": "вечнозеленый",
    "решение": "нерешительность",
    "решающий": "нерешительный",
    "снижение": "увеличение",
    "снизилась": "вырос",
    "декремент": "приращение",
    "поражение": "победа",
    "защищать": "преследовать в судебном порядке",
    "ответчик": "истец",
    "защита": "судебное преследование",
    "оборонительный": "наступление",
    "дерзкий": "уступчивый",
    "дефицит": "изобилие",
    "определенный": "не определено",
    "дефляция": "инфляция",
    "задержка": "порыв",
    "задерживаться": "порыв",
    "спрос": "поставка",
    "отрицать": "признавать",
    "отклонять": "принимать",
    "зависимый": "независимый",
    "депозит": "изымать",
    "амортизация": "признательность",
    "унылый": "веселая",
    "сходить": "восходить",
    "потомок": "предок",
    "спуск": "восхождение",
    "описательный": "предписывающий",
    "желательный": "нежелательный",
    "отчаяние": "надежда",
    "отчаянный": "надежда",
    "безрассудство": "мудрость",
    "разрушенный": "сохраняется",
    "отрывать": "прикреплять",
    "деволюция": "эволюция",
    "отличаться": "равный",
    "неравный": "равный",
    "разница": "одинаковость",
    "сложно": "легко",
    "беспокойный": "легко",
    "трудность": "легкость",
    "прилежный": "нерадивый",
    "разведение": "концентрация",
    "распределение": "концентрация",
    "убывание": "увеличение",
    "грязный": "чистый",
    "нечистый": "чистый",
    "запрещать": "включить",
    "недостаток": "преимущество",
    "не соглашаться": "дать согласие",
    "противный": "приятный",
    "разногласие": "соизволение",
    "исчезновение": "появление",
    "неодобрение": "утверждение",
    "не одобрять": "одобрить",
    "разоружаться": "рука",
    "разряд": "завербоваться",
    "отказываться": "запрос",
    "утрачивать": "запрос",
    "дискомфорт": "комфорт",
    "отключить": "соединять",
    "недовольство": "содержание",
    "прекращение": "продолжение",
    "прекращать": "продолжать",
    "разрыв": "непрерывность",
    "прерывистый": "непрерывный",
    "отговаривать": "поощрять",
    "уныние": "поощрение",
    "выключать": "заниматься",
    "нечестный": "честный",
    "нечестность": "честность",
    "бесчестие": "честь",
    "дезинфицировать": "заражать",
    "распадаться": "интегрировать",
    "разъединяющий": "сослагательное наклонение",
    "нелюбовь": "симпатия",
    "вытеснять": "домик",
    "непослушание": "послушание",
    "непослушный": "послушный",
    "не слушаться": "подчиниться",
    "расстройство": "заказ",
    "беспорядочный": "упорядоченный",
    "дезорганизованный": "организованная",
    "неорганизованный": "организованная",
    "недовольный": "довольный",
    "опровергать": "доказывать",
    "дисквалифицировать": "квалифицировать",
    "постыдный": "уважаемый",
    "дурная слава": "репутация",
    "неуважение": "уважение",
    "непочтительный": "благоговейный",
    "неудовлетворенность": "удовлетворение",
    "вред": "оказание услуг",
    "непохожий": "аналогичный",
    "диссонанс": "гармония",
    "разубеждать": "уговаривать",
    "дистальный": "проксимальный",
    "отдаленный": "закрыть",
    "открытый": "закрыть",
    "различимый": "незаметный",
    "недоверие": "доверять",
    "суточный": "ночной",
    "расходиться": "сходиться",
    "дивергенция": "конвергенция",
    "расходящийся": "сходящийся",
    "делить": "объединять",
    "отдельно": "умножать",
    "разделенный": "единый",
    "делимый": "неделимый",
    "внутренний": "внешний",
    "родной": "иностранные",
    "доминирующий": "подчиненный",
    "бездействующий": "активный",
    "потухший": "сохранившийся",
    "неактивный": "активный",
    "пассивный": "активный",
    "тихо": "шумный",
    "двойной": "один",
    "множественный": "один",
    "голубь": "ястреб",
    "драматичный": "лирический",
    "сухой": "влажный",
    "кислый": "подслащивать",
    "в связи": "несвоевременный",
    "скучный": "точить",
    "расплющить": "точить",
    "умирающий": "рождающийся",
    "легкость": "трудность",
    "легко": "беспокойный",
    "отлив": "волна",
    "эксцентричный": "концентрический",
    "образованный": "необразованный",
    "эффективный": "неэффективный",
    "эффективность": "неэффективность",
    "эффективное": "неэффективный",
    "выход": "вход",
    "эластичный": "неэластичный",
    "право": "неподходящий",
    "эмоциональный": "церебральный",
    "эмпирический": "теоретический",
    "пустота": "полнота",
    "пустой": "полный",
    "тонкий": "сгущаться",
    "включить": "запрещать",
    "поощрять": "отговаривать",
    "поощрение": "уныние",
    "конец": "начало",
    "окончание": "начало",
    "средний": "рано",
    "эндемический": "космополит",
    "провинциальный": "космополит",
    "энергичный": "летаргический",
    "обеспечивать соблюдение": "освобожденный",
    "заниматься": "выключать",
    "наслаждаться": "страдать",
    "войти": "выход",
    "равный": "неравный",
    "равенство": "неравенство",
    "экваториальный": "полярный",
    "равноправный": "несправедливый",
    "сомнительный": "недвусмысленный",
    "стирать": "запись",
    "установить": "упразднять",
    "богатый событиями": "беспрецедентна",
    "вечнозеленый": "лиственный",
    "эволюция": "деволюция",
    "исключение": "включение",
    "освобожденный": "обеспечивать соблюдение",
    "выдыхать": "вдыхать",
    "существующий": "несуществующий",
    "выход": "войти",
    "расширять": "узкий",
    "расширенный": "контракт",
    "расширение": "сгибание",
    "ожидаемый": "неожиданный",
    "дорогая": "дешево",
    "опытный": "неопытный",
    "экспорт": "импортировать",
    "экспресс": "местный",
    "генеральная": "конкретный",
    "национальный": "международный",
    "экстерьер": "интерьер",
    "внешний": "свойственный",
    "внешне": "внутренне",
    "тушить": "воспламеняться",
    "заочный": "очный",
    "необычайный": "обычный",
    "провал": "прохождение",
    "бег": "постоянный",
    "отказ": "принятие",
    "справедливая": "недобросовестный",
    "верный": "вероломный",
    "падать": "подъем",
    "задавать": "подъем",
    "ошибочный": "непогрешимый",
    "падение": "поднимающийся",
    "ложность": "правда",
    "известность": "гнусность",
    "знакомые": "незнакомый",
    "маскарадный": "гладкий",
    "жир": "тонкий",
    "полный": "пустой",
    "толстый": "тонкий",
    "сгущаться": "тонкий",
    "отец": "мама",
    "фауна": "флора",
    "благоприятный": "неблагоприятный",
    "федеральный": "унитарный",
    "женский пол": "мужской",
    "женский": "бесполый",
    "женственность": "мужественность",
    "плодородный": "стерильный",
    "верность": "неверность",
    "фигура": "земля",
    "заполнить": "пустой",
    "найти": "потерять",
    "конец": "начало",
    "стоп": "начало",
    "конечный": "бесконечный",
    "огонь": "наем",
    "сгибание": "расширение",
    "поплавок": "раковина",
    "источник": "раковина",
    "флора": "фауна",
    "фокус": "пятно",
    "недоброжелатель": "друг",
    "складка": "раскрываться",
    "следовать": "предшествовать",
    "добиться успеха": "предшествовать",
    "последователь": "лидер",
    "глупый": "мудрый",
    "фут": "глава",
    "хвост": "глава",
    "запретить": "разрешать",
    "носовой": "кормовой",
    "передний план": "задний план",
    "иностранные": "родной",
    "забывать": "запомнить",
    "всепрощающий": "неумолимый",
    "формализм": "имитация",
    "удачливый": "несчастный",
    "вперед": "задний ход",
    "лицевой": "задний ход",
    "фол": "справедливая",
    "недобросовестный": "щепетильный",
    "найденный": "потерял",
    "братский": "идентичный",
    "замерзать": "кипятить",
    "частый": "нечастый",
    "часто": "не часто",
    "друг": "недоброжелатель",
    "глава": "хвост",
    "функциональная": "органический",
    "неорганический": "органический",
    "усиление": "потеря",
    "газообразный": "твердый",
    "полый": "твердый",
    "собирать": "распространение",
    "всеобщность": "особенность",
    "великодушный": "скупой",
    "девушка": "мальчик",
    "хорошо": "зло",
    "доброта": "негодность",
    "постепенный": "внезапно",
    "благодарный": "неблагодарный",
    "большая": "меньший",
    "зеленый": "созревший",
    "валовой": "сеть",
    "земля": "фигура",
    "вина": "невинность",
    "виновный": "невинный",
    "счастливо": "грустно",
    "счастье": "несчастье",
    "счастливый": "несчастный",
    "твердость": "мягкость",
    "громкость": "мягкость",
    "острота": "мягкость",
    "гармония": "диссонанс",
    "ненавидеть": "люблю",
    "ненавистный": "привлекательный",
    "ястреб": "голубь",
    "здоровый": "нездоровый",
    "слух": "глухой",
    "высокая температура": "круто",
    "небесный": "земной",
    "разнородность": "гомогенность",
    "скрывать": "показать",
    "наем": "огонь",
    "удар": "мисс",
    "святой": "нечестивый",
    "гомогенность": "разнородность",
    "гомологичны": "аналогичный",
    "гомосексуальный": "бисексуал",
    "честный": "нечестный",
    "честность": "нечестность",
    "честь": "бесчестие",
    "надежда": "безрассудство",
    "многообещающий": "безнадежный",
    "безнадежный": "многообещающий",
    "горизонтальный": "вертикальный",
    "враждебный": "дружелюбный",
    "недружественный": "дружелюбный",
    "горячий": "холодно",
    "смиренный": "гордый",
    "смирение": "гордость",
    "голодный": "жаждущий",
    "идентичный": "братский",
    "вхолостую": "работа",
    "изверженный": "водный",
    "воспламеняться": "тушить",
    "игнорировать": "уведомление",
    "нелегальный": "правовой",
    "незаконность": "легальность",
    "неразборчивый": "разборчивый",
    "нелогичный": "логический",
    "имитация": "формализм",
    "несущественный": "материал",
    "незрелость": "зрелость",
    "неизмеримый": "измеримый",
    "аморальный": "моральный",
    "безнравственность": "мораль",
    "бессмертный": "смертный",
    "бессмертие": "смертность",
    "неизменный": "изменчивый",
    "беспристрастность": "пристрастность",
    "непроходимый": "проходимый",
    "нетерпение": "терпение",
    "нетерпеливый": "пациент",
    "незаметный": "бросающийся в глаза",
    "дефектность": "совершенство",
    "непроницаемый": "проницаемый",
    "недопустимый": "допустимый",
    "безличный": "личный",
    "невежливый": "вежливый",
    "импортировать": "экспорт",
    "важный": "неважный",
    "невозможность": "возможность",
    "бессильный": "мощный",
    "невероятный": "вероятный",
    "улучшен": "необработанный",
    "улучшение": "снижение",
    "неосторожный": "осторожный",
    "примесь": "чистота",
    "неспособность": "способность",
    "недоступный": "доступной",
    "неточный": "точный",
    "в бою": "действие",
    "бездеятельность": "мероприятия",
    "неадекватный": "адекватный",
    "неодушевленный": "оживлять",
    "невнимательность": "внимание",
    "неслышный": "слышимый",
    "неспособный": "способный",
    "недееспособность": "вместимость",
    "наклонный": "горизонтальный",
    "вертикальный": "горизонтальный",
    "включение": "исключение",
    "бессвязный": "последовательный",
    "несовместимый": "совместимый",
    "некомпетентность": "компетентность",
    "некомпетентный": "компетентный",
    "неполнота": "полнота",
    "невнимательный": "внимательный",
    "несогласованность": "консистенция",
    "неудобный": "удобный",
    "вырос": "снизилась",
    "приращение": "декремент",
    "неизлечимый": "излечим",
    "непристойность": "порядочность",
    "неприличный": "порядочный",
    "нерешительность": "решение",
    "нерешительный": "решающий",
    "независимый": "зависимый",
    "неразличимый": "различимый",
    "неделимый": "делимый",
    "в помещении": "на открытом воздухе",
    "неэффективный": "эффективное",
    "неэффективность": "эффективность",
    "неэластичный": "эластичный",
    "неподходящий": "право",
    "неравенство": "равенство",
    "несправедливый": "равноправный",
    "неопытный": "опытный",
    "непогрешимый": "ошибочный",
    "гнусность": "известность",
    "заражать": "дезинфицировать",
    "низший": "превосходящий",
    "низкое качество": "превосходство",
    "неверность": "верность",
    "бесконечный": "конечный",
    "инфляция": "дефляция",
    "проинформировал": "несведущий",
    "нечастый": "частый",
    "не часто": "часто",
    "вход": "выход",
    "обитаемый": "необитаемый",
    "вдыхать": "выдыхать",
    "несправедливость": "справедливость",
    "невинность": "вина",
    "невинный": "виновный",
    "безвредный": "вредный",
    "недействующий": "оперативный",
    "невменяемость": "вменяемость",
    "ненадежность": "безопасность",
    "незначительность": "значение",
    "незначительный": "главный",
    "нерастворимый": "растворимый",
    "неплатежеспособность": "кредитоспособность",
    "несостоятельный": "растворитель",
    "нестабильность": "стабильность",
    "инструментальный": "вокальный",
    "недостаточность": "достаточность",
    "недостаточное": "достаточно",
    "недостаточно": "достаточно",
    "интегрировать": "распадаться",
    "интеграция": "сегрегация",
    "интеллект": "тупость",
    "вразумительный": "невразумительный",
    "предназначена": "непреднамеренный",
    "намеренно": "нечаянно",
    "заинтересованный": "незаинтересованный",
    "интересно": "неинтересный",
    "интерьер": "экстерьер",
    "промежуточный": "терминал",
    "внутренне": "внешне",
    "международный": "национальный",
    "местный": "генеральная",
    "непереносимость": "толерантность",
    "нетерпимый": "терпимый",
    "неподатливый": "послушный",
    "очный": "заочный",
    "свойственный": "внешний",
    "невидимость": "видимость",
    "невидимый": "видимый",
    "непроизвольный": "добровольный",
    "иррациональный": "рациональный",
    "нерегулярный": "регулярный",
    "неправильность": "регулярность",
    "не имеет значения": "соответствующий",
    "безответственный": "ответственность",
    "вопрос": "ответ",
    "совместный": "отдельный",
    "радость": "печаль",
    "радостный": "скорбный",
    "младший": "старшая",
    "справедливость": "несправедливость",
    "ювенильный": "для взрослых",
    "деревенщина": "деревенщина",
    "своего рода": "недобрый",
    "король": "королева",
    "миряне": "духовенство",
    "поздно": "рано",
    "смех": "плакать",
    "законный": "незаконное",
    "рыхлый": "напряженный",
    "расслабленный": "напряженный",
    "неспециалист": "священник",
    "вести": "дефицит",
    "лидер": "последователь",
    "оставлять": "прибыть",
    "оставил": "центр",
    "правовой": "нелегальный",
    "легальность": "незаконность",
    "легализовать": "вне закона",
    "разборчивый": "неразборчивый",
    "давать в долг": "заимствовать",
    "удлинять": "укорачивать",
    "меньший": "большая",
    "летаргический": "энергичный",
    "уровень": "повышение",
    "ниже": "повышение",
    "либеральный": "консервативный",
    "ложь": "стоять",
    "уступать": "стоять",
    "легкий": "темно",
    "расторопность": "инертность",
    "симпатия": "нелюбовь",
    "ограниченное": "неограниченный",
    "прямой": "обеспечение",
    "жидкость": "газообразный",
    "твердый": "полый",
    "конкретный": "генеральная",
    "место нахождения": "студия",
    "замок": "отпереть",
    "домик": "вытеснять",
    "логический": "нелогичный",
    "длинный": "короткая",
    "высокий": "короткая",
    "рыхлить": "деревенеть",
    "потерять": "найти",
    "потеря": "усиление",
    "потерял": "найденный",
    "привлекательный": "ненавистный",
    "люблю": "ненавидеть",
    "везучий": "несчастливый",
    "лирический": "драматичный",
    "главный": "незначительный",
    "большинство": "меньшинство",
    "делать": "ломать",
    "ремонт": "ломать",
    "мужской": "женский",
    "злокачественный": "доброкачественный",
    "руководство": "автоматический",
    "отмеченный": "неотмеченный",
    "в браке": "незамужняя",
    "бесполый": "женский",
    "мужественность": "женственность",
    "маскировать": "разоблачать",
    "материал": "несущественный",
    "материнский": "отеческий",
    "зрелость": "незрелость",
    "максимальная": "минимальный",
    "измеримый": "неизмеримый",
    "умственный": "физическое",
    "милостивый": "беспощадный",
    "беспощадный": "милостивый",
    "военные": "гражданский",
    "разум": "забывать",
    "запомнить": "забывать",
    "минимальный": "максимальная",
    "меньшинство": "большинство",
    "неправильное представление": "концепция",
    "мисс": "удар",
    "молярный": "молекулярная",
    "молекулярная": "молярный",
    "моральный": "аморальный",
    "мораль": "безнравственность",
    "смертный": "бессмертный",
    "смертность": "бессмертие",
    "мама": "отец",
    "умножать": "отдельно",
    "объединять": "делить",
    "изменчивый": "неизменный",
    "надир": "зенит",
    "узкий": "расширять",
    "рождающийся": "умирающий",
    "отрицательный": "нейтральный",
    "нерадивый": "прилежный",
    "племянник": "племянница",
    "сеть": "валовой",
    "племянница": "племянник",
    "ночь": "день",
    "ночной": "суточный",
    "номинальный": "реальный",
    "нереально": "реалистический",
    "несуществующий": "существующий",
    "нормальный": "ненормальный",
    "уведомление": "игнорировать",
    "вредный": "безвредный",
    "численный": "словесный",
    "послушание": "непослушание",
    "послушный": "неподатливый",
    "подчиниться": "не слушаться",
    "задача": "субъективный",
    "обязательное": "необязательный",
    "косой": "перпендикуляр",
    "неясность": "протуберанец",
    "помутнение": "прозрачность",
    "преступление": "защита",
    "судебное преследование": "защита",
    "наступление": "оборонительный",
    "официальный": "неофициальный",
    "открытость": "близость",
    "оперативный": "недействующий",
    "против": "единственный",
    "напротив": "чередовать",
    "оптимизм": "пессимизм",
    "оптимист": "пессимист",
    "необязательный": "обязательное",
    "пероральный": "анальный",
    "заказ": "расстройство",
    "упорядоченный": "беспорядочный",
    "органический": "неорганический",
    "организованная": "неорганизованный",
    "ортодоксальный": "неортодоксальный",
    "на открытом воздухе": "в помещении",
    "вне закона": "легализовать",
    "переоценивать": "недооценивать",
    "накладные расходы": "поверхность",
    "неприкрытый": "завуалированный",
    "пак": "распаковывать",
    "болезненный": "безболезненный",
    "безболезненный": "болезненный",
    "параллельно": "косой",
    "перпендикуляр": "косой",
    "родитель": "ребенок",
    "пристрастность": "беспристрастность",
    "особенность": "всеобщность",
    "частично": "полностью",
    "проходимый": "непроходимый",
    "прохождение": "бег",
    "мимо": "будущее",
    "настоящее время": "нет на месте",
    "отеческий": "материнский",
    "терпение": "нетерпение",
    "пациент": "нетерпеливый",
    "покровительствовать": "бойкотировать",
    "мир": "война",
    "штраф": "награда",
    "совершенство": "дефектность",
    "проницаемый": "непроницаемый",
    "разрешающий": "превентивный",
    "разрешать": "запретить",
    "личный": "безличный",
    "уговаривать": "разубеждать",
    "пессимизм": "оптимизм",
    "пессимист": "оптимист",
    "физическое": "умственный",
    "гладкий": "маскарадный",
    "истец": "ответчик",
    "довольный": "недовольный",
    "множественное число": "единственное число",
    "полярный": "экваториальный",
    "вежливый": "невежливый",
    "популярный": "непопулярный",
    "пористость": "основательность",
    "возможность": "невозможность",
    "сильнодействующий": "бессильный",
    "потенциал": "фактический",
    "бедность": "богатство",
    "мощный": "бессильный",
    "хвалить": "критиковать",
    "предшествовать": "добиться успеха",
    "предшествующий": "последующий",
    "префикс": "суффикс",
    "подготовка": "разрешающая способность",
    "подготовленный": "неподготовленный",
    "предписывающий": "описательный",
    "присутствие": "отсутствие",
    "сохраняется": "разрушенный",
    "превентивный": "разрешающий",
    "первичный": "вторичный",
    "частный": "общественности",
    "в частном порядке": "публично",
    "вероятный": "невероятный",
    "продуктивный": "непродуктивный",
    "непосвященный": "священный",
    "профессиональный": "любитель",
    "прогресс": "регрессировать",
    "прогрессирующий": "регрессивный",
    "перспективный": "ретроспективный",
    "защищенный": "незащищенный",
    "гордый": "смиренный",
    "доказывать": "опровергать",
    "проксимальный": "дистальный",
    "ближайший": "окончательный",
    "предусмотрительный": "неосторожный",
    "общественности": "частный",
    "публично": "в частном порядке",
    "опубликованный": "неопубликованный",
    "вытащить": "от себя",
    "пунктуальность": "медлительность",
    "чистка": "реабилитировать",
    "чистота": "примесь",
    "от себя": "вытащить",
    "квалифицировать": "дисквалифицировать",
    "королева": "король",
    "под вопросом": "бесспорный",
    "быстро": "медленно",
    "повышение": "ниже",
    "рациональный": "иррациональный",
    "реальный": "нереально",
    "реалистический": "нереально",
    "успокаивать": "беспокоиться",
    "отзыв": "вопрос",
    "запись": "стирать",
    "отказаться": "принимать",
    "регрессировать": "прогресс",
    "регрессивный": "прогрессирующий",
    "регулярный": "нерегулярный",
    "регулярность": "неправильность",
    "регулируется": "нерегулируемый",
    "реабилитировать": "чистка",
    "омолаживать": "возраст",
    "связанный": "несвязанный",
    "относительный": "абсолютный",
    "соответствующий": "не имеет значения",
    "надежный": "ненадежный",
    "религиозная": "светский",
    "отталкивание": "привлечение",
    "уважаемый": "постыдный",
    "репутация": "дурная слава",
    "оказывать сопротивление": "сдача",
    "разрешающая способность": "подготовка",
    "уважение": "неуважение",
    "почтительный": "непочтительный",
    "ответственность": "безответственный",
    "сдержанный": "несдержанный",
    "ограниченный": "неограниченный",
    "ретроспективный": "перспективный",
    "благоговейный": "непочтительный",
    "реверс": "утверждение",
    "награда": "штраф",
    "поездка": "ходить",
    "созревший": "зеленый",
    "подъем": "задавать",
    "поднимающийся": "падение",
    "ротор": "статор",
    "шероховатость": "ровность",
    "круглый": "квадрат",
    "закругленный": "угловая",
    "сельская местность": "городской",
    "порыв": "задерживаться",
    "священный": "непосвященный",
    "грустно": "счастливо",
    "печаль": "радость",
    "несчастье": "счастье",
    "безопасно": "опасно",
    "безопасность": "ненадежность",
    "одинаковость": "разница",
    "в своем уме": "ненормальный",
    "вменяемость": "невменяемость",
    "удовлетворение": "неудовлетворенность",
    "чабер": "непривлекательный",
    "дефицитный": "обильный",
    "научный": "ненаучный",
    "щепетильный": "недобросовестный",
    "вторичный": "первичный",
    "светский": "религиозная",
    "сегрегация": "интеграция",
    "эгоистичный": "бескорыстный",
    "продавать": "купить",
    "старшая": "младший",
    "отдельный": "совместный",
    "разделение": "союз",
    "септический": "антисептик",
    "оказание услуг": "вред",
    "решен": "нерешенный",
    "точить": "расплющить",
    "короткая": "высокий",
    "укорачивать": "удлинять",
    "окрик": "шептать",
    "показать": "скрывать",
    "сокращаться": "протяжение",
    "боковая сторона": "дно",
    "вверх": "дно",
    "значение": "незначительность",
    "значительное": "незначительный",
    "просто": "соединение",
    "упрощать": "усложнять",
    "один": "множественный",
    "единственное число": "множественное число",
    "раковина": "источник",
    "сестра": "брат",
    "спать": "будить",
    "медленно": "быстро",
    "маленький": "большой",
    "ровность": "шероховатость",
    "мягкость": "острота",
    "основательность": "пористость",
    "растворимый": "нерастворимый",
    "кредитоспособность": "неплатежеспособность",
    "растворитель": "несостоятельный",
    "сын": "дочь",
    "скорбный": "радостный",
    "разговорный": "написано",
    "неписаный": "написано",
    "спорадический": "постоянный",
    "распространение": "собирать",
    "квадрат": "круглый",
    "стабильность": "нестабильность",
    "стабильный": "неустойчивый",
    "стоять": "уступать",
    "начало": "стоп",
    "статор": "ротор",
    "оставаться": "переехать",
    "неуклонный": "неустойчивый",
    "крутой": "постепенный",
    "внезапно": "постепенный",
    "стерильный": "плодородный",
    "деревенеть": "рыхлить",
    "скупой": "великодушный",
    "штормовой": "спокойный",
    "прямо": "изогнутый",
    "выпрямлять": "изгиб",
    "незнакомец": "знакомство",
    "прочность": "слабое место",
    "протяжение": "сокращаться",
    "сильно": "слабо",
    "студия": "место нахождения",
    "тупость": "интеллект",
    "субъективный": "задача",
    "подчиненный": "доминирующий",
    "последующий": "предшествующий",
    "основной": "имя прилагательное",
    "вычитать": "добавить",
    "вычитание": "прибавление",
    "успех": "отказ",
    "успешный": "неудачный",
    "поддаваться": "уцелеть",
    "страдать": "наслаждаться",
    "достаточность": "недостаточность",
    "достаточно": "недостаточно",
    "суффикс": "префикс",
    "восход": "закат солнца",
    "закат солнца": "восход",
    "превосходящий": "низший",
    "превосходство": "низкое качество",
    "поставка": "спрос",
    "поддержанный": "не поддерживается",
    "поверхность": "накладные расходы",
    "сдача": "оказывать сопротивление",
    "уцелеть": "поддаваться",
    "милая": "кислый",
    "влажный": "сухой",
    "подслащивать": "кислый",
    "симметрия": "асимметрия",
    "симпатичный": "несимпатичный",
    "синергистический": "антагонистический",
    "синтез": "анализ",
    "синтетический": "аналитический",
    "медлительность": "пунктуальность",
    "со вкусом": "безвкусный",
    "вкусно": "безвкусный",
    "безвкусный": "вкусно",
    "нежная": "жесткий",
    "напряженный": "расслабленный",
    "терминал": "промежуточный",
    "теизм": "атеизм",
    "теоретический": "эмпирический",
    "жаждущий": "голодный",
    "вдумчивый": "беспечный",
    "беспечный": "вдумчивый",
    "экономный": "расточительный",
    "волна": "отлив",
    "галстук": "развязывать",
    "робкий": "жирный",
    "робость": "смелость",
    "толерантность": "непереносимость",
    "терпимый": "нетерпимый",
    "зубчатый": "беззубый",
    "беззубый": "зубчатый",
    "прикоснулся": "нетронутый",
    "жесткий": "нежная",
    "трагедия": "комедия",
    "обученный": "неподготовленный",
    "доверять": "недоверие",
    "правда": "ложность",
    "уродство": "красота",
    "уродливый": "красивая",
    "окончательный": "ближайший",
    "неприемлемо": "приемлемо",
    "непризнанный": "признанный",
    "неизмененный": "изменено",
    "недвусмысленный": "сомнительный",
    "безоружный": "вооруженный",
    "неразрешенный": "уполномоченный",
    "несбалансированный": "сбалансированный",
    "неверие": "вера",
    "несвязанный": "связанный",
    "неуязвимый": "ломкий",
    "неопределенность": "определенность",
    "неизменяемый": "сменный",
    "без изменений": "изменено",
    "дядя": "тетка",
    "редкий": "общий",
    "беззаботный": "обеспокоенный",
    "неподтвержденный": "подтвердил",
    "беспамятство": "сознание",
    "неконституционный": "конституционная",
    "нетрадиционный": "обычный",
    "убедило": "убежденный",
    "раскрывать": "обложка",
    "неразрезанный": "порез",
    "не определено": "определенный",
    "недооценивать": "переоценивать",
    "нежелательный": "желательный",
    "несвоевременный": "в связи",
    "необразованный": "образованный",
    "беспрецедентна": "богатый событиями",
    "неожиданный": "ожидаемый",
    "вероломный": "верный",
    "незнакомый": "знакомые",
    "неблагоприятный": "благоприятный",
    "раскрываться": "складка",
    "неумолимый": "всепрощающий",
    "несчастный": "счастливый",
    "неблагодарный": "благодарный",
    "нездоровый": "здоровый",
    "нечестивый": "святой",
    "неважный": "важный",
    "необработанный": "улучшен",
    "несведущий": "проинформировал",
    "необитаемый": "обитаемый",
    "невразумительный": "вразумительный",
    "непреднамеренный": "предназначена",
    "нечаянно": "намеренно",
    "незаинтересованный": "заинтересованный",
    "неинтересный": "интересно",
    "союз": "разделение",
    "унитарный": "федеральный",
    "единый": "разделенный",
    "недобрый": "своего рода",
    "незаконное": "законный",
    "неограниченный": "ограниченный",
    "отпереть": "замок",
    "несчастливый": "везучий",
    "неотмеченный": "отмеченный",
    "незамужняя": "в браке",
    "разоблачать": "маскировать",
    "незанятый": "занятый",
    "неофициальный": "официальный",
    "единственный": "против",
    "неортодоксальный": "ортодоксальный",
    "распаковывать": "пак",
    "неприятный": "приятный",
    "непопулярный": "популярный",
    "неподготовленный": "обученный",
    "непродуктивный": "продуктивный",
    "незащищенный": "защищенный",
    "неопубликованный": "опубликованный",
    "бесспорный": "под вопросом",
    "нерегулируемый": "регулируется",
    "ненадежный": "надежный",
    "несдержанный": "сдержанный",
    "непривлекательный": "чабер",
    "ненаучный": "научный",
    "бескорыстный": "эгоистичный",
    "нерешенный": "решен",
    "неустойчивый": "неуклонный",
    "неудачный": "успешный",
    "не поддерживается": "поддержанный",
    "несимпатичный": "симпатичный",
    "развязывать": "галстук",
    "нетронутый": "прикоснулся",
    "необычный": "обычный",
    "открывать": "вуаль",
    "неохотно": "охотно",
    "нежелание": "готовность",
    "размотать": "ветер",
    "недостойный": "достойный",
    "городской": "сельская местность",
    "ценный": "бесполезный",
    "вуаль": "открывать",
    "словесный": "численный",
    "победа": "поражение",
    "добродетельный": "злой",
    "видимость": "невидимость",
    "видимый": "невидимый",
    "вокальный": "инструментальный",
    "добровольный": "непроизвольный",
    "гласная буква": "согласный",
    "будить": "спать",
    "ходить": "поездка",
    "война": "мир",
    "осторожный": "неосторожный",
    "отходы": "консервировать",
    "расточительный": "экономный",
    "воск": "убывать",
    "слабо": "сильно",
    "слабое место": "прочность",
    "богатство": "бедность",
    "невесомый": "весомый",
    "весомый": "невесомый",
    "шептать": "окрик",
    "белый": "черный",
    "полностью": "частично",
    "злой": "добродетельный",
    "широкий": "узкий",
    "охотно": "неохотно",
    "готовность": "нежелание",
    "ветер": "размотать",
    "мудрость": "безрассудство",
    "мудрый": "глупый",
    "изымать": "депозит",
    "беспокоиться": "успокаивать",
    "бесполезный": "ценный",
    "достойный": "недостойный",
    "написано": "неписаный",
    "молодой": "престарелый",
    "зенит": "надир",
}
