_antonyms = {
    "evnen": "manglende evne",
    "unormal": "normal",
    "avskaffe": "etablere",
    "fravær": "tilstedeværelse",
    "fraværende": "nåværende",
    "framtid": "forbi",
    "absolutte": "slektning",
    "avstå": "handling",
    "abstrakt": "betong",
    "overflod": "knapphet",
    "rikelig": "knapp",
    "aksepterer": "avvise",
    "innrømme": "benekte",
    "akseptabel": "uakseptabelt",
    "godkjennelse": "avvisning",
    "tilgjengelig": "utilgjengelig",
    "korrekt": "unøyaktig",
    "anerkjente": "besvares",
    "bekjent": "fremmed",
    "handling": "passivitet",
    "aktiv": "stille",
    "bevart": "ødelagt",
    "støyende": "stille",
    "aktivitet": "inaktivitet",
    "faktiske": "potensial",
    "legg til": "trekke fra",
    "addisjon": "subtraksjon",
    "tilstrekkelig": "utilstrekkelig",
    "adjektiv": "materielle",
    "tillatelig": "utillatelig",
    "voksen": "ungdoms-",
    "avansere": "svekkes",
    "fremover": "tilbake",
    "front": "iden",
    "veer": "tilbake",
    "fordel": "ulempe",
    "bekreftelse": "reversering",
    "bekreftende": "negativ",
    "nøytral": "negativ",
    "akter": "forgrunnen",
    "alder": "forynge",
    "aldrende": "ung",
    "agitasjon": "ro",
    "bli enige": "være uenig",
    "behagelig": "ubehagelig",
    "avtale": "uenighet",
    "endret": "uendret",
    "alternere": "motsatte",
    "amatør": "profesjonell",
    "tvetydig": "utvetydig",
    "minnelig": "fiendtlig",
    "vennlig": "uvennlig",
    "amfibiske": "bakkenett",
    "anal": "muntlig",
    "analogt": "homolog",
    "analyse": "syntese",
    "analytisk": "syntetisk",
    "stamfar": "kommer",
    "vinkel": "avrundet",
    "animere": "livløse",
    "svar": "spørsmål",
    "antagonistisk": "synergistisk",
    "forutgående": "senere",
    "anterior": "posterior",
    "antiseptisk middel": "septisk",
    "utseende": "forsvinning",
    "verdsettelse": "avskrivninger",
    "godkjenning": "misbilligelse",
    "vedta": "mislike",
    "akvatisk": "amfibiske",
    "bakkenett": "amfibiske",
    "vandig": "vulkanske",
    "væpne": "avvæpne",
    "bevæpnet": "ubevæpnet",
    "ankomme": "permisjon",
    "stige": "sett",
    "stigning": "avstamning",
    "sover": "våken",
    "samtykke": "dissens",
    "asymmetri": "symmetri",
    "ateisme": "teisme",
    "feste": "løsne",
    "angrep": "forsvare",
    "tiltale": "forsvar",
    "oppmerksomhet": "uoppmerksomhet",
    "tiltrekning": "frastøting",
    "hørbar": "uhørlig",
    "forstørrelse": "reduksjon",
    "tante": "onkel",
    "autorisert": "uautorisert",
    "automatisk": "håndbok",
    "unngå": "konfrontere",
    "våken": "sover",
    "tilbake": "veer",
    "svekkes": "avansere",
    "iden": "hode",
    "bakgrunn": "forgrunnen",
    "bakover": "framover",
    "omvendt": "advers",
    "dårlig": "flink",
    "ond": "dydig",
    "ondskap": "godhet",
    "balanserte": "ubalansert",
    "bjørn": "okse",
    "vakker": "stygg",
    "skjønnhet": "stygghet",
    "begynne": "slutt",
    "begynnelse": "midten",
    "tidlig": "sent",
    "tro": "vantro",
    "bøye": "rette",
    "godartet": "ondartet",
    "stor": "liten",
    "fødsel": "død",
    "biseksuell": "homoseksuell",
    "svart": "hvit",
    "velsigne": "forbannelse",
    "velsignet": "forbannet",
    "ublodig": "blodig",
    "blodig": "ublodig",
    "uklarhet": "fremtredende",
    "kok opp": "fryse",
    "dristig": "sjenert",
    "dristighet": "fryktsomhet",
    "låne": "låne",
    "låner": "utlåner",
    "bunn": "topp",
    "bundet": "ubundet",
    "gutt": "pike",
    "boikott": "nedlatende",
    "gå i stykker": "reparere",
    "knuselig": "uknuselig",
    "lysne": "mørkere",
    "lette": "mørkere",
    "gått i stykker": "ubrutt",
    "bror": "søster",
    "okse": "bjørn",
    "opptatt": "tomgang",
    "arbeid": "tomgang",
    "kjøpe": "selge",
    "rolig": "storm-",
    "ro": "agitasjon",
    "i stand": "ikke i stand til",
    "kapasitet": "uførhet",
    "penger": "kreditt",
    "debet": "kreditt",
    "senter": "venstre",
    "cerebral": "emosjonelle",
    "sikkerhet": "usikkerhet",
    "endring": "oppholde seg",
    "reise": "oppholde seg",
    "bevege seg": "oppholde seg",
    "foranderlig": "uforanderlige",
    "lade": "utladning",
    "verve": "utladning",
    "billig": "dyrt",
    "oppmuntre": "fraråde",
    "munter": "deprimerende",
    "barn": "forelder",
    "sivil": "militær",
    "krav": "gi opp",
    "klarhet": "opasitet",
    "fremtredende": "uklarhet",
    "åpenhet": "nærhet",
    "ren": "urent",
    "geistlige": "lekfolket",
    "prest": "lekmann",
    "lukk": "åpen",
    "lukket": "åpen",
    "lukke": "åpen",
    "nærhet": "åpenhet",
    "kyst": "inn i landet",
    "sammenhengende": "usammenhengende",
    "kald": "varmt",
    "komedie": "tragedie",
    "komfort": "ubehag",
    "felles": "uvanlig",
    "kompatibel": "trassig",
    "kompetanse": "inkompetanse",
    "kompetent": "inkompetent",
    "konkurranse": "samarbeid",
    "klage": "oppmuntre",
    "fullstendighet": "ufullstendighet",
    "komplekse": "enkel",
    "forbindelse": "enkel",
    "komplisere": "forenkle",
    "konkav": "konveks",
    "innbilskhet": "ydmykhet",
    "stolthet": "ydmykhet",
    "konsentrasjon": "fordeling",
    "konsentriske": "eksentriske",
    "oppfatning": "misforståelse",
    "bekymret": "likegyldig",
    "betong": "abstrakt",
    "bekreftet": "ubekreftet",
    "konfrontere": "unngå",
    "konjunktiv": "disjunktiv",
    "koble": "koble fra",
    "tilkoblet": "usammenhengende",
    "bevissthet": "bevisstløshet",
    "konservative": "liberal",
    "spare": "avfall",
    "hensyns": "hensynsløs",
    "konsistens": "inkonsekvens",
    "konsonant": "vokal",
    "iøynefallende": "iøynefallende",
    "konstitusjonell": "grunnlovsstridig",
    "forbruke": "avstå",
    "innhold": "misnøye",
    "kontinuerlig": "sporadisk",
    "videreføring": "opphør",
    "fortsette": "avvikle",
    "kontinuitet": "diskontinuitet",
    "kontinuerlige": "usammenhengende",
    "kontrakt": "utvidet",
    "kontraksjon": "ekspansjon",
    "beleilig": "upraktisk",
    "konvensjonell": "ukonvensjonell",
    "konvergerer": "divergere",
    "konvergens": "divergens",
    "konvergent": "avvikende",
    "konveks": "konkav",
    "overbevist": "overbevist",
    "kul": "varme",
    "samarbeid": "konkurranse",
    "cosmopolitan": "provinsiell",
    "mot": "feighet",
    "dekke": "avdekke",
    "skjult": "overt",
    "feighet": "mot",
    "kreditt": "debet",
    "kreditor": "debitor",
    "kritisere": "ros",
    "gråte": "latter",
    "herdbart": "uhelbredelig",
    "forbannelse": "velsigne",
    "forbannet": "velsignet",
    "krummet": "rett",
    "kutte opp": "uncut",
    "fare": "sikkerhet",
    "farlig": "sikker",
    "mørk": "lys",
    "mørkere": "lette",
    "mørke": "letthet",
    "tyngde": "letthet",
    "datter": "sønn",
    "dag": "natt",
    "døv": "hørsel",
    "død": "fødsel",
    "debitor": "kreditor",
    "anstendighet": "uanstendighet",
    "skikkelig": "uanstendig",
    "lauv": "evergreen",
    "beslutning": "ubesluttsomhet",
    "avgjørende": "ubesluttsom",
    "avslå": "forbedring",
    "avta": "øke",
    "redusert": "økt",
    "minsk": "tilvekst",
    "nederlag": "seier",
    "forsvare": "tiltale",
    "anklagede": "saksøker",
    "forsvar": "tiltale",
    "defensiv": "støtende",
    "trassig": "kompatibel",
    "underskudd": "lede",
    "definert": "udefinert",
    "deflasjon": "inflasjon",
    "utsette": "skynde",
    "dvele": "skynde",
    "kreve": "forsyning",
    "benekte": "innrømme",
    "avvise": "aksepterer",
    "avhengig": "uavhengig",
    "innskudd": "ta ut",
    "avskrivninger": "verdsettelse",
    "deprimerende": "munter",
    "gå ned": "stige",
    "kommer": "stamfar",
    "avstamning": "stigning",
    "beskrivende": "normative",
    "ønskelig": "uønsket",
    "fortvilelse": "håp",
    "desperat": "håp",
    "desperasjon": "håp",
    "ødelagt": "bevart",
    "løsne": "stive",
    "devolution": "utvikling",
    "avvike": "lik",
    "ulik": "lik",
    "forskjell": "likhet",
    "vanskelig": "mør",
    "urolig": "lett",
    "vanskelighet": "letthet",
    "flittig": "forsømmelig",
    "fortynning": "konsentrasjon",
    "fordeling": "konsentrasjon",
    "reduksjon": "forstørrelse",
    "skitne": "ren",
    "urent": "ren",
    "deaktivere": "aktiver",
    "ulempe": "fordel",
    "være uenig": "bli enige",
    "ubehagelig": "hyggelig",
    "uenighet": "avtale",
    "forsvinning": "utseende",
    "misbilligelse": "godkjenning",
    "mislike": "vedta",
    "avvæpne": "væpne",
    "utladning": "verve",
    "fraskriver": "krav",
    "gi opp": "krav",
    "ubehag": "komfort",
    "koble fra": "koble",
    "misnøye": "innhold",
    "opphør": "videreføring",
    "avvikle": "fortsette",
    "diskontinuitet": "kontinuitet",
    "usammenhengende": "tilkoblet",
    "fraråde": "overtale",
    "motløshet": "oppmuntring",
    "frigjøre": "engasjere",
    "uærlig": "ærlig",
    "uærlighet": "ærlighet",
    "vanære": "ære",
    "desinfisere": "infisere",
    "desintegrerer": "integrere",
    "disjunktiv": "konjunktiv",
    "motvilje": "smak",
    "ulydighet": "lydighet",
    "ulydig": "lyde",
    "lidelse": "rekkefølge",
    "uordentlig": "velordnet",
    "uorganisert": "organisert",
    "misfornøyd": "fornøyd",
    "motbevise": "bevise",
    "diskvalifisere": "kvalifisere",
    "useriøse": "aner",
    "vanry": "anseelse",
    "disrespect": "respekt",
    "respektløs": "ærbødig",
    "utilfredshet": "tilfredshet",
    "dissens": "samtykke",
    "bjørnetjeneste": "service",
    "ulike": "lignende",
    "dissonans": "harmoni",
    "distal": "proksimale",
    "fjern": "lukk",
    "åpen": "lukke",
    "skilles": "utvisket",
    "mistro": "tillit",
    "dagaktive": "nattlig",
    "divergere": "konvergerer",
    "divergens": "konvergens",
    "avvikende": "konvergent",
    "dele opp": "forene",
    "enkeltvis": "multiplisere",
    "delt": "forent",
    "delelig": "udelelig",
    "innenlands": "fremmed",
    "innfødt": "fremmed",
    "dominerende": "underordnet",
    "sovende": "aktiv",
    "utryddet": "bevart",
    "inaktiv": "aktiv",
    "passiv": "aktiv",
    "stille": "støyende",
    "dobbelt": "enkelt",
    "flere": "enkelt",
    "due": "hauk",
    "dramatisk": "tekst",
    "tørke": "våt",
    "sur": "blid",
    "grunn": "utilbørlig",
    "kjedelig": "spisse",
    "flate": "overhead",
    "døende": "begynnende",
    "jordiske": "himmelsk",
    "letthet": "tyngde",
    "lett": "urolig",
    "flo": "tidevann",
    "eksentriske": "konsentriske",
    "utdannet": "uten utdannelse",
    "effektiv": "ineffektiv",
    "effektivitet": "ineffektivitet",
    "egress": "ingress",
    "elastisk": "uelastisk",
    "kvalifisert": "ikke kvalifisert",
    "emosjonelle": "cerebral",
    "empirisk": "teoretisk",
    "tomhet": "fylde",
    "tømme": "full",
    "tynn": "tykne",
    "aktiver": "deaktivere",
    "oppmuntring": "motløshet",
    "slutt": "begynnelse",
    "ending": "begynnelse",
    "midten": "tidlig",
    "endemisk": "cosmopolitan",
    "provinsiell": "cosmopolitan",
    "energisk": "sløv",
    "håndheve": "fritatt",
    "engasjere": "frigjøre",
    "nyt": "lide",
    "tast inn": "exit",
    "lik": "ulik",
    "likestilling": "ulikhet",
    "ekvatoriale": "polar",
    "rettferdig": "urettferdig",
    "viske ut": "ta opp",
    "etablere": "avskaffe",
    "begivenhetsrik": "begivenhetsløs",
    "evergreen": "lauv",
    "utvikling": "devolution",
    "utelukkelse": "inkludering",
    "fritatt": "håndheve",
    "puste ut": "innhalere",
    "eksisterende": "ikke-eksisterende",
    "exit": "tast inn",
    "utvide": "smal",
    "utvidet": "kontrakt",
    "ekspansjon": "kontraksjon",
    "forventet": "uventet",
    "dyrt": "billig",
    "opplevde": "uerfaren",
    "eksport": "import",
    "uttrykke": "lokal",
    "generell": "spesifikk",
    "nasjonal": "internasjonal",
    "forlengelse": "fleksjon",
    "ytre": "interiør",
    "utvendig": "innvendig",
    "eksternt": "internt",
    "slukke": "antennes",
    "ekstramural": "utført",
    "ekstraordinær": "vanlig",
    "extrinsic": "egenverdi",
    "sviktende": "passering",
    "løping": "stående",
    "svikt": "suksess",
    "trofast": "utro",
    "falle": "stige",
    "sett": "stige",
    "feilbarlige": "ufeilbarlig",
    "faller": "stiger",
    "løgn": "sannhet",
    "falskhet": "sannhet",
    "berømmelse": "skjensel",
    "fortrolig": "ukjent",
    "fancy": "vanlig",
    "fett": "tynn",
    "full": "tømme",
    "tykk": "tynn",
    "tykne": "tynn",
    "far": "mor",
    "fauna": "flora",
    "gunstige": "ugunstig",
    "føderal": "enhetlig",
    "hunn": "mann",
    "feminin": "intetkjønn",
    "femininitet": "maskulinitet",
    "fruktbar": "steril",
    "gjengivelse": "utroskap",
    "figur": "bakke",
    "fylle": "tømme",
    "finne": "å tape",
    "bli ferdig": "start",
    "stoppe": "start",
    "avgrenset": "uendelig",
    "brann": "leie",
    "fleksjon": "forlengelse",
    "flyte": "synke",
    "kilde": "synke",
    "flora": "fauna",
    "fokus": "uklarhet",
    "fiende": "venn",
    "brette": "brette",
    "følg": "gå forut for",
    "lykkes": "foregå",
    "tilhenger": "leder",
    "dårskap": "visdom",
    "tullete": "klok",
    "fot": "hode",
    "hale": "hode",
    "forby": "tillate",
    "forgrunnen": "bakgrunn",
    "fremmed": "bekjent",
    "glemme": "huske",
    "forgiving": "uforsonlig",
    "formalisme": "etterligning",
    "heldig": "uheldig",
    "framover": "omvendt",
    "advers": "omvendt",
    "foul": "rettferdig",
    "urettferdig": "rettferdig",
    "funnet": "tapt",
    "broderlig": "identisk",
    "fryse": "kok opp",
    "hyppig": "sjelden",
    "ofte": "sjelden",
    "venn": "fiende",
    "hode": "hale",
    "fylde": "tomhet",
    "funksjonell": "organisk",
    "uorganisk": "organisk",
    "gevinst": "tap",
    "gassformig": "fast",
    "hul": "fast",
    "samle": "spredt",
    "generalitet": "particularity",
    "sjenerøs": "stikkende",
    "pike": "gutt",
    "flink": "ond",
    "godhet": "ondskap",
    "gradvis": "plutselig",
    "takknemlig": "utakknemlig",
    "større": "mindre",
    "grønn": "moden",
    "ekkelt": "nett",
    "bakke": "figur",
    "skyld": "uskyld",
    "skyldig": "uskyldig",
    "gjerne": "dessverre",
    "lykke": "ulykkelighet",
    "lykkelig": "ulykkelig",
    "hardhet": "mykhet",
    "loudness": "mykhet",
    "skarphet": "mykhet",
    "harmoni": "dissonans",
    "hat": "kjærlighet",
    "hatsk": "elskelig",
    "hauk": "due",
    "sunn": "usunn",
    "hørsel": "døv",
    "varme": "kul",
    "himmelsk": "jordiske",
    "heterogenitet": "homogenitet",
    "gjemme seg": "forestilling",
    "leie": "brann",
    "truffet": "gå glipp av",
    "hellig": "profane",
    "homogenitet": "heterogenitet",
    "homolog": "analogt",
    "homoseksuell": "biseksuell",
    "ærlig": "uærlig",
    "ærlighet": "uærlighet",
    "ære": "vanære",
    "håp": "desperasjon",
    "håpe": "håpløs",
    "håpløs": "håpe",
    "horisontal": "vertikal",
    "fiendtlig": "vennlig",
    "uvennlig": "snill",
    "varmt": "kald",
    "ydmyk": "stolt",
    "ydmykhet": "stolthet",
    "sulten": "tørst",
    "identisk": "broderlig",
    "tomgang": "arbeid",
    "vulkanske": "vandig",
    "antennes": "slukke",
    "overse": "legge merke til",
    "ulovlig": "lovlig",
    "ulovlighet": "lovligheten",
    "uleselige": "leselig",
    "ulogisk": "logisk",
    "etterligning": "formalisme",
    "uvesentlig": "materiale",
    "umodenhet": "modenhet",
    "grenseløs": "målbar",
    "umoralsk": "moralsk",
    "umoral": "moral",
    "udødelig": "mortal",
    "udødelighet": "dødelighet",
    "uforanderlige": "foranderlig",
    "habilitet": "partiskhet",
    "uframkommelig": "farbar",
    "utålmodighet": "tålmodighet",
    "utålmodig": "pasient",
    "umerkelig": "merkbar",
    "ufullkommenhet": "fullkommenhet",
    "ugjennomtrengelig": "gjennomtrengelig",
    "utillatelig": "tillatelig",
    "upersonlig": "personlig",
    "uhøflig": "høflig",
    "import": "eksport",
    "viktig": "uviktig",
    "umulighet": "mulighet",
    "impotent": "mektig",
    "usannsynlig": "sannsynlig",
    "forbedret": "uforbedret",
    "forbedring": "avslå",
    "uklok": "forsvarlig",
    "urenhet": "renhet",
    "manglende evne": "evnen",
    "utilgjengelig": "tilgjengelig",
    "unøyaktig": "korrekt",
    "passivitet": "handling",
    "inaktivitet": "aktivitet",
    "utilstrekkelig": "tilstrekkelig",
    "ikke godtas": "tillatelig",
    "livløse": "animere",
    "uoppmerksomhet": "oppmerksomhet",
    "uhørlig": "hørbar",
    "ikke i stand til": "i stand",
    "uførhet": "kapasitet",
    "tilbøyelig": "horisontal",
    "vertikal": "horisontal",
    "inkludering": "utelukkelse",
    "uforenlig": "kompatibel",
    "inkompetanse": "kompetanse",
    "inkompetent": "kompetent",
    "ufullstendighet": "fullstendighet",
    "hensynsløs": "hensyns",
    "inkonsekvens": "konsistens",
    "upraktisk": "beleilig",
    "øke": "avta",
    "økt": "redusert",
    "tilvekst": "minsk",
    "uhelbredelig": "herdbart",
    "uanstendighet": "anstendighet",
    "uanstendig": "skikkelig",
    "ubesluttsomhet": "beslutning",
    "ubesluttsom": "avgjørende",
    "uavhengig": "avhengig",
    "utvisket": "skilles",
    "udelelig": "delelig",
    "innendørs": "utendørs",
    "ineffektiv": "effektiv",
    "ineffektivitet": "effektivitet",
    "uelastisk": "elastisk",
    "ikke kvalifisert": "kvalifisert",
    "ulikhet": "likestilling",
    "uerfaren": "opplevde",
    "ufeilbarlig": "feilbarlige",
    "skjensel": "berømmelse",
    "infisere": "desinfisere",
    "mindreverdig": "overlegen",
    "underlegenhet": "overlegenhet",
    "utroskap": "gjengivelse",
    "uendelig": "avgrenset",
    "inflasjon": "deflasjon",
    "informert": "uinformert",
    "sjelden": "ofte",
    "ingress": "egress",
    "bebodd": "ubebodd",
    "innhalere": "puste ut",
    "urettferdighet": "rettferdighet",
    "inn i landet": "kyst",
    "uskyld": "skyld",
    "uskyldig": "skyldig",
    "ufarlige": "skadelig",
    "virkningsløs": "operative",
    "sinnsyk": "tilregnelig",
    "galskap": "tilregnelighet",
    "usikkerhet": "sikkerhet",
    "ubetydelighet": "betydning",
    "ubetydelig": "betydelige",
    "uoppløselig": "løselig",
    "insolvens": "solvens",
    "insolvent": "løsemiddel",
    "ustabilitet": "stabilitet",
    "instrumental": "vokal",
    "insuffisiens": "forsyning",
    "integrere": "desintegrerer",
    "integrering": "segregering",
    "intelligens": "dumhet",
    "forståelig": "uforståelig",
    "tiltenkt": "utilsiktet",
    "med hensikt": "utilsiktet",
    "interessert": "uinteressert",
    "interessant": "uinteressant",
    "interiør": "ytre",
    "mellomliggende": "terminal",
    "innvendig": "utvendig",
    "internt": "eksternt",
    "internasjonal": "nasjonal",
    "lokal": "generell",
    "intoleranse": "toleranse",
    "intolerant": "tolerant",
    "intraktabel": "medgjørlig",
    "utført": "ekstramural",
    "egenverdi": "extrinsic",
    "usynlighet": "synlighet",
    "usynlig": "synlig",
    "ufrivillig": "frivillig",
    "irrasjonell": "rasjonell",
    "uregelmessig": "regelmessig",
    "uregelmessighet": "regelmessighet",
    "irrelevant": "aktuell",
    "uansvarlig": "ansvarlig",
    "utgave": "minnes",
    "ledd": "skille",
    "glede": "sorg",
    "gledelig": "sorgfull",
    "junior": "senior",
    "rettferdighet": "urettferdighet",
    "ungdoms-": "voksen",
    "kern": "kern",
    "snill": "uvennlig",
    "konge": "dronning",
    "lekfolket": "geistlige",
    "sent": "tidlig",
    "latter": "gråte",
    "lovlig": "ulovlig",
    "lax": "anspent",
    "avslappet": "anspent",
    "lekmann": "prest",
    "lede": "underskudd",
    "leder": "tilhenger",
    "permisjon": "ankomme",
    "venstre": "senter",
    "lovligheten": "ulovlighet",
    "legalisere": "fredløs",
    "leselig": "uleselige",
    "utlåner": "låner",
    "forlenge": "forkorte",
    "mindre": "større",
    "sløv": "energisk",
    "nivå": "heve",
    "nedre": "heve",
    "liberal": "konservative",
    "å ligge": "stå",
    "utbytte": "stå",
    "lys": "mørk",
    "smak": "smakløs",
    "begrenset": "ubegrenset",
    "lineær": "sikkerhet",
    "væske": "gassformig",
    "fast": "hul",
    "spesifikk": "generell",
    "plassering": "studio",
    "låse": "låse opp",
    "lodge": "løsne",
    "logisk": "ulogisk",
    "lang": "kort",
    "høy": "kort",
    "å tape": "finne",
    "tap": "gevinst",
    "tapt": "funnet",
    "elskelig": "hatsk",
    "kjærlighet": "hat",
    "tekst": "dramatisk",
    "major": "liten",
    "flertall": "entall",
    "gjøre": "gå i stykker",
    "reparere": "gå i stykker",
    "mann": "hunn",
    "malign": "godartet",
    "ondartet": "godartet",
    "håndbok": "automatisk",
    "merket": "umerket",
    "gift": "ugift",
    "maskulin": "feminin",
    "intetkjønn": "feminin",
    "maskulinitet": "femininitet",
    "maske": "avsløre",
    "materiale": "uvesentlig",
    "mors": "fars",
    "modenhet": "umodenhet",
    "maksimum": "minimum",
    "målbar": "grenseløs",
    "mental": "fysisk",
    "barmhjertig": "nådeløs",
    "nådeløs": "barmhjertig",
    "militær": "sivil",
    "sinn": "glemme",
    "huske": "glemme",
    "minimum": "maksimum",
    "liten": "stor",
    "minoritet": "flertall",
    "misforståelse": "oppfatning",
    "gå glipp av": "truffet",
    "jeksel": "molekyl~~pos=trunc",
    "molekyl~~pos=trunc": "jeksel",
    "moralsk": "umoralsk",
    "moral": "umoral",
    "mortal": "udødelig",
    "dødelighet": "udødelighet",
    "mor": "far",
    "multiplisere": "enkeltvis",
    "forene": "dele opp",
    "nadir": "zenith",
    "smal": "utvide",
    "begynnende": "døende",
    "negativ": "nøytral",
    "forsømmelig": "flittig",
    "nevø": "niese",
    "nett": "ekkelt",
    "niese": "nevø",
    "natt": "dag",
    "nattlig": "dagaktive",
    "nominell": "ekte",
    "uvirkelig": "ekte",
    "ikke-eksisterende": "eksisterende",
    "normal": "unormal",
    "legge merke til": "overse",
    "skadelig": "ufarlige",
    "numerisk": "verbal",
    "lydighet": "ulydighet",
    "lydig": "ulydig",
    "lyde": "ulydig",
    "objektiv": "subjektiv",
    "obligatorisk": "valgfri",
    "skrå": "vinkelrett",
    "opasitet": "åpenhet",
    "okkupert": "ledig",
    "fornærmelse": "forsvar",
    "støtende": "defensiv",
    "offisielt": "uoffisiell",
    "operative": "virkningsløs",
    "motsetning": "uten motstand",
    "motsatte": "alternere",
    "optimisme": "pessimisme",
    "optimist": "pessimist",
    "valgfri": "obligatorisk",
    "muntlig": "skrevet",
    "rekkefølge": "lidelse",
    "velordnet": "uordentlig",
    "vanlig": "uvanlig",
    "organisk": "uorganisk",
    "organisert": "uorganisert",
    "ortodoks": "uortodokse",
    "utendørs": "innendørs",
    "fredløs": "legalisere",
    "overvurdere": "undervurder",
    "overhead": "flate",
    "overt": "skjult",
    "pakke": "pakke ut",
    "smertefull": "smertefri",
    "smertefri": "smertefull",
    "parallell": "skrå",
    "vinkelrett": "skrå",
    "forelder": "barn",
    "partiskhet": "habilitet",
    "particularity": "generalitet",
    "til dels": "helt",
    "farbar": "uframkommelig",
    "passering": "løping",
    "stående": "løping",
    "forbi": "framtid",
    "nåværende": "fraværende",
    "fars": "mors",
    "tålmodighet": "utålmodighet",
    "pasient": "utålmodig",
    "nedlatende": "boikott",
    "fred": "krig",
    "straff": "belønning",
    "merkbar": "umerkelig",
    "fullkommenhet": "ufullkommenhet",
    "gjennomtrengelig": "ugjennomtrengelig",
    "givende": "forebyggende",
    "tillate": "forby",
    "personlig": "upersonlig",
    "overtale": "fraråde",
    "pessimisme": "optimisme",
    "pessimist": "optimist",
    "fysisk": "mental",
    "saksøker": "anklagede",
    "hyggelig": "ubehagelig",
    "fornøyd": "misfornøyd",
    "polar": "ekvatoriale",
    "høflig": "uhøflig",
    "populær": "upopulær",
    "porøsitet": "soliditet",
    "mulighet": "umulighet",
    "posterior": "anterior",
    "mektig": "impotent",
    "potensial": "faktiske",
    "fattigdom": "rikdom",
    "kraftig": "maktesløs",
    "maktesløs": "kraftig",
    "ros": "kritisere",
    "gå forut for": "lykkes",
    "foregå": "lykkes",
    "prefiks": "suffiks",
    "forberedelse": "vedtak",
    "forberedt": "uforberedt",
    "normative": "beskrivende",
    "tilstedeværelse": "fravær",
    "forebyggende": "givende",
    "hoved~~pos=trunc": "sekundær",
    "privat": "offentlig",
    "sannsynlig": "usannsynlig",
    "produktivt": "uproduktive",
    "profane": "hellig",
    "profesjonell": "amatør",
    "framgang": "regress",
    "progressive": "regressive",
    "prospektive": "retrospektiv",
    "beskyttet": "ubeskyttet",
    "stolt": "ydmyk",
    "bevise": "motbevise",
    "proksimale": "distal",
    "plassen": "ultimat",
    "forsvarlig": "uklok",
    "offentlig": "privat",
    "publisert": "upublisert",
    "dra": "trykk",
    "punktlighet": "tardiness",
    "purge": "rehabilitere",
    "renhet": "urenhet",
    "trykk": "dra",
    "kvalifisere": "diskvalifisere",
    "dronning": "konge",
    "spørsmål": "svar",
    "tvilsom": "udiskutable",
    "raskt": "sakte",
    "heve": "nedre",
    "rasjonell": "irrasjonell",
    "ekte": "uvirkelig",
    "realistisk": "urealistisk",
    "forsikre": "bekymre",
    "minnes": "utgave",
    "ta opp": "viske ut",
    "nekte": "aksepterer",
    "regress": "framgang",
    "regressive": "progressive",
    "regelmessig": "uregelmessig",
    "regelmessighet": "uregelmessighet",
    "regulert": "uregulert",
    "rehabilitere": "purge",
    "avvisning": "godkjennelse",
    "forynge": "alder",
    "i slekt": "urelatert",
    "slektning": "absolutte",
    "aktuell": "irrelevant",
    "pålitelig": "upålitelig",
    "religiøs": "sekulære",
    "frastøting": "tiltrekning",
    "aner": "useriøse",
    "anseelse": "vanry",
    "motstå": "overgivelse",
    "vedtak": "forberedelse",
    "respekt": "respektløs",
    "ansvarlig": "uansvarlig",
    "behersket": "hemningsløs",
    "retrospektiv": "prospektive",
    "ærbødig": "respektløs",
    "reversering": "bekreftelse",
    "belønning": "straff",
    "ri": "gå",
    "moden": "grønn",
    "stiger": "faller",
    "rotoren": "stator",
    "ruhet": "glatthet",
    "rund": "torget",
    "avrundet": "vinkel",
    "landlig": "urban",
    "skynde": "dvele",
    "dessverre": "gjerne",
    "tristhet": "lykke",
    "ulykkelighet": "lykke",
    "sikker": "farlig",
    "likhet": "forskjell",
    "tilregnelig": "sinnsyk",
    "tilregnelighet": "galskap",
    "tilfredshet": "utilfredshet",
    "velsmakende": "smakløs",
    "knapp": "rikelig",
    "knapphet": "overflod",
    "vitenskapelig": "uvitenskapelig",
    "samvittighetsfull": "samvittighetsløs",
    "sekundær": "hoved~~pos=trunc",
    "sekulære": "religiøs",
    "segregering": "integrering",
    "selvopptatt": "uselvisk",
    "selge": "kjøpe",
    "senior": "junior",
    "skille": "ledd",
    "atskillelse": "union",
    "septisk": "antiseptisk middel",
    "service": "bjørnetjeneste",
    "bosatte seg": "uoppgjorte",
    "spisse": "flate",
    "kort": "høy",
    "forkorte": "forlenge",
    "rope": "hviske",
    "forestilling": "gjemme seg",
    "krympe": "tøye ut",
    "side": "bunn",
    "topp": "bunn",
    "betydning": "ubetydelighet",
    "betydelige": "ubetydelig",
    "lignende": "ulike",
    "enkel": "forbindelse",
    "forenkle": "komplisere",
    "enkelt": "flere",
    "entall": "flertall",
    "synke": "kilde",
    "søster": "bror",
    "sove": "våkne",
    "sakte": "raskt",
    "glatthet": "ruhet",
    "mykhet": "skarphet",
    "soliditet": "porøsitet",
    "løselig": "uoppløselig",
    "solvens": "insolvens",
    "løsemiddel": "insolvent",
    "sønn": "datter",
    "sorg": "glede",
    "sorgfull": "gledelig",
    "uskreven": "skrevet",
    "sporadisk": "kontinuerlig",
    "spredt": "samle",
    "torget": "rund",
    "stabilitet": "ustabilitet",
    "stabil": "ustabil",
    "stå": "utbytte",
    "start": "stoppe",
    "stator": "rotoren",
    "oppholde seg": "bevege seg",
    "stødig": "ustødig",
    "bratt": "gradvis",
    "plutselig": "gradvis",
    "steril": "fruktbar",
    "stive": "løsne",
    "stikkende": "sjenerøs",
    "storm-": "rolig",
    "rett": "krummet",
    "rette": "bøye",
    "styrke": "svakhet",
    "tøye ut": "krympe",
    "sterk": "svakt",
    "studio": "plassering",
    "dumhet": "intelligens",
    "subjektiv": "objektiv",
    "underordnet": "dominerende",
    "senere": "forutgående",
    "materielle": "adjektiv",
    "trekke fra": "legg til",
    "subtraksjon": "addisjon",
    "suksess": "svikt",
    "vellykket": "mislykket",
    "bukke": "overleve",
    "lide": "nyt",
    "forsyning": "kreve",
    "suffiks": "prefiks",
    "soloppgang": "solnedgang",
    "solnedgang": "soloppgang",
    "overlegen": "mindreverdig",
    "overlegenhet": "underlegenhet",
    "støttet": "støttes",
    "overgivelse": "motstå",
    "overleve": "bukke",
    "søt": "sur",
    "våt": "tørke",
    "blid": "sur",
    "symmetri": "asymmetri",
    "medfølende": "usympatiske",
    "synergistisk": "antagonistisk",
    "syntese": "analyse",
    "syntetisk": "analytisk",
    "tardiness": "punktlighet",
    "smakløs": "velsmakende",
    "mør": "vanskelig",
    "anspent": "avslappet",
    "terminal": "mellomliggende",
    "teisme": "ateisme",
    "teoretisk": "empirisk",
    "tørst": "sulten",
    "omtenksom": "tankeløs",
    "tankeløs": "omtenksom",
    "sparsommelig": "uøkonomisk",
    "tidevann": "flo",
    "slips": "knytte opp",
    "sjenert": "dristig",
    "fryktsomhet": "dristighet",
    "toleranse": "intoleranse",
    "tolerant": "intolerant",
    "tann": "tannløs",
    "tannløs": "tann",
    "berørt": "urørt",
    "medgjørlig": "intraktabel",
    "tragedie": "komedie",
    "trent": "utrent",
    "tillit": "mistro",
    "sannhet": "falskhet",
    "stygghet": "skjønnhet",
    "stygg": "vakker",
    "ultimat": "plassen",
    "uakseptabelt": "akseptabel",
    "besvares": "anerkjente",
    "uendret": "endret",
    "entydig": "tvetydig",
    "ubevæpnet": "bevæpnet",
    "uautorisert": "autorisert",
    "ubalansert": "balanserte",
    "vantro": "tro",
    "ubundet": "bundet",
    "uknuselig": "knuselig",
    "ubrutt": "gått i stykker",
    "uforanderlig": "foranderlig",
    "onkel": "tante",
    "uvanlig": "vanlig",
    "likegyldig": "bekymret",
    "ubekreftet": "bekreftet",
    "bevisstløshet": "bevissthet",
    "grunnlovsstridig": "konstitusjonell",
    "ukonvensjonell": "konvensjonell",
    "avdekke": "slør",
    "uncut": "kutte opp",
    "udefinert": "definert",
    "undervurder": "overvurdere",
    "uønsket": "ønskelig",
    "utilbørlig": "grunn",
    "uten utdannelse": "utdannet",
    "utvetydig": "tvetydig",
    "begivenhetsløs": "begivenhetsrik",
    "uventet": "forventet",
    "utro": "trofast",
    "ukjent": "fortrolig",
    "ugunstig": "gunstige",
    "uforsonlig": "forgiving",
    "uheldig": "heldig",
    "utakknemlig": "takknemlig",
    "ulykkelig": "lykkelig",
    "usunn": "sunn",
    "uhellig": "hellig",
    "uviktig": "viktig",
    "uforbedret": "forbedret",
    "uinformert": "informert",
    "ubebodd": "bebodd",
    "uforståelig": "forståelig",
    "utilsiktet": "med hensikt",
    "uinteressert": "interessert",
    "uinteressant": "interessant",
    "union": "atskillelse",
    "enhetlig": "føderal",
    "forent": "delt",
    "ubegrenset": "begrenset",
    "låse opp": "låse",
    "umerket": "merket",
    "ugift": "gift",
    "avsløre": "maske",
    "ledig": "okkupert",
    "uoffisiell": "offisielt",
    "uten motstand": "motsetning",
    "uortodokse": "ortodoks",
    "pakke ut": "pakke",
    "upopulær": "populær",
    "uforberedt": "forberedt",
    "uproduktive": "produktivt",
    "ubeskyttet": "beskyttet",
    "upublisert": "publisert",
    "udiskutable": "tvilsom",
    "urealistisk": "realistisk",
    "uregulert": "regulert",
    "urelatert": "i slekt",
    "upålitelig": "pålitelig",
    "hemningsløs": "behersket",
    "usmakelig": "velsmakende",
    "uvitenskapelig": "vitenskapelig",
    "samvittighetsløs": "samvittighetsfull",
    "uselvisk": "selvopptatt",
    "uoppgjorte": "bosatte seg",
    "ustabil": "stabil",
    "ustødig": "stødig",
    "mislykket": "vellykket",
    "støttes": "støttet",
    "usympatiske": "medfølende",
    "knytte opp": "slips",
    "urørt": "berørt",
    "utrent": "trent",
    "uforsiktige": "skeptisk",
    "uvillig": "villig",
    "uvilje": "villighet",
    "koble av": "vind",
    "uverdig": "verdig",
    "urban": "landlig",
    "verdifull": "verdiløs",
    "slør": "avdekke",
    "verbal": "numerisk",
    "seier": "nederlag",
    "dydig": "ond",
    "synlighet": "usynlighet",
    "synlig": "usynlig",
    "vokal": "konsonant",
    "frivillig": "ufrivillig",
    "våkne": "sove",
    "gå": "ri",
    "blekne": "voks",
    "krig": "fred",
    "skeptisk": "uforsiktige",
    "avfall": "spare",
    "uøkonomisk": "sparsommelig",
    "voks": "blekne",
    "svakt": "sterk",
    "svakhet": "styrke",
    "rikdom": "fattigdom",
    "vektløs": "tungtveiende",
    "tungtveiende": "vektløs",
    "hviske": "rope",
    "hvit": "svart",
    "helt": "til dels",
    "bred": "smal",
    "villig": "uvillig",
    "villighet": "uvilje",
    "vind": "koble av",
    "visdom": "dårskap",
    "klok": "tullete",
    "ta ut": "innskudd",
    "bekymre": "forsikre",
    "verdiløs": "verdifull",
    "verdig": "uverdig",
    "skrevet": "uskreven",
    "ung": "aldrende",
    "zenith": "nadir",
}
