_antonyms = {
    "umiejętność": "niemożność",
    "nieprawidłowy": "normalna",
    "znieść": "ustalić",
    "brak": "obecność",
    "nieobecny": "obecny",
    "przyszłość": "przeszłość",
    "absolutny": "krewny",
    "wstrzymać się": "konsumować",
    "abstrakcyjny": "beton",
    "obfitość": "niedostatek",
    "obfity": "deficytowy",
    "zaakceptować": "odrzucać",
    "przyznać": "zaprzeczać",
    "do przyjęcia": "gorszący",
    "przyjęcie": "odmowa",
    "dostępny": "niedostępny",
    "dokładny": "niedokładny",
    "potwierdzone": "niepotwierdzony",
    "znajomy": "nieznany",
    "działać": "refren",
    "akcja": "bezczynność",
    "aktywny": "cichy",
    "pozostały": "wyginąć",
    "głośny": "cichy",
    "czynność": "bezczynność",
    "rzeczywisty": "potencjał",
    "dodaj": "odejmować",
    "dodanie": "odejmowanie",
    "odpowiedni": "niewystarczający",
    "przymiotnik": "rzeczownik",
    "dopuszczalny": "niedopuszczalny",
    "dorosły": "nieletni",
    "postęp": "regres",
    "przed siebie": "plecy",
    "z przodu": "tylny",
    "skręcać": "plecy",
    "korzyść": "niekorzyść",
    "afirmacja": "odwrócenie",
    "twierdzący": "negatywny",
    "neutralny": "negatywny",
    "na rufie": "dziobowy",
    "wiek": "odmładzać",
    "w wieku": "młody",
    "podniecenie": "spokój",
    "zgodzić się": "nie zgadzać się",
    "przyjemny": "nieprzyjemny",
    "umowa": "niezgoda",
    "zmieniony": "niezmieniony",
    "alternatywny": "naprzeciwko",
    "amator": "profesjonalny",
    "dwuznaczny": "jednoznaczny",
    "przyjazny": "nieprzyjazny",
    "ziemnowodny": "ziemski",
    "analny": "doustny",
    "analogiczny": "homologiczny",
    "analiza": "synteza",
    "analityczny": "syntetyczny",
    "przodek": "potomek",
    "kątowy": "bułczasty",
    "animować": "nieożywiony",
    "odpowiedź": "pytanie",
    "antagonistyczny": "synergistyczny",
    "poprzednik": "kolejny",
    "poprzedni": "tylny",
    "antyseptyczny": "septyczny",
    "wygląd": "zanik",
    "uznanie": "deprecjacja",
    "zatwierdzenie": "dezaprobata",
    "zatwierdzać": "potępiać",
    "wodny": "ogniowy",
    "ziemski": "niebiański",
    "ramię": "rozbrajać",
    "uzbrojony": "bezbronny",
    "przybyć": "pozostawiać",
    "wspiąć się": "schodzić",
    "wzlot": "zejście",
    "we śnie": "obudzić",
    "zgoda": "bunt",
    "asymetria": "symetria",
    "ateizm": "teizm",
    "dołączać": "odłączyć",
    "atak": "bronić",
    "zaskarżyć": "bronić",
    "uwaga": "nieuwaga",
    "atrakcja": "odpychanie",
    "słyszalny": "niesłyszalny",
    "powiększenie": "zmniejszenie",
    "ciocia": "wujek",
    "upoważniony": "nieautoryzowany",
    "automatyczny": "podręcznik",
    "uniknąć": "konfrontować",
    "obudzić": "we śnie",
    "plecy": "skręcać",
    "oddalać się": "postęp",
    "tylny": "poprzedni",
    "tło": "pierwszoplanowy",
    "do tyłu": "naprzód",
    "rewers": "awers",
    "zły": "dobry",
    "zło": "dobry",
    "niegodziwość": "dobroć",
    "zrównoważony": "niezrównoważony",
    "niedźwiedź": "byk",
    "piękny": "brzydki",
    "piękno": "brzydota",
    "zaczynać": "koniec",
    "początek": "zatrzymać",
    "wcześnie": "późno",
    "wiara": "niewiara",
    "zakręt": "wyprostować",
    "łagodny": "złośliwy",
    "duży": "mały",
    "narodziny": "śmierć",
    "biseksualny": "homoseksualny",
    "czarny": "biały",
    "błogosławić": "przekleństwo",
    "błogosławiony": "przeklęty",
    "bezkrwawy": "krwawy",
    "krwawy": "bezkrwawy",
    "plama": "skupiać",
    "gotować": "zamrażać",
    "pogrubienie": "nieśmiały",
    "śmiałość": "nieśmiałość",
    "pożyczać": "wypożyczać",
    "pożyczający": "pożyczający",
    "dolny": "top",
    "granica": "rozwiązany",
    "chłopak": "dziewczyna",
    "bojkot": "patronować",
    "przerwa": "naprawa",
    "łamliwy": "niezniszczalny",
    "rozjaśnić": "zaciemniać",
    "złamany": "nieprzerwany",
    "brat": "siostra",
    "byk": "niedźwiedź",
    "zajęty": "wolny",
    "praca": "bezczynny",
    "kupować": "sprzedać",
    "spokojna": "burzliwy",
    "spokój": "podniecenie",
    "zdolny": "niezdolny",
    "pojemność": "nieudolność",
    "gotówka": "kredyt",
    "obciążyć": "kredyt",
    "centrum": "lewo",
    "mózgowy": "emocjonalny",
    "pewność": "niepewność",
    "zmiana": "zostać",
    "odstąpić": "zostać",
    "ruszaj się": "zostać",
    "zmienny": "niezmienny",
    "zmienione": "niezmienione",
    "opłata": "rozładować się",
    "zwerbować": "rozładować się",
    "tani": "kosztowny",
    "dopingować": "skarżyć się",
    "wesoły": "przygnębiający",
    "dziecko": "rodzic",
    "cywil": "wojskowy",
    "roszczenie": "utracić",
    "przejrzystość": "nieprzezroczystość",
    "rozgłos": "zapomnienie",
    "przezroczystość": "nieprzezroczystość",
    "czysty": "nieczysty",
    "kler": "laicy",
    "duchowny": "laik",
    "blisko": "otwarty",
    "zamknięte": "otwarty",
    "zamknąć": "otwarty",
    "bliskość": "otwartość",
    "przybrzeżny": "śródlądowy",
    "zgodny": "wyzywający",
    "zimno": "gorąco",
    "dodatkowy": "liniowy",
    "komedia": "tragedia",
    "komfort": "niewygoda",
    "pospolity": "niezwykły",
    "kompetencja": "niekompetencja",
    "kompetentny": "niekompetentny",
    "zawody": "współpraca",
    "skarżyć się": "dopingować",
    "kompletność": "niekompletność",
    "złożony": "prosty",
    "komplikować": "uproszczać",
    "wklęsły": "wypukły",
    "zarozumiałość": "pokora",
    "duma": "pokora",
    "stężenie": "dystrybucja",
    "koncentryczny": "ekscentryczny",
    "koncepcja": "nieporozumienie",
    "zaniepokojony": "obojętny",
    "beton": "abstrakcyjny",
    "zatwardziały": "niepotwierdzony",
    "konfrontować": "uniknąć",
    "łączący": "dysjunktywny",
    "połączyć": "rozłączyć się",
    "połączony": "odrębny",
    "świadomość": "nieprzytomność",
    "konserwatywny": "liberał",
    "chronić": "marnotrawstwo",
    "taktowny": "nieuprzejmy",
    "konsystencja": "niezgodność",
    "spółgłoska": "samogłoska",
    "wyraźny": "nieoznaczony",
    "konstytucyjny": "niekonstytucyjny",
    "konsumować": "wstrzymać się",
    "zadowolony": "niezadowolony",
    "nieustanny": "sporadyczny",
    "trwanie": "zaprzestanie",
    "dalej": "zaprzestać",
    "ciągłość": "nieciągłość",
    "ciągły": "nieciągły",
    "kontrakt": "rozszerzać",
    "zakontraktowany": "rozszerzony",
    "skurcz": "ekspansja",
    "wygodna": "niewygodny",
    "standardowy": "oryginalny",
    "skupiać": "plama",
    "konwergencja": "rozbieżność",
    "zbieżny": "rozbieżny",
    "wypukły": "wklęsły",
    "przekonany": "nieprzekonany",
    "chłodny": "ciepło",
    "współpraca": "zawody",
    "kosmopolityczny": "prowincjonalny",
    "odwaga": "tchórzostwo",
    "pokrywa": "odkryć",
    "ukryty": "jawny",
    "tchórzostwo": "odwaga",
    "kredyt": "obciążyć",
    "wierzyciel": "dłużnik",
    "krytykować": "pochwała",
    "płakać": "śmiech",
    "uleczalny": "nieuleczalny",
    "przekleństwo": "błogosławić",
    "przeklęty": "błogosławiony",
    "zakrzywiony": "proste",
    "ciąć": "nie oszlifowany",
    "niebezpieczeństwo": "bezpieczeństwo",
    "niebezpieczny": "bezpieczny",
    "ciemny": "lekki",
    "zaciemniać": "rozjaśnić",
    "ciemność": "lekkość",
    "ociężałość": "lekkość",
    "córka": "syn",
    "dzień": "noc",
    "głuchy": "przesłuchanie",
    "śmierć": "narodziny",
    "dłużnik": "wierzyciel",
    "przyzwoitość": "nieprzyzwoitość",
    "przyzwoity": "nieprzyzwoity",
    "liściasty": "zimozielony",
    "decyzja": "niezdecydowanie",
    "decydujący": "niezdecydowany",
    "upadek": "poprawa",
    "zmniejszać": "zwiększać",
    "zmniejszony": "zwiększony",
    "dekrementacja": "przyrost",
    "pokonać": "zwycięstwo",
    "bronić": "zaskarżyć",
    "pozwany": "powód",
    "obrona": "oskarżenie",
    "obronny": "ofensywa",
    "wyzywający": "zgodny",
    "deficyt": "prowadzić",
    "określone": "niezdefiniowany",
    "deflacja": "inflacja",
    "opóźnienie": "pośpiech",
    "marudzić": "pośpiech",
    "żądanie": "dostawa",
    "zaprzeczać": "przyznać",
    "odrzucać": "zaakceptować",
    "zależny": "niezależny",
    "kaucja": "wycofać",
    "deprecjacja": "uznanie",
    "przygnębiający": "wesoły",
    "schodzić": "wspiąć się",
    "potomek": "przodek",
    "zejście": "wzlot",
    "opisowy": "nakazowy",
    "pożądany": "niepożądany",
    "rozpacz": "nadzieja",
    "zdesperowany": "nadzieja",
    "desperacja": "nadzieja",
    "zniszczony": "zachowane",
    "odłączyć": "angażować",
    "degeneracja": "ewolucja",
    "różnić się": "równy",
    "nierówny": "równy",
    "różnica": "identyczność",
    "trudny": "uległy",
    "niespokojny": "łatwo",
    "trudność": "łatwość",
    "pracowity": "niedbały",
    "roztwór": "stężenie",
    "dystrybucja": "stężenie",
    "zmniejszenie": "powiększenie",
    "brudny": "czysty",
    "nieczysty": "czysty",
    "wyłączyć": "włączyć",
    "niekorzyść": "korzyść",
    "nie zgadzać się": "zgodzić się",
    "nieprzyjemny": "przyjemne",
    "niezgoda": "umowa",
    "zanik": "wygląd",
    "dezaprobata": "zatwierdzenie",
    "potępiać": "zatwierdzać",
    "rozbrajać": "ramię",
    "rozładować się": "zwerbować",
    "zrzec się": "roszczenie",
    "utracić": "roszczenie",
    "niewygoda": "komfort",
    "rozłączyć się": "połączyć",
    "niezadowolenie": "zadowolenie",
    "zaprzestanie": "trwanie",
    "zaprzestać": "dalej",
    "nieciągłość": "ciągłość",
    "nieciągły": "ciągły",
    "zniechęcać": "zachęcać",
    "zniechęcenie": "zachęta",
    "nieuczciwy": "szczery",
    "nieuczciwość": "uczciwość",
    "hańba": "sława",
    "dezynfekować": "infekować",
    "rozpadać się": "zintegrować",
    "dysjunktywny": "łączący",
    "nie lubić": "gust",
    "usunąć": "wigwam",
    "nieposłuszeństwo": "posłuszeństwo",
    "nieposłuszny": "posłuszny",
    "być nieposłusznym": "być posłusznym",
    "nieład": "zamówienie",
    "nieporządny": "uporządkowany",
    "zdezorganizowany": "zorganizowany",
    "niezorganizowany": "zorganizowany",
    "niezadowolony": "zadowolony",
    "odeprzeć": "okazać się",
    "zdyskwalifikować": "zakwalifikować",
    "haniebny": "renomowany",
    "zła reputacja": "reputacja",
    "brak szacunku": "poszanowanie",
    "lekceważący": "pełen szacunku",
    "bunt": "zgoda",
    "niedźwiedzia przysługa": "usługa",
    "niepodobny": "podobny",
    "dysonans": "harmonia",
    "odwieść": "namawiać",
    "dystalny": "proksymalny",
    "odległy": "blisko",
    "otwarty": "zamknąć",
    "rozpoznawalny": "nie do odróżnienia",
    "nieufność": "zaufanie",
    "dzienny": "nocny",
    "odchodzić": "skupiać",
    "rozbieżność": "konwergencja",
    "rozbieżny": "zbieżny",
    "podzielić": "zjednoczyć",
    "pojedynczo": "zwielokrotniać",
    "podzielony": "zjednoczony",
    "podzielny": "niepodzielny",
    "krajowy": "międzynarodowy",
    "ojczysty": "obcy",
    "dominujący": "podrzędny",
    "drzemiący": "aktywny",
    "wyginąć": "pozostały",
    "nieaktywny": "aktywny",
    "bierny": "aktywny",
    "cichy": "głośny",
    "podwójnie": "pojedynczy",
    "wielokrotność": "pojedynczy",
    "gołąb": "jastrząb",
    "dramatyczny": "liryczny",
    "suchy": "mokro",
    "kwaśny": "słodzić",
    "z powodu": "nadmierny",
    "nudny": "wyostrzyć",
    "spłaszczyć": "wyostrzyć",
    "umierający": "powstający",
    "łatwość": "trudność",
    "łatwo": "niespokojny",
    "odpływ": "fala",
    "ekscentryczny": "koncentryczny",
    "wykształcony": "niewykształcony",
    "efektywny": "nieskuteczny",
    "wydajność": "stoisko",
    "wydajny": "nieskuteczny",
    "wyjście": "wchodzić",
    "elastyczny": "nieelastyczny",
    "wybieralny": "którego nie można wybrać",
    "emocjonalny": "mózgowy",
    "empiryczny": "teoretyczny",
    "pustka": "pełnia",
    "pusty": "pełny",
    "cienki": "gęstnieć",
    "włączyć": "wyłączyć",
    "zachęcać": "zniechęcać",
    "zachęta": "zniechęcenie",
    "koniec": "początek",
    "kończący się": "początek",
    "środkowy": "wcześnie",
    "endemiczny": "kosmopolityczny",
    "prowincjonalny": "kosmopolityczny",
    "energetyczny": "ospały",
    "egzekwować": "zwolniony",
    "angażować": "odłączyć",
    "cieszyć się": "ponieść",
    "wchodzić": "wyjście",
    "równy": "nierówny",
    "równość": "nierówność",
    "równikowy": "polarny",
    "sprawiedliwy": "niesprawiedliwy",
    "wymazać": "rekord",
    "ustalić": "znieść",
    "urozmaicony": "monotonny",
    "zimozielony": "liściasty",
    "ewolucja": "degeneracja",
    "wykluczenie": "włączenie",
    "zwolniony": "egzekwować",
    "wydychać": "wdychać",
    "istniejący": "nieistniejący",
    "rozszerzać": "kontrakt",
    "rozszerzony": "zakontraktowany",
    "ekspansja": "skurcz",
    "spodziewany": "z mocą wsteczną",
    "kosztowny": "tani",
    "doświadczony": "niedoświadczony",
    "eksport": "import",
    "wyrazić": "lokalny",
    "generał": "konkretny",
    "rozbudowa": "zgięcie",
    "zewnętrzny": "wewnętrzny",
    "zewnętrznie": "wewnętrznie",
    "gasić": "zapalać",
    "zaoczny": "śródścienny",
    "niezwykły": "zwykły",
    "w braku": "przechodzący",
    "bieganie": "na stojąco",
    "niepowodzenie": "powodzenie",
    "targi": "niesprawiedliwy",
    "wierny": "niewierny",
    "spadek": "wzrost",
    "zestaw": "wzrost",
    "omylny": "nieomylny",
    "spadanie": "podniesienie",
    "fałsz": "prawda",
    "sława": "hańba",
    "fantazyjny": "równina",
    "gruby": "cienki",
    "pełny": "pusty",
    "gęstnieć": "cienki",
    "ojciec": "mama",
    "fauna": "flora",
    "korzystny": "niekorzystny",
    "federalny": "jednolity",
    "płeć żeńska": "męski",
    "kobiecy": "nijaki",
    "kobiecość": "męskość",
    "płodny": "jałowy",
    "wierność": "niewierność",
    "postać": "ziemia",
    "napełnić": "pusty",
    "odnaleźć": "stracić",
    "zatrzymać": "początek",
    "skończone": "nieskończony",
    "ogień": "zatrudnić",
    "zgięcie": "rozbudowa",
    "pływak": "tonąć",
    "źródło": "tonąć",
    "flora": "fauna",
    "wróg": "przyjaciel",
    "zagięcie": "rozwijać się",
    "śledzić": "poprzedzać",
    "osiągnąć sukces": "poprzedzać",
    "zwolennik": "lider",
    "szaleństwo": "mądrość",
    "głupi": "mądry",
    "stopa": "głowa",
    "ogon": "głowa",
    "zakazać": "pozwolić",
    "dziobowy": "na rufie",
    "pierwszoplanowy": "tło",
    "obcy": "ojczysty",
    "zapomnieć": "zapamiętaj",
    "wyrozumiały": "pamiętliwy",
    "formalizm": "imitacja",
    "szczęśliwy": "nieszczęśliwy",
    "naprzód": "rewers",
    "awers": "rewers",
    "faul": "targi",
    "niesprawiedliwy": "sprawiedliwy",
    "uznany": "stracony",
    "braterski": "identyczny",
    "zamrażać": "gotować",
    "częsty": "nieczęsty",
    "często": "nieczęsto",
    "przyjaciel": "wróg",
    "głowa": "ogon",
    "pełnia": "pustka",
    "funkcjonalny": "organiczny",
    "nieorganiczny": "organiczny",
    "zdobyć": "utrata",
    "gazowy": "solidny",
    "wydrążony": "solidny",
    "zbierać": "rozpiętość",
    "ogólność": "osobliwość",
    "hojny": "skąpy",
    "dziewczyna": "chłopak",
    "dobry": "zło",
    "dobroć": "niegodziwość",
    "stopniowy": "nagły",
    "wdzięczny": "niewdzięczny",
    "większy": "pomniejszy",
    "zielony": "dojrzały",
    "obrzydliwy": "netto",
    "ziemia": "postać",
    "wina": "niewinność",
    "winny": "niewinny",
    "szczęśliwie": "niestety",
    "szczęście": "nieszczęście",
    "twardość": "miękkość",
    "głośność": "miękkość",
    "ostrość": "miękkość",
    "harmonia": "dysonans",
    "nienawidzić": "miłość",
    "nienawistny": "sympatyczny",
    "jastrząb": "gołąb",
    "zdrowy": "niezdrowy",
    "przesłuchanie": "głuchy",
    "ciepło": "chłodny",
    "niebiański": "ziemski",
    "niejednorodność": "jednorodność",
    "ukryć": "pokazać",
    "zatrudnić": "ogień",
    "trafienie": "tęsknić",
    "święty": "bezbożny",
    "jednorodność": "niejednorodność",
    "homologiczny": "analogiczny",
    "homoseksualny": "biseksualny",
    "szczery": "nieuczciwy",
    "uczciwość": "nieuczciwość",
    "honor": "hańba",
    "nadzieja": "desperacja",
    "pełen nadziei": "beznadziejny",
    "beznadziejny": "pełen nadziei",
    "poziomy": "pionowy",
    "wrogi": "przyjazny",
    "nieprzyjazny": "przyjazny",
    "gorąco": "zimno",
    "pokorny": "dumny",
    "pokora": "duma",
    "głodny": "spragniony",
    "identyczny": "braterski",
    "bezczynny": "praca",
    "ogniowy": "wodny",
    "zapalać": "gasić",
    "ignorować": "ogłoszenie",
    "nielegalny": "prawny",
    "nielegalność": "legalność",
    "nieczytelny": "czytelny",
    "nielogiczny": "logiczny",
    "imitacja": "formalizm",
    "niematerialny": "materiał",
    "niedojrzałość": "dojrzałość",
    "niezmierzony": "wymierny",
    "niemoralny": "morał",
    "niemoralność": "moralność",
    "nieśmiertelny": "śmiertelny",
    "nieśmiertelność": "śmiertelność",
    "niezmienny": "zmienny",
    "bezstronność": "stronniczość",
    "nieprzekraczalny": "zadowalający",
    "niecierpliwość": "cierpliwość",
    "jestem cierpliwy": "cierpliwy",
    "niedostrzegalny": "wyczuwalny",
    "niedoskonałość": "doskonałość",
    "nieprzepuszczalny": "przepuszczalny",
    "niedopuszczalny": "dopuszczalny",
    "bezosobowy": "osobisty",
    "nieuprzejmy": "taktowny",
    "import": "eksport",
    "ważny": "nieważny",
    "niemożliwość": "możliwość",
    "bezsilny": "potężny",
    "nieprawdopodobny": "prawdopodobny",
    "ulepszony": "nieulepszony",
    "poprawa": "upadek",
    "nieroztropny": "ostrożny",
    "zanieczyszczenie": "czystość",
    "niemożność": "umiejętność",
    "niedostępny": "dostępny",
    "niedokładny": "dokładny",
    "bezczynność": "czynność",
    "niewystarczający": "wystarczający",
    "nieożywiony": "animować",
    "nieuwaga": "uwaga",
    "niesłyszalny": "słyszalny",
    "niezdolny": "zdolny",
    "nieudolność": "pojemność",
    "skłonny": "poziomy",
    "pionowy": "poziomy",
    "włączenie": "wykluczenie",
    "niespójny": "zgodny",
    "niekompatybilny": "zgodny",
    "niekompetencja": "kompetencja",
    "niekompetentny": "kompetentny",
    "niekompletność": "kompletność",
    "niezgodność": "konsystencja",
    "niepozorny": "wyraźny",
    "niewygodny": "wygodna",
    "zwiększać": "zmniejszać",
    "zwiększony": "zmniejszony",
    "przyrost": "dekrementacja",
    "nieuleczalny": "uleczalny",
    "nieprzyzwoitość": "przyzwoitość",
    "nieprzyzwoity": "przyzwoity",
    "niezdecydowanie": "decyzja",
    "niezdecydowany": "decydujący",
    "niezależny": "zależny",
    "nie do odróżnienia": "rozpoznawalny",
    "niepodzielny": "podzielny",
    "wnętrz": "na wolnym powietrzu",
    "nieskuteczny": "wydajny",
    "nieskuteczność": "wydajność",
    "nieelastyczny": "elastyczny",
    "którego nie można wybrać": "wybieralny",
    "nierówność": "równość",
    "niedoświadczony": "przeszkolony",
    "nieomylny": "omylny",
    "infekować": "dezynfekować",
    "gorszy": "lepszy",
    "niższość": "wyższość",
    "niewierność": "wierność",
    "nieskończony": "skończone",
    "inflacja": "deflacja",
    "powiadomiony": "niedoinformowany",
    "nieczęsty": "częsty",
    "nieczęsto": "często",
    "ingres": "wyjście",
    "zamieszkany": "bezludny",
    "wdychać": "wydychać",
    "niesprawiedliwość": "sprawiedliwość",
    "śródlądowy": "przybrzeżny",
    "niewinność": "wina",
    "niewinny": "winny",
    "nieszkodliwy": "szkodliwy",
    "nieczynny": "operacyjny",
    "szalony": "rozsądny",
    "niepoczytalność": "zdrowie psychiczne",
    "niepewność": "pewność",
    "znikomość": "znaczenie",
    "nieistotny": "znaczący",
    "nierozpuszczalny": "rozpuszczalny",
    "niewypłacalność": "wypłacalność",
    "niewypłacalny": "rozpuszczalnik",
    "niestabilność": "stabilność",
    "instrumentalny": "wokal",
    "niewydolność": "dostateczność",
    "niewystarczająco": "dostatecznie",
    "zintegrować": "rozpadać się",
    "integracja": "segregacja",
    "inteligencja": "głupota",
    "zrozumiały": "niezrozumiały",
    "zamierzony": "niezamierzony",
    "celowo": "niechcący",
    "zainteresowany": "niezainteresowany",
    "ciekawy": "nieinteresujący",
    "wnętrze": "zewnętrzny",
    "pośredni": "terminal",
    "wewnętrzny": "zewnętrzny",
    "wewnętrznie": "zewnętrznie",
    "międzynarodowy": "krajowy",
    "lokalny": "generał",
    "nietolerancja": "tolerancja",
    "nietolerancyjny": "tolerancyjny",
    "śródścienny": "zaoczny",
    "niewidzialność": "widoczność",
    "niewidzialny": "widoczny",
    "mimowolny": "dobrowolny",
    "irracjonalny": "racjonalny",
    "nieregularny": "regularny",
    "nieprawidłowość": "prawidłowość",
    "bez znaczenia": "istotnych",
    "nieodpowiedzialny": "odpowiedzialny",
    "kwestia": "odwołanie",
    "połączenie": "oddzielny",
    "radość": "smutek",
    "radosny": "smutny",
    "junior": "senior",
    "sprawiedliwość": "niesprawiedliwość",
    "nieletni": "dorosły",
    "kern": "kern",
    "uprzejmy": "nieuprzejmy",
    "król": "królowa",
    "laicy": "kler",
    "późno": "wcześnie",
    "śmiech": "płakać",
    "legalny": "bezprawny",
    "niedbały": "pracowity",
    "zrelaksowany": "czas",
    "laik": "duchowny",
    "prowadzić": "deficyt",
    "lider": "zwolennik",
    "pozostawiać": "przybyć",
    "lewo": "centrum",
    "prawny": "nielegalny",
    "legalność": "nielegalność",
    "zalegalizować": "banita",
    "czytelny": "nieczytelny",
    "wypożyczać": "pożyczać",
    "przedłużać": "skracać",
    "pomniejszy": "większy",
    "ospały": "energetyczny",
    "poziom": "podnieść",
    "niższy": "podnieść",
    "liberał": "konserwatywny",
    "kłamstwo": "stoisko",
    "lekki": "ciemny",
    "lekkość": "ociężałość",
    "gust": "nie lubić",
    "ograniczony": "nieograniczony",
    "liniowy": "dodatkowy",
    "ciekły": "gazowy",
    "solidny": "wydrążony",
    "konkretny": "generał",
    "lokalizacja": "studio",
    "zamek": "odblokować",
    "wigwam": "usunąć",
    "logiczny": "nielogiczny",
    "długie": "krótki",
    "wysoki": "krótki",
    "poluzować": "usztywniać",
    "stracić": "odnaleźć",
    "utrata": "zdobyć",
    "stracony": "uznany",
    "sympatyczny": "nienawistny",
    "miłość": "nienawidzić",
    "szczęściarz": "nieszczęśliwy",
    "liryczny": "dramatyczny",
    "poważny": "mniejszy",
    "większość": "mniejszość",
    "robić": "przerwa",
    "naprawa": "przerwa",
    "męski": "płeć żeńska",
    "złośliwy": "łagodny",
    "podręcznik": "automatyczny",
    "żonaty": "niezamężna",
    "rodzaj męski": "kobiecy",
    "nijaki": "kobiecy",
    "męskość": "kobiecość",
    "maska": "zdemaskować",
    "materiał": "niematerialny",
    "macierzyński": "ojcowski",
    "dojrzałość": "niedojrzałość",
    "maksymalny": "minimum",
    "wymierny": "niezmierzony",
    "psychiczny": "fizyczny",
    "miłosierny": "bezlitosny",
    "bezlitosny": "miłosierny",
    "wojskowy": "cywil",
    "umysł": "zapomnieć",
    "zapamiętaj": "zapomnieć",
    "minimum": "maksymalny",
    "mniejszy": "poważny",
    "mniejszość": "większość",
    "nieporozumienie": "koncepcja",
    "tęsknić": "trafienie",
    "molowy": "molekularny",
    "molekularny": "molowy",
    "morał": "niemoralny",
    "moralność": "niemoralność",
    "śmiertelny": "nieśmiertelny",
    "śmiertelność": "nieśmiertelność",
    "mama": "ojciec",
    "zwielokrotniać": "pojedynczo",
    "zjednoczyć": "podzielić",
    "nadir": "zenit",
    "wąska": "poszerzać",
    "powstający": "umierający",
    "negatywny": "neutralny",
    "bratanek": "siostrzenica",
    "netto": "obrzydliwy",
    "siostrzenica": "bratanek",
    "noc": "dzień",
    "nocny": "dzienny",
    "nominalny": "real",
    "nierealny": "real",
    "nieistniejący": "istniejący",
    "normalna": "nieprawidłowy",
    "ogłoszenie": "ignorować",
    "szkodliwy": "nieszkodliwy",
    "liczbowy": "werbalny",
    "posłuszeństwo": "nieposłuszeństwo",
    "posłuszny": "nieposłuszny",
    "być posłusznym": "być nieposłusznym",
    "cel": "subiektywny",
    "obowiązkowy": "opcjonalny",
    "ukośny": "prostopadły",
    "zapomnienie": "rozgłos",
    "nieprzezroczystość": "przezroczystość",
    "wykroczenie": "obrona",
    "oskarżenie": "obrona",
    "ofensywa": "obronny",
    "urzędnik": "nieoficjalny",
    "otwartość": "bliskość",
    "operacyjny": "nieczynny",
    "przeciwny": "bez sprzeciwu",
    "naprzeciwko": "alternatywny",
    "optymizm": "pesymizm",
    "optymista": "pesymista",
    "opcjonalny": "obowiązkowy",
    "doustny": "analny",
    "zamówienie": "nieład",
    "uporządkowany": "nieporządny",
    "zwyczajny": "niezwykły",
    "organiczny": "nieorganiczny",
    "zorganizowany": "niezorganizowany",
    "prawosławny": "nie ortodoksyjny",
    "na wolnym powietrzu": "wnętrz",
    "banita": "zalegalizować",
    "przeszacować": "nie doceniać",
    "nad głową": "powierzchnia",
    "jawny": "ukryty",
    "pakiet": "rozpakować",
    "bolesny": "bezbolesny",
    "bezbolesny": "bolesny",
    "równolegle": "ukośny",
    "prostopadły": "ukośny",
    "rodzic": "dziecko",
    "stronniczość": "bezstronność",
    "osobliwość": "ogólność",
    "częściowo": "całkowicie",
    "zadowalający": "nieprzekraczalny",
    "przechodzący": "bieganie",
    "na stojąco": "bieganie",
    "przeszłość": "przyszłość",
    "obecny": "nieobecny",
    "ojcowski": "macierzyński",
    "cierpliwość": "niecierpliwość",
    "cierpliwy": "jestem cierpliwy",
    "patronować": "bojkot",
    "pokój": "wojna",
    "rzut karny": "nagroda",
    "wyczuwalny": "niedostrzegalny",
    "doskonałość": "niedoskonałość",
    "przepuszczalny": "nieprzepuszczalny",
    "dozwalający": "zapobiegawczy",
    "pozwolić": "zakazać",
    "osobisty": "bezosobowy",
    "namawiać": "odwieść",
    "pesymizm": "optymizm",
    "pesymista": "optymista",
    "fizyczny": "psychiczny",
    "równina": "fantazyjny",
    "powód": "pozwany",
    "przyjemne": "nieprzyjemny",
    "liczba mnoga": "pojedynczy",
    "polarny": "równikowy",
    "popularny": "niepopularny",
    "porowatość": "solidność",
    "możliwość": "niemożliwość",
    "silny": "bezsilny",
    "potencjał": "rzeczywisty",
    "ubóstwo": "bogactwo",
    "potężny": "bezsilny",
    "pochwała": "krytykować",
    "poprzedzać": "osiągnąć sukces",
    "poprzedzający": "kolejny",
    "prefiks": "przyrostek",
    "przygotowanie": "rozkład",
    "przygotowany": "nieprzygotowany",
    "nakazowy": "opisowy",
    "obecność": "brak",
    "zachowane": "zniszczony",
    "zapobiegawczy": "dozwalający",
    "podstawowa": "wtórny",
    "prywatny": "publiczny",
    "prywatnie": "publicznie",
    "prawdopodobny": "nieprawdopodobny",
    "produktywny": "nieproduktywny",
    "bezcześcić": "poświęcony",
    "profesjonalny": "amator",
    "progresywny": "regresyjny",
    "chroniony": "bezbronny",
    "dumny": "pokorny",
    "okazać się": "odeprzeć",
    "proksymalny": "dystalny",
    "najbliższy": "ostateczny",
    "ostrożny": "nieostrożny",
    "publiczny": "prywatny",
    "publicznie": "prywatnie",
    "opublikowany": "niepublikowane",
    "ciągnąć": "pchać",
    "punktualność": "opieszałość",
    "oczyścić": "zrehabilitować",
    "czystość": "zanieczyszczenie",
    "pchać": "ciągnąć",
    "zakwalifikować": "zdyskwalifikować",
    "królowa": "król",
    "pytanie": "odpowiedź",
    "wątpliwy": "niewątpliwy",
    "szybko": "powoli",
    "podnieść": "niższy",
    "racjonalny": "irracjonalny",
    "real": "nierealny",
    "realistyczny": "nierealistyczne",
    "uspokajać": "martwić się",
    "odwołanie": "kwestia",
    "rekord": "wymazać",
    "refren": "działać",
    "regres": "postęp",
    "regresyjny": "progresywny",
    "regularny": "nieregularny",
    "prawidłowość": "nieprawidłowość",
    "regulowane": "nieuregulowany",
    "zrehabilitować": "oczyścić",
    "odmowa": "przyjęcie",
    "odmładzać": "wiek",
    "związane z": "niezwiązane",
    "krewny": "absolutny",
    "istotnych": "bez znaczenia",
    "niezawodny": "niewiarygodne",
    "religijny": "świecki",
    "odpychanie": "atrakcja",
    "renomowany": "haniebny",
    "reputacja": "zła reputacja",
    "opierać się": "poddanie się",
    "rozkład": "przygotowanie",
    "poszanowanie": "brak szacunku",
    "pełen szacunku": "lekceważący",
    "odpowiedzialny": "nieodpowiedzialny",
    "powściągliwy": "niepohamowany",
    "z mocą wsteczną": "spodziewany",
    "odwrócenie": "afirmacja",
    "nagroda": "rzut karny",
    "jazda": "spacerować",
    "dojrzały": "zielony",
    "wzrost": "zestaw",
    "podniesienie": "spadanie",
    "wirnik": "stojan",
    "chropowatość": "gładkość",
    "okrągły": "plac",
    "bułczasty": "kątowy",
    "wiejski": "miejski",
    "pośpiech": "marudzić",
    "poświęcony": "bezcześcić",
    "niestety": "szczęśliwie",
    "smutek": "radość",
    "nieszczęście": "szczęście",
    "bezpieczny": "niebezpieczny",
    "bezpieczeństwo": "niepewność",
    "identyczność": "różnica",
    "rozsądny": "szalony",
    "zdrowie psychiczne": "niepoczytalność",
    "zadowolenie": "niezadowolenie",
    "cząber": "niesmaczny",
    "deficytowy": "obfity",
    "niedostatek": "obfitość",
    "naukowy": "nienaukowy",
    "skrupulatny": "bez skrupułów",
    "wtórny": "podstawowa",
    "świecki": "religijny",
    "segregacja": "integracja",
    "samolubny": "bezinteresowny",
    "sprzedać": "kupować",
    "senior": "junior",
    "oddzielny": "połączenie",
    "separacja": "unia",
    "septyczny": "antyseptyczny",
    "usługa": "niedźwiedzia przysługa",
    "osiadły": "zaburzony",
    "wyostrzyć": "spłaszczyć",
    "krótki": "wysoki",
    "skracać": "przedłużać",
    "krzyczeć": "szept",
    "pokazać": "ukryć",
    "kurczyć się": "rozciągać",
    "bok": "dolny",
    "top": "dolny",
    "znaczenie": "znikomość",
    "znaczący": "nieistotny",
    "podobny": "niepodobny",
    "prosty": "złożony",
    "uproszczać": "komplikować",
    "pojedynczy": "liczba mnoga",
    "tonąć": "źródło",
    "siostra": "brat",
    "sen": "budzić",
    "powoli": "szybko",
    "mały": "duży",
    "gładkość": "chropowatość",
    "miękkość": "ostrość",
    "solidność": "porowatość",
    "rozpuszczalny": "nierozpuszczalny",
    "wypłacalność": "niewypłacalność",
    "rozpuszczalnik": "niewypłacalny",
    "syn": "córka",
    "smutny": "radosny",
    "mówiony": "pisemny",
    "niepisany": "pisemny",
    "sporadyczny": "nieustanny",
    "rozpiętość": "zbierać",
    "plac": "okrągły",
    "stabilność": "niestabilność",
    "stabilny": "nietrwały",
    "stoisko": "wydajność",
    "stojan": "wirnik",
    "zostać": "ruszaj się",
    "stały": "niepewny",
    "stromy": "stopniowy",
    "nagły": "stopniowy",
    "jałowy": "płodny",
    "usztywniać": "poluzować",
    "skąpy": "hojny",
    "burzliwy": "spokojna",
    "proste": "zakrzywiony",
    "wyprostować": "zakręt",
    "nieznajomy": "znajomy",
    "siła": "słabość",
    "rozciągać": "kurczyć się",
    "silnie": "słabo",
    "studio": "lokalizacja",
    "głupota": "inteligencja",
    "subiektywny": "cel",
    "podrzędny": "dominujący",
    "kolejny": "poprzedzający",
    "rzeczownik": "przymiotnik",
    "odejmować": "dodaj",
    "odejmowanie": "dodanie",
    "powodzenie": "niepowodzenie",
    "odnoszący sukcesy": "nieudany",
    "ulec": "przetrwać",
    "ponieść": "cieszyć się",
    "dostateczność": "niewydolność",
    "wystarczający": "niewystarczający",
    "dostatecznie": "niewystarczająco",
    "przyrostek": "prefiks",
    "wschód słońca": "zachód słońca",
    "zachód słońca": "wschód słońca",
    "lepszy": "gorszy",
    "wyższość": "niższość",
    "dostawa": "żądanie",
    "utrzymany": "nieobsługiwane",
    "powierzchnia": "nad głową",
    "poddanie się": "opierać się",
    "przetrwać": "ulec",
    "słodkie": "kwaśny",
    "mokro": "suchy",
    "słodzić": "kwaśny",
    "symetria": "asymetria",
    "współczujący": "niesympatyczny",
    "synergistyczny": "antagonistyczny",
    "synteza": "analiza",
    "syntetyczny": "analityczny",
    "opieszałość": "punktualność",
    "gustowny": "bez smaku",
    "pyszne": "bez smaku",
    "bez smaku": "pyszne",
    "delikatny": "twardy",
    "czas": "zrelaksowany",
    "terminal": "pośredni",
    "teizm": "ateizm",
    "teoretyczny": "empiryczny",
    "spragniony": "głodny",
    "rozważny": "bezmyślny",
    "bezmyślny": "rozważny",
    "oszczędny": "rozrzutny",
    "fala": "odpływ",
    "wiązanie": "rozwiązać",
    "nieśmiały": "pogrubienie",
    "nieśmiałość": "śmiałość",
    "tolerancja": "nietolerancja",
    "tolerancyjny": "nietolerancyjny",
    "zębaty": "bezzębny",
    "bezzębny": "zębaty",
    "wzruszony": "nietknięty",
    "twardy": "delikatny",
    "uległy": "trudny",
    "tragedia": "komedia",
    "przeszkolony": "niedoświadczony",
    "zaufanie": "nieufność",
    "prawda": "fałsz",
    "brzydota": "piękno",
    "brzydki": "piękny",
    "ostateczny": "najbliższy",
    "gorszący": "do przyjęcia",
    "niepotwierdzony": "zatwardziały",
    "niezmieniony": "zmieniony",
    "niedwuznaczny": "dwuznaczny",
    "bezbronny": "chroniony",
    "nieautoryzowany": "upoważniony",
    "niezrównoważony": "zrównoważony",
    "niewiara": "wiara",
    "rozwiązany": "granica",
    "niezniszczalny": "łamliwy",
    "nieprzerwany": "złamany",
    "niezmienione": "zmienione",
    "wujek": "ciocia",
    "obojętny": "zaniepokojony",
    "odrębny": "połączony",
    "nieprzytomność": "świadomość",
    "niekonstytucyjny": "konstytucyjny",
    "oryginalny": "standardowy",
    "nieprzekonany": "przekonany",
    "odkryć": "pokrywa",
    "nie oszlifowany": "ciąć",
    "niezdefiniowany": "określone",
    "nie doceniać": "przeszacować",
    "niepożądany": "pożądany",
    "nadmierny": "z powodu",
    "niewykształcony": "wykształcony",
    "jednoznaczny": "dwuznaczny",
    "monotonny": "urozmaicony",
    "niespodziewany": "spodziewany",
    "niewierny": "wierny",
    "nieznany": "znajomy",
    "niekorzystny": "korzystny",
    "rozwijać się": "zagięcie",
    "pamiętliwy": "wyrozumiały",
    "niefortunny": "szczęśliwy",
    "niewdzięczny": "wdzięczny",
    "nieszczęśliwy": "szczęściarz",
    "niezdrowy": "zdrowy",
    "bezbożny": "święty",
    "nieważny": "ważny",
    "nieulepszony": "ulepszony",
    "niedoinformowany": "powiadomiony",
    "bezludny": "zamieszkany",
    "niezrozumiały": "zrozumiały",
    "niezamierzony": "zamierzony",
    "niechcący": "celowo",
    "niezainteresowany": "zainteresowany",
    "nieinteresujący": "ciekawy",
    "unia": "separacja",
    "jednolity": "federalny",
    "zjednoczony": "podzielony",
    "niedobry": "uprzejmy",
    "bezprawny": "legalny",
    "nieograniczony": "ograniczony",
    "odblokować": "zamek",
    "nieoznaczony": "wyraźny",
    "niezamężna": "żonaty",
    "zdemaskować": "maska",
    "wolny": "zajęty",
    "nieoficjalny": "urzędnik",
    "bez sprzeciwu": "przeciwny",
    "nie ortodoksyjny": "prawosławny",
    "rozpakować": "pakiet",
    "niepopularny": "popularny",
    "nieprzygotowany": "przygotowany",
    "nieproduktywny": "produktywny",
    "niepublikowane": "opublikowany",
    "niewątpliwy": "wątpliwy",
    "nierealistyczne": "realistyczny",
    "nieuregulowany": "regulowane",
    "niezwiązane": "związane z",
    "niewiarygodne": "niezawodny",
    "niepohamowany": "powściągliwy",
    "nieograniczony": "ograniczony",
    "niesmaczny": "cząber",
    "nienaukowy": "naukowy",
    "bez skrupułów": "skrupulatny",
    "bezinteresowny": "samolubny",
    "zaburzony": "osiadły",
    "nietrwały": "stabilny",
    "niepewny": "stały",
    "nieudany": "odnoszący sukcesy",
    "nieobsługiwane": "utrzymany",
    "niesympatyczny": "współczujący",
    "rozwiązać": "wiązanie",
    "nietknięty": "wzruszony",
    "demaskować": "welon",
    "nieostrożny": "ostrożny",
    "niechętnie": "chętnie",
    "niechęć": "chęci",
    "rozwijać": "wiatr",
    "niegodny": "godny",
    "miejski": "wiejski",
    "zwykły": "niezwykły",
    "cenny": "bezwartościowy",
    "welon": "demaskować",
    "werbalny": "liczbowy",
    "zwycięstwo": "pokonać",
    "cnotliwy": "niegodziwy",
    "widoczność": "niewidzialność",
    "widoczny": "niewidzialny",
    "wokal": "instrumentalny",
    "dobrowolny": "mimowolny",
    "samogłoska": "spółgłoska",
    "budzić": "sen",
    "spacerować": "jazda",
    "słabnąć": "wosk",
    "wojna": "pokój",
    "marnotrawstwo": "chronić",
    "rozrzutny": "oszczędny",
    "wosk": "słabnąć",
    "słabo": "silnie",
    "słabość": "siła",
    "bogactwo": "ubóstwo",
    "nieważki": "ciężki",
    "ciężki": "nieważki",
    "szept": "krzyczeć",
    "biały": "czarny",
    "całkowicie": "częściowo",
    "niegodziwy": "cnotliwy",
    "szeroki": "wąska",
    "poszerzać": "wąska",
    "chętnie": "niechętnie",
    "chęci": "niechęć",
    "wiatr": "rozwijać",
    "mądrość": "szaleństwo",
    "mądry": "głupi",
    "wycofać": "kaucja",
    "martwić się": "uspokajać",
    "bezwartościowy": "cenny",
    "godny": "niegodny",
    "pisemny": "niepisany",
    "młody": "w wieku",
    "zenit": "nadir",
}
