_antonyms = {
    "aptitude": "incapacité",
    "anormal": "ordinaire",
    "abolir": "établir",
    "absence": "présence",
    "absent": "présent",
    "avenir": "passé",
    "absolu": "relatif",
    "abstention": "consommer",
    "abstrait": "béton",
    "abondance": "rareté",
    "abondant": "rare",
    "acceptez": "rejeter",
    "admettre": "nier",
    "acceptable": "inacceptable",
    "acceptation": "rejet",
    "accessible": "inaccessible",
    "précis": "inexacte",
    "reconnu": "non acquitté",
    "connaissance": "étranger",
    "acte": "refrain",
    "action": "inaction",
    "actif": "silencieux",
    "existant": "inexistant",
    "bruyant": "silencieux",
    "activité": "inactivité",
    "réel": "potentiel",
    "ajouter": "soustraire",
    "une addition": "soustraction",
    "adéquat": "inadéquat",
    "adjectif": "substantiel",
    "admissible": "inadmissible",
    "adulte": "juvénile",
    "avance": "reculer",
    "devant": "arrière",
    "de face": "arrière",
    "virer": "arrière",
    "avantage": "désavantage",
    "affirmation": "renversement",
    "affirmative": "négatif",
    "neutre": "féminin",
    "à l'arrière": "avant",
    "âge": "rajeunir",
    "vieilli": "jeune",
    "agitation": "calme",
    "se mettre d'accord": "être en désaccord",
    "agréable": "désagréable",
    "accord": "désaccord",
    "altéré": "inchangé",
    "alterner": "contraire",
    "amateur": "professionnel",
    "ambigu": "non ambigu",
    "amical": "hostile",
    "amphibie": "terrestre",
    "anal": "oral",
    "analogue": "homologue",
    "une analyse": "la synthèse",
    "analytique": "synthétique",
    "ancêtre": "descendant",
    "angulaire": "arrondi",
    "animer": "inanimé",
    "répondre": "question",
    "antagoniste": "synergique",
    "antécédent": "subséquent",
    "antérieur": "postérieur",
    "antiseptique": "septique",
    "apparence": "disparition",
    "appréciation": "dépréciation",
    "approbation": "désapprobation",
    "approuver": "désapprouver",
    "aquatique": "amphibie",
    "terrestre": "céleste",
    "aqueux": "igné",
    "bras": "désarmer",
    "armé": "sans armes",
    "arrivée": "laisser",
    "monter": "descendre",
    "ascension": "descente",
    "endormi": "éveillé",
    "assentiment": "contestation",
    "asymétrie": "symétrie",
    "athéisme": "théisme",
    "attacher": "délier",
    "attaque": "défendre",
    "poursuivre": "défendre",
    "attention": "inattention",
    "attraction": "répulsion",
    "audible": "inaudible",
    "augmentation": "diminution",
    "tante": "oncle",
    "autorisé": "non autorisé",
    "automatique": "manuel",
    "éviter": "affronter",
    "éveillé": "endormi",
    "arrière": "tête",
    "reculer": "avance",
    "contexte": "premier plan",
    "vers l'arrière": "vers l'avant",
    "sens inverse": "face",
    "mal": "bien",
    "méchanceté": "la bonté",
    "équilibré": "déséquilibré",
    "ours": "taureau",
    "beau": "laid",
    "beauté": "la laideur",
    "commencer": "fin",
    "début": "arrêtez",
    "de bonne heure": "en retard",
    "croyance": "incrédulité",
    "pliez": "redresser",
    "bénin": "malin",
    "gros": "petit",
    "grand": "court",
    "naissance": "décès",
    "bisexuel": "homosexuel",
    "noir": "blanc",
    "bénir": "malédiction",
    "béni": "maudit",
    "exsangue": "sanglant",
    "sanglant": "exsangue",
    "brouiller": "concentrer",
    "ébullition": "gel",
    "audacieux": "timide",
    "audace": "timidité",
    "emprunter": "prêter",
    "emprunteur": "prêteur",
    "bas": "haut",
    "lié": "non lié",
    "garçon": "fille",
    "boycotter": "fréquenter",
    "pause": "réparation",
    "cassable": "incassable",
    "éclairer": "assombrir",
    "alléger": "assombrir",
    "cassé": "ininterrompu",
    "frère": "sœur",
    "taureau": "ours",
    "occupé": "inoccupé",
    "travail": "tourner au ralenti",
    "acheter": "vendre",
    "calme": "agitation",
    "capable": "incapable",
    "capacité": "incapacité",
    "en espèces": "crédit",
    "débit": "crédit",
    "centre": "la gauche",
    "cérébral": "émotif",
    "certitude": "incertitude",
    "changement": "rester",
    "partir": "rester",
    "bouge toi": "rester",
    "changeable": "non modifiable",
    "modifié": "inchangé",
    "charge": "décharge",
    "enrôler": "décharge",
    "pas cher": "coûteux",
    "acclamation": "se plaindre",
    "de bonne humeur": "déprimant",
    "enfant": "parent",
    "civil": "militaire",
    "prétendre": "déclarer forfait",
    "clarté": "opacité",
    "importance": "insignifiance",
    "transparence": "opacité",
    "nettoyer": "impur",
    "le clergé": "laïcs",
    "pasteur": "profane",
    "fermer": "ouvrir",
    "fermé": "ouvrir",
    "fermer": "ouvrir",
    "proximité": "ouverture",
    "côtier": "intérieur",
    "cohérent": "incohérent",
    "du froid": "chaud",
    "collatéral": "direct",
    "comédie": "la tragédie",
    "confort": "malaise",
    "commun": "rare",
    "compatible": "incompatible",
    "compétence": "incompétence",
    "compétent": "incompétent",
    "compétition": "la coopération",
    "se plaindre": "acclamation",
    "complétude": "incomplétude",
    "complexe": "simple",
    "composé": "simple",
    "conforme": "de défi",
    "compliquer": "simplifier",
    "concave": "convexe",
    "vanité": "humilité",
    "fierté": "humilité",
    "concentration": "distribution",
    "concentrique": "excentrique",
    "conception": "idée fausse",
    "concerné": "indifférent",
    "béton": "abstrait",
    "confirmé": "non confirmé",
    "affronter": "éviter",
    "conjonctif": "disjonctif",
    "relier": "se déconnecter",
    "connecté": "sans rapport",
    "conscience": "inconscience",
    "conservateur": "libéral",
    "conserver": "déchets",
    "prévenant": "inconsidéré",
    "cohérence": "incohérence",
    "consonne": "voyelle",
    "visible": "invisible",
    "constitutionnel": "inconstitutionnel",
    "consommer": "abstention",
    "contenu": "mécontentement",
    "continuel": "sporadique",
    "continuation": "interruption",
    "continuer": "cesser",
    "continuité": "discontinuité",
    "continu": "discontinu",
    "contrat": "développer",
    "contracté": "étendu",
    "contraction": "expansion",
    "pratique": "incommode",
    "conventionnel": "non conventionnel",
    "converger": "diverger",
    "convergence": "divergence",
    "convergent": "divergent",
    "convexe": "concave",
    "convaincu": "non convaincu",
    "cool": "chaleur",
    "la coopération": "compétition",
    "cosmopolite": "provincial",
    "courage": "lâcheté",
    "couverture": "devoiler",
    "secret": "manifeste",
    "lâcheté": "courage",
    "crédit": "débit",
    "créancier": "débiteur",
    "critiquer": "louange",
    "cri": "rire",
    "guérissable": "incurable",
    "malédiction": "bénir",
    "maudit": "béni",
    "incurvé": "tout droit",
    "couper": "non coupé",
    "danger": "sécurité",
    "dangereux": "sûr",
    "foncé": "lumière",
    "assombrir": "alléger",
    "obscurité": "importance",
    "lourdeur": "légèreté",
    "fille": "garçon",
    "journée": "nuit",
    "sourd": "audition",
    "décès": "naissance",
    "débiteur": "créancier",
    "décence": "indécence",
    "décent": "indécent",
    "à feuilles caduques": "à feuilles persistantes",
    "décision": "indécision",
    "décisif": "indécis",
    "déclin": "amélioration",
    "diminution": "augmentation",
    "diminué": "augmenté",
    "décrémenter": "incrément",
    "défaite": "la victoire",
    "défendre": "poursuivre",
    "défendeur": "demandeur",
    "la défense": "poursuite",
    "défensive": "offensive",
    "de défi": "conforme",
    "déficit": "conduire",
    "défini": "indéfini",
    "déflation": "inflation",
    "retard": "se ruer",
    "s'attarder": "se ruer",
    "demande": "la fourniture",
    "nier": "admettre",
    "rejeter": "acceptez",
    "dépendant": "indépendant",
    "dépôt": "se désister",
    "dépréciation": "appréciation",
    "déprimant": "de bonne humeur",
    "descendre": "monter",
    "descendant": "ancêtre",
    "descente": "ascension",
    "descriptif": "prescriptif",
    "souhaitable": "indésirable",
    "désespoir": "espérer",
    "désespéré": "optimiste",
    "détruit": "conservé",
    "détacher": "attacher",
    "dévolution": "évolution",
    "différer": "égal",
    "inégal": "égal",
    "différence": "similitude",
    "difficile": "facile",
    "inquiet": "facile",
    "difficulté": "facilité",
    "diligent": "négligent",
    "dilution": "concentration",
    "distribution": "concentration",
    "sale": "nettoyer",
    "impur": "nettoyer",
    "désactiver": "activer",
    "désavantage": "avantage",
    "être en désaccord": "se mettre d'accord",
    "désagréable": "agréable",
    "désaccord": "accord",
    "disparition": "apparence",
    "désapprobation": "approbation",
    "désapprouver": "approuver",
    "désarmer": "bras",
    "décharge": "enrôler",
    "désavouer": "prétendre",
    "déclarer forfait": "prétendre",
    "malaise": "confort",
    "se déconnecter": "relier",
    "mécontentement": "contenu",
    "interruption": "continuation",
    "cesser": "continuer",
    "discontinuité": "continuité",
    "discontinu": "continu",
    "décourager": "encourager",
    "découragement": "encouragement",
    "se dégager": "engager",
    "malhonnête": "honnête",
    "malhonnêteté": "honnêteté",
    "déshonorer": "honneur",
    "désinfecter": "infecter",
    "désintégrer": "intégrer",
    "disjonctif": "conjonctif",
    "ne pas aimer": "aimer",
    "déloger": "loge",
    "désobéissance": "obéissance",
    "désobéissant": "obéissant",
    "désobéir": "obéit",
    "désordre": "commande",
    "désordonné": "ordonné",
    "désorganisé": "organisé",
    "non organisé": "organisé",
    "mécontent": "heureux",
    "réfuter": "prouver",
    "disqualifier": "qualifier",
    "de mauvaise réputation": "honorable",
    "déconsidération": "réputation",
    "manque de respect": "le respect",
    "irrespectueux": "respectueux",
    "insatisfaction": "la satisfaction",
    "contestation": "assentiment",
    "mauvais service": "un service",
    "différent": "similaire",
    "dissonance": "harmonie",
    "dissuader": "persuader",
    "distal": "proximal",
    "loin": "fermer",
    "ouvrir": "fermer à clé",
    "distinguable": "indiscernable",
    "méfiance": "confiance",
    "diurne": "nocturne",
    "diverger": "converger",
    "divergence": "convergence",
    "divergent": "convergent",
    "diviser": "unir",
    "séparément": "multiplier",
    "divisé": "uni",
    "divisible": "indivisible",
    "national": "étranger",
    "originaire de": "étranger",
    "dominant": "subalterne",
    "dormant": "actif",
    "disparu": "existant",
    "inactif": "actif",
    "passif": "actif",
    "silencieux": "bruyant",
    "double": "unique",
    "plusieurs": "unique",
    "colombe": "faucon",
    "dramatique": "lyrique",
    "sec": "humide",
    "acide": "sucrer",
    "dû": "indu",
    "terne": "aiguiser",
    "aplatir": "aiguiser",
    "en train de mourir": "naissant",
    "facilité": "difficulté",
    "facile": "inquiet",
    "reflux": "marée",
    "excentrique": "concentrique",
    "éduqué": "sans instruction",
    "efficace": "inefficace",
    "efficacité": "inefficacité",
    "sortie": "entrée",
    "élastique": "inélastique",
    "éligible": "inéligible",
    "émotif": "cérébral",
    "empirique": "théorique",
    "vide": "plein",
    "mince": "épaissir",
    "activer": "désactiver",
    "encourager": "décourager",
    "encouragement": "découragement",
    "fin": "début",
    "milieu": "de bonne heure",
    "endémique": "cosmopolite",
    "provincial": "cosmopolite",
    "énergique": "léthargique",
    "imposer": "exempter",
    "engager": "se dégager",
    "prendre plaisir": "souffrir",
    "entrer": "sortie",
    "égal": "inégal",
    "égalité": "inégalité",
    "équatorial": "polaire",
    "équitable": "inéquitable",
    "équivoque": "sans équivoque",
    "effacer": "record",
    "établir": "abolir",
    "mouvementé": "sans incidents",
    "à feuilles persistantes": "à feuilles caduques",
    "évolution": "dévolution",
    "exclusion": "inclusion",
    "exempter": "imposer",
    "exhaler": "inhaler",
    "sortie": "entrer",
    "développer": "contrat",
    "étendu": "contracté",
    "expansion": "contraction",
    "attendu": "inattendu",
    "coûteux": "pas cher",
    "expérimenté": "inexpérimenté",
    "exportation": "importer",
    "express": "local",
    "général": "spécifique",
    "nationale": "international",
    "extension": "flexion",
    "extérieur": "intérieur",
    "externe": "interne",
    "extérieurement": "intérieurement",
    "éteindre": "enflammer",
    "extra-muros": "intramural",
    "extraordinaire": "ordinaire",
    "extrinsèque": "intrinsèque",
    "échouer": "qui passe",
    "fonctionnement": "permanent",
    "échec": "succès",
    "juste": "injuste",
    "fidèle": "infidèle",
    "tomber": "augmenter",
    "ensemble": "augmenter",
    "faillible": "infaillible",
    "chute": "en hausse",
    "mensonge": "supporter",
    "fausseté": "vérité",
    "célébrité": "infamie",
    "familier": "inconnu",
    "fantaisie": "plaine",
    "graisse": "mince",
    "plein": "vide",
    "épais": "mince",
    "épaissir": "mince",
    "père": "mère",
    "faune": "flore",
    "favorable": "défavorable",
    "fédéral": "unitaire",
    "femelle": "mâle",
    "féminin": "neutre",
    "la féminité": "masculinité",
    "fertile": "stérile",
    "fidélité": "infidélité",
    "figure": "sol",
    "remplir": "vide",
    "trouver": "perdre",
    "terminer": "début",
    "arrêtez": "début",
    "fini": "infini",
    "feu": "louer",
    "flexion": "extension",
    "flotte": "évier",
    "la source": "évier",
    "flore": "faune",
    "concentrer": "brouiller",
    "ennemi": "ami",
    "plier": "se dérouler",
    "suivre": "précéder",
    "réussir": "précédent",
    "disciple": "chef",
    "folie": "santé mentale",
    "insensé": "sain",
    "pied": "tête",
    "queue": "tête",
    "interdire": "permis",
    "avant": "à l'arrière",
    "premier plan": "contexte",
    "étranger": "connaissance",
    "oublier": "rappelles toi",
    "indulgent": "impitoyable",
    "formalisme": "imitation",
    "chanceux": "malchanceux",
    "vers l'avant": "sens inverse",
    "face": "sens inverse",
    "faute": "juste",
    "injuste": "juste",
    "a trouvé": "perdu",
    "fraternel": "identique",
    "gel": "ébullition",
    "fréquent": "rare",
    "fréquemment": "rarement",
    "ami": "ennemi",
    "tête": "queue",
    "plénitude": "vide",
    "fonctionnel": "biologique",
    "inorganique": "biologique",
    "gain": "perte",
    "gazeux": "solide",
    "creux": "solide",
    "recueillir": "propager",
    "généralité": "particularité",
    "généreuse": "avare",
    "bien": "mal",
    "la bonté": "méchanceté",
    "graduel": "soudain",
    "reconnaissant": "ingrat",
    "plus grand": "moindre",
    "vert": "mûr",
    "brut": "net",
    "sol": "figure",
    "culpabilité": "innocence",
    "coupable": "innocent",
    "heureusement": "malheureusement",
    "bonheur": "le malheur",
    "content": "malheureux",
    "dureté": "douceur",
    "intensité": "douceur",
    "acuité": "douceur",
    "harmonie": "dissonance",
    "haine": "amour",
    "odieux": "aimable",
    "faucon": "colombe",
    "en bonne santé": "mauvais pour la santé",
    "audition": "sourd",
    "chaleur": "cool",
    "céleste": "terrestre",
    "hétérogénéité": "homogénéité",
    "cacher": "montrer",
    "louer": "feu",
    "frappé": "manquer",
    "saint": "impie",
    "homogénéité": "hétérogénéité",
    "homologue": "analogue",
    "homosexuel": "bisexuel",
    "honnête": "malhonnête",
    "honnêteté": "malhonnêteté",
    "honneur": "déshonorer",
    "espérer": "désespoir",
    "optimiste": "pessimiste",
    "horizontal": "verticale",
    "hostile": "amical",
    "chaud": "du froid",
    "humble": "fier",
    "humilité": "fierté",
    "affamé": "assoiffé",
    "identique": "fraternel",
    "tourner au ralenti": "travail",
    "igné": "aqueux",
    "enflammer": "éteindre",
    "ignorer": "remarquer",
    "illégal": "légal",
    "illégalité": "légalité",
    "illisible": "lisible",
    "illogique": "logique",
    "imitation": "formalisme",
    "immatériel": "matériel",
    "immaturité": "maturité",
    "incommensurable": "mesurable",
    "immoral": "moral",
    "immoralité": "moralité",
    "immortel": "mortel",
    "immortalité": "mortalité",
    "immuable": "mutable",
    "impartialité": "partialité",
    "infranchissable": "passable",
    "impatience": "la patience",
    "impatient": "patient",
    "imperceptible": "perceptible",
    "imperfection": "la perfection",
    "imperméable": "perméable",
    "inadmissible": "admissible",
    "impersonnel": "personnel",
    "impoli": "poli",
    "importer": "exportation",
    "important": "insignifiant",
    "impossibilité": "possibilité",
    "impuissant": "puissant",
    "improbable": "probable",
    "amélioré": "non amélioré",
    "amélioration": "déclin",
    "imprudent": "prudent",
    "impureté": "pureté",
    "incapacité": "capacité",
    "inaccessible": "accessible",
    "inexacte": "précis",
    "inaction": "action",
    "inactivité": "activité",
    "inadéquat": "adéquat",
    "inanimé": "animer",
    "inattention": "attention",
    "inaudible": "audible",
    "incapable": "capable",
    "incliné": "horizontal",
    "verticale": "horizontal",
    "inclusion": "exclusion",
    "incohérent": "cohérent",
    "incompatible": "compatible",
    "incompétence": "compétence",
    "incompétent": "compétent",
    "incomplétude": "complétude",
    "inconsidéré": "prévenant",
    "incohérence": "cohérence",
    "discret": "visible",
    "incommode": "pratique",
    "augmenter": "ensemble",
    "augmenté": "diminué",
    "incrément": "décrémenter",
    "incurable": "guérissable",
    "indécence": "décence",
    "indécent": "décent",
    "indécision": "décision",
    "indécis": "décisif",
    "indépendant": "dépendant",
    "indiscernable": "distinguable",
    "indivisible": "divisible",
    "intérieur": "extérieur",
    "inefficace": "efficace",
    "inefficacité": "efficacité",
    "inélastique": "élastique",
    "inéligible": "éligible",
    "inégalité": "égalité",
    "inéquitable": "équitable",
    "inexpérimenté": "expérimenté",
    "infaillible": "faillible",
    "infamie": "célébrité",
    "infecter": "désinfecter",
    "inférieur": "élever",
    "infériorité": "supériorité",
    "infidélité": "fidélité",
    "infini": "fini",
    "inflation": "déflation",
    "informé": "mal informé",
    "rare": "commun",
    "rarement": "fréquemment",
    "entrée": "sortie",
    "habité": "inhabité",
    "inhaler": "exhaler",
    "injustice": "justice",
    "innocence": "culpabilité",
    "innocent": "coupable",
    "inoffensif": "nuisible",
    "inopérant": "opératoire",
    "insécurité": "sécurité",
    "insignifiance": "importance",
    "insignifiant": "important",
    "insoluble": "soluble",
    "insolvabilité": "solvabilité",
    "insolvable": "solvant",
    "instabilité": "la stabilité",
    "instrumental": "vocal",
    "insuffisance": "suffisance",
    "insuffisant": "suffisant",
    "insuffisamment": "suffisamment",
    "intégrer": "désintégrer",
    "l'intégration": "ségrégation",
    "intelligence": "stupidité",
    "intelligible": "inintelligible",
    "prévu": "involontaire",
    "intentionnellement": "involontairement",
    "intéressé": "indifférent",
    "intéressant": "inintéressant",
    "intermédiaire": "terminal",
    "interne": "externe",
    "intérieurement": "extérieurement",
    "international": "nationale",
    "local": "général",
    "intolérance": "tolérance",
    "intolérant": "tolérant",
    "intraitable": "docile",
    "intramural": "extra-muros",
    "intrinsèque": "extrinsèque",
    "invisibilité": "visibilité",
    "invisible": "visible",
    "involontaire": "prévu",
    "irrationnel": "rationnel",
    "irrégulier": "ordinaire",
    "irrégularité": "régularité",
    "sans importance": "important",
    "irresponsable": "responsable",
    "irrévérencieux": "respectueux",
    "problème": "rappel",
    "mixte": "séparé",
    "joie": "chagrin",
    "joyeux": "douloureux",
    "junior": "sénior",
    "justice": "injustice",
    "juvénile": "adulte",
    "kern": "kern",
    "gentil": "méchant",
    "roi": "reine",
    "laïcs": "le clergé",
    "en retard": "de bonne heure",
    "rire": "cri",
    "légitime": "illicite",
    "relâché": "tendu",
    "détendu": "tendu",
    "profane": "sacré",
    "conduire": "déficit",
    "chef": "disciple",
    "laisser": "arrivée",
    "la gauche": "centre",
    "légal": "illégal",
    "légalité": "illégalité",
    "légaliser": "hors la loi",
    "lisible": "illisible",
    "prêter": "emprunter",
    "prêteur": "emprunteur",
    "allonger": "raccourcir",
    "moindre": "plus grand",
    "léthargique": "énergique",
    "niveau": "élever",
    "libéral": "conservateur",
    "rendement": "supporter",
    "lumière": "foncé",
    "légèreté": "lourdeur",
    "aimer": "ne pas aimer",
    "limité": "libre",
    "direct": "collatéral",
    "liquide": "gazeux",
    "solide": "creux",
    "spécifique": "général",
    "emplacement": "studio",
    "fermer à clé": "ouvrir",
    "loge": "déloger",
    "logique": "illogique",
    "longue": "court",
    "desserrer": "raidir",
    "perdre": "trouver",
    "perte": "gain",
    "perdu": "a trouvé",
    "aimable": "odieux",
    "amour": "haine",
    "lyrique": "dramatique",
    "majeur": "mineur",
    "majorité": "minorité",
    "faire": "pause",
    "réparation": "pause",
    "mâle": "femelle",
    "calomnier": "bénin",
    "malin": "bénin",
    "manuel": "automatique",
    "marqué": "non marqué",
    "marié": "célibataire",
    "masculin": "féminin",
    "masculinité": "la féminité",
    "masque": "démasquer",
    "matériel": "immatériel",
    "maternel": "paternel",
    "maturité": "immaturité",
    "maximum": "le minimum",
    "mesurable": "incommensurable",
    "mental": "physique",
    "miséricordieux": "sans merci",
    "sans merci": "miséricordieux",
    "militaire": "civil",
    "esprit": "oublier",
    "rappelles toi": "oublier",
    "le minimum": "maximum",
    "mineur": "majeur",
    "minorité": "majorité",
    "idée fausse": "conception",
    "manquer": "frappé",
    "molaire": "moléculaire",
    "moléculaire": "molaire",
    "moral": "immoral",
    "moralité": "immoralité",
    "mortel": "immortel",
    "mortalité": "immortalité",
    "mère": "père",
    "multiplier": "séparément",
    "unir": "diviser",
    "mutable": "immuable",
    "nadir": "zénith",
    "étroit": "élargir",
    "naissant": "en train de mourir",
    "négatif": "neutre",
    "négligent": "diligent",
    "neveu": "nièce",
    "net": "brut",
    "nièce": "neveu",
    "nuit": "journée",
    "nocturne": "diurne",
    "nominal": "réal",
    "irréel": "réal",
    "inexistant": "existant",
    "ordinaire": "anormal",
    "remarquer": "ignorer",
    "nuisible": "inoffensif",
    "numérique": "verbal",
    "obéissance": "désobéissance",
    "obéissant": "désobéissant",
    "obéit": "désobéir",
    "objectif": "subjectif",
    "obligatoire": "optionnel",
    "oblique": "perpendiculaire",
    "opacité": "transparence",
    "infraction": "la défense",
    "poursuite": "la défense",
    "offensive": "défensive",
    "officiel": "non officiel",
    "ouverture": "proximité",
    "opératoire": "inopérant",
    "opposé": "sans opposition",
    "contraire": "alterner",
    "optimisme": "pessimisme",
    "optionnel": "obligatoire",
    "oral": "anal",
    "commande": "désordre",
    "ordonné": "désordonné",
    "ordinaire": "irrégulier",
    "biologique": "inorganique",
    "organisé": "non organisé",
    "orthodoxe": "peu orthodoxe",
    "de plein air": "intérieur",
    "hors la loi": "légaliser",
    "surestimer": "sous-estimer",
    "aérien": "surface",
    "manifeste": "secret",
    "pack": "déballer",
    "douloureux": "joyeux",
    "sans douleur": "douloureux",
    "parallèle": "oblique",
    "perpendiculaire": "oblique",
    "parent": "enfant",
    "partialité": "impartialité",
    "particularité": "généralité",
    "partiellement": "entièrement",
    "passable": "infranchissable",
    "qui passe": "fonctionnement",
    "permanent": "fonctionnement",
    "passé": "avenir",
    "présent": "absent",
    "paternel": "maternel",
    "la patience": "impatience",
    "patient": "impatient",
    "fréquenter": "boycotter",
    "paix": "guerre",
    "peine": "récompense",
    "perceptible": "imperceptible",
    "la perfection": "imperfection",
    "perméable": "imperméable",
    "permis": "interdire",
    "permissif": "préventif",
    "personnel": "impersonnel",
    "persuader": "dissuader",
    "pessimisme": "optimisme",
    "pessimiste": "optimiste",
    "physique": "mental",
    "plaine": "fantaisie",
    "demandeur": "défendeur",
    "heureux": "mécontent",
    "pluriel": "singulier",
    "polaire": "équatorial",
    "poli": "impoli",
    "populaire": "impopulaire",
    "porosité": "solidité",
    "possibilité": "impossibilité",
    "postérieur": "antérieur",
    "puissant": "impuissant",
    "potentiel": "réel",
    "la pauvreté": "richesse",
    "louange": "critiquer",
    "précéder": "réussir",
    "précédent": "réussir",
    "préfixe": "suffixe",
    "préparation": "résolution",
    "préparé": "non préparé",
    "prescriptif": "descriptif",
    "présence": "absence",
    "conservé": "détruit",
    "préventif": "permissif",
    "primaire": "secondaire",
    "privé": "publique",
    "en privé": "publiquement",
    "probable": "improbable",
    "productif": "improductif",
    "professionnel": "amateur",
    "le progrès": "régresser",
    "progressive": "régressif",
    "éventuel": "rétrospective",
    "protégé": "non protégé",
    "fier": "humble",
    "prouver": "réfuter",
    "proximal": "distal",
    "proche": "ultime",
    "prudent": "imprudent",
    "publique": "privé",
    "publiquement": "en privé",
    "publié": "non publié",
    "tirer": "pousser",
    "ponctualité": "lenteur",
    "purge": "réhabiliter",
    "pureté": "impureté",
    "pousser": "tirer",
    "qualifier": "disqualifier",
    "reine": "roi",
    "question": "répondre",
    "discutable": "incontestable",
    "rapidement": "lentement",
    "élever": "inférieur",
    "rationnel": "irrationnel",
    "réal": "irréel",
    "réaliste": "irréaliste",
    "rassurer": "inquiéter",
    "rappel": "problème",
    "record": "effacer",
    "refrain": "acte",
    "refuser": "acceptez",
    "régresser": "le progrès",
    "régressif": "progressive",
    "régularité": "irrégularité",
    "réglementé": "non réglementé",
    "réhabiliter": "purge",
    "rejet": "acceptation",
    "rajeunir": "âge",
    "en relation": "sans rapport",
    "relatif": "absolu",
    "pertinent": "sans importance",
    "fiable": "non fiable",
    "religieux": "séculier",
    "répulsion": "attraction",
    "honorable": "de mauvaise réputation",
    "réputation": "déconsidération",
    "résister": "abandon",
    "résolution": "préparation",
    "le respect": "manque de respect",
    "respectueux": "irrévérencieux",
    "responsable": "irresponsable",
    "restreint": "effréné",
    "rétrospective": "éventuel",
    "renversement": "affirmation",
    "récompense": "peine",
    "balade": "marche",
    "mûr": "vert",
    "en hausse": "chute",
    "rotor": "stator",
    "rugosité": "douceur",
    "rond": "carré",
    "arrondi": "angulaire",
    "rural": "urbain",
    "se ruer": "s'attarder",
    "sacré": "profane",
    "malheureusement": "heureusement",
    "tristesse": "bonheur",
    "le malheur": "bonheur",
    "sûr": "dangereux",
    "sécurité": "danger",
    "similitude": "différence",
    "sain": "insensé",
    "santé mentale": "folie",
    "la satisfaction": "insatisfaction",
    "sarriette": "peu recommandable",
    "rareté": "abondance",
    "scientifique": "peu scientifique",
    "scrupuleux": "sans scrupules",
    "secondaire": "primaire",
    "séculier": "religieux",
    "sécurité": "insécurité",
    "ségrégation": "l'intégration",
    "égoïste": "généreux",
    "vendre": "acheter",
    "sénior": "junior",
    "séparé": "mixte",
    "séparation": "syndicat",
    "septique": "antiseptique",
    "un service": "mauvais service",
    "colonisé": "instable",
    "aiguiser": "aplatir",
    "court": "grand",
    "raccourcir": "allonger",
    "crier": "chuchotement",
    "montrer": "cacher",
    "rétrécir": "étendue",
    "côté": "bas",
    "haut": "bas",
    "similaire": "différent",
    "simple": "composé",
    "simplifier": "compliquer",
    "unique": "plusieurs",
    "singulier": "pluriel",
    "évier": "la source",
    "sœur": "frère",
    "dormir": "réveiller",
    "lentement": "rapidement",
    "petit": "grand",
    "douceur": "acuité",
    "solidité": "porosité",
    "soluble": "insoluble",
    "solvabilité": "insolvabilité",
    "solvant": "insolvable",
    "fils": "fille",
    "chagrin": "joie",
    "parlé": "écrit",
    "non écrit": "écrit",
    "sporadique": "continuel",
    "propager": "recueillir",
    "carré": "rond",
    "la stabilité": "instabilité",
    "stable": "instable",
    "supporter": "rendement",
    "stator": "rotor",
    "rester": "bouge toi",
    "raide": "graduel",
    "soudain": "graduel",
    "stérile": "fertile",
    "raidir": "desserrer",
    "avare": "généreuse",
    "orageux": "calme",
    "tout droit": "incurvé",
    "redresser": "pliez",
    "force": "la faiblesse",
    "étendue": "rétrécir",
    "fortement": "faiblement",
    "studio": "emplacement",
    "stupidité": "intelligence",
    "subjectif": "objectif",
    "subalterne": "dominant",
    "subséquent": "antécédent",
    "substantiel": "adjectif",
    "soustraire": "ajouter",
    "soustraction": "une addition",
    "succès": "échec",
    "réussi": "infructueux",
    "succomber": "survivre",
    "souffrir": "prendre plaisir",
    "suffisance": "insuffisance",
    "suffisant": "insuffisant",
    "suffisamment": "insuffisamment",
    "suffixe": "préfixe",
    "lever du soleil": "le coucher du soleil",
    "le coucher du soleil": "lever du soleil",
    "supérieur": "inférieur",
    "supériorité": "infériorité",
    "la fourniture": "demande",
    "prise en charge": "non pris en charge",
    "surface": "aérien",
    "abandon": "résister",
    "survivre": "succomber",
    "doux": "acide",
    "humide": "sec",
    "sucrer": "acide",
    "symétrie": "asymétrie",
    "sympathique": "antipathique",
    "synergique": "antagoniste",
    "la synthèse": "une analyse",
    "synthétique": "analytique",
    "lenteur": "ponctualité",
    "de bon goût": "insipide",
    "délicieux": "insipide",
    "insipide": "délicieux",
    "soumissionner": "dure",
    "tendu": "détendu",
    "terminal": "intermédiaire",
    "théisme": "athéisme",
    "théorique": "empirique",
    "assoiffé": "affamé",
    "réfléchi": "irréfléchi",
    "irréfléchi": "réfléchi",
    "économe": "gaspilleur",
    "marée": "reflux",
    "timide": "audacieux",
    "timidité": "audace",
    "tolérance": "intolérance",
    "tolérant": "intolérant",
    "denté": "édenté",
    "édenté": "denté",
    "touché": "intacte",
    "dure": "soumissionner",
    "docile": "intraitable",
    "la tragédie": "comédie",
    "qualifié": "non formé",
    "confiance": "méfiance",
    "vérité": "fausseté",
    "la laideur": "beauté",
    "laid": "beau",
    "ultime": "proche",
    "inacceptable": "acceptable",
    "non acquitté": "reconnu",
    "inchangé": "modifié",
    "non ambigu": "ambigu",
    "sans armes": "armé",
    "non autorisé": "autorisé",
    "déséquilibré": "équilibré",
    "incrédulité": "croyance",
    "non lié": "lié",
    "incassable": "cassable",
    "ininterrompu": "cassé",
    "incertitude": "certitude",
    "non modifiable": "changeable",
    "oncle": "tante",
    "indifférent": "intéressé",
    "non confirmé": "confirmé",
    "sans rapport": "en relation",
    "inconscience": "conscience",
    "inconstitutionnel": "constitutionnel",
    "non conventionnel": "conventionnel",
    "non convaincu": "convaincu",
    "devoiler": "couverture",
    "non coupé": "couper",
    "indéfini": "défini",
    "sous-estimer": "surestimer",
    "indésirable": "souhaitable",
    "indu": "dû",
    "sans instruction": "éduqué",
    "sans équivoque": "équivoque",
    "sans incidents": "mouvementé",
    "inattendu": "attendu",
    "infidèle": "fidèle",
    "inconnu": "familier",
    "défavorable": "favorable",
    "se dérouler": "plier",
    "impitoyable": "indulgent",
    "malheureux": "content",
    "ingrat": "reconnaissant",
    "mauvais pour la santé": "en bonne santé",
    "impie": "saint",
    "non amélioré": "amélioré",
    "mal informé": "informé",
    "inhabité": "habité",
    "inintelligible": "intelligible",
    "involontairement": "intentionnellement",
    "inintéressant": "intéressant",
    "syndicat": "séparation",
    "unitaire": "fédéral",
    "uni": "divisé",
    "méchant": "vertueux",
    "illicite": "légitime",
    "illimité": "limité",
    "malchanceux": "chanceux",
    "non marqué": "marqué",
    "célibataire": "marié",
    "démasquer": "masque",
    "inoccupé": "occupé",
    "non officiel": "officiel",
    "sans opposition": "opposé",
    "peu orthodoxe": "orthodoxe",
    "déballer": "pack",
    "impopulaire": "populaire",
    "non préparé": "préparé",
    "improductif": "productif",
    "non protégé": "protégé",
    "non publié": "publié",
    "incontestable": "discutable",
    "irréaliste": "réaliste",
    "non réglementé": "réglementé",
    "non fiable": "fiable",
    "effréné": "restreint",
    "libre": "limité",
    "peu recommandable": "sarriette",
    "peu scientifique": "scientifique",
    "sans scrupules": "scrupuleux",
    "généreux": "égoïste",
    "instable": "stable",
    "infructueux": "réussi",
    "non pris en charge": "prise en charge",
    "antipathique": "sympathique",
    "délier": "attacher",
    "intacte": "touché",
    "non formé": "qualifié",
    "inhabituel": "habituel",
    "dévoiler": "voile",
    "contre son gré": "volontiers",
    "réticence": "volonté",
    "se détendre": "vent",
    "indigne": "digne",
    "urbain": "rural",
    "habituel": "inhabituel",
    "de valeur": "sans valeur",
    "voile": "dévoiler",
    "verbal": "numérique",
    "la victoire": "défaite",
    "vertueux": "méchant",
    "visibilité": "invisibilité",
    "vocal": "instrumental",
    "volontaire": "involontaire",
    "voyelle": "consonne",
    "réveiller": "dormir",
    "marche": "balade",
    "décliner": "la cire",
    "guerre": "paix",
    "déchets": "conserver",
    "gaspilleur": "économe",
    "la cire": "décliner",
    "faiblement": "fortement",
    "la faiblesse": "force",
    "richesse": "la pauvreté",
    "sans poids": "lourd",
    "lourd": "sans poids",
    "chuchotement": "crier",
    "blanc": "noir",
    "entièrement": "partiellement",
    "large": "étroit",
    "élargir": "étroit",
    "volontiers": "contre son gré",
    "volonté": "réticence",
    "vent": "se détendre",
    "sagesse": "folie",
    "sage": "insensé",
    "se désister": "dépôt",
    "inquiéter": "rassurer",
    "sans valeur": "de valeur",
    "digne": "indigne",
    "écrit": "non écrit",
    "jeune": "vieilli",
    "zénith": "nadir",
}
