_antonyms = {
    "能力": "無能",
    "異常な": "正常",
    "廃止する": "確立します",
    "不在": "プレゼント",
    "未来": "過去",
    "絶対の": "相対",
    "棄権する": "消費する",
    "抽象": "コンクリート",
    "豊富": "乏しい",
    "受け入れる": "拒絶する",
    "認める": "否定する",
    "許容可能な": "容認できない",
    "受け入れ": "拒絶",
    "アクセス可能な": "アクセスできない",
    "正確": "不正確",
    "認められた": "未確認の",
    "知り合い": "ストレンジャー",
    "行為": "控える",
    "アクション": "無反応",
    "アクティブ": "静か",
    "現存": "絶滅した",
    "うるさい": "静か",
    "アクティビティ": "不活動",
    "実際の": "潜在的な",
    "追加する": "減算",
    "添加": "減算",
    "十分な": "不十分な",
    "形容詞": "実質的な",
    "容認できる": "容認できない",
    "大人": "少年",
    "前進": "逆",
    "前方に": "バック",
    "フロント": "リア",
    "変化": "バック",
    "利点": "不利益",
    "肯定": "逆転",
    "肯定的な": "負",
    "中性": "フェミニン",
    "後部": "前方",
    "年齢": "若返らせる",
    "老人": "若い",
    "攪拌": "静けさ",
    "同意する": "異議",
    "楽しい": "不快",
    "契約": "不一致",
    "変更されました": "変更なし",
    "代わりの": "反対の",
    "アマチュア": "専門家",
    "あいまいな": "曖昧でない",
    "親切な": "敵対的な",
    "フレンドリーな": "不親切",
    "水陸両用の": "地上の",
    "肛門": "オーラル",
    "類似": "異なる",
    "分析": "合成",
    "分析的": "合成",
    "祖先": "子孫",
    "角張った": "丸みを帯びた",
    "アニメーション化する": "生きていない",
    "回答": "質問",
    "敵対的": "相乗的な",
    "先行する": "成功する",
    "前方": "後部",
    "消毒剤": "敗血症",
    "外観": "インテリア",
    "感謝": "減価償却費",
    "承認": "不承認",
    "承認する": "不承認",
    "水生生物": "水陸両用の",
    "地上の": "天",
    "水性": "火星",
    "腕": "武装解除する",
    "武装した": "非武装の",
    "到着する": "離れる",
    "上昇する": "落下",
    "上昇": "セット",
    "眠っている": "起きている",
    "非対称": "対称",
    "無神論": "有神論",
    "付ける": "デタッチ",
    "攻撃": "防御的",
    "起訴": "防衛",
    "注意": "不注意",
    "アトラクション": "反発",
    "可聴": "聞き取れない",
    "増強": "減少",
    "叔母": "叔父",
    "承認された": "無許可",
    "自動": "マニュアル",
    "避ける": "対峙する",
    "起きている": "眠っている",
    "バック": "変化",
    "後退する": "前進",
    "リア": "頭",
    "バックグラウンド": "前景",
    "後方に": "前進",
    "逆": "表面",
    "悪い": "良い",
    "悪の": "良い",
    "不良": "良さ",
    "バランス": "アンバランス",
    "くま": "ブル",
    "綺麗な": "醜い",
    "美しさ": "醜さ",
    "ベギン": "終わり",
    "始まり": "中間",
    "早い": "遅く",
    "信念": "不信仰",
    "曲げる": "まっすぐにする",
    "良性": "悪性",
    "大きい": "小さい",
    "大": "小さい",
    "誕生": "死",
    "バイセクシュアル": "同性愛者",
    "黒": "白",
    "祝福": "呪い",
    "祝福された": "呪われた",
    "無血": "血まみれの",
    "血まみれの": "無血",
    "ぼかし": "フォーカス",
    "煮る": "フリーズする",
    "大胆な": "臆病な",
    "大胆さ": "臆病",
    "かりて": "貸す",
    "借り手": "貸し手",
    "下": "上",
    "バウンド": "アンバウンド",
    "男の子": "女の子",
    "ボイコット": "ひいきにする",
    "ブレーク": "修復",
    "壊れる": "破られない",
    "明るく": "暗く",
    "壊れた": "破られていない",
    "兄": "シスター",
    "ブル": "くま",
    "忙しい": "アイドル",
    "作業": "アイドル",
    "購入": "売る",
    "落ち着いた": "不安定",
    "静けさ": "攪拌",
    "可能な": "不可能な",
    "容量": "無能",
    "現金": "クレジット",
    "デビット": "クレジット",
    "センター": "左",
    "大脳": "感情の",
    "確実": "不確実性",
    "変化する": "滞在",
    "出発する": "滞在",
    "動く": "滞在",
    "変更可能な": "不変",
    "かわった": "変わらない",
    "電荷": "放電",
    "参加する": "放電",
    "安いです": "高価な",
    "応援": "文句を言う",
    "陽気な": "落ち込む",
    "子": "親",
    "文民": "軍事",
    "請求": "失う",
    "透明度": "不透明度",
    "プロミネンス": "あいまい",
    "透明性": "不透明度",
    "クリーン": "汚れた",
    "聖職者": "信徒",
    "牧師": "素人",
    "閉じる": "開いた",
    "閉まっている": "開いた",
    "シャット": "開いた",
    "親密さ": "開放性",
    "沿岸の": "内陸",
    "コヒーレントな": "インコヒーレントな",
    "コールド": "ホット",
    "担保": "線形",
    "コメディー": "悲劇",
    "快適": "不快",
    "一般": "特定",
    "互換性のある": "互換性のない",
    "有能な": "無能な",
    "コンペ": "協力",
    "文句を言う": "応援",
    "完全": "不完全さ",
    "複合体": "単純",
    "化合物": "単純",
    "準拠する": "反抗的",
    "複雑にする": "簡略化する",
    "凹面の": "凸面",
    "うぬぼれ": "謙虚",
    "誇り": "謙虚",
    "濃度": "分布",
    "同心円の": "偏心",
    "概念": "誤解",
    "心配している": "無関心",
    "コンクリート": "抽象",
    "確認済み": "未確認",
    "対峙する": "避ける",
    "結合的": "離接",
    "接続する": "切断する",
    "接続された": "未接続",
    "意識": "無意識",
    "保守的な": "リベラル",
    "節約する": "廃棄物",
    "思慮深い": "思慮のない",
    "一貫性": "不一致",
    "子音": "母音",
    "目立つ": "目立たない",
    "憲法": "違憲",
    "消費する": "棄権する",
    "コンテンツ": "不満",
    "継続的": "散発的な",
    "継続": "中止",
    "持続する": "中止します",
    "連続": "不連続な",
    "契約する": "拡大する",
    "契約した": "拡張された",
    "収縮": "拡張",
    "便利": "不便",
    "従来の": "独創的ではない",
    "収束する": "発散する",
    "収束": "発散",
    "凸面": "凹面の",
    "確信している": "確信していない",
    "クール": "熱",
    "協力": "コンペ",
    "コスモポリタン": "州",
    "勇気": "臆病",
    "カバー": "明らかにする",
    "秘密": "明白な",
    "臆病": "大胆さ",
    "クレジット": "デビット",
    "債権者": "債務者",
    "批判する": "賞賛",
    "泣く": "笑い",
    "硬化可能な": "不治の",
    "呪い": "祝福",
    "呪われた": "祝福された",
    "湾曲した": "まっすぐ",
    "カット": "未加工",
    "危険": "安全性",
    "危険な": "安全",
    "ダーク": "光",
    "暗く": "明るく",
    "闇": "明度",
    "重さ": "明度",
    "娘": "息子",
    "日": "夜",
    "聴覚障害者": "聴覚",
    "死": "誕生",
    "債務者": "債権者",
    "良識": "卑劣な",
    "まともな": "卑劣な",
    "落葉": "常緑",
    "決定": "絶望",
    "決定的": "決定的ではない",
    "低下": "改善",
    "減少": "増強",
    "減少した": "増加した",
    "デクリメント": "インクリメント",
    "敗北": "勝利",
    "守る": "起訴",
    "被告": "原告",
    "防衛": "起訴",
    "防御的": "攻撃",
    "反抗的": "準拠する",
    "赤字": "鉛",
    "定義された": "未定義",
    "デフレ": "インフレーション",
    "ディレイ": "ラッシュ",
    "残忍な": "ラッシュ",
    "デマンド": "供給",
    "否定する": "認める",
    "拒絶する": "受け入れる",
    "依存": "独立した",
    "保証金": "撤退する",
    "減価償却費": "感謝",
    "落ち込む": "陽気な",
    "降下する": "上昇する",
    "子孫": "祖先",
    "降下": "上昇",
    "記述的な": "規範的",
    "望ましい": "望ましくない",
    "絶望": "決定",
    "絶望的な": "希望",
    "破壊されました": "保存された",
    "デタッチ": "付ける",
    "偏重": "進化",
    "異なる": "類似",
    "不等": "等しい",
    "差": "同一性",
    "難しい": "通行可能な",
    "不安": "セキュリティ",
    "困難": "容易に",
    "勤勉な": "過失",
    "希釈": "濃度",
    "分布": "濃度",
    "汚れた": "クリーン",
    "無効にする": "有効にする",
    "不利益": "利点",
    "同意しない": "同意する",
    "嫌な": "楽しい",
    "不一致": "一貫性",
    "消滅": "外観",
    "不承認": "承認する",
    "武装解除する": "腕",
    "放電": "参加する",
    "放棄する": "請求",
    "失う": "見つける",
    "不快": "楽しい",
    "切断する": "接続する",
    "不満": "満足",
    "中止": "継続",
    "中止します": "持続する",
    "不連続": "連続",
    "不連続な": "連続",
    "落胆する": "奨励します",
    "落胆": "奨励",
    "離れる": "到着する",
    "不正直な": "正直な",
    "不正": "正義",
    "不名誉": "名誉",
    "消毒する": "感染する",
    "崩壊する": "統合する",
    "離接": "結合的",
    "嫌い": "愛",
    "取り除く": "ロッジ",
    "不従順": "従順",
    "不従順な": "従う",
    "障害": "注文",
    "無秩序な": "秩序ある",
    "混乱した": "組織された",
    "組織化されていない": "組織された",
    "不快な": "喜んだ",
    "反証する": "証明する",
    "失格": "修飾する",
    "評判の悪い": "評判の良い",
    "評判が悪い": "評判",
    "無礼な": "丁寧",
    "異議": "同意する",
    "失礼": "サービス",
    "不協和音": "調和",
    "断る": "説得する",
    "遠位の": "近位の",
    "遠い": "閉じる",
    "開いた": "シャット",
    "識別可能な": "区別できない",
    "不信": "信頼",
    "一日": "夜行性の",
    "発散する": "収束する",
    "発散": "収束",
    "分ける": "団結する",
    "単独で": "かける",
    "分割された": "ユナイテッド",
    "割り切れる": "割り切れない",
    "国内の": "外国人",
    "ネイティブ": "外国人",
    "支配的": "下位",
    "休眠する": "アクティブ",
    "絶滅した": "現存",
    "非アクティブ": "アクティブ",
    "受動的": "アクティブ",
    "静か": "うるさい",
    "ダブル": "シングル",
    "複数": "特異な",
    "鳩": "鷹",
    "劇的": "歌詞",
    "ドライ": "湿った",
    "サワー": "甘い",
    "支払う": "過度の",
    "鈍い": "鋭く",
    "平らにする": "鋭く",
    "死んでいる": "新生",
    "容易に": "困難",
    "簡単": "不安",
    "控え目な": "潮",
    "偏心": "同心円の",
    "教育を受けた": "未教育",
    "効果的な": "効果がない",
    "効率": "非効率",
    "効率的な": "非効率的な",
    "出口": "入る",
    "弾性": "非弾性",
    "適格": "不適格",
    "感情の": "大脳",
    "経験的": "理論的",
    "空虚": "充満",
    "空の": "満員",
    "薄いです": "厚く",
    "有効にする": "無効にする",
    "奨励します": "落胆する",
    "奨励": "落胆",
    "終わり": "始まり",
    "エンディング": "始まり",
    "中間": "早い",
    "風土病": "コスモポリタン",
    "州": "コスモポリタン",
    "エネルギッシュな": "無気力",
    "強制する": "免除する",
    "従事する": "離れる",
    "入る": "出口",
    "等しい": "不等",
    "平等": "不平等",
    "赤道": "極地",
    "公平な": "不公平な",
    "不確かな": "明白な",
    "消去する": "記録",
    "確立します": "廃止する",
    "多忙な": "平凡な",
    "常緑": "落葉",
    "進化": "偏重",
    "除外": "包含",
    "免除する": "強制する",
    "吐き出す": "吸入する",
    "存在する": "存在しない",
    "拡大する": "契約する",
    "拡張された": "契約した",
    "拡張": "屈曲",
    "期待される": "予想外の",
    "高価な": "安いです",
    "経験豊富な": "経験の浅い",
    "輸出する": "インポート",
    "表現する": "地元",
    "全国": "国際",
    "外部": "内部",
    "外部から": "内部的に",
    "消す": "着火する",
    "室外": "学内の",
    "特別な": "普通の",
    "外因性": "固有の",
    "失敗する": "通過",
    "ランニング": "立っている",
    "失敗": "成功",
    "フェア": "不公正",
    "忠実な": "不誠実な",
    "秋": "上昇",
    "セット": "上昇",
    "虚弱": "間違いのない",
    "落下": "上昇する",
    "虚偽": "真実",
    "名声": "汚名",
    "身近な": "未知",
    "ファンシー": "プレーン",
    "脂肪": "薄いです",
    "満員": "空の",
    "厚い": "薄いです",
    "厚く": "薄いです",
    "お父さん": "母",
    "動物相": "フローラ",
    "有利な": "不利な",
    "連邦": "ユニタリー",
    "女性": "男性",
    "フェミニン": "中性",
    "女性性": "男性性",
    "肥沃な": "無菌",
    "忠実": "不倫",
    "数字": "接地",
    "埋める": "空の",
    "見つける": "失う",
    "仕上げ": "開始",
    "やめる": "開始",
    "有限": "無限",
    "火災": "雇う",
    "屈曲": "拡張",
    "浮く": "シンク",
    "ソース": "シンク",
    "フローラ": "動物相",
    "フォーカス": "ぼかし",
    "敵": "友人",
    "倍": "展開する",
    "フォローする": "先行する",
    "成功する": "先行する",
    "フォロワー": "リーダー",
    "愚かな": "インテリジェンス",
    "足": "頭",
    "尾": "頭",
    "禁じる": "許可",
    "前": "後部",
    "前景": "バックグラウンド",
    "外国人": "ネイティブ",
    "忘れる": "思い出す",
    "許す": "容赦のない",
    "形式主義": "模倣",
    "幸運な": "不運",
    "表面": "オーバーヘッド",
    "ファウル": "フェア",
    "不公正": "フェア",
    "見つけた": "失われた",
    "兄弟": "同一",
    "フリーズする": "煮る",
    "頻繁な": "まれな",
    "頻繁に": "まれに",
    "友人": "敵",
    "頭": "尾",
    "充満": "空虚",
    "機能的": "オーガニック",
    "無機": "オーガニック",
    "利得": "損失",
    "ガス状": "固体",
    "中空": "固体",
    "ギャザー": "普及",
    "一般性": "特殊性",
    "寛大な": "刺青",
    "女の子": "男の子",
    "良い": "悪の",
    "良さ": "不良",
    "徐々に": "突然",
    "感謝する": "恩知らず",
    "緑": "熟した",
    "キモい": "ネット",
    "接地": "数字",
    "罪悪感": "イノセンス",
    "有罪": "無実",
    "幸せに": "悲しいことに",
    "幸福": "不幸",
    "ハッピー": "不幸",
    "硬度": "柔らかさ",
    "ラウドネス": "柔らかさ",
    "シャープネス": "柔らかさ",
    "調和": "不協和音",
    "憎む": "愛らしい",
    "鷹": "鳩",
    "健康": "不健康",
    "聴覚": "聴覚障害者",
    "熱": "クール",
    "天": "地上の",
    "異質性": "同質性",
    "隠す": "ショー",
    "雇う": "火災",
    "ヒット": "ミス",
    "聖なる": "神聖な",
    "同質性": "異質性",
    "同種の": "類似",
    "同性愛者": "バイセクシュアル",
    "正直な": "不正直な",
    "正直": "不正",
    "名誉": "不名誉",
    "希望": "絶望的な",
    "水平": "垂直",
    "敵対的な": "フレンドリーな",
    "不親切": "種類",
    "ホット": "コールド",
    "謙虚な": "誇りに思う",
    "謙虚": "誇り",
    "空腹": "渇いた",
    "同一": "兄弟",
    "アイドル": "作業",
    "火星": "水性",
    "着火する": "消す",
    "無視する": "通知",
    "違法": "合法的",
    "判読不能な": "読みやすい",
    "不合理な": "ラショナル",
    "模倣": "形式主義",
    "重要ではない": "材料",
    "未熟": "成熟",
    "計り知れない": "測定可能な",
    "不道徳な": "道徳",
    "不道徳": "道徳",
    "不滅の": "死ぬ",
    "不死": "死亡",
    "不変": "変更可能な",
    "公平": "偏見",
    "焦り": "忍耐",
    "せっかち": "患者",
    "知覚できない": "知覚可能な",
    "不完全": "完璧",
    "不浸透性": "透過性の",
    "許されない": "許される",
    "人間的でない": "個人的",
    "インポート": "輸出する",
    "重要": "重要でない",
    "不可能": "可能性",
    "無力": "強力な",
    "思いもよらない": "可能性のある",
    "改善された": "改善されていない",
    "改善": "低下",
    "慎重な": "慎重な",
    "不純物": "純度",
    "無能": "能力",
    "アクセスできない": "アクセス可能な",
    "不正確": "正確",
    "無反応": "アクション",
    "不活動": "アクティビティ",
    "不十分な": "十分な",
    "容認できない": "許容可能な",
    "生きていない": "アニメーション化する",
    "不注意": "思慮深い",
    "聞き取れない": "可聴",
    "不可能な": "可能な",
    "傾斜": "水平",
    "垂直": "斜めの",
    "包含": "除外",
    "インコヒーレントな": "コヒーレントな",
    "互換性のない": "互換性のある",
    "無能な": "有能な",
    "不完全さ": "完全",
    "目立たない": "目立つ",
    "不便": "便利",
    "増加する": "減少",
    "増加した": "減少した",
    "インクリメント": "デクリメント",
    "不治の": "硬化可能な",
    "卑劣な": "まともな",
    "決定的ではない": "決定的",
    "独立した": "依存",
    "区別できない": "識別可能な",
    "割り切れない": "割り切れる",
    "屋内": "屋外",
    "効果がない": "効果的な",
    "非効率": "効率",
    "非効率的な": "効率的な",
    "非弾性": "弾性",
    "不適格": "適格",
    "不平等": "平等",
    "不公平な": "公平な",
    "経験の浅い": "経験豊富な",
    "間違いのない": "虚弱",
    "汚名": "名声",
    "感染する": "消毒する",
    "下位": "支配的",
    "劣等": "優位",
    "不倫": "忠実",
    "無限": "有限",
    "インフレーション": "デフレ",
    "知らされた": "知らない",
    "まれな": "頻繁な",
    "まれに": "頻繁に",
    "入り口": "出口",
    "住む": "無人",
    "吸入する": "吐き出す",
    "内陸": "沿岸の",
    "イノセンス": "罪悪感",
    "無実": "有罪",
    "無害な": "有害な",
    "動作不能": "手術",
    "狂人": "元気",
    "狂気": "正気",
    "無意味": "意義",
    "些細な": "重要な",
    "不溶性": "可溶性",
    "倒産": "ソルベンシー",
    "支払不能": "溶媒",
    "不安定": "落ち着いた",
    "道具": "ボーカル",
    "不足": "十分",
    "不十分": "十分",
    "不十分に": "十分に",
    "統合する": "崩壊する",
    "統合": "分離",
    "インテリジェンス": "愚かな",
    "理解可能な": "理解不能な",
    "意図されました": "意図しない",
    "故意に": "無意識のうちに",
    "興味がある": "無関心",
    "面白い": "興味深い",
    "インテリア": "外観",
    "中間体": "ターミナル",
    "内部": "外部",
    "内部的に": "外部から",
    "国際": "全国",
    "地元": "一般",
    "不寛容": "耐性",
    "寛容な": "耐性のある",
    "扱いにくい": "扱いやすい",
    "学内の": "室外",
    "固有の": "外因性",
    "不可視": "可視性",
    "目に見えない": "目に見える",
    "不随意の": "自発的",
    "不規則な": "定期的",
    "不規則": "規則性",
    "無関係": "関連する",
    "無責任な": "責任ある",
    "不平": "敬虔な",
    "問題": "想起",
    "ジョイント": "別々の",
    "喜び": "悲しみ",
    "楽しげ": "悲しい",
    "ジュニア": "上級",
    "正義": "不正",
    "少年": "大人",
    "カーン": "カーン",
    "種類": "不親切",
    "キング": "女王",
    "信徒": "聖職者",
    "遅く": "早い",
    "笑い": "泣く",
    "合法的": "違法",
    "怠惰": "時制",
    "リラックスした": "時制",
    "素人": "牧師",
    "鉛": "赤字",
    "リーダー": "フォロワー",
    "左": "センター",
    "法的": "違法",
    "合法性": "違法",
    "合法化する": "無法者",
    "読みやすい": "判読不能な",
    "貸す": "かりて",
    "貸し手": "借り手",
    "長くする": "短くする",
    "小さい": "大",
    "無気力": "エネルギッシュな",
    "レベル": "上げる",
    "低い": "上げる",
    "リベラル": "保守的な",
    "嘘つき": "スタンド",
    "産出": "スタンド",
    "光": "ダーク",
    "明度": "重さ",
    "好み": "嫌い",
    "限られた": "無制限",
    "線形": "担保",
    "液体": "ガス状",
    "固体": "中空",
    "特定": "一般",
    "ロケーション": "スタジオ",
    "ロック": "ロック解除する",
    "ロッジ": "取り除く",
    "論理的": "不合理な",
    "長いです": "ショート",
    "背の高い": "ショート",
    "緩む": "強化する",
    "損失": "利得",
    "失われた": "見つけた",
    "愛らしい": "憎む",
    "愛": "嫌い",
    "歌詞": "劇的",
    "メジャー": "マイナー",
    "多数": "少数",
    "作る": "ブレーク",
    "修復": "ブレーク",
    "男性": "女性",
    "悪魔": "良性",
    "悪性": "良性",
    "マニュアル": "自動",
    "マークされた": "マークされていない",
    "既婚": "未婚",
    "男性的": "フェミニン",
    "男性性": "女性性",
    "マスク": "アンマスク",
    "材料": "重要ではない",
    "母性": "父親",
    "成熟": "未熟",
    "最大": "最小",
    "測定可能な": "計り知れない",
    "精神的な": "物理的",
    "慈悲深い": "無慈悲な",
    "無慈悲な": "慈悲深い",
    "軍事": "文民",
    "マインド": "忘れる",
    "思い出す": "忘れる",
    "最小": "最大",
    "マイナー": "メジャー",
    "少数": "多数",
    "誤解": "概念",
    "ミス": "ヒット",
    "大臼歯": "分子",
    "分子": "大臼歯",
    "道徳": "不道徳",
    "死ぬ": "不滅の",
    "死亡": "不死",
    "母": "お父さん",
    "かける": "単独で",
    "団結する": "分ける",
    "天底": "天頂",
    "狭い": "広げる",
    "新生": "死んでいる",
    "負": "中性",
    "過失": "勤勉な",
    "甥": "姪",
    "ネット": "キモい",
    "姪": "甥",
    "夜": "日",
    "夜行性の": "一日",
    "公称": "リアル",
    "非現実的": "現実的な",
    "存在しない": "存在する",
    "正常": "異常な",
    "通知": "無視する",
    "有害な": "無害な",
    "数値": "口頭",
    "従順": "不従順",
    "従順な": "不従順な",
    "従う": "不従順な",
    "目的": "主観的",
    "義務的な": "オプション",
    "斜めの": "垂直",
    "あいまい": "プロミネンス",
    "不透明度": "透明性",
    "占領された": "占領されていない",
    "犯罪": "防衛",
    "公式": "非公式",
    "開放性": "親密さ",
    "手術": "動作不能",
    "反対": "対抗しない",
    "反対の": "代わりの",
    "楽観": "悲観主義",
    "楽観主義者": "悲観主義者",
    "オプション": "義務的な",
    "オーラル": "肛門",
    "注文": "障害",
    "秩序ある": "無秩序な",
    "普通の": "特別な",
    "オーガニック": "無機",
    "組織された": "組織化されていない",
    "正統": "正統",
    "屋外": "屋内",
    "無法者": "合法化する",
    "過大評価する": "過小評価する",
    "オーバーヘッド": "表面",
    "明白な": "不確かな",
    "パック": "アンパック",
    "痛い": "痛みのない",
    "痛みのない": "痛い",
    "平行": "斜めの",
    "親": "子",
    "偏見": "公平",
    "特殊性": "一般性",
    "部分的に": "完全に",
    "通行可能な": "難しい",
    "通過": "ランニング",
    "立っている": "ランニング",
    "過去": "未来",
    "プレゼント": "不在",
    "父親": "母性",
    "忍耐": "焦り",
    "患者": "せっかち",
    "ひいきにする": "ボイコット",
    "平和": "戦争",
    "ペナルティ": "褒賞",
    "知覚可能な": "知覚できない",
    "完璧": "不完全",
    "透過性の": "不浸透性",
    "許される": "許されない",
    "許容的": "予防的",
    "許可": "禁じる",
    "個人的": "人間的でない",
    "説得する": "断る",
    "悲観主義": "楽観",
    "悲観主義者": "楽観主義者",
    "物理的": "精神的な",
    "プレーン": "ファンシー",
    "原告": "被告",
    "喜んだ": "不快な",
    "極地": "赤道",
    "丁寧": "無礼な",
    "人気": "人気がない",
    "空隙率": "固い",
    "可能性": "不可能",
    "強力な": "力のない",
    "潜在的な": "実際の",
    "貧困": "富",
    "力のない": "強力な",
    "賞賛": "批判する",
    "プレフィックス": "サフィックス",
    "準備": "解決",
    "準備された": "準備ができていない",
    "規範的": "記述的な",
    "存在": "不在",
    "保存された": "破壊されました",
    "予防的": "許容的",
    "一次": "二次的",
    "プライベート": "パブリック",
    "私的に": "公然と",
    "可能性のある": "思いもよらない",
    "生産的な": "非生産的",
    "不敬": "神聖",
    "専門家": "アマチュア",
    "進捗": "回帰",
    "プログレッシブ": "退行性の",
    "将来": "回顧",
    "保護された": "保護されていない",
    "誇りに思う": "謙虚な",
    "証明する": "反証する",
    "近位の": "遠位の",
    "近接": "究極",
    "パブリック": "プライベート",
    "公然と": "私的に",
    "出版された": "未発表",
    "引く": "押す",
    "時間厳守": "遅刻",
    "パージ": "リハビリ",
    "純度": "不純物",
    "押す": "引く",
    "修飾する": "失格",
    "女王": "キング",
    "質問": "回答",
    "疑わしい": "疑いのない",
    "早く": "ゆっくり",
    "上げる": "低い",
    "ラショナル": "不合理な",
    "リアル": "非現実的",
    "現実的な": "非現実的",
    "安心する": "心配",
    "想起": "問題",
    "記録": "消去する",
    "控える": "行為",
    "ごみ": "受け入れる",
    "回帰": "進捗",
    "退行性の": "プログレッシブ",
    "定期的": "不規則な",
    "規則性": "不規則",
    "規制された": "規制されていない",
    "リハビリ": "パージ",
    "拒絶": "受け入れ",
    "若返らせる": "年齢",
    "関連する": "無関係",
    "相対": "絶対の",
    "信頼性のある": "信頼できない",
    "宗教的": "世俗的な",
    "反発": "アトラクション",
    "評判の良い": "評判の悪い",
    "評判": "評判が悪い",
    "レジスト": "降伏",
    "解決": "準備",
    "尊敬": "無礼な",
    "尊敬する": "無礼な",
    "責任ある": "無責任な",
    "拘束された": "無制限の",
    "制限された": "無制限の",
    "回顧": "将来",
    "敬虔な": "不平",
    "逆転": "肯定",
    "褒賞": "ペナルティ",
    "ライド": "歩く",
    "熟した": "緑",
    "ローター": "ステータ",
    "粗さ": "滑らかさ",
    "円形": "平方",
    "丸みを帯びた": "角張った",
    "農村": "都市",
    "ラッシュ": "残忍な",
    "神聖": "不敬",
    "悲しいことに": "幸せに",
    "悲しみ": "喜び",
    "不幸": "ハッピー",
    "安全": "危険な",
    "安全性": "危険",
    "同一性": "差",
    "元気": "狂人",
    "正気": "狂気",
    "満足": "不満",
    "おいしい": "味のない",
    "乏しい": "豊富",
    "希少": "豊富",
    "科学的": "非科学的",
    "綿密な": "悪意のある",
    "二次的": "一次",
    "世俗的な": "宗教的",
    "セキュリティ": "不安",
    "分離": "連合",
    "利己的": "非自己",
    "売る": "購入",
    "上級": "ジュニア",
    "別々の": "ジョイント",
    "敗血症": "消毒剤",
    "サービス": "失礼",
    "鋭く": "平らにする",
    "ショート": "背の高い",
    "短くする": "長くする",
    "叫ぶ": "ささやき",
    "ショー": "隠す",
    "シュリンク": "ストレッチ",
    "側": "下",
    "上": "下",
    "意義": "無意味",
    "重要な": "些細な",
    "単純": "化合物",
    "簡略化する": "複雑にする",
    "シングル": "複数",
    "特異な": "複数",
    "シンク": "ソース",
    "シスター": "兄",
    "睡眠": "目覚め",
    "ゆっくり": "早く",
    "滑らかさ": "粗さ",
    "柔らかさ": "シャープネス",
    "固い": "空隙率",
    "可溶性": "不溶性",
    "ソルベンシー": "倒産",
    "溶媒": "支払不能",
    "息子": "娘",
    "悲しい": "楽しげ",
    "話された": "書かれた",
    "書かれていない": "書かれた",
    "散発的な": "継続的",
    "普及": "ギャザー",
    "平方": "円形",
    "安定": "不安定",
    "安定した": "不安定な",
    "スタンド": "産出",
    "開始": "やめる",
    "ステータ": "ローター",
    "滞在": "動く",
    "安定しました": "不安定な",
    "急な": "徐々に",
    "突然": "徐々に",
    "無菌": "肥沃な",
    "強化する": "緩む",
    "刺青": "寛大な",
    "嵐": "落ち着いた",
    "まっすぐ": "湾曲した",
    "まっすぐにする": "曲げる",
    "ストレンジャー": "知り合い",
    "力": "弱点",
    "ストレッチ": "シュリンク",
    "強く": "弱く",
    "スタジオ": "ロケーション",
    "主観的": "目的",
    "その後の": "先行する",
    "実質的な": "形容詞",
    "減算": "添加",
    "成功": "失敗",
    "成功した": "失敗した",
    "負ける": "生き残ります",
    "苦しむ": "楽しい",
    "十分": "不十分",
    "十分に": "不十分に",
    "サフィックス": "プレフィックス",
    "日の出": "日没",
    "日没": "日の出",
    "優れました": "下位",
    "優位": "劣等",
    "供給": "デマンド",
    "サポートされる": "サポートされていない",
    "降伏": "レジスト",
    "生き残ります": "負ける",
    "甘い": "サワー",
    "湿った": "ドライ",
    "対称": "非対称",
    "同情的な": "異教徒",
    "相乗的な": "敵対的",
    "合成": "分析的",
    "遅刻": "時間厳守",
    "味わい深い": "味のない",
    "味のない": "おいしい",
    "入札": "タフ",
    "時制": "リラックスした",
    "ターミナル": "中間体",
    "有神論": "無神論",
    "理論的": "経験的",
    "渇いた": "空腹",
    "思慮のない": "思慮深い",
    "倹約": "無駄な",
    "潮": "控え目な",
    "ネクタイ": "アンティ",
    "臆病な": "大胆な",
    "耐性": "不寛容",
    "耐性のある": "寛容な",
    "歯を付ける": "無駄な",
    "無駄な": "倹約",
    "触れた": "手つかず",
    "タフ": "入札",
    "扱いやすい": "扱いにくい",
    "悲劇": "コメディー",
    "訓練された": "訓練されていない",
    "信頼": "不信",
    "真実": "虚偽",
    "醜さ": "美しさ",
    "醜い": "綺麗な",
    "究極": "近接",
    "未確認の": "認められた",
    "変更なし": "変更されました",
    "曖昧でない": "あいまいな",
    "非武装の": "武装した",
    "無許可": "承認された",
    "アンバランス": "バランス",
    "不信仰": "信念",
    "アンバウンド": "バウンド",
    "破られない": "壊れる",
    "破られていない": "壊れた",
    "不確実性": "確実",
    "変更不可能な": "変更可能な",
    "変わらない": "かわった",
    "叔父": "叔母",
    "珍しい": "通常の",
    "無関心": "興味がある",
    "未確認": "確認済み",
    "未接続": "接続された",
    "無意識": "意識",
    "違憲": "憲法",
    "独創的ではない": "従来の",
    "確信していない": "確信している",
    "明らかにする": "カバー",
    "未加工": "カット",
    "未定義": "定義された",
    "過小評価する": "過大評価する",
    "望ましくない": "望ましい",
    "過度の": "支払う",
    "未教育": "教育を受けた",
    "平凡な": "多忙な",
    "予想外の": "期待される",
    "不誠実な": "忠実な",
    "未知": "身近な",
    "不利な": "有利な",
    "展開する": "倍",
    "容赦のない": "許す",
    "残念な": "幸運な",
    "恩知らず": "感謝する",
    "不健康": "健康",
    "神聖な": "聖なる",
    "重要でない": "重要",
    "改善されていない": "改善された",
    "知らない": "知らされた",
    "無人": "住む",
    "理解不能な": "理解可能な",
    "意図しない": "意図されました",
    "無意識のうちに": "故意に",
    "興味深い": "面白い",
    "連合": "分離",
    "ユニタリー": "連邦",
    "ユナイテッド": "分割された",
    "無制限": "限られた",
    "ロック解除する": "ロック",
    "不運": "幸運な",
    "マークされていない": "マークされた",
    "未婚": "既婚",
    "アンマスク": "マスク",
    "占領されていない": "占領された",
    "非公式": "公式",
    "対抗しない": "反対",
    "アンパック": "パック",
    "人気がない": "人気",
    "準備ができていない": "準備された",
    "非生産的": "生産的な",
    "保護されていない": "保護された",
    "未発表": "出版された",
    "疑いのない": "疑わしい",
    "規制されていない": "規制された",
    "信頼できない": "信頼性のある",
    "無制限の": "制限された",
    "不愉快な": "おいしい",
    "非科学的": "科学的",
    "悪意のある": "綿密な",
    "非自己": "利己的",
    "不安定な": "安定しました",
    "失敗した": "成功した",
    "サポートされていない": "サポートされる",
    "異教徒": "同情的な",
    "アンティ": "ネクタイ",
    "手つかず": "触れた",
    "訓練されていない": "訓練された",
    "発表する": "ベール",
    "不本意な": "注意深い",
    "不本意ながら": "喜んで",
    "不本意": "意欲",
    "くつろげる": "風",
    "価値のない": "価値がある",
    "都市": "農村",
    "通常の": "珍しい",
    "貴重な": "役に立たない",
    "ベール": "発表する",
    "口頭": "数値",
    "勝利": "敗北",
    "善良な": "邪悪な",
    "可視性": "不可視",
    "目に見える": "目に見えない",
    "ボーカル": "道具",
    "自発的": "不随意の",
    "母音": "子音",
    "目覚め": "睡眠",
    "歩く": "ライド",
    "衰える": "ワックス",
    "戦争": "平和",
    "注意深い": "不本意な",
    "廃棄物": "節約する",
    "ワックス": "衰える",
    "弱く": "強く",
    "弱点": "力",
    "富": "貧困",
    "無重力": "重い",
    "重い": "無重力",
    "ささやき": "叫ぶ",
    "白": "黒",
    "完全に": "部分的に",
    "邪悪な": "善良な",
    "ワイド": "狭い",
    "広げる": "狭い",
    "喜んで": "不本意ながら",
    "意欲": "不本意",
    "風": "くつろげる",
    "知恵": "愚かな",
    "賢い": "愚かな",
    "撤退する": "保証金",
    "心配": "安心する",
    "役に立たない": "貴重な",
    "価値がある": "価値のない",
    "書かれた": "書かれていない",
    "若い": "老人",
    "天頂": "天底",
}
