_antonyms = {
    "abilitate": "incapacitate",
    "anormal": "normal",
    "aboli": "a stabili",
    "absență": "prezenţă",
    "absent": "prezent",
    "viitor": "retrospectiv",
    "absolut": "relativ",
    "abține": "act",
    "abstract": "beton",
    "abundenţă": "raritate",
    "abundent": "rar",
    "accept": "respinge",
    "admite": "nega",
    "acceptabil": "de netrecut",
    "acceptare": "respingere",
    "accesibil": "inaccesibil",
    "precis": "ambiguu",
    "recunoscut": "nerecunoscut",
    "cunoștință": "străin",
    "act": "abține",
    "acțiune": "inacțiune",
    "activ": "liniște",
    "existent": "inexistent",
    "zgomotos": "liniște",
    "activitate": "inactivitate",
    "real": "ireal",
    "adăuga": "scădea",
    "plus": "scădere",
    "adecvat": "neadecvat",
    "adjectiv": "substantiv",
    "admisibil": "inadmisibil",
    "adult": "juvenil",
    "avans": "retrage",
    "înainte": "înapoi",
    "față": "spate",
    "a-și schimba direcția": "înapoi",
    "avantaj": "dezavantaj",
    "afirmare": "inversare",
    "afirmativ": "negativ",
    "neutru": "feminin",
    "la pupă": "proră",
    "vârstă": "întineri",
    "în vârstă de": "tineri",
    "agitaţie": "calm",
    "de acord": "dezacord",
    "agreabil": "dezagreabil",
    "acord": "dezacord",
    "modificată": "neschimbat",
    "alterna": "opus",
    "amator": "profesional",
    "ambiguu": "precis",
    "amical": "ostil",
    "prietenos": "neprietenos",
    "amfibiu": "terestru",
    "anal": "oral",
    "analog": "omolog",
    "analiză": "sinteză",
    "analitic": "sintetic",
    "strămoş": "descendent",
    "unghiular": "rotunjit",
    "anima": "neînsufleţit",
    "răspuns": "întrebare",
    "antagonic": "sinergică",
    "antecedente": "ulterior",
    "anterior": "posterior",
    "antiseptic": "septic",
    "aspect": "dispariție",
    "apreciere": "depreciere",
    "aprobare": "dezaprobare",
    "aproba": "dezaproba",
    "acvatic": "amfibiu",
    "terestru": "amfibiu",
    "apos": "de foc",
    "braţ": "dezarma",
    "armat": "neînarmat",
    "ajunge": "părăsi",
    "urca": "coborî",
    "ascensiune": "coborâre",
    "adormit": "treaz",
    "consimțământ": "disidență",
    "asimetrie": "simetrie",
    "ateism": "teismului",
    "atașa": "desprinde",
    "atac": "apăra",
    "urmări în justiție": "apăra",
    "atenţie": "neatenţie",
    "atracţie": "repulsie",
    "perceptibil": "imperceptibil",
    "augmentare": "diminuare",
    "mătuşă": "unchi",
    "autorizat": "neautorizat",
    "automat": "manual",
    "evita": "confrunta",
    "treaz": "adormit",
    "înapoi": "redirecţiona",
    "retrage": "depozit",
    "spate": "cap",
    "fundal": "prim plan",
    "verso": "avers",
    "rău": "virtuos",
    "proastă calitate": "bunătate",
    "echilibrat": "dezechilibrat",
    "urs": "taur",
    "frumoasa": "urât",
    "frumuseţe": "urâţenie",
    "începe": "sfârşit",
    "început": "mijloc",
    "din timp": "târziu",
    "credință": "necredinţă",
    "îndoire": "îndrepta",
    "benign": "maligne",
    "mare": "mic",
    "naștere": "moarte",
    "bisexuat": "homosexual",
    "negru": "alb",
    "binecuvânta": "blestem",
    "binecuvântat": "blestemat",
    "fără vlagă": "sângeros",
    "sângeros": "fără vlagă",
    "estompa": "concentra",
    "a fierbe": "îngheţa",
    "îndrăzneţ": "timid",
    "îndrăzneală": "timiditate",
    "împrumuta": "a împrumuta",
    "debitor": "creditor",
    "fund": "top",
    "legat": "nelegat",
    "băiat": "fată",
    "boicota": "patrona",
    "pauză": "reparație",
    "casant": "incasabil",
    "lumina": "întuneca",
    "uşura": "dificultate",
    "spart": "neîntrerupt",
    "frate": "soră",
    "taur": "urs",
    "ocupat": "neocupat",
    "muncă": "inactiv",
    "a cumpara": "vinde",
    "calm": "agitaţie",
    "capabil": "incapabil",
    "capacitate": "incapacitate",
    "bani gheata": "credit",
    "debit": "credit",
    "centru": "stânga",
    "cerebral": "emoţional",
    "certitudine": "incertitudine",
    "schimbare": "stau",
    "pleca": "stau",
    "mișcare": "stau",
    "schimbător": "egal",
    "schimbat": "neschimbat",
    "încărca": "descărcare",
    "înrola": "descărcare",
    "ieftin": "scump",
    "ridica moralul": "plânge",
    "bine dispus": "deprimant",
    "copil": "mamă",
    "civil": "militar",
    "revendicare": "pierdut",
    "claritate": "opacitate",
    "proeminenţă": "obscuritate",
    "transparenţă": "opacitate",
    "curat": "necurat",
    "cler": "laici",
    "cleric": "laic",
    "închide": "deschis",
    "închis": "deschis",
    "apropiere": "sinceritate",
    "de coastă": "interior",
    "coerent": "incoerent",
    "rece": "fierbinte",
    "colateral": "descinzând direct",
    "comedie": "tragedie",
    "confort": "disconfort",
    "comun": "extraordinar",
    "compatibil": "incompatibil",
    "competență": "incompetenţă",
    "competent": "incompetent",
    "competiție": "cooperare",
    "plânge": "ridica moralul",
    "deplinătate": "incompletitudine",
    "complex": "simplu",
    "compus": "simplu",
    "conforme": "sfidător",
    "complica": "simplifica",
    "concav": "convex",
    "vanitate": "umilinţă",
    "mândrie": "umilinţă",
    "concentraţie": "distribuire",
    "concentric": "excentric",
    "concepţie": "neînțelegere",
    "îngrijorat": "indiferent",
    "beton": "abstract",
    "confirmat": "neconfirmat",
    "confrunta": "evita",
    "conjunctiv": "disjunctiv",
    "conectați": "deconecta",
    "conectat": "neconectat",
    "constiinta": "inconştienţă",
    "conservator": "liberal",
    "conserva": "deşeuri",
    "grijuliu": "nechibzuit",
    "consistență": "incoerență",
    "consoană": "vocală",
    "evident": "inobservabil",
    "constituţional": "neconstituțional",
    "a consuma": "abține",
    "conţinut": "nemulţumire",
    "continuu": "discontinuu",
    "continuare": "întrerupere",
    "continua": "întrerupe",
    "continuitate": "discontinuitate",
    "contracta": "extinde",
    "contractat": "extins",
    "contracție": "expansiune",
    "convenabil": "incomod",
    "convenţional": "neconvențional",
    "converge": "diverge",
    "convergenţă": "divergenţă",
    "convergent": "divergent",
    "convex": "concav",
    "convins": "neconvins",
    "misto": "căldură",
    "cooperare": "competiție",
    "cosmopolit": "provincial",
    "curaj": "laşitate",
    "acoperi": "descoperi",
    "ascuns": "deschis",
    "laşitate": "curaj",
    "credit": "debit",
    "creditor": "debitor",
    "a critica": "laudă",
    "strigăt": "şoaptă",
    "vindecabil": "incurabil",
    "blestem": "binecuvânta",
    "blestemat": "binecuvântat",
    "curb": "drept",
    "a taia": "netăiat",
    "pericol": "siguranță",
    "periculos": "sigur",
    "întuneric": "lumină",
    "întuneca": "uşura",
    "greutate": "lumină",
    "fiică": "fiu",
    "zi": "noapte",
    "surd": "auz",
    "moarte": "născând",
    "decenţă": "indecenţă",
    "decent": "indecent",
    "cu frunze căzătoare": "vesnic verde",
    "decizie": "nehotărâre",
    "decisiv": "nehotărât",
    "declin": "ceară",
    "scădea": "adăuga",
    "scăzut": "a crescut",
    "decrementare": "creştere",
    "înfrângere": "victorie",
    "apăra": "urmări în justiție",
    "pârât": "reclamant",
    "apărare": "urmarire penala",
    "defensivă": "ofensator",
    "sfidător": "conforme",
    "deficit": "conduce",
    "definit": "nedefinit",
    "deflaţie": "umflare",
    "întârziere": "te grabesti",
    "persista": "te grabesti",
    "cerere": "livra",
    "nega": "admite",
    "respinge": "accept",
    "dependent": "independent",
    "depozit": "retrage",
    "depreciere": "apreciere",
    "deprimant": "bine dispus",
    "coborî": "urca",
    "descendent": "strămoş",
    "coborâre": "ascensiune",
    "descriptiv": "prescriptiv",
    "de dorit": "indezirabil",
    "disperare": "speranţă",
    "disperată": "speranţă",
    "desperare": "speranţă",
    "distrus": "conservat",
    "desprinde": "atașa",
    "transfer": "evoluţie",
    "diferi": "egal",
    "inegal": "egal",
    "diferență": "monotonie",
    "dificil": "uşor",
    "neliniștit": "uşor",
    "dificultate": "uşura",
    "harnic": "neglijent",
    "diluare": "concentraţie",
    "distribuire": "concentraţie",
    "diminuare": "augmentare",
    "murdar": "curat",
    "necurat": "curat",
    "dezactivați": "permite",
    "dezavantaj": "avantaj",
    "dezacord": "acord",
    "dezagreabil": "agreabil",
    "dispariție": "aspect",
    "dezaprobare": "aprobare",
    "dezaproba": "aproba",
    "dezarma": "braţ",
    "descărcare": "înrola",
    "repudia": "revendicare",
    "pierdut": "găsite",
    "disconfort": "confort",
    "deconecta": "conectați",
    "nemulţumire": "satisfacţie",
    "întrerupere": "continuare",
    "întrerupe": "continua",
    "discontinuitate": "continuitate",
    "discontinuu": "continuu",
    "descuraja": "convinge",
    "descurajare": "încurajare",
    "decupla": "angaja",
    "necinstit": "sincer",
    "necinste": "onestitate",
    "dezonoare": "reputaţie",
    "dezinfecta": "infecta",
    "dezintegra": "integra",
    "disjunctiv": "conjunctiv",
    "nu-i plăcea": "simpatie",
    "deplasa": "depune",
    "nesupunere": "ascultare",
    "neascultător": "ascultător",
    "nu se supune": "asculta",
    "tulburare": "ordin",
    "dezordonat": "ordonat",
    "dezorganizat": "organizat",
    "neorganizat": "organizat",
    "nemulțumit": "mulţumit",
    "demonstra falsitatea": "dovedi",
    "descalifica": "califica",
    "infamant": "cu reputație bună",
    "lipsă de respect": "respect",
    "nerespectuos": "respectuos",
    "disidență": "consimțământ",
    "deserviciu": "serviciu",
    "diferit": "asemănător",
    "disonanţă": "armonie",
    "distală": "proxim",
    "îndepărtat": "închide",
    "deschis": "ascuns",
    "neîncredere": "încredere",
    "diurn": "nocturn",
    "diverge": "converge",
    "divergenţă": "convergenţă",
    "divergent": "convergent",
    "divide": "uni",
    "unul câte unul": "multiplica",
    "împărțit": "unit",
    "divizibil": "indivizibil",
    "intern": "extern",
    "nativ": "străin",
    "dominant": "subordonat",
    "inactiv": "muncă",
    "dispărut": "existent",
    "pasiv": "activ",
    "liniște": "zgomotos",
    "dubla": "singur",
    "multiplu": "singur",
    "porumbel": "şoim",
    "dramatic": "liric",
    "uscat": "umed",
    "acru": "îndulci",
    "datorat": "nedrept",
    "plictisitor": "ascuţi",
    "aplatiza": "ascuţi",
    "pământesc": "ceresc",
    "uşor": "neliniștit",
    "reflux": "maree",
    "excentric": "concentric",
    "educat": "necultivat",
    "efectiv": "ineficace",
    "eficienţă": "ineficacitate",
    "eficient": "ineficace",
    "ieşire": "pătrundere",
    "elastic": "inelastică",
    "eligibil": "neeligibile",
    "emoţional": "cerebral",
    "empiric": "teoretic",
    "goliciune": "plenitudine",
    "gol": "solid",
    "subţire": "se îngroșa",
    "permite": "interzis",
    "a incuraja": "descuraja",
    "încurajare": "descurajare",
    "sfârşit": "început",
    "final": "proxim",
    "mijloc": "din timp",
    "endemic": "cosmopolit",
    "provincial": "cosmopolit",
    "energic": "letargic",
    "impune": "scuti",
    "angaja": "decupla",
    "se bucura": "suferi",
    "introduce": "ieșire",
    "egal": "schimbător",
    "egalitate": "inegalitate",
    "ecuatorial": "polar",
    "echitabil": "nedrept",
    "echivoc": "neechivoc",
    "şterge": "record",
    "a stabili": "aboli",
    "bogat în evenimente": "fără evenimente importante",
    "vesnic verde": "cu frunze căzătoare",
    "evoluţie": "transfer",
    "excludere": "includere",
    "scuti": "impune",
    "exala": "inhala",
    "ieșire": "introduce",
    "extinde": "contracta",
    "extins": "contractat",
    "expansiune": "contracție",
    "așteptat": "neașteptat",
    "scump": "ieftin",
    "cu experienta": "lipsit de experiență",
    "export": "import",
    "expres": "local",
    "general": "specific",
    "naţional": "internaţional",
    "extensie": "flexiune",
    "exterior": "interior",
    "extern": "intern",
    "a stinge": "aprinde",
    "extramural": "intramurale",
    "extraordinar": "comun",
    "extrinsecă": "intrinsec",
    "în lipsa": "trecere",
    "alergare": "permanent",
    "eșec": "succes",
    "credincios": "necredincios",
    "cădea": "creştere",
    "a stabilit": "creştere",
    "supus greșelii": "infailibil",
    "cădere": "în creștere",
    "falsitate": "adevăr",
    "faimă": "infamie",
    "familiar": "necunoscut",
    "extravagant": "simplu",
    "gras": "subţire",
    "deplin": "gol",
    "gros": "subţire",
    "se îngroșa": "subţire",
    "tată": "mamă",
    "faună": "floră",
    "favorabil": "nefavorabil",
    "federal": "unitar",
    "femeie": "masculin",
    "feminin": "neutru",
    "feminitate": "masculinitate",
    "fertil": "steril",
    "fidelitate": "infidelitate",
    "figura": "sol",
    "completati": "gol",
    "găsi": "pierde",
    "finalizarea": "start",
    "stop": "start",
    "finit": "infinit",
    "foc": "închiriere",
    "flexiune": "extensie",
    "pluti": "chiuvetă",
    "sursă": "chiuvetă",
    "floră": "faună",
    "concentra": "estompa",
    "duşman": "prieten",
    "plia": "desfășura",
    "urma": "preceda",
    "a reusi": "preceda",
    "adept": "lider",
    "nebunie": "sănătate psihică",
    "prostesc": "înţelept",
    "picior": "cap",
    "coadă": "cap",
    "interzis": "permite",
    "proră": "la pupă",
    "prim plan": "fundal",
    "străin": "cunoștință",
    "a uita": "tine minte",
    "iertător": "neiertat",
    "formalism": "imitaţie",
    "norocos": "ghinionist",
    "redirecţiona": "verso",
    "avers": "verso",
    "fault": "echitabil",
    "nedrept": "datorat",
    "găsite": "pierdut",
    "fratern": "identic",
    "îngheţa": "a fierbe",
    "frecvent": "rar",
    "des": "rar",
    "prieten": "duşman",
    "cap": "coadă",
    "plenitudine": "goliciune",
    "funcţional": "organic",
    "anorganic": "organic",
    "câştig": "pierderi",
    "gazos": "solid",
    "aduna": "răspândire",
    "generalitate": "particularitate",
    "generos": "zgârcit",
    "fată": "băiat",
    "bun": "rău",
    "bunătate": "proastă calitate",
    "treptat": "brusc",
    "recunoscător": "nerecunoscător",
    "mai mare": "mai puțin",
    "verde": "copt",
    "brut": "net",
    "sol": "figura",
    "vinovăţie": "nevinovăţie",
    "vinovat": "nevinovat",
    "fericit": "nefericit",
    "fericire": "nefericire",
    "duritate": "moliciune",
    "intensitate": "moliciune",
    "acuitate": "moliciune",
    "armonie": "disonanţă",
    "ură": "dragoste",
    "odios": "amabil",
    "şoim": "porumbel",
    "sănătos": "nesănătos",
    "auz": "surd",
    "căldură": "misto",
    "ceresc": "pământesc",
    "eterogenitate": "omogenitate",
    "ascunde": "spectacol",
    "închiriere": "foc",
    "lovit": "domnișoară",
    "sfânt": "nesfânt",
    "omogenitate": "eterogenitate",
    "omolog": "analog",
    "homosexual": "bisexuat",
    "sincer": "necinstit",
    "onestitate": "necinste",
    "onora": "dezonoare",
    "speranţă": "desperare",
    "plin de speranță": "fara speranta",
    "fara speranta": "plin de speranță",
    "orizontală": "vertical",
    "ostil": "prietenos",
    "neprietenos": "prietenos",
    "fierbinte": "rece",
    "umil": "mândru",
    "umilinţă": "mândrie",
    "flămând": "însetat",
    "identic": "fratern",
    "de foc": "apos",
    "aprinde": "a stinge",
    "ignora": "înștiințare",
    "ilegal": "legal",
    "nelegalitate": "legalitate",
    "ilizibil": "lizibil",
    "ilogic": "logic",
    "imitaţie": "formalism",
    "imaterial": "material",
    "imaturitate": "maturitate",
    "nemasurata": "măsurabil",
    "imoral": "morală",
    "imoralitate": "moralitate",
    "nemuritor": "muritor",
    "nemurire": "mortalitate",
    "imuabil": "mutabil",
    "imparţialitate": "părtinire",
    "de netrecut": "acceptabil",
    "nerăbdare": "răbdare",
    "nerăbdător": "rabdator",
    "imperceptibil": "perceptibil",
    "imperfecţiune": "perfecţiune",
    "impermeabil": "permeabil",
    "de nepermis": "permisibil",
    "impersonal": "personal",
    "nepoliticos": "politicos",
    "import": "export",
    "important": "neimportant",
    "imposibilitate": "posibilitate",
    "impotent": "puternic",
    "improbabil": "probabil",
    "îmbunătățit": "neamenajat",
    "îmbunătăţire": "declin",
    "imprudent": "prudent",
    "impuritate": "puritate",
    "incapacitate": "capacitate",
    "inaccesibil": "accesibil",
    "inexact": "precis",
    "inacțiune": "acțiune",
    "inactivitate": "activitate",
    "neadecvat": "adecvat",
    "inadmisibil": "admisibil",
    "neînsufleţit": "anima",
    "neatenţie": "atenţie",
    "abia auzit": "perceptibil",
    "incapabil": "capabil",
    "înclinat": "orizontală",
    "vertical": "orizontală",
    "includere": "excludere",
    "incoerent": "coerent",
    "incompatibil": "compatibil",
    "incompetenţă": "competență",
    "incompetent": "competent",
    "incompletitudine": "deplinătate",
    "nechibzuit": "grijuliu",
    "incoerență": "consistență",
    "inobservabil": "evident",
    "incomod": "convenabil",
    "crește": "scădea",
    "a crescut": "scăzut",
    "creştere": "a stabilit",
    "incurabil": "vindecabil",
    "indecenţă": "decenţă",
    "indecent": "decent",
    "nehotărâre": "decizie",
    "nehotărât": "decisiv",
    "independent": "dependent",
    "indivizibil": "divizibil",
    "de interior": "în aer liber",
    "ineficace": "eficient",
    "ineficacitate": "eficienţă",
    "inelastică": "elastic",
    "neeligibile": "eligibil",
    "inegalitate": "egalitate",
    "inechitabil": "echitabil",
    "lipsit de experiență": "cu experienta",
    "infailibil": "supus greșelii",
    "infamie": "faimă",
    "infecta": "dezinfecta",
    "inferior": "a ridica",
    "inferioritate": "superioritate",
    "infidelitate": "fidelitate",
    "infinit": "finit",
    "umflare": "deflaţie",
    "informat": "neinformat",
    "rar": "abundent",
    "pătrundere": "ieşire",
    "locuit": "nelocuit",
    "inhala": "exala",
    "nedreptate": "justiţie",
    "interior": "exterior",
    "nevinovăţie": "vinovăţie",
    "nevinovat": "vinovat",
    "inofensiv": "nociv",
    "inoperant": "operativ",
    "nebun": "normal",
    "nesiguranță": "securitate",
    "inconsistență": "semnificaţie",
    "nesemnificativ": "semnificativ",
    "insolubil": "solubil",
    "insolvabilitate": "solvabilitate",
    "insolvabil": "solvent",
    "instabilitate": "stabilitate",
    "instrumental": "vocal",
    "insuficienţă": "suficienta",
    "insuficient": "suficient",
    "integra": "dezintegra",
    "integrare": "segregare",
    "inteligență": "prostie",
    "inteligibil": "ininteligibil",
    "destinate": "neintenționate",
    "intentionat": "fara intentie",
    "interesat": "dezinteresați",
    "interesant": "neinteresant",
    "intermediar": "terminal",
    "internaţional": "naţional",
    "local": "general",
    "intoleranţă": "toleranţă",
    "intolerant": "tolerant",
    "intratabil": "maleabil",
    "intramurale": "extramural",
    "intrinsec": "extrinsecă",
    "invizibilitate": "vizibilitate",
    "invizibil": "vizibil",
    "involuntar": "voluntar",
    "iraţional": "raţional",
    "neregulat": "regulat",
    "neregularitate": "regularitate",
    "irelevant": "relevant",
    "iresponsabil": "responsabil",
    "ireverențios": "respectuos",
    "problema": "rechemare",
    "bucurie": "întristare",
    "vesel": "trist",
    "junior": "senior",
    "justiţie": "nedreptate",
    "juvenil": "adult",
    "țăran irlandez": "țăran irlandez",
    "drăguț": "aspru",
    "rege": "regină",
    "laici": "cler",
    "târziu": "din timp",
    "a rade": "strigăt",
    "legal": "ilegal",
    "lax": "încordat",
    "relaxat": "încordat",
    "laic": "religios",
    "conduce": "deficit",
    "lider": "adept",
    "părăsi": "ajunge",
    "stânga": "centru",
    "legalitate": "nelegalitate",
    "legaliza": "haiduc",
    "lizibil": "ilizibil",
    "a împrumuta": "împrumuta",
    "prelungi": "scurta",
    "mai puțin": "mai mare",
    "letargic": "energic",
    "nivel": "a ridica",
    "liberal": "conservator",
    "minciună": "stand",
    "randament": "stand",
    "ușoară": "întuneric",
    "lumină": "greutate",
    "simpatie": "nu-i plăcea",
    "limitat": "nelimitat",
    "descinzând direct": "colateral",
    "lichid": "gazos",
    "solid": "gol",
    "specific": "general",
    "locație": "studio",
    "blocare": "descuia",
    "depune": "deplasa",
    "logic": "ilogic",
    "lung": "mic de statura",
    "înalt": "mic de statura",
    "slăbi": "înțepeni",
    "pierde": "găsi",
    "pierderi": "câştig",
    "amabil": "odios",
    "dragoste": "ură",
    "liric": "dramatic",
    "major": "minor",
    "majoritate": "minoritate",
    "face": "pauză",
    "reparație": "pauză",
    "masculin": "feminin",
    "bârfi": "benign",
    "maligne": "benign",
    "manual": "automat",
    "marcat": "nemarcate",
    "căsătorit": "necăsătorit",
    "masculinitate": "feminitate",
    "masca": "demasca",
    "material": "imaterial",
    "matern": "patern",
    "maturitate": "imaturitate",
    "maxim": "minim",
    "măsurabil": "nemasurata",
    "mental": "fizic",
    "milostiv": "nemilos",
    "nemilos": "milostiv",
    "militar": "civil",
    "minte": "a uita",
    "tine minte": "a uita",
    "minim": "maxim",
    "minor": "major",
    "minoritate": "majoritate",
    "neînțelegere": "concepţie",
    "domnișoară": "lovit",
    "molar": "molecular",
    "molecular": "molar",
    "morală": "imoral",
    "moralitate": "imoralitate",
    "muritor": "nemuritor",
    "mortalitate": "nemurire",
    "mamă": "copil",
    "multiplica": "unul câte unul",
    "uni": "divide",
    "mutabil": "imuabil",
    "nadir": "zenit",
    "îngust": "largi",
    "născând": "moarte",
    "negativ": "neutru",
    "neglijent": "harnic",
    "nepot": "nepoată",
    "net": "brut",
    "nepoată": "nepot",
    "noapte": "zi",
    "nocturn": "diurn",
    "nominal": "real",
    "ireal": "real",
    "inexistent": "existent",
    "normal": "nebun",
    "înștiințare": "ignora",
    "nociv": "inofensiv",
    "numeric": "verbal",
    "ascultare": "nesupunere",
    "ascultător": "neascultător",
    "asculta": "nu se supune",
    "obiectiv": "subiectiv",
    "obligatoriu": "facultativ",
    "oblic": "perpendicular",
    "obscuritate": "proeminenţă",
    "opacitate": "transparenţă",
    "delict": "apărare",
    "urmarire penala": "apărare",
    "ofensator": "defensivă",
    "oficial": "neoficial",
    "sinceritate": "apropiere",
    "operativ": "inoperant",
    "opus": "alterna",
    "optimism": "pesimism",
    "optimist": "pesimist",
    "facultativ": "obligatoriu",
    "oral": "anal",
    "ordin": "tulburare",
    "ordonat": "dezordonat",
    "organic": "anorganic",
    "organizat": "neorganizat",
    "ortodox": "neortodox",
    "în aer liber": "de interior",
    "haiduc": "legaliza",
    "exagera": "subestima",
    "deasupra": "suprafaţă",
    "ambalaj": "despacheta",
    "dureros": "nedureros",
    "nedureros": "dureros",
    "paralel": "oblic",
    "perpendicular": "oblic",
    "părtinire": "imparţialitate",
    "particularitate": "generalitate",
    "parţial": "în întregime",
    "trecere": "alergare",
    "permanent": "alergare",
    "trecut": "viitor",
    "prezent": "absent",
    "patern": "matern",
    "răbdare": "nerăbdare",
    "rabdator": "nerăbdător",
    "patrona": "boicota",
    "pace": "război",
    "penalizare": "recompensă",
    "perfecţiune": "imperfecţiune",
    "permeabil": "impermeabil",
    "permisibil": "de nepermis",
    "permisiv": "preventiv",
    "personal": "impersonal",
    "convinge": "descuraja",
    "pesimism": "optimism",
    "pesimist": "optimist",
    "fizic": "mental",
    "simplu": "compus",
    "reclamant": "pârât",
    "placut": "neplăcut",
    "mulţumit": "nemulțumit",
    "plural": "singular",
    "polar": "ecuatorial",
    "politicos": "nepoliticos",
    "popular": "nepopular",
    "porozitate": "soliditate",
    "posibilitate": "imposibilitate",
    "posterior": "anterior",
    "puternic": "fără putere",
    "potenţial": "real",
    "sărăcie": "bogatie",
    "fără putere": "puternic",
    "laudă": "a critica",
    "preceda": "a reusi",
    "precedent": "reușind",
    "prefix": "sufix",
    "preparare": "rezoluţie",
    "pregătit": "nepregătit",
    "prescriptiv": "descriptiv",
    "prezenţă": "absență",
    "conservat": "distrus",
    "preventiv": "permisiv",
    "primar": "secundar",
    "privat": "public",
    "probabil": "improbabil",
    "productiv": "neproductiv",
    "profan": "sacru",
    "profesional": "amator",
    "progres": "regres",
    "progresiv": "regresiv",
    "protejat": "neprotejat",
    "mândru": "umil",
    "dovedi": "demonstra falsitatea",
    "proxim": "final",
    "prudent": "imprudent",
    "public": "privat",
    "publicat": "nepublicat",
    "trage": "apăsaţi",
    "punctualitate": "încetineală",
    "epurare": "reabilita",
    "puritate": "impuritate",
    "apăsaţi": "trage",
    "califica": "descalifica",
    "regină": "rege",
    "întrebare": "răspuns",
    "discutabil": "necontestat",
    "repede": "încet",
    "a ridica": "inferior",
    "raţional": "iraţional",
    "realist": "nerealiste",
    "reasigura": "face griji",
    "rechemare": "problema",
    "record": "şterge",
    "refuza": "accept",
    "regres": "progres",
    "regresiv": "progresiv",
    "regulat": "neregulat",
    "regularitate": "neregularitate",
    "reglementate": "nereglementat",
    "reabilita": "epurare",
    "respingere": "acceptare",
    "întineri": "vârstă",
    "legate de": "fără legătură",
    "relativ": "absolut",
    "relevant": "irelevant",
    "de încredere": "nedemn de încredere",
    "religios": "laic",
    "repulsie": "atracţie",
    "cu reputație bună": "infamant",
    "reputaţie": "dezonoare",
    "a rezista": "predare",
    "rezoluţie": "preparare",
    "respect": "lipsă de respect",
    "respectuos": "ireverențios",
    "responsabil": "iresponsabil",
    "reținut": "nestăpânit",
    "restrâns": "fără restricții",
    "retrospectiv": "viitor",
    "inversare": "afirmare",
    "recompensă": "penalizare",
    "călătorie": "mers pe jos",
    "copt": "verde",
    "în creștere": "cădere",
    "rotor": "stator",
    "rugozitate": "finete",
    "rundă": "pătrat",
    "rotunjit": "unghiular",
    "rural": "urban",
    "te grabesti": "persista",
    "sacru": "profan",
    "trist": "vesel",
    "tristeţe": "fericire",
    "nefericire": "fericire",
    "sigur": "periculos",
    "siguranță": "pericol",
    "monotonie": "diferență",
    "sănătate psihică": "nebunie",
    "satisfacţie": "nemulţumire",
    "cimbru": "grețos",
    "raritate": "abundenţă",
    "științific": "neştiinţific",
    "scrupulos": "lipsit de scrupule",
    "secundar": "primar",
    "securitate": "nesiguranță",
    "segregare": "integrare",
    "egoist": "altruist",
    "vinde": "a cumpara",
    "senior": "junior",
    "separa": "comun",
    "separare": "uniune",
    "septic": "antiseptic",
    "serviciu": "deserviciu",
    "stabilit": "nelocuit",
    "ascuţi": "aplatiza",
    "mic de statura": "înalt",
    "scurta": "prelungi",
    "spectacol": "ascunde",
    "se contracta": "întinde",
    "latură": "fund",
    "top": "fund",
    "semnificaţie": "inconsistență",
    "semnificativ": "nesemnificativ",
    "asemănător": "diferit",
    "simplifica": "complica",
    "singur": "multiplu",
    "singular": "plural",
    "chiuvetă": "sursă",
    "soră": "frate",
    "dormi": "trezi",
    "încet": "repede",
    "mic": "mare",
    "finete": "rugozitate",
    "moliciune": "acuitate",
    "soliditate": "porozitate",
    "solubil": "insolubil",
    "solvabilitate": "insolvabilitate",
    "solvent": "insolvabil",
    "fiu": "fiică",
    "întristare": "bucurie",
    "vorbit": "scris",
    "nescris": "scris",
    "sporadic": "continuu",
    "răspândire": "aduna",
    "pătrat": "rundă",
    "stabilitate": "instabilitate",
    "grajd": "instabil",
    "stand": "randament",
    "start": "stop",
    "stator": "rotor",
    "stau": "mișcare",
    "constant": "inconstant",
    "abrupt": "treptat",
    "brusc": "treptat",
    "steril": "fertil",
    "înțepeni": "slăbi",
    "zgârcit": "generos",
    "furtunos": "calm",
    "drept": "curb",
    "îndrepta": "îndoire",
    "putere": "slăbiciune",
    "întinde": "se contracta",
    "tare": "slab",
    "studio": "locație",
    "prostie": "inteligență",
    "subiectiv": "obiectiv",
    "subordonat": "dominant",
    "ulterior": "antecedente",
    "substantiv": "adjectiv",
    "scădere": "plus",
    "reușind": "precedent",
    "succes": "eșec",
    "de succes": "fără succes",
    "sucomba": "supravieţui",
    "suferi": "se bucura",
    "suficienta": "insuficienţă",
    "suficient": "insuficient",
    "sufix": "prefix",
    "răsărit": "apus de soare",
    "apus de soare": "răsărit",
    "superior": "inferior",
    "superioritate": "inferioritate",
    "livra": "cerere",
    "sprijinit": "neacceptat",
    "suprafaţă": "deasupra",
    "predare": "a rezista",
    "supravieţui": "sucomba",
    "dulce": "acru",
    "umed": "uscat",
    "îndulci": "acru",
    "simetrie": "asimetrie",
    "simpatic": "unsympathetic",
    "sinergică": "antagonic",
    "sinteză": "analiză",
    "sintetic": "analitic",
    "încetineală": "punctualitate",
    "gustos": "insipid",
    "insipid": "gustos",
    "delicat, fraged": "greu",
    "încordat": "relaxat",
    "terminal": "intermediar",
    "teismului": "ateism",
    "teoretic": "empiric",
    "însetat": "flămând",
    "gospodar": "risipitor",
    "maree": "reflux",
    "cravată": "dezlega",
    "timid": "îndrăzneţ",
    "timiditate": "îndrăzneală",
    "toleranţă": "intoleranţă",
    "tolerant": "intolerant",
    "dințat": "ştirb",
    "ştirb": "dințat",
    "atins": "neatins",
    "greu": "delicat, fraged",
    "maleabil": "intratabil",
    "tragedie": "comedie",
    "dresat": "neinstruit",
    "încredere": "neîncredere",
    "adevăr": "falsitate",
    "urâţenie": "frumuseţe",
    "urât": "frumoasa",
    "inacceptabil": "acceptabil",
    "nerecunoscut": "recunoscut",
    "neschimbat": "schimbat",
    "neînarmat": "armat",
    "neautorizat": "autorizat",
    "dezechilibrat": "echilibrat",
    "necredinţă": "credință",
    "nelegat": "legat",
    "incasabil": "casant",
    "neîntrerupt": "spart",
    "incertitudine": "certitudine",
    "unchi": "mătuşă",
    "neobișnuit": "ca de obicei",
    "indiferent": "îngrijorat",
    "neconfirmat": "confirmat",
    "neconectat": "conectat",
    "inconştienţă": "constiinta",
    "neconstituțional": "constituţional",
    "neconvențional": "convenţional",
    "neconvins": "convins",
    "descoperi": "acoperi",
    "netăiat": "a taia",
    "nedefinit": "definit",
    "subestima": "exagera",
    "indezirabil": "de dorit",
    "necultivat": "educat",
    "neechivoc": "echivoc",
    "fără evenimente importante": "bogat în evenimente",
    "neașteptat": "așteptat",
    "necredincios": "credincios",
    "necunoscut": "familiar",
    "nefavorabil": "favorabil",
    "desfășura": "plia",
    "neiertat": "iertător",
    "nefericit": "fericit",
    "nerecunoscător": "recunoscător",
    "nesănătos": "sănătos",
    "nesfânt": "sfânt",
    "neimportant": "important",
    "neamenajat": "îmbunătățit",
    "neinformat": "informat",
    "nelocuit": "stabilit",
    "ininteligibil": "inteligibil",
    "neintenționate": "destinate",
    "fara intentie": "intentionat",
    "dezinteresați": "interesat",
    "neinteresant": "interesant",
    "uniune": "separare",
    "unitar": "federal",
    "unit": "împărțit",
    "aspru": "drăguț",
    "nelimitat": "limitat",
    "descuia": "blocare",
    "ghinionist": "norocos",
    "nemarcate": "marcat",
    "necăsătorit": "căsătorit",
    "demasca": "masca",
    "neocupat": "ocupat",
    "neoficial": "oficial",
    "fără opoziție": "opus",
    "neortodox": "ortodox",
    "despacheta": "ambalaj",
    "neplăcut": "placut",
    "nepopular": "popular",
    "nepregătit": "pregătit",
    "neproductiv": "productiv",
    "neprotejat": "protejat",
    "nepublicat": "publicat",
    "necontestat": "discutabil",
    "nerealiste": "realist",
    "nereglementat": "reglementate",
    "fără legătură": "legate de",
    "nedemn de încredere": "de încredere",
    "nestăpânit": "reținut",
    "fără restricții": "restrâns",
    "grețos": "cimbru",
    "neştiinţific": "științific",
    "lipsit de scrupule": "scrupulos",
    "altruist": "egoist",
    "instabil": "grajd",
    "inconstant": "constant",
    "fără succes": "de succes",
    "neacceptat": "sprijinit",
    "unsympathetic": "simpatic",
    "dezlega": "cravată",
    "neatins": "atins",
    "neinstruit": "dresat",
    "dezvălui": "voal",
    "nevigilent": "precaut",
    "fără voie": "de bunăvoie",
    "refuzul": "bunăvoință",
    "se desface": "vânt",
    "nevrednic": "vrednic",
    "urban": "rural",
    "ca de obicei": "neobișnuit",
    "valoros": "lipsit de valoare",
    "voal": "dezvălui",
    "verbal": "numeric",
    "victorie": "înfrângere",
    "virtuos": "rău",
    "vizibilitate": "invizibilitate",
    "vizibil": "invizibil",
    "vocal": "instrumental",
    "voluntar": "involuntar",
    "vocală": "consoană",
    "trezi": "dormi",
    "mers pe jos": "călătorie",
    "război": "pace",
    "precaut": "nevigilent",
    "deşeuri": "conserva",
    "risipitor": "gospodar",
    "ceară": "declin",
    "slab": "tare",
    "slăbiciune": "putere",
    "bogatie": "sărăcie",
    "imponderabilă": "cu greutate",
    "cu greutate": "imponderabilă",
    "şoaptă": "strigăt",
    "alb": "negru",
    "în întregime": "parţial",
    "larg": "îngust",
    "largi": "îngust",
    "de bunăvoie": "fără voie",
    "bunăvoință": "refuzul",
    "vânt": "se desface",
    "înţelepciune": "nebunie",
    "înţelept": "prostesc",
    "face griji": "reasigura",
    "lipsit de valoare": "valoros",
    "vrednic": "nevrednic",
    "scris": "nescris",
    "tineri": "în vârstă de",
    "zenit": "nadir",
}
