_antonyms = {
    "capacità": "incapacità",
    "anormale": "normale",
    "abolire": "stabilire",
    "assenza": "presenza",
    "assente": "presente",
    "futuro": "passato",
    "assoluto": "parente",
    "astenersi": "consumare",
    "astratto": "calcestruzzo",
    "abbondanza": "scarsità",
    "abbondante": "scarso",
    "accettare": "rifiutare",
    "ammettere": "negare",
    "accettabile": "impraticabile",
    "accettazione": "rifiuto",
    "accessibile": "inaccessibile",
    "preciso": "impreciso",
    "riconosciuto": "non riconosciuto",
    "conoscenza": "sconosciuto",
    "atto": "ritornello",
    "azione": "inattività",
    "attivo": "silenzioso",
    "esistente": "inesistente",
    "rumoroso": "silenzioso",
    "attività": "inattività",
    "effettivo": "potenziale",
    "inserisci": "sottrarre",
    "aggiunta": "sottrazione",
    "adeguato": "insufficiente",
    "aggettivo": "sostanziale",
    "ammissibile": "inammissibile",
    "adulto": "giovanile",
    "avanzare": "recedere",
    "avanti": "indietro",
    "davanti": "posteriore",
    "virare": "indietro",
    "vantaggio": "svantaggio",
    "affermazione": "inversione",
    "affermativa": "negativo",
    "neutro": "femminile",
    "a poppa": "prua, testa",
    "età": "ringiovanire",
    "anziano": "junior",
    "agitazione": "quiete",
    "essere d'accordo": "disaccordo",
    "piacevole": "sgradevole",
    "accordo": "disaccordo",
    "alterato": "inalterato",
    "alternato": "di fronte",
    "dilettante": "professionale",
    "ambiguo": "non ambiguo",
    "amichevole": "ostile",
    "anfibio": "terrestre",
    "anale": "orale",
    "analogo": "omologo",
    "analisi": "sintesi",
    "analitico": "sintetico",
    "antenato": "discendente",
    "angolare": "arrotondato",
    "animare": "inanimato",
    "risposta": "domanda",
    "antagonistico": "sinergico",
    "antecedente": "successivo",
    "anteriore": "posteriore",
    "antisettico": "settico",
    "aspetto": "scomparsa",
    "apprezzamento": "ammortamento",
    "approvazione": "disapprovazione",
    "approvare": "disapprovare",
    "acquatico": "anfibio",
    "terrestre": "celeste",
    "acquoso": "igneo",
    "braccio": "disarmare",
    "armato": "disarmato",
    "arrivo": "partire",
    "ascendere": "scendere",
    "salita": "discesa",
    "addormentato": "sveglio",
    "assenso": "dissenso",
    "asimmetria": "simmetria",
    "ateismo": "teismo",
    "allegare": "distaccare",
    "attacco": "difendere",
    "perseguire": "difendere",
    "attenzione": "disattenzione",
    "attrazione": "repulsione",
    "udibile": "impercettibile",
    "aumento": "diminuzione",
    "zia": "zio",
    "autorizzato": "non autorizzato",
    "automatico": "manuale",
    "evitare": "affrontare",
    "sveglio": "addormentato",
    "indietro": "virare",
    "recedere": "avanzare",
    "posteriore": "anteriore",
    "sfondo": "primo piano",
    "arretrato": "inoltrare",
    "inverso": "diritto",
    "cattivo": "bene",
    "il male": "bene",
    "cattiveria": "bontà",
    "equilibrato": "squilibrato",
    "orso": "toro",
    "bellissimo": "brutta",
    "bellezza": "bruttezza",
    "inizio": "stop",
    "presto": "in ritardo",
    "credenza": "incredulità",
    "piegare": "spiegare",
    "benigno": "maligno",
    "grande": "piccolo",
    "nascita": "morte",
    "bisessuale": "omosessuale",
    "nero": "bianca",
    "benedire": "maledizione",
    "benedetto": "maledetto",
    "esangue": "sanguinoso",
    "sanguinoso": "esangue",
    "sfocatura": "messa a fuoco",
    "bollire": "congelare",
    "grassetto": "timido",
    "audacia": "timidezza",
    "prendere in prestito": "prestare",
    "mutuatario": "prestatore",
    "parte inferiore": "superiore",
    "limite": "unbound",
    "ragazzo": "ragazza",
    "boicottare": "patrocinare",
    "rompere": "riparazione",
    "fragile": "infrangibile",
    "rallegrare": "lamentarsi",
    "alleggerire": "scurire",
    "rotto": "ininterrotto",
    "fratello": "sorella",
    "toro": "orso",
    "occupato": "disoccupato",
    "lavoro": "inattivo",
    "acquistare": "vendere",
    "calma": "tempestoso",
    "quiete": "agitazione",
    "capace": "incapace",
    "contanti": "credito",
    "addebito": "credito",
    "centro": "sinistra",
    "cerebrale": "emotivo",
    "certezza": "incertezza",
    "modificare": "restare",
    "partire": "arrivo",
    "mossa": "restare",
    "variabile": "immutabile",
    "cambiato": "immutato",
    "carica": "scarico",
    "arruolare": "scarico",
    "a buon mercato": "costoso",
    "allegro": "deprimente",
    "bambino": "genitore",
    "civile": "militare",
    "richiesta": "pegno",
    "chiarezza": "opacità",
    "prominenza": "oscurità",
    "trasparenza": "opacità",
    "pulito": "immondo",
    "clero": "laicato",
    "ecclesiastico": "laico",
    "vicino": "aperto",
    "chiuso": "aperto",
    "vicinanza": "apertura",
    "costiero": "nell'entroterra",
    "coerente": "incoerente",
    "freddo": "calore",
    "collaterale": "diretto",
    "commedia": "tragedia",
    "comfort": "sconforto",
    "comune": "raro",
    "compatibile": "incompatibile",
    "competenza": "incompetenza",
    "competente": "incompetente",
    "concorrenza": "cooperazione",
    "lamentarsi": "rallegrare",
    "completezza": "incompletezza",
    "complesso": "semplice",
    "composto": "semplice",
    "conforme": "provocatorio",
    "complicato": "semplificare",
    "concavo": "convesso",
    "presunzione": "umiltà",
    "orgoglio": "umiltà",
    "concentrazione": "distribuzione",
    "concentrico": "eccentrico",
    "concezione": "idea sbagliata",
    "ha riguardato": "indifferente",
    "calcestruzzo": "astratto",
    "confermato": "non confermato",
    "affrontare": "evitare",
    "congiuntivo": "disgiuntivo",
    "collegare": "disconnect",
    "collegato": "non connesso",
    "coscienza": "incoscienza",
    "prudente": "imprudente",
    "conservare": "rifiuto",
    "premuroso": "sconsiderato",
    "consistenza": "incoerenza",
    "consonante": "vocale",
    "cospicuo": "non appariscente",
    "costituzionale": "anticostituzionale",
    "consumare": "astenersi",
    "soddisfare": "malcontento",
    "continuo": "discontinuo",
    "continuazione": "interruzione",
    "continua": "interrompere",
    "continuità": "discontinuità",
    "contrarre": "espandere",
    "contratto": "allargato",
    "contrazione": "espansione",
    "conveniente": "sconveniente",
    "convenzionale": "non convenzionale",
    "convergere": "divergere",
    "convergenza": "divergenza",
    "convergente": "divergente",
    "convesso": "concavo",
    "convinto": "poco convinta",
    "cooperazione": "concorrenza",
    "cosmopolita": "provinciale",
    "coraggio": "viltà",
    "copertina": "scoprire",
    "nascosto": "evidente",
    "viltà": "coraggio",
    "credito": "addebito",
    "creditore": "debitore",
    "criticare": "lode",
    "piangere": "ridere",
    "curabile": "incurabile",
    "maledizione": "benedire",
    "maledetto": "benedetto",
    "curvo": "dritto",
    "tagliare": "integrale",
    "pericolo": "sicurezza",
    "pericoloso": "sicuro",
    "buio": "leggerezza",
    "scurire": "alleggerire",
    "pesantezza": "leggerezza",
    "figlia": "figlio",
    "giorno": "notte",
    "sordo": "udito",
    "morte": "nascita",
    "debitore": "creditore",
    "decenza": "indecenza",
    "decente": "indecente",
    "deciduo": "sempreverde",
    "decisione": "indecisione",
    "decisivo": "indeciso",
    "declino": "cera",
    "diminuire": "aumentare",
    "diminuita": "è aumentato",
    "diminuzione": "aumento",
    "la sconfitta": "vittoria",
    "difendere": "perseguire",
    "imputato": "attore",
    "difesa": "accusa",
    "difensiva": "offensivo",
    "provocatorio": "conforme",
    "disavanzo": "condurre",
    "definito": "non definito",
    "deflazione": "inflazione",
    "ritardo": "puntualità",
    "soffermarsi": "corsa",
    "richiesta": "fornitura",
    "negare": "ammettere",
    "rifiutare": "accettare",
    "dipendente": "indipendente",
    "depositare": "ritirarsi",
    "ammortamento": "apprezzamento",
    "deprimente": "allegro",
    "scendere": "ascendere",
    "discendente": "antenato",
    "discesa": "salita",
    "descrittivo": "prescrittivo",
    "auspicabile": "indesiderabile",
    "disperazione": "speranza",
    "disperato": "speranza",
    "distrutto": "conservato",
    "distaccare": "allegare",
    "devoluzione": "evoluzione",
    "differire": "pari",
    "ineguale": "pari",
    "differenza": "monotonia",
    "difficile": "tenero",
    "inquieto": "facile",
    "difficoltà": "alleviare",
    "diligente": "negligente",
    "diluizione": "concentrazione",
    "distribuzione": "concentrazione",
    "sporco": "pulito",
    "immondo": "pulito",
    "disattivare": "abilitare",
    "svantaggio": "vantaggio",
    "disaccordo": "accordo",
    "sgradevole": "salato",
    "scomparsa": "aspetto",
    "disapprovazione": "approvazione",
    "disapprovare": "approvare",
    "disarmare": "braccio",
    "scarico": "arruolare",
    "disconoscere": "richiesta",
    "pegno": "richiesta",
    "sconforto": "comfort",
    "disconnect": "collegare",
    "malcontento": "soddisfare",
    "interruzione": "continuazione",
    "interrompere": "continua",
    "discontinuità": "continuità",
    "discontinuo": "continuo",
    "scoraggiare": "incoraggiare",
    "scoraggiamento": "incoraggiamento",
    "disimpegnare": "impegnare",
    "disonesto": "onesto",
    "disonestà": "onestà",
    "disonore": "onore",
    "disinfettare": "infettare",
    "disintegrare": "integrare",
    "disgiuntivo": "congiuntivo",
    "antipatia": "simpatia",
    "sloggiare": "casetta",
    "disobbedienza": "obbedienza",
    "disobbediente": "obbediente",
    "disobbedire": "obbedire",
    "disturbo": "ordine",
    "disordinato": "ordinato",
    "disorganizzato": "organizzato",
    "scontento": "contento",
    "confutare": "dimostrare",
    "squalificare": "qualificarsi",
    "sconveniente": "conveniente",
    "discredito": "reputazione",
    "mancanza di rispetto": "rispetto",
    "irrispettoso": "rispettoso",
    "insoddisfazione": "soddisfazione",
    "dissenso": "assenso",
    "disservizio": "servizio",
    "dissimile": "simile",
    "dissonanza": "armonia",
    "dissuadere": "persuadere",
    "distale": "prossimale",
    "lontano": "vicino",
    "aperto": "chiuso",
    "distinguibile": "indistinguibile",
    "diffidenza": "fiducia",
    "diurno": "notturno",
    "divergere": "convergere",
    "divergenza": "convergenza",
    "divergente": "convergente",
    "dividere": "unire",
    "singolarmente": "moltiplicare",
    "diviso": "unito",
    "divisibile": "indivisibile",
    "domestico": "straniero",
    "nativo": "straniero",
    "dominante": "subordinare",
    "inattivo": "lavoro",
    "estinto": "esistente",
    "passivo": "attivo",
    "silenzioso": "rumoroso",
    "doppio": "singolo",
    "multiplo": "singolo",
    "colomba": "falco",
    "drammatico": "lirica",
    "asciutto": "bagnato",
    "aspro": "addolcire",
    "dovuto": "indebito",
    "noioso": "affilare",
    "appiattire": "affilare",
    "sta morendo": "nascente",
    "alleviare": "difficoltà",
    "facile": "inquieto",
    "riflusso": "marea",
    "eccentrico": "concentrico",
    "educato": "incolto",
    "efficace": "inefficace",
    "efficienza": "inefficienza",
    "efficiente": "inefficiente",
    "uscita": "ingresso",
    "elastico": "non elastico",
    "idoneo": "ineleggibile",
    "emotivo": "cerebrale",
    "empirico": "teorico",
    "vuoto": "pieno",
    "magro": "addensare",
    "abilitare": "disattivare",
    "incoraggiare": "scoraggiare",
    "incoraggiamento": "scoraggiamento",
    "fine": "inizio",
    "mezzo": "presto",
    "endemico": "cosmopolita",
    "provinciale": "cosmopolita",
    "energico": "letargico",
    "imporre": "esonerare",
    "impegnare": "disimpegnare",
    "godere": "soffrire",
    "accedere": "uscita",
    "pari": "ineguale",
    "uguaglianza": "disuguaglianza",
    "equatoriale": "polare",
    "equo": "non equo",
    "equivoco": "inequivocabile",
    "cancellare": "disco",
    "stabilire": "abolire",
    "movimentato": "non movimentato",
    "sempreverde": "deciduo",
    "evoluzione": "devoluzione",
    "esclusione": "inclusione",
    "esonerare": "imporre",
    "esalare": "inalare",
    "uscita": "accedere",
    "espandere": "contrarre",
    "allargato": "contratto",
    "espansione": "contrazione",
    "previsto": "inaspettato",
    "costoso": "a buon mercato",
    "esperto": "inesperto",
    "esportare": "importare",
    "esprimere": "locale",
    "generale": "specifica",
    "nazionale": "internazionale",
    "estensione": "flessione",
    "esterno": "interno",
    "esternamente": "internamente",
    "spegnere": "infiammare",
    "fuori dell'università": "intramurale",
    "straordinario": "ordinario",
    "estrinseco": "intrinseco",
    "in mancanza di": "passaggio",
    "in esecuzione": "in piedi",
    "fallimento": "successo",
    "giusto": "sleale",
    "fedele": "infedele",
    "autunno": "salire",
    "impostato": "salire",
    "fallibile": "infallibile",
    "caduta": "crescente",
    "falsità": "verità",
    "fama": "infamia",
    "familiare": "sconosciuto",
    "fantasia": "pianura",
    "grasso": "magro",
    "pieno": "vuoto",
    "di spessore": "magro",
    "addensare": "magro",
    "padre": "madre",
    "fauna": "flora",
    "favorevole": "sfavorevole",
    "federale": "unitario",
    "femmina": "maschio",
    "femminile": "neutro",
    "femminilità": "mascolinità",
    "fertile": "sterile",
    "fedeltà": "infedeltà",
    "figura": "terra",
    "riempire": "vuoto",
    "trova": "perdere",
    "finire": "inizio",
    "stop": "inizio",
    "finito": "infinito",
    "fuoco": "assumere",
    "flessione": "estensione",
    "galleggiante": "lavello",
    "fonte": "lavello",
    "flora": "fauna",
    "messa a fuoco": "sfocatura",
    "nemico": "amico",
    "seguire": "precedere",
    "avere successo": "precedere",
    "seguace": "capo",
    "follia": "salute mentale",
    "folle": "sano di mente",
    "piede": "capo",
    "coda": "capo",
    "vietare": "permesso",
    "prua, testa": "a poppa",
    "primo piano": "sfondo",
    "straniero": "nativo",
    "dimenticare": "ricorda",
    "perdonare": "imperdonabile",
    "formalismo": "imitazione",
    "fortunato": "sfortunato",
    "inoltrare": "inverso",
    "diritto": "inverso",
    "fallo": "giusto",
    "sleale": "giusto",
    "trovato": "perduto",
    "fraterno": "identico",
    "congelare": "bollire",
    "frequente": "infrequente",
    "frequentemente": "non frequentemente",
    "amico": "nemico",
    "capo": "seguace",
    "pienezza": "vuoto",
    "funzionale": "biologico",
    "inorganico": "biologico",
    "guadagno": "perdita",
    "gassoso": "solido",
    "cavo": "solido",
    "raccogliere": "diffusione",
    "generalità": "particolarità",
    "generoso": "avaro",
    "ragazza": "ragazzo",
    "bene": "il male",
    "bontà": "cattiveria",
    "graduale": "improvviso",
    "grato": "ingrato",
    "maggiore": "minore",
    "verde": "maturo",
    "schifoso": "netto",
    "terra": "figura",
    "colpa": "innocenza",
    "colpevole": "innocente",
    "felicemente": "purtroppo",
    "felicità": "infelicità",
    "contento": "scontento",
    "durezza": "morbidezza",
    "rumorosità": "morbidezza",
    "nitidezza": "morbidezza",
    "armonia": "dissonanza",
    "odiare": "amore",
    "odioso": "amabile",
    "falco": "colomba",
    "salutare": "malsano",
    "udito": "sordo",
    "calore": "freddo",
    "celeste": "terrestre",
    "eterogeneità": "omogeneità",
    "nascondere": "mostrare",
    "assumere": "fuoco",
    "colpire": "perdere",
    "santo": "empio",
    "omogeneità": "eterogeneità",
    "omologo": "analogo",
    "omosessuale": "bisessuale",
    "onesto": "disonesto",
    "onestà": "disonestà",
    "onore": "disonore",
    "speranza": "disperazione",
    "pieno di speranza": "senza speranza",
    "senza speranza": "pieno di speranza",
    "orizzontale": "verticale",
    "ostile": "amichevole",
    "caldo": "freddo",
    "umile": "orgoglioso",
    "umiltà": "orgoglio",
    "affamato": "assetato",
    "identico": "fraterno",
    "igneo": "acquoso",
    "infiammare": "spegnere",
    "ignorare": "avviso",
    "illegale": "legale",
    "illegalità": "legalità",
    "illeggibile": "leggibile",
    "illogico": "logico",
    "imitazione": "formalismo",
    "immateriale": "materiale",
    "immaturità": "scadenza",
    "incommensurabile": "misurabile",
    "immorale": "morale",
    "immoralità": "moralità",
    "immortale": "mortale",
    "immortalità": "mortalità",
    "immutabile": "variabile",
    "imparzialità": "parzialità",
    "impraticabile": "accettabile",
    "impazienza": "pazienza",
    "impaziente": "paziente",
    "impercettibile": "udibile",
    "imperfezione": "perfezione",
    "impermeabile": "permeabile",
    "inammissibile": "ammissibile",
    "impersonale": "personale",
    "scortese": "genere",
    "importare": "esportare",
    "importante": "irrilevante",
    "impossibilità": "possibilità",
    "impotente": "potente",
    "improbabile": "probabile",
    "migliorata": "unimproved",
    "miglioramento": "declino",
    "imprudente": "prudente",
    "impurità": "purezza",
    "incapacità": "capacità",
    "inaccessibile": "accessibile",
    "impreciso": "preciso",
    "inattività": "attività",
    "insufficiente": "sufficiente",
    "inanimato": "animare",
    "disattenzione": "attenzione",
    "incapace": "capace",
    "inclinato": "orizzontale",
    "verticale": "orizzontale",
    "inclusione": "esclusione",
    "incoerente": "coerente",
    "incompatibile": "compatibile",
    "incompetenza": "competenza",
    "incompetente": "competente",
    "incompletezza": "completezza",
    "sconsiderato": "premuroso",
    "incoerenza": "consistenza",
    "non appariscente": "cospicuo",
    "aumentare": "inferiore",
    "è aumentato": "diminuita",
    "incremento": "diminuzione",
    "incurabile": "curabile",
    "indecenza": "decenza",
    "indecente": "decente",
    "indecisione": "decisione",
    "indeciso": "decisivo",
    "indipendente": "dipendente",
    "indistinguibile": "distinguibile",
    "indivisibile": "divisibile",
    "interno": "esterno",
    "inefficace": "efficace",
    "inefficienza": "efficienza",
    "inefficiente": "efficiente",
    "non elastico": "elastico",
    "ineleggibile": "idoneo",
    "disuguaglianza": "uguaglianza",
    "non equo": "equo",
    "inesperto": "esperto",
    "infallibile": "fallibile",
    "infamia": "fama",
    "infettare": "disinfettare",
    "inferiore": "aumentare",
    "inferiorità": "superiorità",
    "infedeltà": "fedeltà",
    "infinito": "finito",
    "inflazione": "deflazione",
    "informato": "disinformato",
    "infrequente": "frequente",
    "non frequentemente": "frequentemente",
    "ingresso": "uscita",
    "abitato": "disabitato",
    "inalare": "esalare",
    "ingiustizia": "giustizia",
    "nell'entroterra": "costiero",
    "innocenza": "colpa",
    "innocente": "colpevole",
    "innocuo": "nocivo",
    "non operante": "operativo",
    "insicurezza": "sicurezza",
    "piccolezza": "significato",
    "insignificante": "significativo",
    "insolubile": "solubile",
    "insolvenza": "solvibilità",
    "insolvente": "solvente",
    "instabilità": "stabilità",
    "strumentale": "vocale",
    "insufficienza": "sufficienza",
    "insufficientemente": "sufficientemente",
    "integrare": "disintegrare",
    "integrazione": "segregazione",
    "intelligenza": "stupidità",
    "intelligibile": "incomprensibile",
    "destinato": "non inteso",
    "apposta": "involontariamente",
    "interessato": "indifferente",
    "interessante": "non interessante",
    "intermedio": "terminale",
    "internamente": "esternamente",
    "internazionale": "nazionale",
    "locale": "generale",
    "intolleranza": "tolleranza",
    "intollerante": "tollerante",
    "intrattabile": "trattabile",
    "intramurale": "fuori dell'università",
    "intrinseco": "estrinseco",
    "invisibilità": "visibilità",
    "invisibile": "visibile",
    "involontario": "volontario",
    "irrazionale": "razionale",
    "irregolare": "regolare",
    "irregolarità": "regolarità",
    "non pertinente": "pertinente",
    "irresponsabile": "responsabile",
    "irriverente": "riverente",
    "problema": "richiamare",
    "comune": "separato",
    "gioia": "tristezza",
    "gioioso": "dolente",
    "junior": "anziano",
    "giustizia": "ingiustizia",
    "giovanile": "adulto",
    "contadino irlandese": "contadino irlandese",
    "genere": "scortese",
    "re": "regina",
    "laicato": "clero",
    "in ritardo": "presto",
    "ridere": "piangere",
    "legale": "illegale",
    "negligente": "diligente",
    "rilassato": "teso",
    "laico": "ecclesiastico",
    "condurre": "disavanzo",
    "sinistra": "centro",
    "legalità": "illegalità",
    "legalizzare": "fuorilegge",
    "leggibile": "illeggibile",
    "prestare": "prendere in prestito",
    "prestatore": "mutuatario",
    "allungare": "contrarsi",
    "minore": "maggiore",
    "letargico": "energico",
    "livello": "aumentare",
    "liberale": "prudente",
    "menzogna": "stare in piedi",
    "dare la precedenza": "stare in piedi",
    "leggero": "buio",
    "leggerezza": "pesantezza",
    "simpatia": "antipatia",
    "limitato": "illimitato",
    "diretto": "collaterale",
    "liquido": "gassoso",
    "solido": "cavo",
    "specifica": "generale",
    "posizione": "studio",
    "serratura": "sbloccare",
    "casetta": "sloggiare",
    "logico": "illogico",
    "lungo": "corto",
    "alto": "superficie",
    "allentare": "irrigidirsi",
    "perdere": "trova",
    "perdita": "guadagno",
    "perduto": "trovato",
    "amabile": "odioso",
    "amore": "odiare",
    "lirica": "drammatico",
    "maggioranza": "minoranza",
    "rendere": "rompere",
    "riparazione": "rompere",
    "maschio": "femmina",
    "maligno": "benigno",
    "manuale": "automatico",
    "segnato": "non marcato",
    "sposato": "celibe",
    "maschile": "femminile",
    "mascolinità": "femminilità",
    "maschera": "smascherare",
    "materiale": "immateriale",
    "materno": "paterno",
    "scadenza": "immaturità",
    "massimo": "minimo",
    "misurabile": "incommensurabile",
    "mentale": "fisico",
    "misericordioso": "spietato",
    "spietato": "misericordioso",
    "militare": "civile",
    "mente": "dimenticare",
    "ricorda": "dimenticare",
    "minimo": "massimo",
    "minoranza": "maggioranza",
    "idea sbagliata": "concezione",
    "perdere": "colpire",
    "molare": "molecolare",
    "molecolare": "molare",
    "morale": "immorale",
    "moralità": "immoralità",
    "mortale": "immortale",
    "mortalità": "immortalità",
    "madre": "padre",
    "moltiplicare": "singolarmente",
    "unire": "dividere",
    "mutevole": "immutabile",
    "nadir": "zenit",
    "stretto": "allargare",
    "nascente": "sta morendo",
    "negativo": "neutro",
    "nipote": "nipote",
    "netto": "schifoso",
    "notte": "giorno",
    "notturno": "diurno",
    "nominale": "vero",
    "irreale": "vero",
    "inesistente": "esistente",
    "normale": "anormale",
    "avviso": "ignorare",
    "nocivo": "innocuo",
    "numerico": "verbale",
    "obbedienza": "disobbedienza",
    "obbediente": "disobbediente",
    "obbedire": "disobbedire",
    "obbiettivo": "soggettivo",
    "obbligatorio": "opzionale",
    "obliquo": "perpendicolare",
    "oscurità": "prominenza",
    "opacità": "trasparenza",
    "offesa": "difesa",
    "accusa": "difesa",
    "offensivo": "difensiva",
    "ufficiale": "non ufficiale",
    "apertura": "vicinanza",
    "operativo": "non operante",
    "contrario": "incontrastata",
    "di fronte": "alternato",
    "ottimismo": "pessimismo",
    "ottimista": "pessimista",
    "opzionale": "obbligatorio",
    "orale": "anale",
    "ordine": "disturbo",
    "ordinato": "disordinato",
    "ordinario": "straordinario",
    "biologico": "inorganico",
    "organizzato": "disorganizzato",
    "ortodosso": "non ortodosso",
    "all'aperto": "interno",
    "fuorilegge": "legalizzare",
    "sopravvalutare": "sottovalutare",
    "evidente": "nascosto",
    "pacco": "disfare",
    "doloroso": "indolore",
    "indolore": "doloroso",
    "parallelo": "obliquo",
    "perpendicolare": "obliquo",
    "genitore": "bambino",
    "parzialità": "imparzialità",
    "particolarità": "generalità",
    "in parte": "interamente",
    "passaggio": "in esecuzione",
    "in piedi": "in esecuzione",
    "passato": "futuro",
    "presente": "assente",
    "paterno": "materno",
    "pazienza": "impazienza",
    "paziente": "impaziente",
    "patrocinare": "boicottare",
    "pace": "guerra",
    "pena": "ricompensa",
    "percettibile": "impercettibile",
    "perfezione": "imperfezione",
    "permeabile": "impermeabile",
    "permissivo": "preventivo",
    "permesso": "vietare",
    "personale": "impersonale",
    "persuadere": "dissuadere",
    "pessimismo": "ottimismo",
    "pessimista": "ottimista",
    "fisico": "mentale",
    "pianura": "fantasia",
    "attore": "imputato",
    "plurale": "singolare",
    "polare": "equatoriale",
    "gentile": "scortese",
    "popolare": "impopolare",
    "porosità": "solidità",
    "possibilità": "impossibilità",
    "potente": "impotente",
    "potenziale": "effettivo",
    "povertà": "ricchezza",
    "lode": "criticare",
    "precedere": "avere successo",
    "precedente": "successivo",
    "prefisso": "suffisso",
    "preparazione": "risoluzione",
    "preparato": "impreparato",
    "prescrittivo": "descrittivo",
    "presenza": "assenza",
    "conservato": "distrutto",
    "preventivo": "permissivo",
    "primario": "secondario",
    "privato": "pubblico",
    "privatamente": "pubblicamente",
    "probabile": "improbabile",
    "produttivo": "improduttivo",
    "profano": "sacro",
    "professionale": "dilettante",
    "progresso": "regredire",
    "progressivo": "regressivo",
    "prospettiva": "retrospettiva",
    "protetta": "indifeso",
    "orgoglioso": "umile",
    "dimostrare": "confutare",
    "prossimale": "distale",
    "prossimità": "finale",
    "pubblico": "privato",
    "pubblicamente": "privatamente",
    "pubblicato": "inedito",
    "tirare": "spingere",
    "puntualità": "ritardo",
    "epurazione": "riabilitare",
    "purezza": "impurità",
    "spingere": "tirare",
    "qualificarsi": "squalificare",
    "regina": "re",
    "domanda": "risposta",
    "discutibile": "indiscutibile",
    "velocemente": "lentamente",
    "razionale": "irrazionale",
    "vero": "irreale",
    "realistico": "non realistico",
    "rassicurare": "preoccupazione",
    "richiamare": "problema",
    "disco": "cancellare",
    "ritornello": "atto",
    "rifiuto": "conservare",
    "regredire": "progresso",
    "regressivo": "progressivo",
    "regolare": "irregolare",
    "regolarità": "irregolarità",
    "regolata": "non regolamentata",
    "riabilitare": "epurazione",
    "ringiovanire": "età",
    "relazionato": "estraneo",
    "parente": "assoluto",
    "pertinente": "non pertinente",
    "affidabile": "inaffidabile",
    "religioso": "secolare",
    "repulsione": "attrazione",
    "rispettabile": "sconveniente",
    "reputazione": "discredito",
    "resistere": "resa",
    "risoluzione": "preparazione",
    "rispetto": "mancanza di rispetto",
    "rispettoso": "irrispettoso",
    "responsabile": "irresponsabile",
    "contenuto": "sfrenato",
    "retrospettiva": "prospettiva",
    "riverente": "irriverente",
    "inversione": "affermazione",
    "ricompensa": "pena",
    "cavalcata": "camminare",
    "maturo": "verde",
    "salire": "impostato",
    "crescente": "caduta",
    "rotore": "statore",
    "rugosità": "levigatezza",
    "il giro": "piazza",
    "arrotondato": "angolare",
    "rurale": "urbano",
    "corsa": "soffermarsi",
    "sacro": "profano",
    "purtroppo": "felicemente",
    "tristezza": "gioia",
    "infelicità": "felicità",
    "sicuro": "pericoloso",
    "sicurezza": "insicurezza",
    "monotonia": "differenza",
    "sano di mente": "folle",
    "salute mentale": "follia",
    "soddisfazione": "insoddisfazione",
    "salato": "sgradevole",
    "scarso": "abbondante",
    "scarsità": "abbondanza",
    "scientifico": "non scientifico",
    "scrupoloso": "senza scrupoli",
    "secondario": "primario",
    "secolare": "religioso",
    "segregazione": "integrazione",
    "egoista": "altruista",
    "vendere": "acquistare",
    "separato": "comune",
    "separazione": "unione",
    "settico": "antisettico",
    "servizio": "disservizio",
    "sistemato": "incerto",
    "affilare": "appiattire",
    "corto": "alto",
    "accorciare": "allungare",
    "grido": "sussurro",
    "mostrare": "nascondere",
    "contrarsi": "allungare",
    "lato": "parte inferiore",
    "superiore": "inferiore",
    "significato": "piccolezza",
    "significativo": "insignificante",
    "simile": "dissimile",
    "semplice": "composto",
    "semplificare": "complicato",
    "singolo": "multiplo",
    "singolare": "plurale",
    "lavello": "fonte",
    "sorella": "fratello",
    "dormire": "svegliare",
    "lentamente": "velocemente",
    "piccolo": "grande",
    "levigatezza": "rugosità",
    "morbidezza": "nitidezza",
    "solidità": "porosità",
    "solubile": "insolubile",
    "solvibilità": "insolvenza",
    "solvente": "insolvente",
    "figlio": "figlia",
    "dolente": "gioioso",
    "verbale": "numerico",
    "non scritto": "scritto",
    "sporadico": "continuo",
    "diffusione": "raccogliere",
    "piazza": "il giro",
    "stabilità": "instabilità",
    "stabile": "instabile",
    "stare in piedi": "dare la precedenza",
    "statore": "rotore",
    "restare": "mossa",
    "costante": "instabile",
    "ripido": "graduale",
    "improvviso": "graduale",
    "sterile": "fertile",
    "irrigidirsi": "allentare",
    "avaro": "generoso",
    "tempestoso": "calma",
    "dritto": "curvo",
    "raddrizzare": "piegare",
    "sconosciuto": "familiare",
    "forza": "debolezza",
    "fortemente": "debolmente",
    "studio": "posizione",
    "stupidità": "intelligenza",
    "soggettivo": "obbiettivo",
    "subordinare": "dominante",
    "successivo": "precedente",
    "sostanziale": "aggettivo",
    "sottrarre": "inserisci",
    "sottrazione": "aggiunta",
    "successo": "fallimento",
    "riuscito": "senza esito",
    "soccombere": "sopravvivere",
    "soffrire": "godere",
    "sufficienza": "insufficienza",
    "sufficiente": "insufficiente",
    "sufficientemente": "insufficientemente",
    "suffisso": "prefisso",
    "alba": "tramonto",
    "tramonto": "alba",
    "superiorità": "inferiorità",
    "fornitura": "richiesta",
    "supportato": "supportato",
    "superficie": "alto",
    "resa": "resistere",
    "sopravvivere": "soccombere",
    "dolce": "aspro",
    "bagnato": "asciutto",
    "addolcire": "aspro",
    "simmetria": "asimmetria",
    "comprensivo": "antipatico",
    "sinergico": "antagonistico",
    "sintesi": "analisi",
    "sintetico": "analitico",
    "raffinato": "insapore",
    "gustoso": "insapore",
    "insapore": "gustoso",
    "tenero": "difficile",
    "teso": "rilassato",
    "terminale": "intermedio",
    "teismo": "ateismo",
    "teorico": "empirico",
    "assetato": "affamato",
    "riflessivo": "senza pensieri",
    "senza pensieri": "riflessivo",
    "parsimonioso": "dispendioso",
    "marea": "riflusso",
    "cravatta": "sciogliere",
    "timido": "grassetto",
    "timidezza": "audacia",
    "tolleranza": "intolleranza",
    "tollerante": "intollerante",
    "dentata": "sdentato",
    "sdentato": "dentata",
    "toccato": "intatto",
    "trattabile": "intrattabile",
    "tragedia": "commedia",
    "allenato": "non addestrato",
    "fiducia": "diffidenza",
    "verità": "falsità",
    "bruttezza": "bellezza",
    "brutta": "bellissimo",
    "finale": "prossimità",
    "inaccettabile": "accettabile",
    "non riconosciuto": "riconosciuto",
    "inalterato": "alterato",
    "non ambiguo": "ambiguo",
    "disarmato": "armato",
    "non autorizzato": "autorizzato",
    "squilibrato": "equilibrato",
    "incredulità": "credenza",
    "unbound": "limite",
    "infrangibile": "fragile",
    "ininterrotto": "rotto",
    "incertezza": "certezza",
    "immutato": "cambiato",
    "zio": "zia",
    "raro": "comune",
    "indifferente": "interessato",
    "non confermato": "confermato",
    "non connesso": "collegato",
    "incoscienza": "coscienza",
    "anticostituzionale": "costituzionale",
    "non convenzionale": "convenzionale",
    "poco convinta": "convinto",
    "scoprire": "copertina",
    "integrale": "tagliare",
    "non definito": "definito",
    "sottovalutare": "sopravvalutare",
    "indesiderabile": "auspicabile",
    "indebito": "dovuto",
    "incolto": "educato",
    "inequivocabile": "equivoco",
    "non movimentato": "movimentato",
    "inaspettato": "previsto",
    "infedele": "fedele",
    "sfavorevole": "favorevole",
    "spiegare": "piegare",
    "imperdonabile": "perdonare",
    "sfortunato": "fortunato",
    "ingrato": "grato",
    "infelice": "contento",
    "malsano": "salutare",
    "empio": "santo",
    "irrilevante": "importante",
    "unimproved": "migliorata",
    "disinformato": "informato",
    "disabitato": "abitato",
    "incomprensibile": "intelligibile",
    "non inteso": "destinato",
    "involontariamente": "apposta",
    "non interessante": "interessante",
    "unione": "separazione",
    "unitario": "federale",
    "unito": "diviso",
    "illimitato": "limitato",
    "sbloccare": "serratura",
    "non marcato": "segnato",
    "celibe": "sposato",
    "smascherare": "maschera",
    "disoccupato": "occupato",
    "non ufficiale": "ufficiale",
    "incontrastata": "contrario",
    "non ortodosso": "ortodosso",
    "disfare": "pacco",
    "impopolare": "popolare",
    "impreparato": "preparato",
    "improduttivo": "produttivo",
    "indifeso": "protetta",
    "inedito": "pubblicato",
    "indiscutibile": "discutibile",
    "non realistico": "realistico",
    "non regolamentata": "regolata",
    "estraneo": "relazionato",
    "inaffidabile": "affidabile",
    "sfrenato": "contenuto",
    "non scientifico": "scientifico",
    "senza scrupoli": "scrupoloso",
    "altruista": "egoista",
    "incerto": "sistemato",
    "instabile": "costante",
    "senza esito": "riuscito",
    "antipatico": "comprensivo",
    "sciogliere": "cravatta",
    "intatto": "toccato",
    "non addestrato": "allenato",
    "insolito": "solito",
    "svelare": "velo",
    "incauto": "diffidente",
    "controvoglia": "volentieri",
    "riluttanza": "buona volontà",
    "rilassarsi": "vento",
    "indegno": "degno",
    "urbano": "rurale",
    "solito": "insolito",
    "prezioso": "senza valore",
    "velo": "svelare",
    "vittoria": "la sconfitta",
    "virtuoso": "malvagio",
    "visibilità": "invisibilità",
    "visibile": "invisibile",
    "vocale": "consonante",
    "volontario": "involontario",
    "svegliare": "dormire",
    "camminare": "cavalcata",
    "guerra": "pace",
    "diffidente": "incauto",
    "dispendioso": "parsimonioso",
    "cera": "declino",
    "debolmente": "fortemente",
    "debolezza": "forza",
    "ricchezza": "povertà",
    "senza peso": "pesante",
    "pesante": "senza peso",
    "sussurro": "grido",
    "bianca": "nero",
    "interamente": "in parte",
    "malvagio": "virtuoso",
    "largo": "stretto",
    "allargare": "stretto",
    "volentieri": "controvoglia",
    "buona volontà": "riluttanza",
    "vento": "rilassarsi",
    "saggezza": "follia",
    "saggio": "folle",
    "ritirarsi": "depositare",
    "preoccupazione": "rassicurare",
    "senza valore": "prezioso",
    "degno": "indegno",
    "scritto": "non scritto",
    "giovane": "anziano",
    "zenit": "nadir",
}
