_antonyms = {
    "habilidade": "incapacidade",
    "anormal": "normal",
    "abolir": "estabelecer",
    "ausência": "presença",
    "ausente": "presente",
    "futuro": "passado",
    "absoluto": "relativo",
    "abster-se": "consumir",
    "abstrato": "concreto",
    "abundância": "escassez",
    "abundante": "escasso",
    "aceitar": "rejeitar",
    "admitem": "negar",
    "aceitável": "inaceitável",
    "aceitação": "rejeição",
    "acessível": "inacessível",
    "preciso": "impreciso",
    "reconhecido": "não reconhecido",
    "conhecido": "desconhecido",
    "aja": "refrão",
    "açao": "inação",
    "ativo": "quieto",
    "existente": "inexistente",
    "barulhento": "quieto",
    "atividade": "inatividade",
    "real": "irreal",
    "adicionar": "subtrair",
    "adição": "subtração",
    "adequado": "inadequado",
    "adjetivo": "substantivo",
    "admissível": "inadmissível",
    "adulto": "juvenil",
    "avançar": "recuar",
    "adiante": "costas",
    "frente": "traseira",
    "virar": "costas",
    "vantagem": "desvantagem",
    "afirmação": "perder",
    "afirmativo": "negativo",
    "neutro": "feminino",
    "a popa": "fore",
    "era": "rejuvenescer",
    "idade": "jovem",
    "agitação": "calma",
    "aceita": "discordar",
    "agradável": "desagradável",
    "acordo": "desacordo",
    "alterado": "inalterado",
    "alternar": "oposto",
    "amador": "profissional",
    "ambíguo": "sem ambiguidade",
    "amigável": "hostil",
    "amigáveis": "hostil",
    "anfíbio": "terrestre",
    "anal": "oral",
    "análogo": "homóloga",
    "análise": "síntese",
    "analítico": "sintético",
    "antepassado": "descendente",
    "angular": "arredondado",
    "animar": "inanimado",
    "responda": "questão",
    "antagônico": "sinérgico",
    "antecedente": "subseqüente",
    "anterior": "posterior",
    "antisséptico": "séptico",
    "aparência": "desaparecimento",
    "apreciação": "depreciação",
    "aprovação": "desaprovação",
    "aprovar": "desaprovar",
    "aquático": "anfíbio",
    "terrestre": "celestial",
    "aquoso": "ígneo",
    "braço": "desarmar",
    "armado": "desarmado",
    "chegar": "sair",
    "subir": "conjunto",
    "subida": "descida",
    "adormecido": "acordado",
    "concordância": "dissidência",
    "assimetria": "simetria",
    "ateísmo": "teísmo",
    "anexar": "desanexar",
    "ataque": "defender",
    "processar": "defender",
    "atenção": "falta de atenção",
    "atração": "repulsão",
    "audível": "inaudível",
    "aumento": "diminuição",
    "tia": "tio",
    "autorizado": "não autorizado",
    "automático": "manual",
    "evitar": "enfrentar",
    "acordado": "adormecido",
    "costas": "virar",
    "recuar": "avançar",
    "traseira": "cabeça",
    "fundo": "primeiro plano",
    "para trás": "frente",
    "marcha ré": "anverso",
    "mau": "boa",
    "mal": "boa",
    "maldade": "bondade",
    "equilibrado": "desequilibrado",
    "urso": "touro",
    "bonita": "feio",
    "beleza": "feiúra",
    "início": "fim",
    "começando": "meio",
    "cedo": "atrasado",
    "crença": "incredulidade",
    "dobrar": "endireitar",
    "benigno": "maligno",
    "grande": "pequeno",
    "ampla": "pequeno",
    "nascimento": "morte",
    "bissexual": "homossexual",
    "preto": "branco",
    "abençoe": "maldição",
    "abençoado": "amaldiçoado",
    "sem sangue": "sangrento",
    "sangrento": "sem sangue",
    "borrão": "foco",
    "ferver": "congelar",
    "negrito": "tímido",
    "ousadia": "timidez",
    "pedir emprestado": "emprestar",
    "mutuário": "emprestador",
    "inferior": "superior",
    "limite": "não consolidado",
    "garoto": "menina",
    "boicote": "patrocinar",
    "pausa": "reparar",
    "quebrável": "inquebrável",
    "iluminar": "escurecer",
    "aliviar": "escurecer",
    "partido": "inteiro",
    "irmão": "irmã",
    "touro": "urso",
    "ocupado": "desocupado",
    "trabalhos": "ocioso",
    "comprar": "vender",
    "calma": "agitação",
    "capaz": "incapaz",
    "capacidade": "incapacidade",
    "dinheiro": "crédito",
    "débito": "crédito",
    "centro": "esquerda",
    "cerebral": "emocional",
    "certeza": "incerteza",
    "mudança": "fique",
    "partida": "fique",
    "mover": "fique",
    "mutável": "imutável",
    "mudou": "inalterado",
    "carregar": "descarga",
    "alista": "descarga",
    "barato": "caro",
    "torcer": "reclamar",
    "alegre": "triste",
    "criança": "pai",
    "civil": "militares",
    "clareza": "opacidade",
    "proeminência": "obscuridade",
    "transparência": "opacidade",
    "limpar \ limpo": "imundo",
    "clero": "leigos",
    "clérigo": "leigo",
    "fechar": "aberto",
    "fechadas": "aberto",
    "proximidade": "abertura",
    "costeiro": "interior",
    "coerente": "incoerente",
    "frio": "quente",
    "colateral": "linear",
    "comédia": "tragédia",
    "conforto": "desconforto",
    "comum": "extraordinário",
    "compatível": "desafiante",
    "competência": "incompetência",
    "competente": "incompetente",
    "concorrência": "cooperação",
    "reclamar": "torcer",
    "completude": "incompletude",
    "complexo": "simples",
    "composto": "simples",
    "complicar": "simplificar",
    "côncavo": "convexo",
    "presunção": "humildade",
    "orgulho": "humildade",
    "concentração": "distribuição",
    "concêntrico": "excêntrico",
    "concepção": "equívoco",
    "preocupado": "despreocupado",
    "concreto": "abstrato",
    "confirmado": "não confirmado",
    "enfrentar": "evitar",
    "conjuntivo": "disjuntivo",
    "conectar": "desconectar",
    "conectado": "desconectado",
    "consciência": "inconsciência",
    "conservador": "liberal",
    "conservar": "desperdício",
    "atencioso": "inconsiderado",
    "consistência": "inconsistência",
    "consoante": "vogal",
    "conspícuo": "discreto",
    "constitucional": "inconstitucional",
    "consumir": "abster-se",
    "conteúdo": "descontentamento",
    "contínuo": "descontínuo",
    "continuação": "descontinuação",
    "continuar": "descontinuar",
    "continuidade": "descontinuidade",
    "contrato": "expandir",
    "contratado": "expandido",
    "contração": "expansão",
    "conveniente": "inconveniente",
    "convencional": "não convencional",
    "convergem": "divergir",
    "convergência": "divergência",
    "convergente": "divergente",
    "convexo": "côncavo",
    "convencido": "não convencido",
    "legal": "ilegal",
    "cooperação": "concorrência",
    "cosmopolita": "provincial",
    "coragem": "covardia",
    "tampa": "descobrir",
    "encoberta": "abertos",
    "covardia": "coragem",
    "crédito": "débito",
    "credor": "devedor",
    "criticar": "elogio",
    "chorar": "rir",
    "curável": "incurável",
    "maldição": "abençoe",
    "amaldiçoado": "abençoado",
    "curvado": "direto",
    "cortar": "sem cortes",
    "perigo": "segurança",
    "perigoso": "seguro",
    "sombrio": "luz",
    "escurecer": "aliviar",
    "trevas": "leveza",
    "peso": "leveza",
    "filha": "filho",
    "dia": "noite",
    "surdo": "audição",
    "morte": "nascimento",
    "devedor": "credor",
    "decência": "indecência",
    "decente": "indecente",
    "decíduo": "evergreen",
    "decisão": "indecisão",
    "decisivo": "indeciso",
    "declínio": "melhoria",
    "diminuir": "aumentar",
    "diminuiu": "aumentou",
    "decremento": "incremento",
    "derrota": "vitória",
    "defender": "processar",
    "réu": "demandante",
    "defesa": "processo",
    "defensiva": "ofensiva",
    "desafiante": "compatível",
    "déficit": "conduzir",
    "definiram": "indefinido",
    "deflação": "inflação",
    "demora": "pressa",
    "demorar": "pressa",
    "exigem": "fornecem",
    "negar": "admitem",
    "rejeitar": "aceitar",
    "dependente": "independente",
    "depósito": "retirar o",
    "depreciação": "apreciação",
    "deprimente": "alegre",
    "descer": "subir",
    "descendente": "antepassado",
    "descida": "subida",
    "descritivo": "prescritivo",
    "desejável": "indesejável",
    "desespero": "esperança",
    "desesperado": "esperança",
    "destruído": "preservado",
    "desanexar": "anexar",
    "devolução": "evolução",
    "diferem": "igual",
    "desigual": "equitativo",
    "diferença": "semelhança",
    "difícil": "fácil",
    "desconfortável": "fácil",
    "dificuldade": "facilidade",
    "diligente": "negligente",
    "diluição": "concentração",
    "distribuição": "concentração",
    "diminuição": "aumento",
    "sujo": "limpar \ limpo",
    "imundo": "limpar \ limpo",
    "desativar": "habilitar",
    "desvantagem": "vantagem",
    "discordar": "aceita",
    "desagradável": "salgados",
    "desacordo": "acordo",
    "desaparecimento": "aparência",
    "desaprovação": "aprovação",
    "desaprovar": "aprovar",
    "desarmar": "braço",
    "descarga": "alista",
    "renunciar": "afirmação",
    "perder": "encontrar",
    "desconforto": "conforto",
    "desconectar": "conectar",
    "descontentamento": "conteúdo",
    "descontinuação": "continuação",
    "descontinuar": "continuar",
    "descontinuidade": "continuidade",
    "descontínuo": "contínuo",
    "desencorajar": "encorajar",
    "desânimo": "encorajamento",
    "desengatar": "se empenhar",
    "desonesto": "honesto",
    "desonestidade": "honestidade",
    "desonra": "honra",
    "desinfecte": "infectar",
    "desintegrar": "integrar",
    "disjuntivo": "conjuntivo",
    "não gosta": "gosto",
    "desalojar": "apresentar",
    "desobediência": "obediência",
    "desobediente": "obediente",
    "desobedecer": "obedecer",
    "desordem": "ordem",
    "desordenado": "ordenadamente",
    "desorganizado": "organizado",
    "desagradado": "satisfeito",
    "refutar": "provar",
    "desqualificar": "qualificar",
    "infeliz": "feliz",
    "descrédito": "reputação",
    "desrespeito": "respeito",
    "desrespeitoso": "respeitoso",
    "insatisfação": "satisfação",
    "dissidência": "concordância",
    "desserviço": "serviço",
    "diferente": "semelhante",
    "dissonância": "harmonia",
    "dissuadir": "persuadir",
    "distal": "proximal",
    "distante": "fechar",
    "aberto": "fechar",
    "distinguível": "indistinguível",
    "desconfiança": "confiar em",
    "diurno": "noturno",
    "divergir": "convergem",
    "divergência": "convergência",
    "divergente": "convergente",
    "dividir": "unir",
    "sozinho": "multiplicar",
    "dividido": "unidos",
    "divisível": "indivisível",
    "doméstica": "estrangeiro",
    "nativo": "estrangeiro",
    "dominante": "subordinar",
    "dormente": "ativo",
    "extinto": "existente",
    "inativo": "ativo",
    "passiva": "ativo",
    "quieto": "barulhento",
    "duplo": "solteiro",
    "múltiplo": "solteiro",
    "pomba": "falcão",
    "dramático": "letra",
    "seco": "molhado",
    "azedar": "adoçar",
    "vencimento": "indevida",
    "maçante": "aguçar",
    "aplainar": "aguçar",
    "morrendo": "nascente",
    "facilidade": "dificuldade",
    "fácil": "desconfortável",
    "ebb": "maré",
    "excêntrico": "concêntrico",
    "educado": "indelicado",
    "eficaz": "ineficaz",
    "eficiência": "ineficiência",
    "eficiente": "ineficiente",
    "saída": "entrada",
    "elástico": "inelástica",
    "elegíveis": "inelegível",
    "emocional": "cerebral",
    "empírico": "teórico",
    "vazio": "cheio",
    "fino": "engrossar",
    "habilitar": "desativar",
    "encorajar": "desencorajar",
    "encorajamento": "desânimo",
    "fim": "começando",
    "final": "próximo",
    "meio": "cedo",
    "endêmico": "cosmopolita",
    "provincial": "cosmopolita",
    "energético": "letárgico",
    "reforçar": "isentar",
    "se empenhar": "desengatar",
    "apreciar": "sofra",
    "entrar": "saída",
    "igual": "desigual",
    "igualdade": "desigualdade",
    "equatorial": "polar",
    "equitativo": "desigual",
    "equívoco": "concepção",
    "apagar": "registro",
    "estabelecer": "abolir",
    "agitado": "sem intercorrências",
    "evergreen": "decíduo",
    "evolução": "devolução",
    "exclusão": "inclusão",
    "isentar": "reforçar",
    "exalar": "inalar",
    "saída": "entrar",
    "expandir": "contrato",
    "expandido": "contratado",
    "expansão": "contração",
    "esperado": "inesperado",
    "caro": "barato",
    "com experiência": "inexperiente",
    "exportar": "importar",
    "expressar": "local",
    "geral": "específico",
    "nacional": "internacional",
    "extensão": "flexão",
    "exterior": "interior",
    "externo": "interno",
    "externamente": "internamente",
    "extinguir": "inflamar",
    "extramuros": "intramural",
    "extraordinário": "comum",
    "extrínseco": "intrínseco",
    "falhando": "passagem",
    "corrida": "parado",
    "falha": "sucesso",
    "justo": "injusto",
    "fiel": "infiel",
    "cair": "subir",
    "conjunto": "subir",
    "falível": "infalível",
    "queda": "aumentar",
    "falsidade": "verdade",
    "fama": "infâmia",
    "familiar": "desconhecido",
    "chique": "avião",
    "gordo": "fino",
    "cheio": "vazio",
    "grosso": "fino",
    "engrossar": "fino",
    "pai": "criança",
    "fauna": "flora",
    "favorável": "desfavorável",
    "federal": "unitário",
    "fêmea": "masculino",
    "feminino": "neutro",
    "feminilidade": "masculinidade",
    "fertil": "estéril",
    "fidelidade": "infidelidade",
    "figura": "chão",
    "preencher": "vazio",
    "encontrar": "perder",
    "terminar": "começar",
    "pare": "começar",
    "finito": "infinito",
    "fogo": "contratar",
    "flexão": "extensão",
    "flutuador": "pia",
    "fonte": "pia",
    "flora": "fauna",
    "foco": "borrão",
    "inimigo": "amigos",
    "dobra": "desdobrar",
    "segue": "preceder",
    "ter sucesso": "preceder",
    "seguidor": "líder",
    "loucura": "sabedoria",
    "insensato": "sensato",
    "pé": "cabeça",
    "rabo": "cabeça",
    "proibido": "permitir",
    "fore": "a popa",
    "primeiro plano": "fundo",
    "estrangeiro": "nativo",
    "esqueço": "lembrar",
    "perdoando": "implacável",
    "formalismo": "imitação",
    "afortunado": "infeliz",
    "anverso": "marcha ré",
    "falta": "justo",
    "injusto": "justo",
    "encontrado": "perdido",
    "fraterno": "idêntico",
    "congelar": "ferver",
    "freqüente": "infreqüente",
    "freqüentemente": "raramente",
    "amigos": "inimigo",
    "cabeça": "rabo",
    "plenitude": "vazio",
    "funcional": "orgânico",
    "inorgânico": "orgânico",
    "ganho": "perda",
    "gasoso": "sólido",
    "oco": "sólido",
    "reunir": "espalhar",
    "generalidade": "particularidade",
    "generoso": "mesquinho",
    "menina": "garoto",
    "boa": "mal",
    "bondade": "maldade",
    "gradual": "de repente",
    "grato": "ingrato",
    "maior": "menor",
    "verde": "maduro",
    "bruto": "líquido",
    "chão": "figura",
    "culpa": "inocência",
    "culpado": "inocente",
    "alegremente": "infelizmente",
    "felicidade": "infelicidade",
    "feliz": "infeliz",
    "dureza": "suavidade",
    "intensidade": "suavidade",
    "nitidez": "suavidade",
    "harmonia": "dissonância",
    "ódio": "amor",
    "odioso": "adorável",
    "falcão": "pomba",
    "saudável": "pouco saudável",
    "audição": "surdo",
    "calor": "legal",
    "celestial": "terrestre",
    "heterogeneidade": "homogeneidade",
    "ocultar": "exposição",
    "contratar": "fogo",
    "acertar": "senhorita",
    "piedosos": "impiedade",
    "homogeneidade": "heterogeneidade",
    "homóloga": "análogo",
    "homossexual": "bissexual",
    "honesto": "desonesto",
    "honestidade": "desonestidade",
    "honra": "desonra",
    "esperança": "desespero",
    "esperançoso": "sem esperança",
    "sem esperança": "esperançoso",
    "horizontal": "vertical",
    "hostil": "amigáveis",
    "quente": "frio",
    "humilde": "orgulhoso",
    "humildade": "orgulho",
    "com fome": "com sede",
    "idêntico": "fraterno",
    "ocioso": "trabalhos",
    "ígneo": "aquoso",
    "inflamar": "extinguir",
    "ignorar": "aviso prévio",
    "ilegal": "legal",
    "ilegalidade": "legalidade",
    "ilegível": "legível",
    "ilógico": "lógico",
    "imitação": "formalismo",
    "imaterial": "material",
    "imaturidade": "maturidade",
    "imensurável": "mensurável",
    "imoral": "moral",
    "imoralidade": "moralidade",
    "imortal": "mortal",
    "imortalidade": "mortalidade",
    "imutável": "mutável",
    "imparcialidade": "parcialidade",
    "intransitável": "passável",
    "impaciência": "paciência",
    "impaciente": "paciente",
    "imperceptível": "perceptível",
    "imperfeição": "perfeição",
    "impermeável": "permeável",
    "inadmissível": "admissível",
    "impessoal": "pessoal",
    "indelicado": "educado",
    "importar": "exportar",
    "importante": "sem importância",
    "impossibilidade": "possibilidade",
    "impotente": "poderoso",
    "improvável": "provável",
    "melhorado": "não melhorado",
    "melhoria": "declínio",
    "imprudente": "cauteloso",
    "impureza": "pureza",
    "incapacidade": "capacidade",
    "inacessível": "acessível",
    "impreciso": "preciso",
    "inação": "açao",
    "inatividade": "atividade",
    "inadequado": "adequado",
    "inanimado": "animar",
    "falta de atenção": "atenção",
    "inaudível": "audível",
    "incapaz": "capaz",
    "inclinado": "horizontal",
    "vertical": "horizontal",
    "inclusão": "exclusão",
    "incoerente": "coerente",
    "incompatível": "compatível",
    "incompetência": "competência",
    "incompetente": "competente",
    "incompletude": "completude",
    "inconsiderado": "atencioso",
    "inconsistência": "consistência",
    "discreto": "conspícuo",
    "inconveniente": "conveniente",
    "aumentar": "diminuir",
    "aumentou": "diminuiu",
    "incremento": "decremento",
    "incurável": "curável",
    "indecência": "decência",
    "indecente": "decente",
    "indecisão": "decisão",
    "indeciso": "decisivo",
    "independente": "dependente",
    "indistinguível": "distinguível",
    "indivisível": "divisível",
    "interior": "exterior",
    "ineficaz": "eficaz",
    "ineficiência": "eficiência",
    "ineficiente": "eficiente",
    "inelástica": "elástico",
    "inelegível": "elegíveis",
    "desigualdade": "igualdade",
    "inexperiente": "com experiência",
    "infalível": "falível",
    "infâmia": "fama",
    "infectar": "desinfecte",
    "inferioridade": "superioridade",
    "infidelidade": "fidelidade",
    "infinito": "finito",
    "inflação": "deflação",
    "informado": "desinformado",
    "infreqüente": "freqüente",
    "raramente": "freqüentemente",
    "entrada": "saída",
    "habitado": "desabafado",
    "inalar": "exalar",
    "injustiça": "justiça",
    "inocência": "culpa",
    "inocente": "culpado",
    "inócuo": "nocivo",
    "inoperante": "operativo",
    "insano": "sã",
    "insanidade": "sanidade",
    "insegurança": "segurança",
    "insignificância": "significado",
    "insignificante": "significativo",
    "insolúvel": "solúvel",
    "insolvência": "solvência",
    "insolvente": "solvente",
    "instabilidade": "estabilidade",
    "instrumental": "vocal",
    "insuficiência": "suficiência",
    "insuficiente": "suficiente",
    "insuficientemente": "suficientemente",
    "integrar": "desintegrar",
    "integração": "separação",
    "inteligência": "estupidez",
    "inteligível": "ininteligível",
    "pretendido": "não intencional",
    "intencionalmente": "sem querer",
    "interessado": "desinteressado",
    "interessante": "desinteressante",
    "intermediário": "terminal",
    "interno": "externo",
    "internamente": "externamente",
    "internacional": "nacional",
    "local": "geral",
    "intolerância": "tolerância",
    "intolerante": "tolerante",
    "intratável": "tratável",
    "intramural": "extramuros",
    "intrínseco": "extrínseco",
    "invisibilidade": "visibilidade",
    "invisível": "visível",
    "involuntário": "voluntário",
    "irracional": "racional",
    "irregular": "regular",
    "irregularidade": "regularidade",
    "irrelevante": "relevante",
    "irresponsável": "responsável",
    "irreverente": "reverente",
    "questão": "responda",
    "junta": "separado",
    "alegria": "tristeza",
    "júnior": "senior",
    "justiça": "injustiça",
    "juvenil": "adulto",
    "kern": "kern",
    "tipo": "desagradável",
    "rei": "rainha",
    "leigos": "clero",
    "atrasado": "cedo",
    "rir": "chorar",
    "laxista": "tenso",
    "relaxado": "tenso",
    "leigo": "clérigo",
    "conduzir": "déficit",
    "líder": "seguidor",
    "sair": "chegar",
    "esquerda": "centro",
    "legalidade": "ilegalidade",
    "legalizar": "bandido",
    "legível": "ilegível",
    "emprestar": "pedir emprestado",
    "emprestador": "mutuário",
    "alongar": "encurtar",
    "menor": "principal",
    "letárgico": "energético",
    "nível": "levantar",
    "mais baixo": "levantar",
    "liberal": "conservador",
    "mentira": "ficar de pé",
    "produção": "ficar de pé",
    "luz": "sombrio",
    "leveza": "peso",
    "gosto": "não gosta",
    "limitado": "ilimitado",
    "linear": "colateral",
    "líquido": "bruto",
    "sólido": "oco",
    "específico": "geral",
    "localização": "estúdio",
    "bloqueio": "desbloquear",
    "apresentar": "desalojar",
    "lógico": "ilógico",
    "longo": "curto",
    "alta": "curto",
    "afrouxar": "endurecer",
    "perda": "ganho",
    "perdido": "encontrado",
    "adorável": "odioso",
    "amor": "ódio",
    "por sorte": "azarado",
    "letra": "dramático",
    "principal": "menor",
    "maioria": "minoria",
    "faço": "pausa",
    "reparar": "pausa",
    "masculino": "feminino",
    "maligno": "benigno",
    "manual": "automático",
    "marcado": "sem marca",
    "casado": "solteiro",
    "masculinidade": "feminilidade",
    "mascarar": "desmascarar",
    "material": "imaterial",
    "materno": "paterno",
    "maturidade": "imaturidade",
    "máximo": "mínimo",
    "mensurável": "imensurável",
    "mental": "fisica",
    "misericordioso": "implacável",
    "implacável": "perdoando",
    "militares": "civil",
    "mente": "esqueço",
    "lembrar": "esqueço",
    "mínimo": "máximo",
    "minoria": "maioria",
    "senhorita": "acertar",
    "molar": "molecular",
    "molecular": "molar",
    "moral": "imoral",
    "moralidade": "imoralidade",
    "mortal": "imortal",
    "mortalidade": "imortalidade",
    "mãe": "pai",
    "multiplicar": "sozinho",
    "unir": "dividir",
    "nadir": "zênite",
    "limitar": "ampliar",
    "nascente": "morrendo",
    "negativo": "neutro",
    "negligente": "diligente",
    "sobrinho": "sobrinha",
    "sobrinha": "sobrinho",
    "noite": "dia",
    "noturno": "diurno",
    "nominal": "real",
    "irreal": "real",
    "inexistente": "existente",
    "normal": "anormal",
    "aviso prévio": "ignorar",
    "nocivo": "inócuo",
    "numérico": "verbal",
    "obediência": "desobediência",
    "obediente": "desobediente",
    "obedecer": "desobedecer",
    "objetivo": "subjetivo",
    "obrigatório": "opcional",
    "oblíquo": "perpendicular",
    "obscuridade": "proeminência",
    "opacidade": "transparência",
    "ofensa": "defesa",
    "processo": "defesa",
    "ofensiva": "defensiva",
    "oficial": "não oficial",
    "abertura": "proximidade",
    "operativo": "inoperante",
    "opôs-se": "sem oposição",
    "oposto": "alternar",
    "otimismo": "pessimismo",
    "otimista": "pessimista",
    "opcional": "obrigatório",
    "oral": "anal",
    "ordem": "desordem",
    "ordenadamente": "desordenado",
    "orgânico": "inorgânico",
    "organizado": "desorganizado",
    "ortodoxo": "pouco ortodoxo",
    "ao ar livre": "interior",
    "bandido": "legalizar",
    "superestimar": "subestimar",
    "a sobrecarga": "superfície",
    "abertos": "encoberta",
    "pacote": "descompactar",
    "doloroso": "sem dor",
    "sem dor": "doloroso",
    "paralelo": "oblíquo",
    "perpendicular": "oblíquo",
    "parcialidade": "imparcialidade",
    "particularidade": "generalidade",
    "parcialmente": "completamente",
    "passável": "intransitável",
    "passagem": "corrida",
    "parado": "corrida",
    "passado": "futuro",
    "presente": "ausente",
    "paterno": "materno",
    "paciência": "impaciência",
    "paciente": "impaciente",
    "patrocinar": "boicote",
    "paz": "guerra",
    "pena": "recompensa",
    "perceptível": "imperceptível",
    "perfeição": "imperfeição",
    "permeável": "impermeável",
    "permitida": "inadmissível",
    "permissivo": "preventivo",
    "permitir": "proibido",
    "pessoal": "impessoal",
    "persuadir": "dissuadir",
    "pessimismo": "otimismo",
    "pessimista": "otimista",
    "fisica": "mental",
    "avião": "chique",
    "demandante": "réu",
    "satisfeito": "desagradado",
    "plural": "singular",
    "polar": "equatorial",
    "popular": "impopular",
    "porosidade": "solidez",
    "possibilidade": "impossibilidade",
    "posterior": "anterior",
    "potente": "impotente",
    "potencial": "real",
    "pobreza": "riqueza",
    "poderoso": "impotente",
    "elogio": "criticar",
    "preceder": "ter sucesso",
    "precedente": "sucedendo",
    "prefixo": "sufixo",
    "preparação": "resolução",
    "preparado": "despreparado",
    "prescritivo": "descritivo",
    "presença": "ausência",
    "preservado": "destruído",
    "preventivo": "permissivo",
    "primário": "secundário",
    "privado": "público",
    "em particular": "publicamente",
    "provável": "improvável",
    "produtivo": "improdutivo",
    "profano": "sagrado",
    "profissional": "amador",
    "progresso": "regredir",
    "progressivo": "regressivo",
    "prospectivo": "retrospectivo",
    "protegido": "desprotegido",
    "orgulhoso": "humilde",
    "provar": "refutar",
    "proximal": "distal",
    "próximo": "final",
    "prudente": "imprudente",
    "público": "privado",
    "publicamente": "em particular",
    "publicados": "inédito",
    "puxar": "empurrar",
    "pontualidade": "atraso",
    "purga": "reabilitar",
    "pureza": "impureza",
    "empurrar": "puxar",
    "qualificar": "desqualificar",
    "rainha": "rei",
    "questionável": "inquestionável",
    "rapidamente": "lentamente",
    "levantar": "mais baixo",
    "racional": "irracional",
    "realista": "irrealista",
    "tranquilizar": "preocupação",
    "recordar": "questão",
    "registro": "apagar",
    "refrão": "aja",
    "recusar": "aceitar",
    "regredir": "progresso",
    "regressivo": "progressivo",
    "regular": "irregular",
    "regularidade": "irregularidade",
    "regulamentado": "não regulamentado",
    "reabilitar": "purga",
    "rejeição": "aceitação",
    "rejuvenescer": "era",
    "relacionado": "não relacionado",
    "relativo": "absoluto",
    "relevante": "irrelevante",
    "confiável": "não confiável",
    "religioso": "secular",
    "repulsão": "atração",
    "respeitável": "infeliz",
    "reputação": "descrédito",
    "resistir": "entrega",
    "resolução": "preparação",
    "respeito": "desrespeito",
    "respeitoso": "desrespeitoso",
    "responsável": "irresponsável",
    "restringido": "sem restrições",
    "restrito": "sem restrições",
    "retrospectivo": "prospectivo",
    "reverente": "irreverente",
    "reversão": "afirmação",
    "recompensa": "pena",
    "passeio": "andar",
    "maduro": "verde",
    "aumentar": "queda",
    "rotor": "estator",
    "rugosidade": "suavidade",
    "volta": "quadrado",
    "arredondado": "angular",
    "rural": "urbano",
    "pressa": "demorar",
    "sagrado": "profano",
    "infelizmente": "alegremente",
    "tristeza": "alegria",
    "infelicidade": "felicidade",
    "seguro": "perigoso",
    "segurança": "insegurança",
    "semelhança": "diferença",
    "sã": "insano",
    "sanidade": "insanidade",
    "satisfação": "insatisfação",
    "salgados": "desagradável",
    "escasso": "abundante",
    "escassez": "abundância",
    "científico": "não científico",
    "escrupuloso": "sem escrúpulos",
    "secundário": "primário",
    "secular": "religioso",
    "separação": "união",
    "egoísta": "altruísta",
    "vender": "comprar",
    "senior": "júnior",
    "separado": "junta",
    "séptico": "antisséptico",
    "serviço": "desserviço",
    "resolvido": "inesgotável",
    "aguçar": "aplainar",
    "curto": "alta",
    "encurtar": "alongar",
    "gritar": "sussurro",
    "exposição": "ocultar",
    "encolher": "esticam",
    "lado": "inferior",
    "topo": "inferior",
    "significado": "insignificância",
    "significativo": "insignificante",
    "semelhante": "diferente",
    "simples": "composto",
    "simplificar": "complicar",
    "solteiro": "casado",
    "singular": "plural",
    "pia": "fonte",
    "irmã": "irmão",
    "dormir": "despertar",
    "lentamente": "rapidamente",
    "pequeno": "ampla",
    "suavidade": "rugosidade",
    "suavidade": "nitidez",
    "solidez": "porosidade",
    "solúvel": "insolúvel",
    "solvência": "insolvência",
    "solvente": "insolvente",
    "filho": "filha",
    "triste": "alegre",
    "falada": "escrito",
    "não escrito": "escrito",
    "esporádico": "contínuo",
    "espalhar": "reunir",
    "quadrado": "volta",
    "estabilidade": "instabilidade",
    "estável": "instável",
    "ficar de pé": "produção",
    "começar": "pare",
    "estator": "rotor",
    "fique": "mover",
    "íngreme": "gradual",
    "de repente": "gradual",
    "estéril": "fertil",
    "endurecer": "afrouxar",
    "mesquinho": "generoso",
    "tormentoso": "calma",
    "direto": "curvado",
    "endireitar": "dobrar",
    "desconhecido": "familiar",
    "força": "fraqueza",
    "esticam": "encolher",
    "fortemente": "fracamente",
    "estúdio": "localização",
    "estupidez": "inteligência",
    "subjetivo": "objetivo",
    "subordinar": "dominante",
    "subseqüente": "antecedente",
    "substantivo": "adjetivo",
    "subtrair": "adicionar",
    "subtração": "adição",
    "sucedendo": "precedente",
    "sucesso": "falha",
    "bem sucedido": "mal sucedido",
    "sucumbir": "sobreviver",
    "sofra": "apreciar",
    "suficiência": "insuficiência",
    "suficiente": "insuficiente",
    "suficientemente": "insuficientemente",
    "sufixo": "prefixo",
    "nascer do sol": "por do sol",
    "por do sol": "nascer do sol",
    "superior": "inferior",
    "superioridade": "inferioridade",
    "fornecem": "exigem",
    "apoiado": "não suportado",
    "superfície": "a sobrecarga",
    "entrega": "resistir",
    "sobreviver": "sucumbir",
    "doce": "azedar",
    "molhado": "seco",
    "adoçar": "azedar",
    "simetria": "assimetria",
    "simpático": "antipático",
    "sinérgico": "antagônico",
    "síntese": "análise",
    "sintético": "analítico",
    "atraso": "pontualidade",
    "de bom gosto": "insípido",
    "saboroso": "insípido",
    "insípido": "saboroso",
    "concurso": "resistente",
    "tenso": "relaxado",
    "terminal": "intermediário",
    "teísmo": "ateísmo",
    "teórico": "empírico",
    "com sede": "com fome",
    "pensativo": "irrefletido",
    "irrefletido": "pensativo",
    "econômico": "desperdício",
    "maré": "ebb",
    "gravata": "desatar",
    "tímido": "negrito",
    "timidez": "ousadia",
    "tolerância": "intolerância",
    "tolerante": "intolerante",
    "denteado": "desdentado",
    "desdentado": "denteado",
    "tocou": "intocado",
    "resistente": "concurso",
    "tratável": "intratável",
    "tragédia": "comédia",
    "treinado": "não treinado",
    "confiar em": "desconfiança",
    "verdade": "falsidade",
    "feiúra": "beleza",
    "feio": "bonita",
    "inaceitável": "aceitável",
    "não reconhecido": "reconhecido",
    "inalterado": "mudou",
    "sem ambiguidade": "ambíguo",
    "desarmado": "armado",
    "não autorizado": "autorizado",
    "desequilibrado": "equilibrado",
    "incredulidade": "crença",
    "não consolidado": "limite",
    "inquebrável": "quebrável",
    "inteiro": "partido",
    "incerteza": "certeza",
    "tio": "tia",
    "incomum": "usual",
    "despreocupado": "preocupado",
    "não confirmado": "confirmado",
    "desconectado": "conectado",
    "inconsciência": "consciência",
    "inconstitucional": "constitucional",
    "não convencional": "convencional",
    "não convencido": "convencido",
    "descobrir": "tampa",
    "sem cortes": "cortar",
    "indefinido": "definiram",
    "subestimar": "superestimar",
    "indesejável": "desejável",
    "indevida": "vencimento",
    "sem instrução": "educado",
    "inequívoca": "equívoco",
    "sem intercorrências": "agitado",
    "inesperado": "esperado",
    "infiel": "fiel",
    "desfavorável": "favorável",
    "desdobrar": "dobra",
    "ingrato": "grato",
    "pouco saudável": "saudável",
    "impiedade": "piedosos",
    "sem importância": "importante",
    "não melhorado": "melhorado",
    "desinformado": "informado",
    "desabafado": "habitado",
    "ininteligível": "inteligível",
    "não intencional": "pretendido",
    "sem querer": "intencionalmente",
    "desinteressado": "interessado",
    "desinteressante": "interessante",
    "união": "separação",
    "unitário": "federal",
    "unidos": "dividido",
    "ilimitado": "limitado",
    "desbloquear": "bloqueio",
    "azarado": "por sorte",
    "sem marca": "marcado",
    "desmascarar": "mascarar",
    "desocupado": "ocupado",
    "não oficial": "oficial",
    "sem oposição": "opôs-se",
    "pouco ortodoxo": "ortodoxo",
    "descompactar": "pacote",
    "impopular": "popular",
    "despreparado": "preparado",
    "improdutivo": "produtivo",
    "desprotegido": "protegido",
    "inédito": "publicados",
    "inquestionável": "questionável",
    "irrealista": "realista",
    "não regulamentado": "regulamentado",
    "não relacionado": "relacionado",
    "não confiável": "confiável",
    "sem restrições": "restrito",
    "não científico": "científico",
    "sem escrúpulos": "escrupuloso",
    "altruísta": "egoísta",
    "inesgotável": "resolvido",
    "instável": "estável",
    "mal sucedido": "bem sucedido",
    "não suportado": "apoiado",
    "antipático": "simpático",
    "desatar": "gravata",
    "intocado": "tocou",
    "não treinado": "treinado",
    "desvendar": "véu",
    "de forma involuntária": "de boa vontade",
    "falta de vontade": "disposição",
    "relaxar": "vento",
    "indigno": "digno",
    "urbano": "rural",
    "usual": "incomum",
    "valioso": "inútil",
    "véu": "desvendar",
    "verbal": "numérico",
    "vitória": "derrota",
    "virtuoso": "perverso",
    "visibilidade": "invisibilidade",
    "visível": "invisível",
    "vocal": "instrumental",
    "voluntário": "involuntário",
    "vogal": "consoante",
    "despertar": "dormir",
    "andar": "passeio",
    "piora": "cera",
    "guerra": "paz",
    "cauteloso": "imprudente",
    "desperdício": "econômico",
    "cera": "piora",
    "fracamente": "fortemente",
    "fraqueza": "força",
    "riqueza": "pobreza",
    "sem peso": "pesado",
    "pesado": "sem peso",
    "sussurro": "gritar",
    "branco": "preto",
    "completamente": "parcialmente",
    "perverso": "virtuoso",
    "largo": "limitar",
    "ampliar": "limitar",
    "de boa vontade": "de forma involuntária",
    "disposição": "falta de vontade",
    "vento": "relaxar",
    "sabedoria": "loucura",
    "sensato": "insensato",
    "retirar o": "depósito",
    "preocupação": "tranquilizar",
    "inútil": "valioso",
    "digno": "indigno",
    "escrito": "não escrito",
    "jovem": "idade",
    "zênite": "nadir",
}
