_antonyms = {
    "способност": "неспособност",
    "абнормални": "нормално",
    "укинување": "утврди",
    "отсуство": "присуство",
    "отсутен": "присутен",
    "иднина": "минато",
    "апсолутно": "роднина",
    "апстинираат": "консумираат",
    "апстракт": "бетон",
    "изобилство": "ретки",
    "прифати": "отфрли",
    "признаам": "негира",
    "прифатливо": "неприфатливо",
    "прифаќање": "одбивање",
    "достапни": "недостапни",
    "точен": "неточни",
    "признати": "непознат",
    "познаник": "странец",
    "чин": "воздржете се",
    "акција": "неактивност",
    "активен": "тивок",
    "постоечки": "исчезнат",
    "бучна": "тивок",
    "активност": "неактивност",
    "вистински": "потенцијал",
    "додадете": "одземе",
    "покрај тоа": "одземање",
    "соодветен": "несоодветни",
    "придавка": "суштински",
    "допуштена": "неприфатливо",
    "возрасен": "малолетничка",
    "однапред": "отстапи",
    "напред": "заден",
    "вечер": "назад",
    "предност": "недостаток",
    "афирмација": "пресврт",
    "потврден": "негативно",
    "неутрален": "негативно",
    "назад": "напред",
    "возраст": "подмладување",
    "на возраст": "млад",
    "агитација": "смиреност",
    "се согласувам": "не се согласувам",
    "согласна": "непријатни",
    "договор": "проширен",
    "променети": "непроменета",
    "алтернативен": "спротивното",
    "аматер": "професионален",
    "двосмислена": "недвосмислено",
    "пријателски": "непријателски",
    "амфибиски": "земно",
    "анален": "орален",
    "аналогно": "хомологна",
    "анализа": "синтеза",
    "аналитички": "синтетички",
    "предок": "потомок",
    "аголна": "заоблени",
    "анимирај": "неживо",
    "одговор": "прашање",
    "антагонистички": "синергистички",
    "претходник": "последователните",
    "предна страна": "постериорно",
    "антисептик": "септички",
    "изглед": "исчезнување",
    "благодарност": "амортизација",
    "одобрување": "несогласување",
    "одобри": "одобри",
    "водни": "амфибиски",
    "земно": "небесен",
    "воден": "изненаден",
    "рака": "разоружа",
    "вооружени": "невооружени",
    "пристигне": "остави",
    "се искачи": "слезе",
    "искачување": "потекло",
    "спие": "буден",
    "асиметрија": "симетрија",
    "атеизам": "теизмот",
    "прикачи": "одвој",
    "напад": "брани",
    "гонење": "одбрана",
    "внимание": "невнимание",
    "атракција": "одбивност",
    "звучен": "нечујни",
    "зголемување": "декрет",
    "тетка": "чичко",
    "овластен": "неовластено",
    "автоматски": "прирачник",
    "избегнувајте": "се соочи",
    "буден": "спие",
    "отстапи": "однапред",
    "заден": "главата",
    "позадина": "преден план",
    "обратна": "аверс",
    "лошо": "добрина",
    "зло": "добро",
    "избалансиран": "неурамнотежен",
    "мечка": "бик",
    "убава": "грдо",
    "убавина": "грдотија",
    "започнете": "запре",
    "почеток": "средината",
    "рано": "доцна",
    "верување": "неверување",
    "се наведнуваат": "исправи",
    "бенигни": "малигни",
    "големо": "мал",
    "големи": "малолетник",
    "раѓање": "смрт",
    "бисексуалци": "хомосексуалец",
    "црна": "бела",
    "благослови": "проклетство",
    "благословен": "проколнати",
    "без крв": "крвав",
    "крвав": "без крв",
    "заматено": "фокус",
    "врие": "замрзнување",
    "задебелен": "срамежливи",
    "смелост": "плашливост",
    "позајми": "позајми",
    "заемопримачот": "давателот",
    "дното": "врв",
    "врзана": "неврзан",
    "момче": "девојче",
    "бојкот": "покрови",
    "пауза": "поправка",
    "кршливи": "нераскинлива",
    "осветли": "потемни",
    "скршен": "непрекинат",
    "брат": "сестра",
    "бик": "мечка",
    "зафатен": "неактивен",
    "работа": "неактивен",
    "купи": "продаде",
    "смирен": "горди",
    "смиреност": "агитација",
    "способен": "неспособни",
    "капацитет": "неспособност",
    "готовина": "кредит",
    "дебитна": "кредит",
    "центар": "лево",
    "церебрална": "емоционално",
    "сигурност": "неизвесност",
    "промена": "останете",
    "заминам": "останете",
    "се движи": "останете",
    "променлива": "непроменлив",
    "сменето": "непроменет",
    "задолжен": "празнење",
    "пријави": "празнење",
    "евтини": "скапо",
    "навиваат": "се жалат",
    "весели": "депресивно",
    "дете": "родител",
    "цивилен": "воена",
    "тврдат": "се губи",
    "јасност": "непроѕирност",
    "важност": "опскурност",
    "транспарентност": "непроѕирност",
    "чист": "нечист",
    "свештенството": "лаици",
    "свештеник": "лаик",
    "затвори": "отворен",
    "затворена": "отворен",
    "блискост": "отвореност",
    "крајбрежни": "во внатрешноста",
    "кохерентна": "некохерентни",
    "студ": "топло",
    "колатерал": "линеарен",
    "комедија": "трагедија",
    "удобност": "непријатност",
    "чести": "ретко",
    "компатибилен": "некомпатибилни",
    "компетентност": "некомпетентност",
    "компетентен": "неспособни",
    "конкуренција": "соработка",
    "се жалат": "навиваат",
    "комплетноста": "некомплетност",
    "комплексен": "едноставно",
    "соединение": "едноставно",
    "согласност": "пркосен",
    "комплицира": "поедноставување",
    "конкавна": "конвексен",
    "суета": "смирение",
    "гордост": "смирение",
    "концентрација": "дистрибуција",
    "концентрично": "ексцентричен",
    "концепција": "заблуда",
    "загрижени": "незаинтересиран",
    "бетон": "апстракт",
    "потврдено": "непотврдени",
    "се соочи": "избегнувајте",
    "конјунктивно": "дисјугентен",
    "поврзи се": "исклучете го",
    "поврзани": "неповрзани",
    "свест": "несвесност",
    "конзервативен": "либерален",
    "зачувување": "отпад",
    "внимателен": "безмислено",
    "конзистентност": "неконзистентност",
    "согласка": "самогласка",
    "упадливи": "незабележливо",
    "уставно": "неуставен",
    "консумираат": "апстинираат",
    "содржина": "незадоволство",
    "континуирано": "дисконтинуиран",
    "продолжување": "скрати",
    "продолжи": "прекинете",
    "континуитет": "дисконтинуитет",
    "контракција": "експанзија",
    "погодно": "незгодно",
    "конвенционален": "неконвенционален",
    "конвергираат": "разминуваат",
    "конвергенција": "дивергенција",
    "конвергентна": "дивергентни",
    "конвексен": "конкавна",
    "убеден": "неубедени",
    "кул": "топлина",
    "соработка": "конкуренција",
    "космополитски": "провинциски",
    "храброст": "кукавичлук",
    "покритие": "открие",
    "тајно": "отворена",
    "кукавичлук": "храброст",
    "кредит": "дебитна",
    "доверител": "должник",
    "критикуваат": "пофалба",
    "плаче": "се смееш",
    "лекува": "неизлечива",
    "проклетство": "благослови",
    "проколнати": "благословен",
    "криви": "директно",
    "сече": "несечени",
    "опасност": "безбедност",
    "опасно": "безбеден",
    "темно": "светлина",
    "потемни": "осветли",
    "темнина": "леснотија",
    "тежина": "леснотија",
    "ќерка": "син",
    "ден": "ноќ",
    "глуви": "слух",
    "смрт": "раѓање",
    "должник": "доверител",
    "пристојност": "неприлична",
    "пристоен": "непристојни",
    "листопадни": "зимзелени",
    "одлука": "неодлучноста",
    "одлучувачки": "неодлучен",
    "пад": "подобрување",
    "намалување": "зголемување",
    "намален": "се зголеми",
    "декрет": "зголемување",
    "пораз": "победа",
    "брани": "гонење",
    "обвинетиот": "тужителот",
    "одбрана": "гонење",
    "дефанзивен": "офанзива",
    "пркосен": "согласност",
    "дефицит": "олово",
    "дефинирани": "недефинирано",
    "дефлација": "инфлација",
    "одложување": "брзање",
    "се задржува": "брзање",
    "побарувачка": "снабдување",
    "негира": "доказ",
    "отфрли": "прифати",
    "зависен": "независна",
    "депозит": "се повлече",
    "амортизација": "благодарност",
    "депресивно": "весели",
    "слезе": "се искачи",
    "потомок": "предок",
    "потекло": "искачување",
    "описни": "пропишан",
    "пожелно": "непожелни",
    "очај": "надеж",
    "очајни": "надеж",
    "уништени": "зачувани",
    "одвој": "прикачи",
    "деволуција": "еволуција",
    "се разликуваат": "еднакви",
    "нееднаков": "еднакви",
    "разлика": "истосност",
    "тешко": "тендер",
    "непријатно": "пријатен",
    "тешкотии": "леснотија",
    "вредни": "безвредни",
    "разредување": "концентрација",
    "дистрибуција": "концентрација",
    "валкани": "чист",
    "нечист": "чист",
    "оневозможи": "овозможи",
    "недостаток": "изобилство",
    "не се согласувам": "се согласувам",
    "непријатни": "согласна",
    "несогласување": "одобрување",
    "исчезнување": "изглед",
    "неодобрување": "одобрување",
    "разоружа": "рака",
    "празнење": "пријави",
    "одрекувам": "тврдат",
    "се губи": "тврдат",
    "непријатност": "удобност",
    "исклучете го": "поврзи се",
    "незадоволство": "задоволство",
    "прекин": "продолжување",
    "прекинете": "продолжи",
    "дисконтинуитет": "континуитет",
    "дисконтинуиран": "континуирано",
    "обесхрабри": "поттикнете",
    "обесхрабрување": "охрабрување",
    "ослободување": "се вклучи",
    "нечесен": "искрен",
    "нечесност": "искреност",
    "срамно": "чест",
    "дезинфицира": "зарази",
    "се распадне": "интегрираат",
    "дисјугентен": "конјунктивно",
    "не им се допаѓаат": "вкус",
    "исфрли": "ложа",
    "непослушност": "послушност",
    "непослушен": "послушен",
    "непослушни": "послушај се",
    "нарушување": "со цел",
    "неуредно": "уреден",
    "неорганизирано": "организирано",
    "незадоволен": "задоволен",
    "дисквалификува": "се квалификува",
    "дискредитиран": "реномирани",
    "заблуда": "концепција",
    "непочитување": "почитувана",
    "лоша услуга": "сервис",
    "различен": "слично",
    "дисонанца": "хармонија",
    "одврати": "убеди",
    "дистална": "проксимална",
    "далечно": "затвори",
    "отворен": "затвори",
    "разликува": "не се разликува",
    "недоверба": "доверба",
    "дневни": "ноќен",
    "разминуваат": "конвергираат",
    "дивергенција": "конвергенција",
    "дивергентни": "конвергентна",
    "подели": "обедини",
    "посебно": "множете се",
    "поделени": "обединета",
    "делив": "неделив",
    "домашен": "странски",
    "мајчин": "странски",
    "доминантна": "подредени",
    "хибернација": "активен",
    "исчезнат": "постоечки",
    "неактивен": "работа",
    "пасивно": "активен",
    "тивок": "бучна",
    "двојно": "сингл",
    "повеќекратно": "сингл",
    "гулаб": "јастреб",
    "драматично": "лирски",
    "сува": "влажни",
    "кисело": "слатка",
    "поради": "непотребно",
    "досадна": "остри",
    "израмните": "остри",
    "умирање": "зародиш",
    "леснотија": "тежина",
    "лесно": "непријатно",
    "одлив": "плима",
    "ексцентричен": "концентрично",
    "образовани": "необразован",
    "ефикасен": "неефикасен",
    "ефикасност": "неефикасност",
    "излез": "внесете",
    "еластична": "нееластичен",
    "подобни": "неподобен",
    "емоционално": "церебрална",
    "емпириски": "теоретски",
    "празнина": "полнота",
    "празен": "целосна",
    "тенки": "се згусне",
    "овозможи": "оневозможи",
    "поттикнете": "обесхрабри",
    "охрабрување": "обесхрабрување",
    "крајот": "почеток",
    "завршувајќи": "почеток",
    "средината": "рано",
    "ендемични": "космополитски",
    "провинциски": "космополитски",
    "енергичен": "летаргичен",
    "enforce": "ослободен",
    "се вклучи": "ослободување",
    "уживајте": "страдаат",
    "внесете": "излез",
    "еднакви": "нееднаков",
    "еднаквост": "нееднаквост",
    "екваториски": "поларна",
    "правична": "нееднакво",
    "избришете": "рекорд",
    "утврди": "укинување",
    "паметен": "нерамномерно",
    "зимзелени": "листопадни",
    "еволуција": "деволуција",
    "исклучување": "инклузија",
    "ослободен": "enforce",
    "издишува": "дишам",
    "постои": "непостоечки",
    "прошири": "тесен",
    "проширен": "договор",
    "експанзија": "контракција",
    "се очекува": "неочекувано",
    "скапо": "евтини",
    "искусен": "неискусни",
    "извоз": "увоз",
    "изрази": "локален",
    "општо": "специфични",
    "национално": "меѓународни",
    "екстериер": "внатрешни работи",
    "надворешен": "внатрешна",
    "надворешно": "вродена",
    "изгаснат": "запалам",
    "вонредна": "обични",
    "неуспешно": "поминува",
    "трчање": "стои",
    "неуспех": "успех",
    "фер": "нефер",
    "верен": "неверен",
    "падне": "пораст",
    "во собата": "пораст",
    "погрешно": "непогрешлив",
    "паѓа": "расте",
    "лага": "стојат",
    "фалсификат": "вистина",
    "слава": "срам",
    "познат": "непознат",
    "фенси": "обичен",
    "масти": "тенки",
    "целосна": "празен",
    "дебели": "тенки",
    "се згусне": "тенки",
    "татко": "мајка",
    "фауна": "флора",
    "поволна": "неповолно",
    "федерални": "унитарна",
    "женски": "среден",
    "женственост": "машкост",
    "плодна": "стерилен",
    "верност": "неверство",
    "фигура": "земјата",
    "пополнете": "празен",
    "најдете": "изгуби",
    "заврши": "започнете",
    "запре": "започнете",
    "конечни": "бесконечно",
    "оган": "вработи",
    "флексија": "продолжување",
    "плови": "мијалник",
    "извор": "мијалник",
    "флора": "фауна",
    "фокус": "заматено",
    "непријател": "пријател",
    "пати": "се расплетува",
    "следи": "претходи",
    "успее": "претходи",
    "следбеник": "лидер",
    "глупост": "интелигенција",
    "глупаво": "мудар",
    "нога": "главата",
    "опашка": "главата",
    "забрани": "дозвола",
    "fore": "назад",
    "преден план": "позадина",
    "странски": "мајчин",
    "заборави": "се сеќавам",
    "простува": "непростлив",
    "формализам": "имитација",
    "среќа": "несреќен",
    "аверс": "обратна",
    "фаул": "фер",
    "нефер": "фер",
    "пронајден": "изгубени",
    "братски": "идентични",
    "замрзнување": "врие",
    "често": "ретко",
    "пријател": "непријател",
    "главата": "опашка",
    "полнота": "празнина",
    "функционален": "органски",
    "неоргански": "органски",
    "добивка": "загуба",
    "гасовити": "солидна",
    "шупливи": "солидна",
    "се соберат": "се шири",
    "генералност": "посебност",
    "дарежлив": "скржавиот",
    "девојче": "момче",
    "добро": "зло",
    "добрина": "лошо",
    "постепено": "одеднаш",
    "благодарни": "неблагодарна",
    "поголемо": "помалку",
    "зелена": "зрели",
    "бруто": "net",
    "земјата": "фигура",
    "вина": "невиност",
    "виновен": "невини",
    "среќно": "за жал",
    "среќен": "несреќни",
    "цврстина": "порозност",
    "гласност": "мекост",
    "острина": "мекост",
    "хармонија": "дисонанца",
    "омраза": "љубовен",
    "јастреб": "гулаб",
    "здрав": "нездраво",
    "слух": "глуви",
    "топлина": "кул",
    "небесен": "земно",
    "хетерогеност": "хомогеност",
    "крие": "шоу",
    "вработи": "оган",
    "удри": "госпоѓица",
    "свето": "профана",
    "хомогеност": "хетерогеност",
    "хомологна": "аналогно",
    "хомосексуалец": "бисексуалци",
    "искрен": "нечесен",
    "искреност": "нечесност",
    "чест": "срамно",
    "надеж": "очај",
    "надевајќи се": "безнадежен",
    "безнадежен": "надевајќи се",
    "хоризонтална": "вертикално",
    "непријателски": "пријателски",
    "топло": "студ",
    "смирение": "гордост",
    "гладни": "жеден",
    "идентични": "братски",
    "изненаден": "воден",
    "запалам": "изгаснат",
    "игнорирај": "забележи",
    "нелегално": "правен",
    "незаконитост": "законитост",
    "нечитлив": "читлив",
    "нелогично": "логично",
    "имитација": "формализам",
    "нематеријално": "материјал",
    "незрелост": "зрелост",
    "неизмеримо": "мерливи",
    "неморално": "морално",
    "неморал": "морал",
    "бесмртна": "смртен",
    "бесмртност": "смртност",
    "непроменлив": "променлива",
    "непристрасност": "пристрасност",
    "непрооден": "преоден",
    "нетрпеливост": "трпение",
    "нетрпелив": "трпелив",
    "незабележливо": "упадливи",
    "несовршеност": "совршенство",
    "непропустлив": "пропустливост",
    "недозволиво": "дозволената",
    "безлична": "лично",
    "неволја": "љубезен",
    "увоз": "извоз",
    "важно": "неважно",
    "неможност": "можност",
    "импотентен": "моќен",
    "неверојатно": "веројатно",
    "подобрени": "неоправдано",
    "подобрување": "пад",
    "неразумно": "разумно",
    "нечистотија": "чистота",
    "неспособност": "капацитет",
    "недостапни": "достапни",
    "неточни": "точен",
    "неактивност": "активност",
    "несоодветни": "соодветен",
    "неприфатливо": "прифатливо",
    "неживо": "анимирај",
    "невнимание": "внимание",
    "нечујни": "звучен",
    "неспособни": "компетентен",
    "наклонет": "хоризонтална",
    "вертикално": "хоризонтална",
    "инклузија": "исклучување",
    "некохерентни": "кохерентна",
    "некомпатибилни": "компатибилен",
    "некомпетентност": "компетентност",
    "некомплетност": "комплетноста",
    "невнимателен": "претпазливи",
    "неконзистентност": "конзистентност",
    "незгодно": "погодно",
    "се зголеми": "намален",
    "неизлечива": "лекува",
    "неприлична": "пристојност",
    "непристојни": "солени",
    "неодлучноста": "одлука",
    "неодлучен": "одлучувачки",
    "независна": "зависен",
    "не се разликува": "разликува",
    "неделив": "делив",
    "затворен": "отворено",
    "неефикасни": "ефикасен",
    "неефикасност": "ефикасност",
    "неефикасен": "ефикасен",
    "нееластичен": "еластична",
    "неподобен": "подобни",
    "нееднаквост": "еднаквост",
    "нееднакво": "правична",
    "неискусни": "искусен",
    "непогрешлив": "погрешно",
    "срам": "слава",
    "зарази": "дезинфицира",
    "инфериорен": "супериорен",
    "инфериорност": "супериорност",
    "неверство": "верност",
    "бесконечно": "конечни",
    "инфлација": "дефлација",
    "информирани": "неинформирани",
    "ретко": "често",
    "влез": "излез",
    "населени": "ненаселени",
    "дишам": "издишува",
    "неправда": "правда",
    "во внатрешноста": "крајбрежни",
    "невиност": "вина",
    "невини": "виновен",
    "едноставен": "штетен",
    "неоперативна": "оперативен",
    "лудо": "нормален",
    "лудило": "разумност",
    "несигурност": "безбедност",
    "безначајност": "значење",
    "незначителен": "значајно",
    "нерастворлив": "растворлив",
    "несолвентност": "солвентност",
    "несолвентен": "растворувач",
    "нестабилност": "стабилност",
    "инструментална": "вокал",
    "инсуфициенција": "доволност",
    "недоволно": "доволно",
    "интегрираат": "се распадне",
    "интеграција": "сегрегација",
    "интелигенција": "глупост",
    "разбирливо": "неразбирливо",
    "наменети": "ненамерно",
    "намерно": "ненамерно",
    "заинтересирани": "незаинтересирани",
    "интересно": "неинтересен",
    "внатрешни работи": "екстериер",
    "средно": "основно",
    "внатрешна": "надворешен",
    "внатрешно": "надворешно",
    "меѓународни": "национално",
    "локален": "општо",
    "нетолеранција": "толеранција",
    "нетолерантен": "толерантни",
    "неподнослива": "исполнет",
    "интрамурална": "надворешно",
    "вродена": "надворешно",
    "невидливост": "видливост",
    "невидлив": "видлив",
    "принудно": "доброволно",
    "ирационален": "рационално",
    "нередовно": "редовно",
    "неправилност": "регуларност",
    "неважно": "важно",
    "неодговорно": "одговорен",
    "непочтителен": "почитуван",
    "проблем": "потсетиме",
    "заеднички": "одделно",
    "радост": "тага",
    "весела": "тажен",
    "помлади": "сениор",
    "правда": "неправда",
    "малолетничка": "возрасен",
    "kern": "kern",
    "вид": "нељубезен",
    "цар": "кралица",
    "лаици": "свештенството",
    "доцна": "рано",
    "се смееш": "плаче",
    "законски": "незаконско",
    "лабави": "напната",
    "опуштено": "напната",
    "лаик": "свештеник",
    "олово": "дефицит",
    "лидер": "следбеник",
    "остави": "пристигне",
    "лево": "центар",
    "правен": "нелегално",
    "законитост": "незаконитост",
    "легализира": "одметник",
    "читлив": "нечитлив",
    "давателот": "заемопримачот",
    "помалку": "поголемо",
    "летаргичен": "енергичен",
    "ниво": "се подигне",
    "пониско": "се подигне",
    "либерален": "конзервативен",
    "принос": "стојат",
    "светлина": "темно",
    "вкус": "не им се допаѓаат",
    "ограничен": "неограничено",
    "линеарен": "колатерал",
    "течност": "гасовити",
    "солидна": "шупливи",
    "специфични": "општо",
    "локација": "студио",
    "заклучување": "отклучи",
    "ложа": "исфрли",
    "логично": "нелогично",
    "долго": "кратко",
    "висок": "кратко",
    "олабави": "вкочанети",
    "изгуби": "најдете",
    "загуба": "добивка",
    "изгубени": "пронајден",
    "љубовен": "омраза",
    "љубов": "омраза",
    "лирски": "драматично",
    "мнозинство": "малцинство",
    "направи": "пауза",
    "поправка": "пауза",
    "машки": "женски",
    "малигни": "бенигни",
    "прирачник": "автоматски",
    "обележан": "необележани",
    "оженет": "немажени",
    "среден": "женски",
    "машкост": "женственост",
    "маска": "демаскирам",
    "материјал": "нематеријално",
    "мајчина": "татковски",
    "зрелост": "незрелост",
    "максимум": "минимум",
    "мерливи": "неизмеримо",
    "ментален": "физички",
    "милостив": "безмилосно",
    "безмилосно": "милостив",
    "воена": "цивилен",
    "ум": "заборави",
    "се сеќавам": "заборави",
    "минимум": "максимум",
    "малолетник": "големи",
    "малцинство": "мнозинство",
    "госпоѓица": "удри",
    "моларен": "молекуларна",
    "молекуларна": "моларен",
    "морално": "неморално",
    "морал": "неморал",
    "смртен": "бесмртна",
    "смртност": "бесмртност",
    "мајка": "татко",
    "множете се": "посебно",
    "обедини": "подели",
    "mutable": "непроменлив",
    "nadir": "зенит",
    "тесен": "прошири",
    "зародиш": "умирање",
    "негативно": "неутрален",
    "несовесни": "вредни",
    "внук": "внука",
    "net": "бруто",
    "внука": "внук",
    "ноќ": "ден",
    "ноќен": "дневни",
    "номинална": "реално",
    "нереален": "реално",
    "непостоечки": "постои",
    "нормално": "коси",
    "забележи": "игнорирај",
    "штетен": "едноставен",
    "нумерички": "вербална",
    "послушност": "непослушност",
    "послушен": "непослушен",
    "послушај се": "непослушни",
    "цел": "субјективно",
    "задолжително": "изборен",
    "коси": "нормално",
    "опскурност": "важност",
    "непроѕирност": "транспарентност",
    "окупирана": "ненаселени",
    "прекршок": "одбрана",
    "офанзива": "дефанзивен",
    "официјален": "неофицијален",
    "отвореност": "блискост",
    "оперативен": "неоперативна",
    "наспроти": "неприфатен",
    "спротивното": "алтернативен",
    "оптимизам": "песимизам",
    "оптимист": "песимист",
    "изборен": "задолжително",
    "орален": "анален",
    "со цел": "нарушување",
    "уреден": "неуредно",
    "обични": "вонредна",
    "органски": "неоргански",
    "организирано": "неорганизирано",
    "православни": "необично",
    "отворено": "затворен",
    "одметник": "легализира",
    "преценете": "потценувајте",
    "надземни": "површина",
    "отворена": "тајно",
    "пакет": "отпакувај",
    "болно": "безболно",
    "безболно": "болно",
    "паралелно": "коси",
    "родител": "дете",
    "пристрасност": "непристрасност",
    "посебност": "генералност",
    "делумно": "целосно",
    "преоден": "непрооден",
    "поминува": "трчање",
    "стои": "трчање",
    "минато": "иднина",
    "присутен": "отсутен",
    "татковски": "мајчина",
    "трпение": "нетрпеливост",
    "трпелив": "нетрпелив",
    "покрови": "бојкот",
    "мир": "војна",
    "казна": "награда",
    "забележлива": "незабележливо",
    "совршенство": "несовршеност",
    "пропустливост": "непропустлив",
    "дозволената": "недозволиво",
    "попустлив": "превентивна",
    "дозвола": "забрани",
    "лично": "безлична",
    "убеди": "одврати",
    "песимизам": "оптимизам",
    "песимист": "оптимист",
    "физички": "ментален",
    "обичен": "фенси",
    "тужителот": "обвинетиот",
    "пријатен": "непријатно",
    "задоволен": "незадоволен",
    "множина": "еднина",
    "поларна": "екваториски",
    "љубезен": "неволја",
    "популарна": "непопуларен",
    "порозност": "цврстина",
    "можност": "неможност",
    "постериорно": "предна страна",
    "моќен": "немоќен",
    "потенцијал": "вистински",
    "сиромаштија": "богатство",
    "немоќен": "моќен",
    "пофалба": "критикуваат",
    "претходи": "успее",
    "претходна": "наследувајќи",
    "префикс": "суфикс",
    "подготовка": "резолуција",
    "подготвени": "неподготвени",
    "пропишан": "описни",
    "присуство": "отсуство",
    "зачувани": "уништени",
    "превентивна": "попустлив",
    "основно": "средно",
    "приватен": "јавноста",
    "приватно": "јавно",
    "веројатно": "неверојатно",
    "продуктивен": "непродуктивни",
    "профана": "свето",
    "професионален": "аматер",
    "напредок": "регрес",
    "прогресивно": "регресивно",
    "потенцијален": "ретроспектива",
    "заштитени": "незаштитени",
    "горди": "смирен",
    "доказ": "негира",
    "проксимална": "дистална",
    "блиска": "крајно",
    "разумно": "неразумно",
    "јавноста": "приватен",
    "јавно": "приватно",
    "објавен": "необјавени",
    "повлече": "притисни",
    "точност": "доцнење",
    "чистка": "рехабилитира",
    "чистота": "нечистотија",
    "притисни": "повлече",
    "се квалификува": "дисквалификува",
    "кралица": "цар",
    "прашање": "одговор",
    "сомнително": "несомнено",
    "брзо": "полека",
    "се подигне": "пониско",
    "рационално": "ирационален",
    "реално": "нереален",
    "реален": "нереално",
    "успокојувај": "се грижи",
    "потсетиме": "проблем",
    "рекорд": "избришете",
    "воздржете се": "чин",
    "одбие": "прифати",
    "регрес": "напредок",
    "регресивно": "прогресивно",
    "редовно": "нередовно",
    "регуларност": "неправилност",
    "регулирани": "нерегулиран",
    "рехабилитира": "чистка",
    "одбивање": "прифаќање",
    "подмладување": "возраст",
    "роднина": "апсолутно",
    "релевантни": "неважно",
    "сигурен": "несигурен",
    "религиозни": "секуларна",
    "одбивност": "атракција",
    "реномирани": "дискредитиран",
    "углед": "заблуда",
    "се спротивстави": "предавање",
    "резолуција": "подготовка",
    "почит": "непочитување",
    "почитувана": "непочитување",
    "одговорен": "неодговорно",
    "воздржани": "неограничен",
    "ограничено": "неограничен",
    "ретроспектива": "потенцијален",
    "почитуван": "непочтителен",
    "пресврт": "афирмација",
    "награда": "казна",
    "возење": "прошетка",
    "зрели": "зелена",
    "пораст": "во собата",
    "расте": "паѓа",
    "ротор": "статор",
    "грубост": "мазност",
    "круг": "квадрат",
    "заоблени": "аголна",
    "рурални": "урбани",
    "брзање": "се задржува",
    "за жал": "среќно",
    "тага": "радост",
    "несреќа": "среќа",
    "безбеден": "опасно",
    "безбедност": "несигурност",
    "истосност": "разлика",
    "нормален": "лудо",
    "разумност": "лудило",
    "задоволство": "незадоволство",
    "солени": "непристојни",
    "ретки": "изобилство",
    "научни": "ненаучно",
    "скрупулозно": "бескрупулозните",
    "секуларна": "религиозни",
    "сегрегација": "интеграција",
    "себични": "несебичен",
    "продаде": "купи",
    "сениор": "помлади",
    "одделно": "заеднички",
    "поделба": "унија",
    "септички": "антисептик",
    "сервис": "лоша услуга",
    "се населиле": "несмирен",
    "остри": "израмните",
    "кратко": "висок",
    "скрати": "продолжување",
    "викај": "шепот",
    "шоу": "крие",
    "се намалува": "се протега",
    "страна": "дното",
    "врв": "дното",
    "значење": "безначајност",
    "значајно": "незначителен",
    "слично": "различен",
    "едноставно": "соединение",
    "поедноставување": "комплицира",
    "сингл": "повеќекратно",
    "еднина": "множина",
    "мијалник": "извор",
    "сестра": "брат",
    "спиење": "разбуди",
    "полека": "брзо",
    "мал": "големи",
    "мазност": "грубост",
    "мекост": "острина",
    "растворлив": "нерастворлив",
    "солвентност": "несолвентност",
    "растворувач": "несолвентен",
    "син": "ќерка",
    "тажен": "весела",
    "зборува": "напишано",
    "непишано": "напишано",
    "спорадични": "континуирано",
    "се шири": "се соберат",
    "квадрат": "круг",
    "стабилност": "нестабилност",
    "стабилно": "нестабилен",
    "стојат": "принос",
    "статор": "ротор",
    "останете": "се движи",
    "стабилен": "нестабилен",
    "стрмен": "постепено",
    "одеднаш": "постепено",
    "стерилен": "плодна",
    "вкочанети": "олабави",
    "скржавиот": "дарежлив",
    "бурна": "смирен",
    "директно": "криви",
    "исправи": "се наведнуваат",
    "странец": "познаник",
    "сила": "слабост",
    "се протега": "се намалува",
    "силно": "слабо",
    "студио": "локација",
    "субјективно": "цел",
    "подредени": "доминантна",
    "последователните": "претходник",
    "суштински": "придавка",
    "одземе": "додадете",
    "одземање": "покрај тоа",
    "наследувајќи": "претходна",
    "успех": "неуспех",
    "успешна": "неуспешни",
    "подлегнува": "преживее",
    "страдаат": "уживајте",
    "доволност": "инсуфициенција",
    "доволно": "недоволно",
    "суфикс": "префикс",
    "изгрејсонце": "зајдисонце",
    "зајдисонце": "изгрејсонце",
    "супериорен": "инфериорен",
    "супериорност": "инфериорност",
    "снабдување": "побарувачка",
    "поддржан": "неподдржан",
    "површина": "надземни",
    "предавање": "се спротивстави",
    "преживее": "подлегнува",
    "слатко": "кисело",
    "влажни": "сува",
    "слатка": "кисело",
    "симетрија": "асиметрија",
    "симпатична": "несимпатичен",
    "синергистички": "антагонистички",
    "синтеза": "анализа",
    "синтетички": "аналитички",
    "доцнење": "точност",
    "вкусно": "без вкус",
    "вкусна": "без вкус",
    "без вкус": "вкусна",
    "тендер": "тешко",
    "напната": "опуштено",
    "терминал": "средно",
    "теизмот": "атеизам",
    "теоретски": "емпириски",
    "жеден": "гладни",
    "безмислено": "внимателен",
    "пестовен": "непотребно",
    "плима": "одлив",
    "вратоврска": "одврзете",
    "срамежливи": "задебелен",
    "плашливост": "смелост",
    "толеранција": "нетолеранција",
    "толерантни": "нетолерантен",
    "заби": "беззабани",
    "беззабани": "заби",
    "допре": "недопрени",
    "исполнет": "неподнослива",
    "трагедија": "комедија",
    "обучени": "необучен",
    "доверба": "недоверба",
    "вистина": "фалсификат",
    "грдотија": "убавина",
    "грдо": "убава",
    "крајно": "блиска",
    "непознат": "познат",
    "непроменета": "променети",
    "недвосмислена": "двосмислена",
    "невооружени": "вооружени",
    "неовластено": "овластен",
    "неурамнотежен": "избалансиран",
    "неверување": "верување",
    "неврзан": "врзана",
    "нераскинлива": "кршливи",
    "непрекинат": "скршен",
    "неизвесност": "сигурност",
    "непроменет": "сменето",
    "чичко": "тетка",
    "невообичаено": "чести",
    "незаинтересиран": "загрижени",
    "непотврдени": "потврдено",
    "неповрзан": "поврзани",
    "несвесност": "свест",
    "неуставен": "уставно",
    "неконвенционален": "конвенционален",
    "неубедени": "убеден",
    "открие": "покритие",
    "несечени": "сече",
    "недефинирано": "дефинирани",
    "потценувајте": "преценете",
    "непожелни": "пожелно",
    "непотребно": "пестовен",
    "необразован": "образовани",
    "недвосмислено": "двосмислена",
    "нерамномерно": "паметен",
    "неочекувано": "се очекува",
    "неверен": "верен",
    "неповолно": "поволна",
    "се расплетува": "пати",
    "непростлив": "простува",
    "несреќно": "среќа",
    "неблагодарна": "благодарни",
    "несреќни": "среќен",
    "нездраво": "здрав",
    "несреќен": "среќа",
    "неоправдано": "подобрени",
    "неинформирани": "информирани",
    "ненаселени": "окупирана",
    "неразбирливо": "разбирливо",
    "ненамерно": "намерно",
    "незаинтересирани": "заинтересирани",
    "неинтересен": "интересно",
    "унија": "поделба",
    "унитарна": "федерални",
    "обединета": "поделени",
    "нељубезен": "вид",
    "незаконско": "законски",
    "неограничено": "ограничен",
    "отклучи": "заклучување",
    "необележани": "обележан",
    "немажени": "оженет",
    "демаскирам": "маска",
    "неофицијален": "официјален",
    "неприфатен": "наспроти",
    "необично": "обично",
    "отпакувај": "пакет",
    "непопуларен": "популарна",
    "неподготвени": "подготвени",
    "непродуктивни": "продуктивен",
    "незаштитени": "заштитени",
    "необјавени": "објавен",
    "несомнено": "сомнително",
    "нереално": "реален",
    "нерегулиран": "регулирани",
    "неповрзани": "поврзани",
    "несигурен": "сигурен",
    "неограничен": "ограничено",
    "ненаучно": "научни",
    "бескрупулозните": "скрупулозно",
    "несебичен": "себични",
    "несмирен": "се населиле",
    "нестабилен": "стабилен",
    "неуспешни": "успешна",
    "неподдржан": "поддржан",
    "несимпатичен": "симпатична",
    "одврзете": "вратоврска",
    "недопрени": "допре",
    "необучен": "обучени",
    "открива": "превез",
    "неволно": "доброволно",
    "неподготвеност": "подготвеност",
    "развивам": "ветер",
    "недостоен": "достоен",
    "урбани": "рурални",
    "обично": "необично",
    "превез": "открива",
    "вербална": "нумерички",
    "победа": "пораз",
    "доблесни": "злите",
    "видливост": "невидливост",
    "видлив": "невидлив",
    "вокал": "инструментална",
    "доброволно": "неволно",
    "самогласка": "согласка",
    "разбуди": "спиење",
    "прошетка": "возење",
    "бледнее": "восок",
    "војна": "мир",
    "претпазливи": "невнимателен",
    "отпад": "зачувување",
    "восок": "бледнее",
    "слабо": "силно",
    "слабост": "сила",
    "богатство": "сиромаштија",
    "бестежински": "тешки",
    "тешки": "бестежински",
    "шепот": "викај",
    "бела": "црна",
    "целосно": "делумно",
    "злите": "доблесни",
    "широк": "тесен",
    "подготвеност": "неподготвеност",
    "ветер": "развивам",
    "мудрост": "глупост",
    "мудар": "глупаво",
    "се повлече": "депозит",
    "се грижи": "успокојувај",
    "безвредни": "вредни",
    "достоен": "недостоен",
    "напишано": "непишано",
    "млад": "на возраст",
    "зенит": "nadir",
}
