_positive = set(
    [
        "abba",
        "evnen",
        "NO TRANSLATION",
        "absolutte",
        "absolusjon",
        "absorbert",
        "rikelig",
        "akademisk",
        "akademi",
        "akseptabel",
        "godkjennelse",
        "tilgjengelig",
        "utmerkelse",
        "overnatting",
        "akkompagnement",
        "utrette",
        "oppnås",
        "gjennomføring",
        "accord",
        "ansvarlighet",
        "ansvarlig",
        "akkreditert",
        "NO TRANSLATION",
        "korrekt",
        "ess",
        "oppnå",
        "oppnåelse",
        "bekreftelse",
        "tilegne",
        "anskaffe",
        "akrobat",
        "handling",
        "faktiske",
        "skarphet",
        "sans",
        "tilpasse",
        "tilpasningsdyktig",
        "adresser",
        "dyktig",
        "NO TRANSLATION",
        "medhjelper",
        "beundringsverdig",
        "admiral",
        "beundring",
        "beundre",
        "beundrer",
        "tillatelig",
        "bedårende",
        "tilbedelse",
        "elsker",
        "avansere",
        "avansert",
        "forfremmelse",
        "fordel",
        "fordelaktige",
        "advent",
        "eventyr",
        "eventyrlig",
        "tilrådelig",
        "rådgi",
        "rådgiver",
        "beslutningspåvirkning",
        "estetisk",
        "estetikk",
        "omgjengelige",
        "kjærlighet",
        "tilknyttet",
        "bekrefte",
        "bekreftelse",
        "bekreftende",
        "bekreftende",
        "velstand",
        "velstående",
        "ha råd til",
        "NO TRANSLATION",
        "smidig",
        "smidighet",
        "bli enige",
        "behagelig",
        "avtalt",
        "enige",
        "avtale",
        "jordbruk",
        "fremover",
        "bistand",
        "hjelpe",
        "alabast",
        "årvåkenhet",
        "NO TRANSLATION",
        "i live",
        "dempe",
        "troskap",
        "allegro",
        "lindre",
        "lindring",
        "allierte",
        "tillatte",
        "allure",
        "forlokkende",
        "alliert",
        "allmektig",
        "aloha",
        "utrolig",
        "ambassadør",
        "ambisjon",
        "bøte",
        "amen",
        "mottagelig",
        "endre",
        "bot",
        "amenity",
        "elskverdig",
        "minnelig",
        "amnesti",
        "NO TRANSLATION",
        "underholde",
        "underholdt",
        "fornøyelse",
        "morsomt",
        "analytiker",
        "anker",
        "forankring",
        "engel",
        "engleaktig",
        "animere",
        "animert",
        "antibiotika",
        "motgift",
        "soppdrepende",
        "antikk",
        "antiseptisk middel",
        "glans",
        "unnskyld",
        "be om unnskyldning",
        "unnskyldning",
        "apostel",
        "bifall",
        "verdsettelse",
        "bifall",
        "godkjenning",
        "vedta",
        "godkjenne",
        "apt",
        "evne",
        "arkeologi",
        "ildfull",
        "iver",
        "aristokrati",
        "aristokratisk",
        "rustning",
        "aroma",
        "vekke",
        "matrise",
        "Kunst",
        "artikulere",
        "artikulasjon",
        "håndverker",
        "NO TRANSLATION",
        "kunstnerisk",
        "overtak",
        "stigning",
        "aspirasjon",
        "strebe",
        "fremadstormende",
        "montering",
        "samtykke",
        "hevde",
        "eiendeler",
        "assistere",
        "assistanse",
        "forbinder",
        "lindre",
        "forsikring",
        "trygg",
        "NO TRANSLATION",
        "forbauselse",
        "astrolog",
        "astronaut",
        "astronom",
        "slu",
        "atlet",
        "atletisk",
        "atom",
        "sone",
        "soning",
        "feste",
        "oppnåelig",
        "oppnåelse",
        "attendant",
        "oppmerksomhet",
        "oppmerksomme",
        "attestere",
        "advokat",
        "tiltrekning",
        "attraktivitet",
        "øke",
        "august",
        "tante",
        "aura",
        "auspicious",
        "autentisk",
        "ekthet",
        "forfatter",
        "autoritær",
        "autoritet",
        "autorisasjon",
        "autorisert",
        "avatar",
        "tildele",
        "ay",
        "aye",
        "baby",
        "Baccalaureate",
        "ryggrad",
        "balansere",
        "balanserte",
        "ballade",
        "ballett",
        "stemmeseddel",
        "balsam",
        "bankett",
        "dåp",
        "døpe",
        "bard",
        "handel",
        "basketball",
        "bastion",
        "bad",
        "stråle",
        "Stråling",
        "beautification",
        "vakker",
        "forskjønne",
        "skjønnhet",
        "berggrunn",
        "øl",
        "Passer",
        "bli venn",
        "tro",
        "velgjører",
        "gunstig",
        "fordel",
        "velvilje",
        "godartet",
        "køye",
        "forlovet",
        "better",
        "drikke",
        "bibelsk",
        "tospråklig",
        "fødsel",
        "fødselsdag",
        "ulastelige",
        "velsigne",
        "velsignet",
        "velsignelse",
        "velsignelser",
        "lykksalighet",
        "lykkelig",
        "ublodig",
        "blomst",
        "blomstre",
        "livvakt",
        "dristig",
        "dristighet",
        "styrke",
        "bonanza",
        "NO TRANSLATION",
        "bonus",
        "akademisk",
        "bokhandel",
        "velsignelse",
        "bountiful",
        "skuddpremie",
        "bukett",
        "hjerner",
        "tapperhet",
        "frokost",
        "brude",
        "brud",
        "brudgom",
        "brudepike",
        "lysne",
        "lysstyrke",
        "strålende",
        "brokade",
        "bror",
        "brorskap",
        "broderlig",
        "buddy",
        "bygge",
        "bygning",
        "bulldog",
        "skuddsikker",
        "bøye",
        "buss",
        "hovmester",
        "buttery",
        "yppig",
        "buzz",
        "drosje",
        "kabinett",
        "kafe",
        "kalkulator",
        "kalv",
        "rolig",
        "kanarifuglen",
        "oppriktige",
        "kandidat",
        "kandiserte",
        "kapitalist",
        "kaptein",
        "fange",
        "fengslende",
        "karriere",
        "forsiktig",
        "nøye",
        "kjærtegn",
        "vaktmester",
        "carol",
        "kaskade",
        "penger",
        "kategorisk",
        "imøtekomme",
        "rensende",
        "katedral",
        "forsiktige",
        "forsiktig",
        "feiret",
        "feire",
        "feiring",
        "himmelsk",
        "senter",
        "centurion",
        "cerebral",
        "seremoni",
        "sikkerhet",
        "Formann",
        "styreleder",
        "champion",
        "chant",
        "lader",
        "veldedig",
        "veldedighet",
        "sjarm",
        "sjarmerende",
        "kyskhet",
        "chatte",
        "sjekkliste",
        "oppmuntre",
        "munter",
        "munterhet",
        "cheering",
        "NO TRANSLATION",
        "kjemiker",
        "verne",
        "kirsebær",
        "høvding",
        "barn",
        "barndom",
        "kvitre",
        "meisel",
        "ridderlighet",
        "sjokolade",
        "valg",
        "kor",
        "kor",
        "kor",
        "valgt ut",
        "suppe",
        "kronikk",
        "latter",
        "kirke",
        "sider",
        "omskjæring",
        "borger",
        "sivil",
        "høflighet",
        "sivilisasjon",
        "sivilisert",
        "clairvoyant",
        "klapp",
        "avklare",
        "klassiker",
        "klassisk",
        "klassikere",
        "klassifisere",
        "ren",
        "rengjøring",
        "renslighet",
        "renslig",
        "rens",
        "rensing",
        "klaring",
        "klarhet",
        "geistlige",
        "flink",
        "dyktighet",
        "klimaks",
        "nærhet",
        "nedleggelse",
        "NO TRANSLATION",
        "klovn",
        "koalisjon",
        "kyst",
        "sameksistere",
        "cogent",
        "kognitiv",
        "sammenheng",
        "sammenhengende",
        "sammenhengende",
        "samlet sett",
        "oberst",
        "enorm",
        "komfort",
        "kommandant",
        "kommanderende",
        "minnes",
        "markeringen",
        "minnemynter",
        "anbefale",
        "verdig",
        "kommentator",
        "forpliktet",
        "commodore",
        "Samveldet",
        "kommunisere",
        "kommunikative",
        "kommunion",
        "samfunnet",
        "omgjøring",
        "pendle",
        "kompanjong",
        "medfølelse",
        "medfølende",
        "kompatibilitet",
        "kompatibel",
        "overbevisende",
        "kompensere",
        "kompenserende",
        "kompetanse",
        "kompetanse",
        "kompetent",
        "selvtilfredshet",
        "komplement",
        "utfyllende",
        "helt",
        "fullstendighet",
        "fullført",
        "ferdigstillelse",
        "samsvar",
        "kompatibel",
        "NO TRANSLATION",
        "komponert",
        "komponist",
        "sinnsro",
        "fatte",
        "omfattende",
        "kamerat",
        "konsentriske",
        "forlik",
        "avslutt",
        "concord",
        "konkordans",
        "kondolanse",
        "tolerere",
        "bidrar",
        "ledningsevne",
        "confederate",
        "selvtillit",
        "Selvsikker",
        "bekreftet",
        "conformance",
        "congenial",
        "gratulasjons",
        "forsamling",
        "sammenfallende",
        "connoisseur",
        "samvittighet",
        "pliktoppfyllende",
        "bevissthet",
        "innvielse",
        "bevaring",
        "spare",
        "betraktelig",
        "hensyns",
        "konsistens",
        "konsoll",
        "konsonant",
        "standhaftighet",
        "konstant",
        "konstitusjonell",
        "konstruere",
        "consummate",
        "kontakt",
        "tanke",
        "innhold",
        "Fortsette",
        "kontur",
        "bidra",
        "bidragsyter",
        "bekvemmelighet",
        "beleilig",
        "kloster",
        "konvensjon",
        "fortrolig",
        "conversational",
        "konvertere",
        "overbevise",
        "kul",
        "coolness",
        "samarbeide",
        "samvirkende",
        "samarbeid",
        "kooperativ",
        "kjerne",
        "kroning",
        "selskap",
        "legemlige",
        "korrigerende",
        "korrespondanse",
        "underbygge",
        "cosmopolitan",
        "koselig",
        "råd",
        "råd",
        "rådgiver",
        "telle",
        "grevinne",
        "mot",
        "modig",
        "høflig",
        "høflighet",
        "frieri",
        "vik",
        "pakt",
        "vugge",
        "håndverket",
        "håndverker",
        "krem",
        "skape",
        "kreativ",
        "troverdighet",
        "credential",
        "troverdighet",
        "troverdig",
        "kreditt",
        "NO TRANSLATION",
        "kreditert",
        "crescendo",
        "kritikk",
        "kroningen",
        "avgjørende",
        "krystall",
        "kose",
        "kulinarisk",
        "kulminasjonen",
        "dyrke",
        "dyrket",
        "dyrking",
        "kultur",
        "herdbart",
        "nysgjerrighet",
        "curl",
        "pute",
        "kunde",
        "søt",
        "kuttere",
        "dame",
        "danse",
        "dristig",
        "elskling",
        "dashing",
        "datter",
        "soloppgang",
        "avtale",
        "kjære",
        "debatt",
        "anstendighet",
        "skikkelig",
        "declaratory",
        "dedikasjon",
        "forsvare",
        "forsvarte",
        "forsvarer",
        "forsvare",
        "forsvar",
        "aktelse",
        "definitive",
        "grad",
        "delectable",
        "delegat",
        "tilsiktet",
        "nydelig",
        "glede",
        "glad",
        "herlig",
        "levering",
        "leveranse",
        "demokrati",
        "påviselig",
        "demonstrative",
        "dybde",
        "beskrivende",
        "fortjene",
        "fortjent",
        "designer",
        "ønskelig",
        "ønsker",
        "begjærlig",
        "mål",
        "oppdage",
        "gjenkjenning",
        "besluttsomhet",
        "fast bestemt",
        "utvikle",
        "andakt",
        "troende",
        "behendighet",
        "diamant",
        "dagbok",
        "ordbok",
        "didaktisk",
        "kosttilskudd",
        "ærverdig",
        "verdighet",
        "aktsomhet",
        "middag",
        "diplomati",
        "diplomatisk",
        "regissør",
        "oppdagelse",
        "NO TRANSLATION",
        "diskresjon",
        "skjønns",
        "diskusjon",
        "desinfeksjon",
        "anordnet",
        "spre",
        "destillasjon",
        "forskjell",
        "ditty",
        "diversifisert",
        "Omkjøring",
        "guddommelighet",
        "doktor",
        "doer",
        "seig",
        "delfin",
        "don",
        "donasjon",
        "utvilsomt",
        "due",
        "dunete",
        "duett",
        "hertug",
        "varighet",
        "varig",
        "pliktoppfyllende",
        "ivrig",
        "iver",
        "earl",
        "tjene",
        "alvor",
        "alvorlig",
        "alvor",
        "letthet",
        "Servitutt",
        "NO TRANSLATION",
        "spise",
        "ecstasy",
        "ekstatisk",
        "oppbyggelse",
        "utdanne",
        "utdannet",
        "pedagogisk",
        "effektiv",
        "effekten",
        "effektivitet",
        "effektiv",
        "anstrengelse",
        "utløsning",
        "utdypning",
        "opprømt",
        "eldre",
        "eldste",
        "velge",
        "elektrisk",
        "elektrisitet",
        "eleganse",
        "elegant",
        "høyde",
        "kvalifisert",
        "elite",
        "veltalenhet",
        "veltalende",
        "belyse",
        "frigjøring",
        "omfavne",
        "emeritus",
        "eminense",
        "eminent",
        "utpreget",
        "NO TRANSLATION",
        "empati",
        "myndiggjøre",
        "etterligne",
        "Aktiver",
        "aktivering",
        "fortrylle",
        "fortryllet",
        "fortryllende",
        "NO TRANSLATION",
        "oppmuntre",
        "oppmuntring",
        "leksikon",
        "bestrebelse",
        "gi gave",
        "begavet",
        "legat",
        "utholdenhet",
        "utholde",
        "energisk",
        "engasjert",
        "engasjerende",
        "forbedre",
        "Nyt",
        "Nyter",
        "opplyse",
        "opplysning",
        "live opp",
        "berike",
        "ensemble",
        "banner",
        "driftige",
        "underholde",
        "holdt",
        "underhold",
        "underholdning",
        "entusiasme",
        "entusiast",
        "NO TRANSLATION",
        "ephemeris",
        "episk",
        "resymé",
        "likestilling",
        "likt",
        "likevekt",
        "egenkapital",
        "ærend",
        "lærd",
        "esprit",
        "viktig",
        "etablert",
        "følelse",
        "estetisk",
        "etisk",
        "etikk",
        "Evergreen",
        "evig",
        "tydelig",
        "utvikling",
        "opphøye",
        "opphøyelse",
        "opphøyet",
        "overskride",
        "utmerke",
        "fortreffelighet",
        "utmerket",
        "Utveksling",
        "hissige",
        "eksitasjon",
        "opphisse",
        "spent",
        "begeistring",
        "spennende",
        "eksemplarisk",
        "fritak",
        "exhilaration",
        "formane",
        "forman",
        "eksistens",
        "eksotisk",
        "forvente",
        "forventning",
        "hensiktsmessig",
        "ekspedisjon",
        "opplevde",
        "Ekspert",
        "ekspertise",
        "forklare",
        "utsøkt",
        "utsøkt",
        "forlenge",
        "omfattende",
        "ekstra",
        "ekstraordinær",
        "frigjøre",
        "begeistring",
        "legge til rette",
        "fakta",
        "fakultet",
        "NO TRANSLATION",
        "rettferdig",
        "ganske",
        "tro",
        "trofast",
        "berømmelse",
        "fortrolig",
        "familiær",
        "berømt",
        "famously",
        "fancy",
        "fanfare",
        "fascinerende",
        "fascinasjon",
        "fasjonable",
        "feilfri",
        "gunstige",
        "favoritt",
        "favorisering",
        "fryktløs",
        "bragd",
        "trekk",
        "lykke",
        "kar",
        "fellesskap",
        "hunn",
        "fruktbar",
        "inderlighet",
        "festival",
        "festlig",
        "NO TRANSLATION",
        "gjengivelse",
        "fiesta",
        "endelig",
        "stas",
        "finesse",
        "ildkule",
        "brannsikker",
        "fasthet",
        "NO TRANSLATION",
        "fitting",
        "ligaen",
        "flatte",
        "flåte",
        "fleksibilitet",
        "floral",
        "strømme",
        "blomstrende",
        "flush",
        "flying",
        "fokus",
        "forkjærlighet",
        "mat",
        "Fotball",
        "overbærenhet",
        "forgrunnen",
        "forfedre",
        "foregå",
        "formann",
        "forløper",
        "forutse",
        "forutsett",
        "framsyn",
        "smi",
        "tilgi",
        "tilgitt",
        "forgiving",
        "formativ",
        "formel",
        "NO TRANSLATION",
        "kommende",
        "forsterke",
        "heltemot",
        "festning",
        "heldig",
        "formue",
        "framover",
        "funnet",
        "fundament",
        "duftende",
        "oppriktig",
        "åpenhet",
        "broderlig",
        "frihet",
        "fritt",
        "venn",
        "vennlighet",
        "vennlig",
        "vennskap",
        "spretten",
        "munterhet",
        "nøysom",
        "fruktbar",
        "innfri",
        "oppfyllelse",
        "full",
        "fullt",
        "moro",
        "fundamental",
        "sikring",
        "fusjon",
        "gevinst",
        "få",
        "galant",
        "gallantry",
        "fleng",
        "hage",
        "granat",
        "garnison",
        "Gazette",
        "utstyr",
        "perle",
        "generell",
        "gavmildhet",
        "sjenerøs",
        "genial",
        "geni",
        "fornem",
        "herre",
        "mildhet",
        "Gentry",
        "ekte",
        "geranium",
        "gave",
        "begavet",
        "gigantisk",
        "fnise",
        "bjelke",
        "gi",
        "glad",
        "glede",
        "glede",
        "glid",
        "glimmer",
        "glitrende",
        "forherligelse",
        "lovprise",
        "herlighet",
        "gloss",
        "gløde",
        "glødende",
        "Gud",
        "gudfryktig",
        "gudegave",
        "gull",
        "flink",
        "frukt",
        "godhet",
        "varer",
        "velvilje",
        "nydelig",
        "evangelium",
        "styre",
        "nåde",
        "grasiøs",
        "nådig",
        "nådigst",
        "konfirmasjonen",
        "barnebarn",
        "storhet",
        "bestemor",
        "stipend",
        "innvilget",
        "takknemlig",
        "glede",
        "takknemlighet",
        "større",
        "storhet",
        "grønn",
        "hilsen",
        "selskapelig",
        "glise",
        "grist",
        "grus",
        "grunnarbeid",
        "vokse",
        "vekst",
        "garanti",
        "vakt",
        "verge",
        "vergemål",
        "gubernatorial",
        "veiledning",
        "guide",
        "guidebok",
        "guru",
        "guts",
        "turner",
        "habitat",
        "hale",
        "praktisk",
        "gjerne",
        "lykke",
        "lykkelig",
        "hardfør",
        "harmonisk",
        "harmoni",
        "innhøsting",
        "haven",
        "framskritt",
        "helbrede",
        "helbredelse",
        "sunn",
        "sunn",
        "hjertefølt",
        "ildsted",
        "hjertelig",
        "himmelsk",
        "himmelen",
        "heft",
        "hjelm",
        "hjelper",
        "hjelpsom",
        "urte",
        "helt",
        "heroisk",
        "heroics",
        "heltinne",
        "heltemot",
        "storhetstid",
        "morsom",
        "hilarity",
        "leie",
        "Hobby",
        "ferie",
        "hellighet",
        "hellig",
        "hyllest",
        "homologi",
        "ærlig",
        "ærlighet",
        "honning",
        "bryllupsreise",
        "ære",
        "hederlig",
        "håp",
        "håpe",
        "horisont",
        "gjestfrihet",
        "husstand",
        "renhold",
        "Klem",
        "human",
        "humanitær",
        "menneskeheten",
        "ydmyket",
        "ydmykt",
        "ydmykhet",
        "humorist",
        "humoristisk",
        "hurra",
        "oppdrett",
        "hysj",
        "hytte",
        "hygienisk",
        "salme",
        "idealisme",
        "idol",
        "NO TRANSLATION",
        "belysning",
        "illustrere",
        "strålende",
        "Fantasifull",
        "plettfri",
        "enorme",
        "senke",
        "udødelig",
        "formidle",
        "upartisk",
        "habilitet",
        "upåklagelig",
        "ugjennomtrengelig",
        "betydning",
        "viktig",
        "imponere",
        "inntrykk",
        "forbedre",
        "forbedret",
        "forbedring",
        "forbedring",
        "improvisere",
        "umistelige",
        "innsettelse",
        "Pent",
        "inkludere",
        "inkludert",
        "gjelder også",
        "inklusive",
        "øke",
        "uutslettelig",
        "erstatning",
        "selvstendighet",
        "uforgjengelig",
        "individualitet",
        "ukuelig",
        "uutsigelige",
        "rimelig",
        "ufeilbarlig",
        "spedbarn",
        "uendelig",
        "evighet",
        "innflytelsesrik",
        "informasjon",
        "genial",
        "arv",
        "inimitable",
        "uskyld",
        "uskyldig",
        "uskyldig",
        "ufarlige",
        "innovere",
        "innovasjon",
        "Inquirer",
        "forespørsel",
        "nysgjerrige",
        "uatskillelig",
        "insignia",
        "inspektør",
        "inspirasjon",
        "inspirere",
        "inspirert",
        "instinktiv",
        "undervise",
        "instruksjon",
        "instruktør",
        "instrumental",
        "forsikre",
        "intakt",
        "integritet",
        "intellekt",
        "intellektuell",
        "intelligens",
        "intelligent",
        "tiltenkt",
        "samleie",
        "renter",
        "interessert",
        "interessant",
        "interiør",
        "kjennelse",
        "mellomspill",
        "intime",
        "intonasjon",
        "uforferdet",
        "intuisjon",
        "intuitiv",
        "alltid",
        "oppfinneriske",
        "oppfinner",
        "undersøke",
        "styrke",
        "invitasjon",
        "invitere",
        "innbydende",
        "jern",
        "irreducible",
        "ugjendrivelige",
        "jackpot",
        "syltetøy",
        "NO TRANSLATION",
        "jobb",
        "bli med",
        "ble med",
        "joker",
        "tuller",
        "journalist",
        "reise",
        "jovial",
        "glede",
        "gledelig",
        "glad",
        "jubilant",
        "jubilee",
        "rettslig",
        "klok",
        "hoppe",
        "rettferdighet",
        "forsvarlig",
        "berettigelse",
        "minnesmerke",
        "ken",
        "keynote",
        "keystone",
        "snill",
        "vennlighet",
        "slekt",
        "konge",
        "kysse",
        "kattunge",
        "håndlag",
        "ridder",
        "vite",
        "kunnskap",
        "Kudos",
        "arbeid",
        "lam",
        "land",
        "landet",
        "laser",
        "rosverdig",
        "latter",
        "ler",
        "latter",
        "lanseringen",
        "prisvinner",
        "laurbær",
        "laurbær",
        "overdådig",
        "lovlig",
        "lede",
        "leder",
        "liga",
        "lære",
        "læring",
        "foreleser",
        "spillerom",
        "lovlig",
        "legalisert",
        "legendarisk",
        "lesbarhet",
        "leselig",
        "fritid",
        "makelig",
        "lemma",
        "skånsom",
        "lekse",
        "lettered",
        "nivå",
        "innflytelse",
        "frigjøre",
        "frigjøring",
        "frihet",
        "bibliotek",
        "livsnerven",
        "fyr",
        "smak",
        "ling",
        "løve",
        "smidige",
        "logisk",
        "levetid",
        "herredømme",
        "elskelig",
        "kjærlighet",
        "herlig",
        "NO TRANSLATION",
        "lover",
        "kjærlig",
        "lojal",
        "lojalitet",
        "flaks",
        "heldig",
        "saftig",
        "glans",
        "skinnende",
        "frodig",
        "luksuriøs",
        "luksus",
        "lyre",
        "lyrisk",
        "magisk",
        "magnet",
        "magnetisme",
        "magnetitt",
        "storhet",
        "storslått",
        "maiden",
        "hoved-",
        "bærebjelke",
        "majestetiske",
        "majestet",
        "major",
        "flertall",
        "få til",
        "ledelse",
        "mandarin",
        "manndom",
        "manifestert",
        "mandig",
        "manna",
        "mannered",
        "manerer",
        "produsent",
        "mars",
        "merket",
        "salg",
        "marquis",
        "ekteskap",
        "marg",
        "gifte seg",
        "marshal",
        "vidunder",
        "strålende",
        "marvellously",
        "maskulin",
        "massasje",
        "herre",
        "mesterverk",
        "mestring",
        "kamerat",
        "ekteskap",
        "forstander",
        "maksimum",
        "borgermester",
        "eng",
        "målt",
        "medalje",
        "mekle",
        "mekling",
        "mellommann",
        "medisinsk",
        "NO TRANSLATION",
        "Middelhavet",
        "medley",
        "Memento",
        "minneverdig",
        "bøtte",
        "menstruasjon",
        "mentor",
        "barmhjertig",
        "nåde",
        "slå sammen",
        "bragd",
        "meritter",
        "munterhet",
        "god",
        "metropolitan",
        "mettle",
        "mikroskopi",
        "jordmor",
        "mektig",
        "mime",
        "tankefull",
        "tankefullhet",
        "departement",
        "mirakel",
        "mirakuløs",
        "munterhet",
        "misjonær",
        "modell",
        "moderat",
        "moderator",
        "beskjeden",
        "beskjedenhet",
        "momentum",
        "monetære",
        "penger",
        "munk",
        "monument",
        "moralsk",
        "moral",
        "moral",
        "mørtel",
        "morskap",
        "motiv",
        "flyttbar",
        "mover",
        "muskulær",
        "musikk",
        "musikalsk",
        "foranderlig",
        "gjensidig",
        "lur",
        "natura",
        "farbare",
        "pent",
        "nektar",
        "nål",
        "forhandle",
        "forhandler",
        "nabo",
        "nerve",
        "Nestlé",
        "adel",
        "edel",
        "adelsmann",
        "nominasjon",
        "normalitet",
        "bemerkelsesverdig",
        "kjende",
        "NO TRANSLATION",
        "forestilling",
        "næring",
        "tall",
        "sykepleier",
        "planteskole",
        "nurture",
        "næringsrik",
        "eik",
        "oase",
        "ed",
        "lydighet",
        "objektiv",
        "vennlighet",
        "oppmerksom",
        "oppnåelig",
        "åpenbart",
        "beboer",
        "okkupasjon",
        "okkupere",
        "by på",
        "offiser",
        "offset",
        "avlegger",
        "allvitende",
        "åpenhet",
        "opera",
        "opportunt",
        "mulighet",
        "optimisme",
        "optimist",
        "alternativ",
        "valgfri",
        "orakel",
        "tale",
        "orkester",
        "ordinert",
        "velordnet",
        "ordinasjon",
        "organisk",
        "organisasjon",
        "organisere",
        "organisert",
        "orgasme",
        "originalitet",
        "ornamentert",
        "utsmykkede",
        "utfall",
        "overgå",
        "ytre",
        "lykkelig",
        "overveldende",
        "eie",
        "pacific",
        "pad",
        "padding",
        "padle",
        "spiselig",
        "palliativ",
        "universalmiddel",
        "bravur",
        "NO TRANSLATION",
        "paprika",
        "paragon",
        "overordnet",
        "tilgi",
        "foreldre",
        "parietal",
        "ta del",
        "deltakelse",
        "samboer",
        "samarbeid",
        "lidenskap",
        "lidenskapelig",
        "tidsfordriv",
        "pastor",
        "kake",
        "beitemark",
        "patentere",
        "tålmodighet",
        "pasient",
        "patriarkalske",
        "skyts",
        "beskyttelse",
        "betale",
        "fred",
        "fredsommelig",
        "fredelig",
        "påfugl",
        "Peck",
        "særegenhet",
        "stamtavle",
        "Peerless",
        "forkjærlighet",
        "oppfatte",
        "merkbar",
        "flerårig",
        "perfekt",
        "fullkommenhet",
        "utøver",
        "ekstra fordel",
        "tillatelse",
        "uendelige",
        "standhaftighet",
        "vedvarende",
        "person",
        "relevant",
        "farmasøytisk",
        "filantrop",
        "filantropi",
        "filosof",
        "Føniks",
        "fonetisk",
        "lege",
        "fysikk",
        "fysiologi",
        "fysikk",
        "plukke",
        "piknik",
        "pittoreske",
        "fromhet",
        "pille",
        "pute",
        "Pilot",
        "høydepunkt",
        "pioner",
        "fromme",
        "marg",
        "dreie",
        "placid",
        "planlegger",
        "leken",
        "lekeplass",
        "lekehus",
        "hyggelig",
        "fornøyd",
        "behage",
        "løfte",
        "plenum",
        "rikelig",
        "plexus",
        "plomme",
        "lodd",
        "plysj",
        "ply",
        "demonstrativt",
        "politiet",
        "politimann",
        "pusse",
        "polert",
        "høflig",
        "høflighet",
        "NO TRANSLATION",
        "basseng",
        "pave",
        "popularitet",
        "popularisert",
        "befolkning",
        "bærbar",
        "eie",
        "drikkevann",
        "potens",
        "kraftig",
        "kraft",
        "øve på",
        "praktisert",
        "øve på",
        "ros",
        "skryt",
        "verdig",
        "be",
        "forholdsregel",
        "gå forut for",
        "presedens",
        "dyrebar",
        "nøyaktig",
        "presisjon",
        "forkjærlighet",
        "fremherskende",
        "fremragende",
        "foretrekker",
        "premier",
        "lokaler",
        "forberede",
        "forberedt",
        "forutse",
        "tilstedeværelse",
        "nåværende",
        "presentabel",
        "konserverings",
        "bevare",
        "president",
        "prestisje",
        "presto",
        "ganske",
        "råde",
        "forebygging",
        "uvurderlig",
        "stolthet",
        "prest",
        "prestedømmet",
        "preste",
        "forrang",
        "hoved~~POS=TRUNC",
        "prime",
        "primer",
        "prins",
        "fyrstelig",
        "prinsesse",
        "rektor",
        "uberørte",
        "privilegert",
        "redelighet",
        "fremgangsmåte",
        "prosesjon",
        "Proctor",
        "anskaffe",
        "uhyre",
        "vidunderbarn",
        "produsent",
        "produserende",
        "produksjon",
        "produktivt",
        "produktivitet",
        "yrke",
        "profesjonell",
        "professor",
        "ferdighet",
        "dyktig",
        "rikelig",
        "framgang",
        "progresjon",
        "progressive",
        "produktive",
        "fremtredende",
        "fremtredende",
        "love",
        "lovende",
        "forfremmelse",
        "rekvisitt",
        "ordentlig",
        "profet",
        "profylaktisk",
        "forslag",
        "prospektet",
        "blomstre",
        "velstand",
        "velstående",
        "beskytte",
        "beskyttende",
        "beskyttende",
        "beskytter",
        "stolt",
        "bevise",
        "velkjente",
        "gi",
        "gi",
        "klokskap",
        "forsvarlig",
        "salme",
        "offentlig",
        "dra",
        "prekestol",
        "punktlig",
        "punktlighet",
        "valp",
        "rent",
        "rensing",
        "rense",
        "purist",
        "renhet",
        "purr",
        "eiendommelig",
        "utdannet",
        "kvalifiserende",
        "oppdrag",
        "spørsmål",
        "hurtighet",
        "hvil",
        "stille",
        "kinin",
        "utstråling",
        "strålende",
        "utstråle",
        "radio",
        "henført",
        "henrykkelse",
        "rasjonell",
        "leser",
        "lett",
        "beredskap",
        "lesning",
        "stadfester",
        "ekte",
        "grunnen til",
        "beroligelse",
        "Forsikre",
        "rabatt",
        "støpt",
        "mottatt",
        "mottak",
        "NO TRANSLATION",
        "gjengjelde",
        "gjenvinning",
        "lene",
        "gjenkjennelig",
        "anbefale",
        "forsoning",
        "ny vurdering",
        "gjenoppbygge",
        "gjenoppbygging",
        "opptaker",
        "hente inn",
        "gjenoppretting",
        "rekreasjon",
        "rekreasjons",
        "utbedre",
        "forløsning",
        "oppreisning",
        "raffinere",
        "avgrensning",
        "reform",
        "reformasjon",
        "reformator",
        "forfriskende",
        "pusse opp",
        "kongelig",
        "regent",
        "regelmessighet",
        "regulere",
        "rehabilitere",
        "rehabilitering",
        "betale",
        "refusjon",
        "forsterkning",
        "gjeninnsette",
        "fryde",
        "gleder seg",
        "forynge",
        "forynget",
        "avslapning",
        "aktuell",
        "pålitelighet",
        "pålitelig",
        "avhengighet",
        "lettelse",
        "lindrende",
        "remake",
        "bemerkelsesverdig",
        "NO TRANSLATION",
        "middel",
        "remisjon",
        "oppussing",
        "renessanse",
        "gjengi",
        "fornyelse",
        "renovere",
        "renovering",
        "kjent",
        "kjente",
        "omorganisere",
        "reparasjon",
        "betale tilbake",
        "angre",
        "fylle",
        "replete",
        "journalist",
        "hvile",
        "representert",
        "reproduktiv",
        "aner",
        "redde",
        "reservere",
        "beboer",
        "elastisk",
        "resistive",
        "resolutt",
        "ressurser",
        "respekt",
        "respektabilitet",
        "respekt",
        "respekt",
        "respektere",
        "henseender",
        "pusterom",
        "strålende",
        "ansvarlig",
        "mottakelig",
        "hvile",
        "avslappende",
        "restitusjon",
        "restorative",
        "gjenopprette",
        "tilbakeholdenhet",
        "gjenopptakelse",
        "bevaring",
        "gjenforening",
        "kalas",
        "revels",
        "revere",
        "ærbødighet",
        "Reverend",
        "dagdrøm",
        "revidere",
        "vekkelse",
        "revolusjonerende",
        "belønning",
        "rytme",
        "rytmisk",
        "bånd",
        "rikdom",
        "rytter",
        "rettferdige",
        "rettmessige",
        "rette",
        "moden",
        "modne",
        "stiger",
        "medrivende",
        "roadster",
        "robust",
        "stein",
        "stang",
        "lystig",
        "romanse",
        "romantisk",
        "romantikken",
        "tumle",
        "forankret",
        "rosenrød",
        "rota",
        "rutine",
        "royalty",
        "rubrikk",
        "ruth",
        "sikker",
        "ivareta",
        "salvie",
        "helgen",
        "hellig",
        "lønn",
        "fremtredende",
        "sunn",
        "honnør",
        "frelse",
        "salve",
        "samurai",
        "helliggjørelse",
        "helliger",
        "helligdom",
        "Sanguine",
        "sanitær~~POS=TRUNC",
        "sateng",
        "tilfredsstillende",
        "fornøyd",
        "lagre",
        "sparing",
        "duft",
        "velsmakende",
        "erfarne",
        "lærd",
        "stipend",
        "vitenskapelig",
        "forsker",
        "NO TRANSLATION",
        "poengsum",
        "skribent",
        "manus",
        "deilig",
        "skulptur",
        "hav",
        "Tetning",
        "erfaren",
        "sekretariatet",
        "ansiennitet",
        "oppsiktsvekkende",
        "føle",
        "følsomhet",
        "fornuftig",
        "sensualitet",
        "sanselig",
        "sentimental",
        "sentimentalitet",
        "sentinel",
        "sinnsro",
        "preken",
        "serum",
        "Stifterne",
        "kjønn",
        "form",
        "velskapt",
        "dele",
        "husly",
        "gjeter",
        "skinne",
        "skinner",
        "kjøpesenter",
        "skulder",
        "skarp",
        "silke",
        "forenkle",
        "oppriktig",
        "oppriktighet",
        "synge",
        "enkeltvis",
        "Herr",
        "søster",
        "dyktig",
        "dyktig",
        "himmel",
        "skifer",
        "slank",
        "slank",
        "slank",
        "smil",
        "smilende",
        "smittet",
        "glatthet",
        "snicker",
        "Edruelighet",
        "sosial",
        "trøst",
        "soldat",
        "fast",
        "soliditet",
        "løsning",
        "solvens",
        "sonar",
        "sonata",
        "sonett",
        "klang",
        "bero",
        "beroligende",
        "NO TRANSLATION",
        "soliditet",
        "suppe",
        "spa",
        "romslig",
        "spaniel",
        "gnisten",
        "spesiell",
        "NO TRANSLATION",
        "tale",
        "speedy",
        "staving",
        "krydder",
        "ånd",
        "ånder",
        "fantastisk",
        "prakt",
        "sponsor",
        "plettfrie",
        "ektefelle",
        "gran",
        "stabil",
        "stakkato",
        "rustfritt",
        "hingst",
        "trofaste",
        "utholdenhet",
        "stående",
        "stjerne",
        "stjernelys",
        "stjernehimmel",
        "stase",
        "uttalelse",
        "statue",
        "status",
        "trofast",
        "standhaftig",
        "stellar",
        "steward",
        "stillhet",
        "butikk",
        "rett fram",
        "strategisk",
        "strateg",
        "styrke",
        "forsterke",
        "styrking",
        "slående",
        "slående",
        "sterk",
        "struktur",
        "stud",
        "studere",
        "solid",
        "sublime",
        "stoff",
        "materielle",
        "lykkes",
        "lykkes",
        "suksess",
        "vellykket",
        "fyndig",
        "forsyning",
        "sukker",
        "passende",
        "trykkende",
        "sol",
        "solfylt",
        "solnedgang",
        "solskinn",
        "suveren",
        "menneskelig",
        "overlegen",
        "overlegenhet",
        "superman",
        "super",
        "bønn",
        "forsyninger",
        "forsyning",
        "støttet",
        "supporter",
        "bære",
        "supreme",
        "super",
        "kausjonist",
        "anta",
        "overgår",
        "overraskelse",
        "oppmåling",
        "overleve",
        "sverge",
        "søt",
        "kjæreste",
        "søtnos",
        "søthet",
        "søtsaker",
        "fort",
        "svømme",
        "symbolsk",
        "symmetrisk",
        "symmetri",
        "medfølende",
        "sympati",
        "symfoni",
        "synkron",
        "synergistisk",
        "synoden",
        "takt",
        "eventyr",
        "talent",
        "talisman",
        "snakke",
        "solbrun",
        "oppgave",
        "smak",
        "velsmakende",
        "lære bort",
        "lærer",
        "teknologi",
        "måtehold",
        "herdet",
        "holdbar",
        "utholdende",
        "fasthet",
        "leieforholdet",
        "leietaker",
        "mør",
        "ømhet",
        "takknemlig",
        "takksigelse",
        "teoretisk",
        "terapeutisk",
        "terapeutika",
        "NO TRANSLATION",
        "fullblods",
        "omtenksom",
        "omtanke",
        "sparsommelighet",
        "spenningen",
        "spennende",
        "blomstrende",
        "trone",
        "kile",
        "flislegging",
        "betimelig",
        "tinsel",
        "tittel",
        "skål",
        "tolerant",
        "toleranse",
        "topp",
        "seighet",
        "tårn",
        "ruvende",
        "tradisjonell",
        "rolig",
        "ro",
        "transcendens",
        "transcendental",
        "reiser",
        "skatt",
        "tre",
        "enormt",
        "trend",
        "trendy",
        "sideelv",
        "hyllest",
        "trig",
        "triumf",
        "triumferende",
        "trofé",
        "våpenhvile",
        "EKTE",
        "trofaste",
        "sannhet",
        "sannferdighet",
        "veiledning",
        "veileder",
        "tvilling",
        "blinke",
        "til syvende og sist",
        "oppmann",
        "enstemmighet",
        "enstemmig",
        "beskjeden",
        "objektivt",
        "uknuselig",
        "ubrutt",
        "ubegrenset",
        "understreke",
        "forståelse",
        "underwrite",
        "udelt",
        "udødelig",
        "utvetydig",
        "brette",
        "samling",
        "jevnt",
        "infisert",
        "unik",
        "unison",
        "enhetlig",
        "forent",
        "enhet",
        "universitet",
        "ubegrenset",
        "upretensiøs",
        "udiskutable",
        "utvilsomt",
        "unquestioned",
        "uskadd",
        "uselvisk",
        "uovertruffen",
        "urokkelig",
        "friinntekt",
        "oppreist",
        "nytten",
        "usher",
        "vanlig",
        "nytte",
        "utopisk",
        "ferie",
        "vaksine",
        "tapper",
        "NO TRANSLATION",
        "verdifull",
        "fortropp",
        "vanquish",
        "fløyel",
        "fløyelsmyk",
        "ærverdige",
        "ærbødighet",
        "sannferdighet",
        "frodige",
        "bekreftelse",
        "verifisert",
        "sannelig",
        "veritabel",
        "vernal",
        "verve",
        "veteran",
        "prest",
        "victor",
        "seirende",
        "seier",
        "årvåkenhet",
        "årvåken",
        "Vigør",
        "energisk",
        "landsbyboer",
        "vindicated",
        "oppreisning",
        "jomfru",
        "jomfrudom",
        "dyd",
        "dydig",
        "syn",
        "visjonær",
        "besøk",
        "besøkende",
        "vital",
        "vitalitet",
        "livlig",
        "levende",
        "ordforråd",
        "frivillig",
        "sensuell",
        "innestå",
        "løfte",
        "lønn",
        "garanti",
        "kriger",
        "vakthund",
        "vaktsom",
        "vekteren",
        "vanntett",
        "rikdom",
        "værbestandig",
        "velkommen",
        "hvit",
        "hvithet",
        "sunn",
        "wicket",
        "utbredt",
        "villig",
        "villighet",
        "nedfallsfrukt",
        "vinner",
        "vinne",
        "gevinster",
        "trådløst",
        "wis",
        "visdom",
        "klok",
        "vidd",
        "stå imot",
        "wits",
        "vittig",
        "veiviser",
        "livmor",
        "herlig",
        "fantastisk",
        "wondrous",
        "ord",
        "arbeider",
        "tilbedelse",
        "verdi",
        "verdig",
        "wot",
        "forfatter",
        "ung",
        "yngre",
        "ungdom",
        "iver",
        "nidkjær",
        "zest",
    ]
)

_negative = set(
    [
        "forlate",
        "forlatt",
        "oppgivelse",
        "bortføring",
        "avvik",
        "aberrasjon",
        "avsky",
        "avskyelig",
        "ynke",
        "unormal",
        "avskaffe",
        "avskaffelse",
        "avskyelig",
        "styggedom",
        "avbryte",
        "abort",
        "mislykket",
        "slitasje",
        "oppheve",
        "abscess",
        "fravær",
        "fraværende",
        "fraværende",
        "fravær",
        "absurd",
        "absurditet",
        "misbruke",
        "abysmal",
        "avgrunnen",
        "ulykke",
        "utilsiktet",
        "forbannet",
        "anklage",
        "akkusativ",
        "tiltalte",
        "anklageren",
        "anklagende",
        "smerte",
        "verk",
        "syre",
        "handlings",
        "huggorm",
        "avhengighet",
        "adipose",
        "avgjøre",
        "formaning",
        "adrift",
        "adulterated",
        "utroskap",
        "motpart",
        "uheldig",
        "motgang",
        "plage",
        "rammet",
        "lidelse",
        "krenkelse",
        "redd",
        "kjølvannet",
        "smak",
        "forverret",
        "irriterende",
        "forverring",
        "aggresjon",
        "aggressiv",
        "angriper",
        "forferdet",
        "opphisset",
        "agitasjon",
        "pinefull",
        "smerte",
        "grunnstøting",
        "ail",
        "skrantende",
        "formålsløs",
        "airs",
        "alarm",
        "foruroligende",
        "alkoholisme",
        "romvesen",
        "fremmedgjøre",
        "fremmedgjort",
        "fremmedgjøring",
        "underholdsbidrag",
        "påstand",
        "påstår",
        "reservert",
        "krangel",
        "tvetydig",
        "bakhold",
        "amnesi",
        "amfetamin",
        "anakonda",
        "anal",
        "anarkisme",
        "anarkist",
        "anarki",
        "anathema",
        "eldgammel",
        "sinne",
        "angina",
        "sportsfiske",
        "sint",
        "kval",
        "fiendtlighet",
        "animus",
        "utslette",
        "utslettet",
        "utslettelse",
        "irritere",
        "irritasjon",
        "irriterende",
        "annullere",
        "annulering",
        "anomali",
        "anonym",
        "antagonisme",
        "motstander",
        "antagonistisk",
        "anthrax",
        "antikrist",
        "antipati",
        "antikvert",
        "antisosial",
        "antitese",
        "angst",
        "engstelig",
        "apache",
        "apatisk",
        "apati",
        "bladlus",
        "forferdelig",
        "blindtarmbetennelse",
        "engstelse",
        "engstelig",
        "tilegnelse",
        "arkaisk",
        "krevende",
        "argumentere",
        "argument",
        "argumentative",
        "arid",
        "våpen",
        "arraignment",
        "restskatt",
        "arrestere",
        "arroganse",
        "arrogant",
        "arsen",
        "mordbrann",
        "artilleri",
        "aske",
        "skamfull",
        "aske",
        "ass",
        "angripe",
        "overfallsmann",
        "snikmorder",
        "myrde",
        "attentat",
        "overfall",
        "drittsekk",
        "på avveie",
        "snerpende",
        "asyl",
        "ateisme",
        "aterosklerose",
        "fryktelig",
        "grusomhet",
        "atrofi",
        "angrep",
        "angripe",
        "dempes",
        "demping",
        "frekkhet",
        "strenge",
        "nøysomhet",
        "autokratiske",
        "autopsi",
        "snøskred",
        "gjerrighet",
        "hevner",
        "uvillig",
        "aversjon",
        "unngå",
        "unngåelse",
        "fryktelig",
        "awkwardness",
        "forkjært",
        "babble",
        "babling",
        "bavian",
        "bakover",
        "bakover",
        "bakevje",
        "bakterie",
        "NO TRANSLATION",
        "dårlig",
        "grevling",
        "dårlig",
        "ondskap",
        "namsmann",
        "agn",
        "bale",
        "balk",
        "NO TRANSLATION",
        "banditt",
        "bane",
        "bang",
        "banger",
        "forvise",
        "forvist",
        "forvisning",
        "konkurs",
        "konkurser",
        "banshee",
        "brodd",
        "barbar",
        "barbariske",
        "barbari",
        "bark",
        "utestengt",
        "ufruktbar",
        "barrikade",
        "barriere",
        "grunnløs",
        "drittsekk",
        "røre",
        "ramponert",
        "batteri",
        "slag",
        "kjempet",
        "marken",
        "uanstendige",
        "bajonett",
        "bærer",
        "beist",
        "dyrisk",
        "slår",
        "ramme",
        "tigge",
        "tigger",
        "ber",
        "Behemoth",
        "beholden",
        "forsinket",
        "bagatelliserer",
        "Fiendtlig",
        "belte",
        "bender",
        "etterlatte",
        "sorg",
        "berøvet",
        "Berserk",
        "bestialsk",
        "forråde",
        "forræderi",
        "pass",
        "forvirret",
        "partiskhet",
        "forutinntatt",
        "krangling",
        "NO TRANSLATION",
        "fanatiker",
        "hyklersk",
        "galle",
        "biopsi",
        "bjørk",
        "fødested",
        "tispe",
        "bite",
        "bittert",
        "bitterhet",
        "bisarr",
        "svart",
        "blackjack",
        "utpressing",
        "svarthet",
        "skylde på",
        "kjedelig",
        "blasfemisk",
        "blasfemi",
        "blast",
        "blatant",
        "blather",
        "Blaze",
        "bleik",
        "blør",
        "lyte",
        "sykdom på planter",
        "blighted",
        "blind",
        "blindet",
        "blindt",
        "blindhet",
        "blemme",
        "oppsvulmet",
        "blob",
        "blokade",
        "blodsutgytelse",
        "blodtørstig",
        "blodig",
        "blot",
        "Blåseren",
        "blåse ut",
        "blues",
        "bløff",
        "bommert",
        "uklarhet",
        "uskarp",
        "rødme",
        "skryt",
        "bog",
        "tull",
        "Kok opp",
        "tekst",
        "bombe",
        "bombardere",
        "bombardement",
        "bombet",
        "bondage",
        "bindinger",
        "boo",
        "booby",
        "sprit",
        "NO TRANSLATION",
        "kjedsomhet",
        "kjedelig",
        "låner",
        "bry",
        "plager",
        "bunn",
        "bundet",
        "bout",
        "storfe",
        "gutt",
        "boikott",
        "skryte",
        "brandy",
        "Bravado",
        "slåsskamp",
        "skamløs",
        "brudd",
        "sammenbrudd",
        "halsbrekkende",
        "NO TRANSLATION",
        "bestikkelse",
        "bestikkelser",
        "brigade",
        "svovel",
        "bust",
        "bred",
        "broil",
        "blakk",
        "gått i stykker",
        "bordell",
        "blåmerke",
        "brunt",
        "brutal",
        "brutalitet",
        "brute",
        "buffet",
        "bug",
        "NO TRANSLATION",
        "oppsvulmede",
        "bølle",
        "boms",
        "nedtur",
        "tyngende",
        "byråkrati",
        "byråkrat",
        "innbruddstyv",
        "innbrudd",
        "begravelse",
        "begravet",
        "burke",
        "brent",
        "tatt på fersken",
        "slakter",
        "rumpe",
        "surra",
        "Cabal",
        "kakofoni",
        "cad",
        "kadaver",
        "bur",
        "beregning",
        "NO TRANSLATION",
        "samtaler",
        "valgkamp",
        "Avbryt",
        "kreft",
        "canker",
        "kannibal",
        "kannibalisme",
        "NO TRANSLATION",
        "fange",
        "fangenskap",
        "Kidnapperen",
        "fangst",
        "skrott",
        "karsinom",
        "kardiomyopati",
        "uforsiktighet",
        "karikatur",
        "karies",
        "blodbad",
        "kjødelig",
        "kjøttet",
        "kartell",
        "sak",
        "skrin",
        "slott",
        "havari",
        "grå stær",
        "katastrofe",
        "kateteret",
        "forsiktighet",
        "avstå",
        "gravplass",
        "sensor",
        "sensurere",
        "cess",
        "opphør",
        "agner",
        "gnaging",
        "ergrelse",
        "utfordring",
        "kaos",
        "kaotisk",
        "narrespill",
        "avgift",
        "jage",
        "straff",
        "pratsom",
        "billig",
        "jukse",
        "ostekake",
        "chicane",
        "barnslig",
        "kjølig",
        "kloroform",
        "kvele",
        "kolera",
        "hugge",
        "ork",
        "kronisk",
        "sigarett",
        "clamor",
        "clash",
        "kranglet",
        "klo",
        "kloster",
        "tåkete",
        "uklarhet",
        "klynge",
        "klønete",
        "kokain",
        "tvinge",
        "tvang",
        "kiste",
        "kald",
        "kaldt",
        "kulde",
        "kolikk",
        "kollapse",
        "kollisjon",
        "sammensvergelser",
        "koma",
        "komatøs",
        "kamp",
        "stridende",
        "stridslystne",
        "innsettelse",
        "oppstyr",
        "kommunisme",
        "kommunistisk",
        "konkurranse",
        "klage",
        "klage",
        "kompleks",
        "kompleksitet",
        "komplisere",
        "komplisert",
        "komplikasjon",
        "kompost",
        "tvang",
        "obligatorisk",
        "skjule",
        "skjult",
        "fortielse",
        "innbilskhet",
        "innbilsk",
        "hjernerystelse",
        "fordømme",
        "fordømmelse",
        "nedlatende",
        "nedlatenhet",
        "tilståelse",
        "begrense",
        "begrenset",
        "sperring",
        "konfiskere",
        "inndragning",
        "brannen",
        "konflikt",
        "motstrid",
        "skamme",
        "forvirret",
        "forvirre",
        "forvirring",
        "opphopning",
        "besvergelse",
        "erobring",
        "conspirator",
        "konspirerer",
        "bestyrtelse",
        "forstoppelse",
        "begrense, forhindre",
        "begrenset",
        "begrensning",
        "smitte",
        "smittsom",
        "forurense",
        "forurenset",
        "forurensning",
        "forakt",
        "foraktelig",
        "foraktelig",
        "omstridte",
        "smugler",
        "kontrakt",
        "motsi",
        "motsigelse",
        "motstrid",
        "motsetning",
        "kontras",
        "strid",
        "overtredelse",
        "kontroversielt",
        "Kontrovers",
        "dømme",
        "dom",
        "coop",
        "kopiere",
        "copycat",
        "rettslege",
        "korporal",
        "lik",
        "korreksjon",
        "korrosjon",
        "etsende",
        "korrupt",
        "ødelegge",
        "korrupsjon",
        "hoste",
        "rådgiver",
        "kursing",
        "begjære",
        "feiging",
        "feighet",
        "feigt",
        "sur",
        "sprekk",
        "sprakk",
        "sprengning",
        "krampe",
        "trangt",
        "sveiv",
        "gretten",
        "dritt",
        "brak",
        "crawl",
        "gal",
        "gal",
        "knirk",
        "skapning",
        "creep",
        "forbrytelse",
        "forbryter",
        "kriminalitet",
        "kleint",
        "krøpling",
        "forkrøplet",
        "krise",
        "sprø",
        "kritisk",
        "kritikk",
        "kritisere",
        "kjeltring",
        "kryss",
        "huk",
        "cruciate",
        "korsfestelsen",
        "grov",
        "grusom",
        "grusomt",
        "grusomhet",
        "smuldrer",
        "knase",
        "korstog",
        "knust",
        "knusing",
        "sprø",
        "gråte",
        "gråt",
        "krypten",
        "hanrei",
        "gjøk",
        "Cull",
        "skyld",
        "klanderverdig",
        "skyldige",
        "kult",
        "tungvint",
        "kopping",
        "cur",
        "forbannelse",
        "forbannet",
        "forbannelse",
        "overfladisk",
        "kutter",
        "cutthroat",
        "skjæring",
        "cyanid",
        "syklon",
        "cyste",
        "cytomegalovirus",
        "dabbling",
        "daemon",
        "tåpelig",
        "dolk",
        "skader",
        "skader",
        "jævla",
        "fortapelse",
        "forbannet",
        "spjeldet",
        "flass",
        "dandy",
        "fare",
        "farlig",
        "mørkere",
        "mørknet",
        "mørke",
        "stiplede",
        "feige",
        "omtumlet",
        "deaktivere",
        "vranglås",
        "dødelig",
        "døv",
        "død",
        "fiaskoen",
        "utskeielser",
        "rester",
        "gjeld",
        "debitor",
        "forfall",
        "forfalt",
        "avdød",
        "bedrageri",
        "bedragersk",
        "lure",
        "bedratt",
        "bedra",
        "bedrag",
        "villedende",
        "deklinasjon",
        "avslå",
        "synkende",
        "nedbrytning",
        "avta",
        "minsk",
        "avfeldig",
        "fordømme",
        "trekke",
        "ærekrenkelse",
        "ærekrenkende",
        "misligholde",
        "nederlag",
        "nedkjempet",
        "defekt",
        "NO TRANSLATION",
        "defekt",
        "forsvarsløs",
        "utsettelse",
        "trass",
        "trassig",
        "mangel",
        "underskudd",
        "deflate",
        "deflasjon",
        "deformeres",
        "deformert",
        "misdannelse",
        "bedra",
        "nedlagte",
        "trosse",
        "degenerasjon",
        "degenerert",
        "degradering",
        "degradere",
        "nedverdigende",
        "utsette",
        "forsinket",
        "skadelig",
        "sletting",
        "lovovertredelse",
        "betalingsudyktig",
        "delirisk",
        "delirium",
        "oversvømmelse",
        "vrangforestilling",
        "vrangforestillinger",
        "kreve",
        "krevende",
        "demente",
        "demens",
        "død",
        "rive",
        "riving",
        "demon",
        "demoniske",
        "demoralisert",
        "benektelse",
        "benektet",
        "fordømme",
        "Oppsigelsen",
        "benekte",
        "benektes",
        "avdød",
        "avgang",
        "avhengighet",
        "avhengighet",
        "beklagelig",
        "beklage",
        "deportere",
        "deportasjon",
        "fordervet",
        "fordervelse",
        "svekke",
        "avskrives",
        "avskrivninger",
        "trykke",
        "deprimert",
        "deprimerende",
        "depresjon",
        "depressiv",
        "deprivasjon",
        "sinnsforvirret",
        "falleferdige",
        "hån",
        "unntak",
        "nedsettende",
        "skjending",
        "ørken",
        "forlatt",
        "deserte",
        "avstå",
        "ødeleggelse",
        "fortvilelse",
        "fortvilet",
        "desperat",
        "avskyelig",
        "NO TRANSLATION",
        "despotiske",
        "despotisme",
        "nødlidende",
        "ødelagt",
        "ødelegger",
        "ødelegge",
        "ødeleggelse",
        "destruktiv",
        "løsrivelse",
        "holde tilbake",
        "innsatte",
        "fengsling",
        "forringes",
        "forverret",
        "forverring",
        "avsky",
        "detonere",
        "døve",
        "skade",
        "skadelig",
        "detritus",
        "ødelegge",
        "ødeleggende",
        "ødeleggelse",
        "djevel",
        "djevelsk",
        "utspekulert",
        "devolution",
        "sluke",
        "djevelske",
        "diagnose",
        "diatribe",
        "diktator",
        "diktatorisk",
        "diktatur",
        "NO TRANSLATION",
        "vanskeligheter",
        "vanskelighet",
        "digresjon",
        "falleferdig",
        "fortynne",
        "avta",
        "redusert",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "skitt",
        "skitne",
        "uførhet",
        "deaktivere",
        "funksjonshemmet",
        "misfornøyde",
        "være uenig",
        "uenige",
        "uenighet",
        "nektet",
        "skuffe",
        "skuffet",
        "skuff",
        "skuffelse",
        "misbilligelse",
        "mislike",
        "ikke godkjent",
        "misbilligende",
        "katastrofe",
        "katastrofal",
        "vantro",
        "utkast",
        "utladning",
        "disiplin",
        "fraskriver",
        "misfarging",
        "misfarget",
        "ubehag",
        "koble fra",
        "frakoblet",
        "frakobling",
        "misnøye",
        "avvikle",
        "diskontinuitet",
        "splid",
        "fraråde",
        "motløshet",
        "diskreditere",
        "diskriminere",
        "diskriminerende",
        "diskriminering",
        "forakt",
        "sykdom",
        "død",
        "disembodied",
        "utkobling",
        "vansiret",
        "vanære",
        "NO TRANSLATION",
        "skammelig",
        "misfornøyd",
        "avsky",
        "motbydelig",
        "motløs",
        "nedslående",
        "uærlig",
        "uærlighet",
        "vanære",
        "desillusjon",
        "desinformasjon",
        "disingenuous",
        "desintegrerer",
        "oppløsning",
        "uinteressert",
        "motvilje",
        "mislikte",
        "forstuet",
        "sturen",
        "forferdelse",
        "lemlesting",
        "avskjedigelse",
        "ulydighet",
        "ulydig",
        "ulydig",
        "lidelse",
        "uordentlig",
        "uorganisert",
        "nedvurdere",
        "nedsettende",
        "misforhold",
        "objektiv",
        "fjerne",
        "spredning",
        "forflytte",
        "misfornøyd",
        "misnøye",
        "avhending",
        "fratatt",
        "tvist",
        "diskvalifikasjon",
        "diskvalifisert",
        "diskvalifisere",
        "se bort fra",
        "tilsidesatt",
        "useriøse",
        "disrespect",
        "respektløs",
        "avbrudd",
        "utilfredshet",
        "uenighet",
        "dissen",
        "bjørnetjeneste",
        "dissident",
        "oppløsning",
        "dissonans",
        "avsmak",
        "usmakelig",
        "forvrengt",
        "forvrengning",
        "distrahere",
        "distrahert",
        "distraherende",
        "distraksjon",
        "fortvilet",
        "nød",
        "distressed",
        "plagsom",
        "mistro",
        "forstyrrelse",
        "forstyrret",
        "stillstand",
        "nedlagt",
        "avvikende",
        "solgt",
        "salget",
        "skilsmisse",
        "svimmelhet",
        "svimmel",
        "dokket",
        "NO TRANSLATION",
        "doldrums",
        "dole",
        "NO TRANSLATION",
        "dominerende",
        "dominans",
        "esel",
        "Doodle",
        "undergang",
        "dømt",
        "dommedag",
        "tvil",
        "tvilsom",
        "tvilende",
        "douche",
        "tok",
        "fall",
        "trist",
        "drenering",
        "ulempen",
        "Grue seg",
        "dreadful",
        "fryktelig",
        "kjedelig",
        "drikkevann",
        "vrøvl",
        "drone",
        "hengende",
        "tørke",
        "drukne",
        "døsighet",
        "slit",
        "drunken",
        "drukkenskap",
        "tvilsomme",
        "kjedelig",
        "dum",
        "dummy",
        "dumper",
        "dun",
        "fangehull",
        "lure",
        "dobbelthet",
        "tvang",
        "støv",
        "overskygget",
        "døende",
        "dysenteri",
        "jordskjelv",
        "tjuvlytte",
        "edikt",
        "feminin",
        "selvopptatt",
        "skjerpende",
        "støte",
        "utstøting",
        "eliminering",
        "flyktig",
        "avmagret",
        "NO TRANSLATION",
        "flau",
        "pinlig",
        "flause",
        "underslag",
        "emboli",
        "involvert",
        "nødsituasjon",
        "enklave",
        "inngrep",
        "heftelse",
        "sette i fare",
        "truet",
        "endemisk",
        "fiende",
        "håndhevelse",
        "gåtefull",
        "fiendskap",
        "slavebinde",
        "slaver",
        "slaveri",
        "viklet",
        "forviklinger",
        "innvoller",
        "misunnelig",
        "epidemi",
        "epilepsi",
        "utrydde",
        "utrydding",
        "viske ut",
        "erosjon",
        "err",
        "villfaren",
        "uberegnelig",
        "erratum",
        "feilaktig",
        "feil",
        "bryte ut",
        "utbrudd",
        "eskalere",
        "eschew",
        "spionasje",
        "fraseparerte",
        "aktiv dødshjelp",
        "evakuere",
        "evakuering",
        "unngå",
        "unnvikelse",
        "kaste",
        "utkastelse",
        "ond",
        "forverre",
        "forverring",
        "krevende",
        "overdrive",
        "overdrevet",
        "undersøkelse",
        "forbitrelse",
        "utgraving",
        "overflødig",
        "avgiftsdirektoratet",
        "ekskludert",
        "Eksklusiv",
        "utelukkelse",
        "ekskrement",
        "uutholdelig",
        "unnskyldning",
        "henrettelse",
        "bøddel",
        "eksos",
        "utslitt",
        "utmattelse",
        "NO TRANSLATION",
        "eksil",
        "eksorsisme",
        "eksil",
        "utvise",
        "utgifter",
        "utgifter",
        "utløpe",
        "utløpt",
        "kraftuttrykk",
        "eksplodere",
        "eksplosjon",
        "eksplosiv",
        "utsatt",
        "ekspropriasjon",
        "utvisning",
        "utrydde",
        "utryddelse",
        "utryddet",
        "slukke",
        "utenomrettslig",
        "ekstremitet",
        "dikte",
        "fabrikasjon",
        "falme",
        "avføring",
        "sviktende",
        "svikt",
        "besvimelse",
        "troløse",
        "forfalskning",
        "falle",
        "uholdbar",
        "feilslutning",
        "feilbarlige",
        "faller",
        "brakk",
        "løgn",
        "feilaktig",
        "forfalskning",
        "forfalske",
        "falskhet",
        "svikte",
        "hungersnød",
        "fanatiker",
        "farse",
        "farcical",
        "Fasting",
        "fett",
        "fatal",
        "dødsulykke",
        "skjebne",
        "utmattelse",
        "trøtt",
        "fet",
        "feil",
        "defekt",
        "fawn",
        "frykt",
        "engstelig",
        "skremmende",
        "fryktet",
        "febril",
        "fekal",
        "avføring",
        "avgift",
        "svak",
        "simulerte",
        "falt",
        "forbryter",
        "forbrytelse",
        "gjære",
        "glupsk",
        "grusomhet",
        "feide",
        "føydal",
        "føydalisme",
        "febrilsk",
        "fiasco",
        "fib",
        "fikle",
        "fiktiv",
        "djevel",
        "voldsom",
        "slåss",
        "slåssing",
        "filibuster",
        "skitt",
        "skitten",
        "skytevåpen",
        "passer inn",
        "pløsete",
        "slapp",
        "flagging",
        "åpenbar",
        "flak",
        "klaff",
        "flatulens",
        "flaunt",
        "feil",
        "loppe",
        "NO TRANSLATION",
        "fleece",
        "kjøttfulle",
        "rykke til",
        "piske",
        "flop",
        "flyndre",
        "influensa",
        "svingning",
        "fiende",
        "foliert",
        "dårskap",
        "lure",
        "tullete",
        "tåpelighet",
        "grovfôr",
        "streiftog",
        "forby",
        "avskrekkende",
        "makt",
        "tvang",
        "med makt",
        "illevarslende",
        "close",
        "slipp",
        "fremmed",
        "utlending",
        "advart",
        "gi opp",
        "forspilt",
        "inndragning",
        "falskneri",
        "glemme",
        "glemt",
        "laus",
        "formløs",
        "utukt",
        "svikte",
        "forlatt",
        "foul",
        "brudd",
        "skjør",
        "skrøpelighet",
        "panisk",
        "bedrageri",
        "uredelig",
        "nervøs",
        "slagsmålet",
        "frynsete",
        "freakish",
        "frysing",
        "frenetisk",
        "vanvittige",
        "raseri",
        "gnage",
        "frykt",
        "skremme",
        "skremt",
        "skrekkelig",
        "frigid",
        "fjollete",
        "frostskader",
        "skum",
        "rynke",
        "frowning",
        "nytteløs",
        "frustrere",
        "frustrert",
        "frustrasjon",
        "fudge",
        "rømling",
        "rote",
        "ryke",
        "illsint",
        "sopp",
        "funk",
        "rasende",
        "furor",
        "raseri",
        "oppstyr",
        "masete",
        "nytteløs",
        "nytteløse",
        "gaby",
        "gag",
        "galle",
        "galgen",
        "spille",
        "spiller",
        "gambling",
        "gjeng",
        "fengsel",
        "mellomrom",
        "søppel",
        "glorete",
        "garnityr",
        "flenge",
        "gisper",
        "NO TRANSLATION",
        "avmagret",
        "gent",
        "geriatrisk",
        "uhyggelig",
        "ghetto",
        "spøkelsesaktig",
        "tøv",
        "glacial",
        "blending",
        "grell",
        "glib",
        "tungsinn",
        "dystert",
        "glum",
        "glut",
        "fråtsing",
        "gnome",
        "goblin",
        "gudløse",
        "gonoré",
        "goo",
        "gore",
        "kløft",
        "gorilla",
        "blodig",
        "sladder",
        "gouge",
        "gikt",
        "regjering",
        "gripe",
        "fatte",
        "rist",
        "raspet",
        "grating",
        "grav",
        "grådighet",
        "grådig",
        "granat",
        "sorg",
        "klagemål",
        "sørge",
        "alvorlig",
        "uhyggelig",
        "skitt",
        "sotete",
        "sliping",
        "uhyggelig",
        "grizzly",
        "stønn",
        "NO TRANSLATION",
        "ekkelt",
        "grotesk",
        "jordet",
        "grunn",
        "knurre",
        "growling",
        "nag",
        "motvillig",
        "gyselig",
        "barsk",
        "beklage",
        "grinete",
        "guerilla",
        "svik",
        "giljotin",
        "skyld",
        "skyldig",
        "forkledning",
        "måke",
        "godtroende",
        "våpen",
        "utbrudd",
        "Guzzling",
        "sigøyner",
        "kjerring",
        "Haggard",
        "hårete",
        "halvveis",
        "hallusinasjon",
        "halter",
        "halting",
        "hemme",
        "hamstring",
        "handicap",
        "henger",
        "bøddel",
        "trakassere",
        "budbringer",
        "herdet",
        "hardhet",
        "motgang",
        "skjøge",
        "skade",
        "skadelig",
        "opprivende",
        "harry",
        "strenghet",
        "hash",
        "hasj",
        "forhastet",
        "hat",
        "hatsk",
        "hating",
        "hat",
        "hovmodig",
        "hjemsøke",
        "hjemsøkt",
        "ødeleggelse",
        "fare",
        "farlig",
        "tåke",
        "hodepine",
        "berusende",
        "hørsel",
        "rykter",
        "likvogn",
        "hjertesorg",
        "halsbrann",
        "hjerteløs",
        "hedning",
        "tungt",
        "hæl",
        "forsterke",
        "grufulle",
        "helvete",
        "jævli",
        "hjelpeløs",
        "hjelpeløshet",
        "blødning",
        "hemorroider",
        "kjetteri",
        "kjetter",
        "hermafroditt",
        "heroin",
        "herpes",
        "herpesvirus",
        "nøling",
        "skjult",
        "skrekkelig",
        "hindrer",
        "hindring",
        "hippie",
        "susing",
        "hvesende",
        "truffet",
        "hittil",
        "bikube",
        "hes",
        "hoary",
        "bløff",
        "uteligger",
        "hog",
        "hul",
        "holocaust",
        "hjemløs",
        "lengter hjem",
        "morderisk",
        "drap",
        "homofili",
        "hette",
        "hekta",
        "ule",
        "håpløs",
        "håpløshet",
        "horde",
        "fryktelig",
        "forferdelig",
        "vemmelig",
        "forferdelig",
        "forskrekket",
        "forferdelig",
        "skrekk",
        "grusomheter",
        "gissel",
        "fiendtlig",
        "fiendtlighetene",
        "fiendtlighet",
        "hyle",
        "huff",
        "humbug",
        "ydmyke",
        "ydmyk",
        "ydmykelse",
        "anelse",
        "sulten",
        "jeger",
        "jakt",
        "orkan",
        "oppjaget",
        "skade",
        "sårende",
        "sårer",
        "hustler",
        "hydra",
        "hydrocephalus",
        "hype",
        "overdrivelse",
        "Hykleri",
        "hykler",
        "hyklersk",
        "hysteri",
        "hysterisk",
        "idioti",
        "idiot",
        "idiotisk",
        "dagdriver",
        "avgudsdyrkelse",
        "uvitenhet",
        "uvitende",
        "overse",
        "jeg vil",
        "ulovlig",
        "ulovlighet",
        "uleselige",
        "uekte",
        "ulovlig",
        "analfabet",
        "sykdom",
        "ulogisk",
        "illusjon",
        "imiterte",
        "etterligning",
        "umoden",
        "umodenhet",
        "umoralsk",
        "umoral",
        "svekke",
        "svekkelse",
        "uframkommelig",
        "utålmodighet",
        "utålmodig",
        "impeach",
        "riksrett",
        "hindre",
        "ufullkommenhet",
        "ufullkomment",
        "ligne",
        "etterligning",
        "uforsonlig",
        "implisere",
        "uhøflig",
        "ileggelse",
        "umulig",
        "maktesløshet",
        "impotent",
        "beslaglegge",
        "upraktisk",
        "fengsle",
        "fengslet",
        "fengsling",
        "impropriety",
        "uklok",
        "uren",
        "urenhet",
        "imputering",
        "manglende evne",
        "utilgjengelig",
        "unøyaktig",
        "passivitet",
        "inaktivitet",
        "NO TRANSLATION",
        "utilstrekkelig",
        "ikke godtas",
        "tåpelig",
        "ubrukelig",
        "upassende",
        "uoppmerksomhet",
        "uhørlig",
        "uberegnelige",
        "uførhet",
        "fengsling",
        "i tilfelle",
        "brannstifter",
        "røkelse",
        "uopphørlig",
        "incest",
        "incestuøse",
        "forbrenning",
        "egge",
        "dårlig",
        "usammenhengende",
        "uforenlig",
        "inkompetanse",
        "inkompetent",
        "ufullstendighet",
        "ubegripelig",
        "urimelig",
        "uviktig",
        "hensynsløs",
        "inkonsekvens",
        "upraktisk",
        "stemmer ikke",
        "tvil",
        "incrimination",
        "Incubus",
        "pådra",
        "uhelbredelig",
        "incursion",
        "uanstendig",
        "ubesluttsomhet",
        "ubesluttsom",
        "uholdbar",
        "erstatte",
        "indenture",
        "ubestemt",
        "tiltale",
        "tiltale",
        "likegyldighet",
        "indigent",
        "indignert",
        "indignasjon",
        "utydelig",
        "indoktrinering",
        "lat",
        "ineffektiv",
        "ørkesløshet",
        "ineffektivitet",
        "ineffektiv",
        "udugelig",
        "ineptitude",
        "ulikhet",
        "urettferdig",
        "inert",
        "utilgivelig",
        "NO TRANSLATION",
        "uerfaren",
        "uforklarlig",
        "beryktet",
        "skjensel",
        "barnedrap",
        "infantile",
        "infarkt",
        "infisere",
        "infeksjon",
        "smittsomme",
        "mindreverdig",
        "underlegenhet",
        "Helvete",
        "infertilitet",
        "angrep",
        "vantro",
        "utroskap",
        "uføre",
        "skrøpelighet",
        "betennelse",
        "oppblåst",
        "inflasjon",
        "påføre",
        "infliction",
        "influensa",
        "angiver",
        "brudd",
        "sjelden",
        "overtredelse",
        "hemme",
        "ugjestmilde",
        "umenneskelig",
        "umenneskelighet",
        "fiendtlig",
        "urett",
        "kjennelse",
        "skade",
        "skadet",
        "skadelig",
        "skade",
        "urettferdighet",
        "innsatt",
        "virkningsløs",
        "sinnsyk",
        "galskap",
        "utrygg",
        "usikkerhet",
        "snik",
        "ubetydelighet",
        "ubetydelig",
        "smakløs",
        "uforskammet",
        "insolvens",
        "insolvent",
        "ustabilitet",
        "iverksette",
        "oppfordring",
        "insuffisiens",
        "utilstrekkelig",
        "utilstrekkelig",
        "fornærmelse",
        "fornærmende",
        "opprører",
        "uoverstigelig",
        "opprør",
        "inter",
        "forbud",
        "innblanding",
        "inter",
        "avbryte",
        "avbrutt",
        "testamente",
        "skremme",
        "trusler",
        "uutholdelig",
        "intoleranse",
        "intolerant",
        "beruset",
        "intraktabel",
        "intrige",
        "inntrenger",
        "inntrenging",
        "påtrengende",
        "invadere",
        "inntrenger",
        "ugyldig",
        "invalide",
        "ugyldighet",
        "invasjon",
        "ufrivillig",
        "involusjon",
        "rasende",
        "NO TRANSLATION",
        "strykejern",
        "irrasjonell",
        "irrasjonalitet",
        "uforsonlig",
        "uregelmessig",
        "uregelmessighet",
        "irrelevant",
        "uopprettelig",
        "uansvarlig",
        "respektløs",
        "ugjenkallelig",
        "irritabilitet",
        "irritabel",
        "irriterende",
        "irritasjon",
        "isolert",
        "isolasjon",
        "jabber",
        "fengsel",
        "sjargong",
        "rystende",
        "gulsott",
        "sjalu",
        "sjalusi",
        "sette på spill",
        "fare",
        "john",
        "vits",
        "NO TRANSLATION",
        "virvar",
        "skrot",
        "junta",
        "ungdoms-",
        "Kern",
        "sparke",
        "kidnappe",
        "drepe",
        "drap",
        "Drage",
        "knell",
        "knyttede",
        "anstrengt",
        "strevsom",
        "labyrint",
        "mangel på",
        "mangler",
        "laber",
        "laden",
        "lag",
        "lagging",
        "reir",
        "beklage",
        "jordskred",
        "sløv",
        "vansmekte",
        "smektende",
        "lapse",
        "tyveri",
        "lash",
        "sent",
        "lateness",
        "latent",
        "latriner",
        "latterlig",
        "lava",
        "lovløshet",
        "rettssak",
        "advokat",
        "lax",
        "avføringsmiddel",
        "lat",
        "lekke",
        "lekkasje",
        "lekk",
        "permisjon",
        "igle",
        "igler",
        "NO TRANSLATION",
        "sitron",
        "spedalskhet",
        "lesbisk",
        "minske",
        "mindre",
        "dødelig",
        "apati",
        "leukemi",
        "levy",
        "utuktig",
        "liaison",
        "løgner",
        "injurie",
        "slikke",
        "å ligge",
        "livløs",
        "begrenset",
        "halte",
        "lo",
        "brennevin",
        "giddeløs",
        "litigant",
        "saksøke",
        "Prosedyre, rettstvist",
        "saksøkende",
        "søppel",
        "Bleik",
        "brød",
        "dagdriver",
        "NO TRANSLATION",
        "avsky",
        "avsky",
        "motbydelig",
        "lobbyist",
        "NO TRANSLATION",
        "locust",
        "oppløftet",
        "ensomhet",
        "ensom",
        "ensom",
        "loo",
        "vevstol",
        "storlom",
        "loony",
        "tyvegods",
        "å tape",
        "å miste",
        "tap",
        "tapt",
        "loudness",
        "salong",
        "lus",
        "Nedre",
        "senking",
        "lavest",
        "lavlandet",
        "ydmyk",
        "latterlig",
        "lumbering",
        "klump",
        "klumpete",
        "galskap",
        "galning",
        "stikken",
        "lokke",
        "uhyggelig",
        "ligge på lur",
        "lurking",
        "frodige",
        "begjær",
        "vellystig",
        "liggende",
        "lynch",
        "Labyrint",
        "gal",
        "madden",
        "galning",
        "galskap",
        "mafia",
        "mark",
        "provisorisk",
        "sykdom",
        "utilpasshet",
        "malaria",
        "ondskapsfull",
        "funksjonsfeil",
        "misdannelse",
        "ondskapsfullhet",
        "skadelig",
        "malign",
        "malignitet",
        "ondartet",
        "malpractice",
        "mandamus",
        "NO TRANSLATION",
        "mangle",
        "mani",
        "galning",
        "maniske",
        "manipulere",
        "manipulasjon",
        "uaktsomt drap",
        "gjødsel",
        "mar",
        "margin",
        "rødbrun",
        "martingal",
        "martyr",
        "martyrium",
        "masochisme",
        "massakre",
        "materialisme",
        "materialist",
        "bukt",
        "meningsløs",
        "meslinger",
        "blande seg",
        "middelmådig",
        "middelmådighet",
        "melankolsk",
        "melankoli",
        "melee",
        "melodrama",
        "nedsmelting",
        "trussel",
        "truende",
        "menial",
        "leiesoldat",
        "nådeløs",
        "rot",
        "rotete",
        "metastase",
        "metanol",
        "mugg",
        "milits",
        "mimikk",
        "minimere",
        "minimum",
        "minoritet",
        "NO TRANSLATION",
        "dårlig oppførsel",
        "spontanabort",
        "ugagn",
        "rampete",
        "misforståelse",
        "dårlig oppførsel",
        "elendig",
        "stort",
        "elendighet",
        "ulykke",
        "villedet",
        "uhell",
        "feiltolkning",
        "villede",
        "villedende",
        "vanstyre",
        "mismatch",
        "misvisende",
        "forlegge",
        "feilplassert",
        "feilrepresentere",
        "feilaktig fremstilling",
        "Misrepresented",
        "savnet",
        "feilinformasjon",
        "feil",
        "feil",
        "elskerinne",
        "NO TRANSLATION",
        "misforstå",
        "misforståelse",
        "misbruk",
        "midd",
        "mob",
        "hån",
        "gjøre narr av",
        "overgrep",
        "monokrom",
        "monopolist",
        "monsun",
        "monster",
        "uhyrlighet",
        "humørsyk",
        "moot",
        "sykelig",
        "dødelighet",
        "likhus",
        "døende",
        "idiot",
        "moronic",
        "godbitene",
        "mortal",
        "dødelighet",
        "mortifikasjon",
        "likhus",
        "mygg",
        "sørge over",
        "sørgmodig",
        "sorg",
        "møkk",
        "søle",
        "rot",
        "rotete",
        "gjørmete",
        "muff",
        "muldyr",
        "mamma",
        "mumle",
        "kusma",
        "mord",
        "morder",
        "morderisk",
        "skummel",
        "NO TRANSLATION",
        "muggen",
        "mutant",
        "lemlestet",
        "lemlestelse",
        "mytteri",
        "NO TRANSLATION",
        "munnkurv",
        "nærsynthet",
        "fakke",
        "nadir",
        "NO TRANSLATION",
        "naiv",
        "navnløs",
        "bleie",
        "narkotiske",
        "ekkel",
        "slem",
        "kvalme",
        "kvalm",
        "NO TRANSLATION",
        "trengende",
        "trengende",
        "nefarious",
        "negasjon",
        "negativ",
        "forsømmelse",
        "forsømt",
        "mishandling",
        "forsømmelse",
        "forsømmelig",
        "NO TRANSLATION",
        "neger",
        "nepotisme",
        "nervøs",
        "nether",
        "brennesle",
        "nevralgi",
        "nevrose",
        "nevrotiske",
        "nikotin",
        "nigger",
        "mareritt",
        "nihilisme",
        "bråk",
        "støyende",
        "NO TRANSLATION",
        "tull",
        "nonsens",
        "løkke",
        "intet",
        "skadelig",
        "plage",
        "NO TRANSLATION",
        "opphever",
        "nummen",
        "nummenhet",
        "NO TRANSLATION",
        "oAF",
        "overvektige",
        "fedme",
        "obi",
        "obit",
        "nekrolog",
        "innvending",
        "støtende",
        "tvinge",
        "obligor",
        "utslette",
        "utslettet",
        "utslettelse",
        "oblivion",
        "ytterst ubehagelig",
        "obskøn",
        "obskønitet",
        "uklarhet",
        "hindring",
        "sta",
        "blokkere",
        "hindring",
        "obstruktiv",
        "stumpe",
        "okkult",
        "særhet",
        "motbydelig",
        "lukt",
        "fornærme",
        "fornærmet",
        "lovbryteren",
        "fornærmelse",
        "støtende",
        "offhand",
        "offing",
        "troll",
        "lukte",
        "oligarki",
        "tegn",
        "illevarslende",
        "utelate",
        "tyngende",
        "tyngende",
        "sive",
        "ugjennomsiktig",
        "opera",
        "opiat",
        "sta",
        "opium",
        "motstander",
        "motsette",
        "motsetning",
        "motstand",
        "undertrykke",
        "undertrykkelse",
        "undertrykkende",
        "undertrykker",
        "ork",
        "ildprøve",
        "artilleri",
        "foreldreløs",
        "tilsynelatende",
        "utkonkurrere",
        "utstøtt",
        "ramaskrik",
        "uthus",
        "outlandish",
        "fredløs",
        "raseri",
        "applaus",
        "nedlatende",
        "belaste",
        "overskyet",
        "drive",
        "overdose",
        "forfalt",
        "overvurdert",
        "flyte",
        "grodd",
        "overbelastning",
        "betalte",
        "overmakten",
        "overveldende",
        "priset",
        "forglemmelse",
        "styrte",
        "velte",
        "overvelde",
        "overveldet",
        "som skylder",
        "oksidasjon",
        "smerte",
        "smertelig",
        "smertefull",
        "smertefullt",
        "smerter",
        "parese",
        "pandemi",
        "NO TRANSLATION",
        "panikk",
        "lammelse",
        "lammet",
        "paranoia",
        "parasitt",
        "NO TRANSLATION",
        "papegøye",
        "parsimonious",
        "partisan",
        "NO TRANSLATION",
        "passiv",
        "passivitet",
        "lapp",
        "patetisk",
        "nedlatende",
        "NO TRANSLATION",
        "sparsomme",
        "fattiglem",
        "bonde",
        "Payback",
        "innbetaling",
        "særegenheter",
        "fotgjenger",
        "straffe~~POS=TRUNC",
        "straff",
        "penetrasjon",
        "Penitentiary",
        "fortapelse",
        "Peril",
        "farefull",
        "omkomme",
        "forgjengelig",
        "omkom",
        "fortapt",
        "mened",
        "pernisiøs",
        "gjerningspersonen",
        "opprettholdelse",
        "rådvill",
        "forvirring",
        "forfølge",
        "forfølgelse",
        "forstyrrelse",
        "kikhoste",
        "perverse",
        "perversjon",
        "pervers",
        "pervertert",
        "pessimisme",
        "pessimist",
        "skadedyr",
        "pest",
        "kjæledyr",
        "smålig",
        "phantom",
        "slim",
        "falsk",
        "picket",
        "vakter",
        "pickle",
        "gris",
        "Due",
        "hauger",
        "plyndring",
        "hallik",
        "Kvise",
        "furu",
        "pinion",
        "pique",
        "piratkopiering",
        "sjørøver",
        "pistol",
        "fallgruve",
        "plagiat",
        "pest",
        "saksøker",
        "belagt",
        "spiller",
        "bønn",
        "vanskelige situasjon",
        "plodding",
        "falle",
        "plyndre",
        "plunge",
        "lungebetennelse",
        "Koking",
        "meningsløst",
        "gift",
        "forgiftet",
        "forgiftning",
        "giftig",
        "stikke",
        "polemikk",
        "polio",
        "forurense",
        "forurensing",
        "polygami",
        "pomp",
        "pompøs",
        "klossete",
        "dårlig",
        "pop",
        "pinnsvin",
        "porno",
        "porno",
        "pornografisk",
        "pornografi",
        "posere",
        "besatt",
        "besittelse",
        "posthum",
        "utsettelse",
        "pund",
        "fattigdom",
        "maktesløs",
        "spøk",
        "prekær",
        "politistasjon",
        "rov",
        "knipe",
        "svangerskap",
        "fordommer",
        "fordomsfull",
        "skadelig",
        "lagt",
        "press",
        "arrogant",
        "late som",
        "lot",
        "late",
        "påskudd",
        "pretensjoner",
        "forebyggende",
        "bytte",
        "stikk",
        "stikk",
        "fengsel",
        "fange",
        "do",
        "problem",
        "utsette",
        "utsettelse",
        "profane",
        "banning",
        "vell",
        "forbudt",
        "forbud",
        "forlenge",
        "promiskuøse",
        "propaganda",
        "tiltale",
        "tiltale",
        "prostituert",
        "prostitusjon",
        "provokasjon",
        "vekk",
        "lirke",
        "nysgjerrige",
        "psykose",
        "publisist",
        "Oppblåst",
        "punsj",
        "stikk",
        "straffe",
        "straffet",
        "straffe",
        "avstraffelse",
        "straff",
        "skjærsilden",
        "purge",
        "puss",
        "kvakk",
        "hengemyr",
        "vaktel",
        "dilemma",
        "krangle",
        "oppheve",
        "kvele",
        "tvilsom",
        "kvikksølv",
        "slutte",
        "kogger",
        "dirrende",
        "quiz",
        "pøbel",
        "rabiat",
        "rabies",
        "stativ",
        "rekkert",
        "stråling",
        "radioaktiv",
        "radon",
        "raseri",
        "rasende",
        "filler",
        "raid",
        "skinne",
        "RAM",
        "springende",
        "rampage",
        "harsk",
        "løsepenger",
        "voldtekt",
        "rovfugler",
        "rakker",
        "utslett",
        "rotte",
        "vurdering",
        "hes",
        "skrubbsulten",
        "raving",
        "reaksjonær",
        "iden",
        "opprører",
        "irettesettelse",
        "tilbakevise",
        "trassig",
        "resesjon",
        "tilbakefall",
        "uforsvarlig",
        "hensynsløshet",
        "overflødig",
        "refluks",
        "ildfast",
        "avslag",
        "nekte",
        "nektet",
        "regress",
        "regresjon",
        "angre",
        "beklagelig",
        "angret",
        "angre",
        "regulatoriske",
        "tøyle",
        "avvise",
        "avvist",
        "avvisning",
        "avviser",
        "tilbakefall",
        "nedrykk",
        "frafalle",
        "motvillige",
        "varetekts",
        "avhjelp",
        "remiss",
        "samvittighetsnag",
        "fjerning",
        "fjerne",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "løper",
        "gi avkall på",
        "forsakelse",
        "NO TRANSLATION",
        "frastøtende",
        "repelling",
        "undertrykke",
        "undertrykkelse",
        "reprimande",
        "opptrykk",
        "represalier",
        "bebreidelse",
        "republikk",
        "repudiation",
        "frastøting",
        "oppheve",
        "heving",
        "mislike",
        "ergerlig",
        "harme",
        "si opp",
        "oppsigelse",
        "gikk av",
        "motstå",
        "motstand",
        "motstandsdyktig",
        "motsette",
        "beherske",
        "begrense",
        "begrensning",
        "restriktiv",
        "gjengjelde",
        "hevn",
        "gjengjeldelses",
        "tilbakestående",
        "retardasjon",
        "tilbakeholden",
        "skarpt svar",
        "trekke tilbake",
        "tilbaketrekking",
        "nedskjæringer",
        "straff",
        "retrograd",
        "hevn",
        "reversering",
        "tilbakekall",
        "tilbakekalle",
        "opprør",
        "frastøtende",
        "revolver",
        "avsky",
        "revmatisme",
        "vaklevorne",
        "pepret",
        "latterlig",
        "latterlig",
        "florerer",
        "rifle",
        "rift",
        "ubøyelig",
        "stivhet",
        "rigor",
        "streng",
        "ringe",
        "opptøyer",
        "opprørsk",
        "Fare",
        "risikabelt",
        "rivalisering",
        "rane",
        "raner",
        "ran",
        "rogue",
        "tårn",
        "råtne",
        "rotting",
        "ruhet",
        "NO TRANSLATION",
        "rad",
        "bølle",
        "søppel",
        "steinsprut",
        "rue",
        "ruffle",
        "robust",
        "ruin",
        "ruinert",
        "ødeleggende",
        "rykte",
        "runaway",
        "ruptur",
        "NO TRANSLATION",
        "rust",
        "rusten",
        "hensynsløs",
        "NO TRANSLATION",
        "sabotasje",
        "ofrene",
        "dessverre",
        "tristhet",
        "sag",
        "sevje",
        "sarkasme",
        "sarkom",
        "sardonisk",
        "satanisk",
        "mettet",
        "villmann",
        "villskap",
        "skorpe",
        "stillas",
        "skalpell",
        "skjell",
        "skandale",
        "skandaløs",
        "sparsom",
        "syndebukk",
        "arr",
        "knapp",
        "knapt",
        "knapphet",
        "skremme",
        "plyndrer",
        "ordningen",
        "skisma",
        "schizofreni",
        "isjias",
        "spotter",
        "skjenne",
        "skjenn",
        "glohet",
        "forakt",
        "skorpion",
        "skotsk whisky",
        "kjeltring",
        "svøpe",
        "scrambling",
        "skrapesyke",
        "hyle",
        "skrik",
        "hvin",
        "skrudd",
        "scrimmage",
        "skrubbe",
        "granske",
        "granskning",
        "avskum",
        "svi",
        "løsrivelse",
        "bortgjemt",
        "NO TRANSLATION",
        "sekresjon",
        "hemmelighetsfull",
        "sekteriske",
        "oppvigleri",
        "forføre",
        "forførelse",
        "segregere",
        "segregert",
        "gripe",
        "selvopptatt",
        "egoisme",
        "senil",
        "meningsløs",
        "setning",
        "separatist",
        "sepsis",
        "septisk",
        "deponering",
        "fredelig",
        "slange",
        "tjener",
        "tjene",
        "servile",
        "trelldom",
        "tilbakeslag",
        "sever",
        "kloakk",
        "avløp",
        "loslitt",
        "skur",
        "sjakkel",
        "skygge",
        "rister",
        "skjelvende",
        "sham",
        "shambles",
        "skam",
        "skammelig",
        "skamløs",
        "shanghai",
        "hai",
        "knuse",
        "knust",
        "skur",
        "shell",
        "skrin",
        "skipsvrak",
        "dritt",
        "skjelve",
        "sjokk",
        "shoddy",
        "skyte",
        "skyting",
        "butikktyveri",
        "mangel",
        "brist",
        "skudd",
        "skubbe",
        "prangende",
        "skrik",
        "skingrende",
        "krympe",
        "krympet",
        "gyse",
        "shun",
        "syk",
        "kvalm",
        "sykelig",
        "sykdom",
        "dum",
        "NO TRANSLATION",
        "syndig",
        "skummel",
        "synder",
        "synde",
        "sirene",
        "pingle",
        "skeptisk",
        "tvilsom",
        "skjev",
        "skid",
        "hoppe",
        "trefning",
        "slakk",
        "slagg",
        "slam",
        "bakvaskelse",
        "ærekrenkende",
        "dask",
        "slakte",
        "slakteri",
        "slakting",
        "slave",
        "slaveri",
        "slå ihjel",
        "slakter",
        "sludd",
        "slimete",
        "slink",
        "slip",
        "NO TRANSLATION",
        "slurvet",
        "dovendyr",
        "slentre",
        "slough",
        "treghet",
        "slam",
        "slug",
        "treg",
        "slum",
        "nedgangen",
        "Nedsmelting",
        "slaps",
        "ludder",
        "sly",
        "smack",
        "liten",
        "knuse",
        "knust",
        "overfladisk kjennskap",
        "lukt",
        "lukt",
        "tåpelig flir",
        "slå",
        "røyker",
        "kvele",
        "smudge",
        "selvgode",
        "smugle",
        "smugler",
        "smugling",
        "sote",
        "ulempe",
        "snags",
        "slange",
        "skarptromme",
        "snerr",
        "snerrende",
        "snike",
        "snik",
        "flir",
        "nyse",
        "snide",
        "snobb",
        "suge",
        "NO TRANSLATION",
        "sosialist",
        "jord",
        "skitten",
        "somatisk",
        "sturen",
        "sot",
        "trolldom",
        "simpel",
        "sår",
        "sårt",
        "sårhet",
        "sorg",
        "sorgfull",
        "NO TRANSLATION",
        "sjelløse",
        "sjelevenn",
        "sur",
        "slå",
        "krampe",
        "spyttet",
        "spyd",
        "speck",
        "spekter",
        "spektral",
        "spekulasjon",
        "brukt",
        "ugift kvinne",
        "Til tross",
        "ondskapsfull",
        "flis",
        "dele",
        "splitting",
        "skjemme bort",
        "spoiler",
        "snakket",
        "svamp",
        "Spook",
        "forstuing",
        "rangel",
        "sprite",
        "falsk",
        "squall",
        "husokkupant",
        "pysete",
        "squelch",
        "vri",
        "stikke",
        "svimlende",
        "stillestående",
        "flekk",
        "Ståle",
        "forfølge",
        "standoff",
        "stillstand",
        "stirrer",
        "stark",
        "skremme",
        "sult",
        "sultet",
        "sulter",
        "stasjonær",
        "demme",
        "stjele",
        "stjele",
        "stealthy",
        "stereotype",
        "stereotype",
        "steril",
        "sterilitet",
        "Stern",
        "stiv",
        "stivhet",
        "kvele",
        "kvalt",
        "stigma",
        "dødfødt",
        "stikke",
        "stinging",
        "stikkende",
        "stinke",
        "stinkende",
        "stint",
        "aksjer",
        "stjålet",
        "stein",
        "stein",
        "avføring",
        "stans",
        "storm",
        "storm-",
        "anstrengt",
        "straits",
        "strandet",
        "fremmed",
        "kvele",
        "Stray",
        "understreke",
        "stridigheter",
        "streik",
        "strimmel",
        "stripe",
        "strippet",
        "hjerneslag",
        "streve",
        "spankulere",
        "trykkende",
        "snuble",
        "stunned",
        "forkrøplet",
        "dum",
        "dumhet",
        "stupor",
        "svinesti",
        "undertrykke",
        "Emne",
        "kastet",
        "under",
        "undertrykkelse",
        "underordnet",
        "stevning",
        "innsynkning",
        "subsidie",
        "livnære",
        "trekke fra",
        "subversion",
        "undergravende",
        "grave",
        "bukke",
        "suge",
        "sucker",
        "saksøke",
        "lide",
        "lidende",
        "lidelse",
        "kvelende",
        "kvelning",
        "suicidal",
        "selvmord",
        "mutt",
        "stevning",
        "senket",
        "overfladisk",
        "overflødig",
        "overtroisk",
        "undertrykke",
        "undertrykkelse",
        "tilleggsavgift",
        "surly",
        "overgivelse",
        "overgivelse",
        "utsatt",
        "mistenkt",
        "suspensjon",
        "mistanke",
        "mistenkelig",
        "pinne",
        "sump",
        "myrlendt",
        "hakekors",
        "opphovning",
        "slurk",
        "svin",
        "hoven",
        "symptom",
        "synkope",
        "tabu",
        "plett",
        "NO TRANSLATION",
        "flokete",
        "tardiness",
        "sen",
        "tariff",
        "anløpe",
        "tjæreaktig",
        "smakløs",
        "spydighet",
        "avgift",
        "plage",
        "erting",
        "langtekkelig",
        "NO TRANSLATION",
        "uvær",
        "fristelse",
        "leiegård",
        "terminal",
        "avslutning",
        "termitt",
        "fryktelig",
        "skrekk",
        "terrorisme",
        "terrorist",
        "terror",
        "stivkrampe",
        "tjore",
        "tyveri",
        "teisme",
        "teokratisk",
        "tyv",
        "tørst",
        "torn",
        "tornete",
        "tankeløs",
        "søppel",
        "trussel",
        "True",
        "truende",
        "treske",
        "banke",
        "Gasspedal",
        "bølle",
        "dunk",
        "tordn",
        "hindre",
        "tiff",
        "sjenert",
        "fryktsomhet",
        "tipsy",
        "tirade",
        "trett",
        "tretthet",
        "slitsom",
        "tit",
        "padde",
        "tobakk",
        "toalett",
        "toils",
        "tolerere",
        "tannverk",
        "pine",
        "revet",
        "torpedo",
        "Torrid",
        "tort",
        "skadegjørende",
        "tortur",
        "berørt",
        "nærtagende",
        "vanskelig",
        "giftig",
        "toksin",
        "tragedie",
        "tragisk",
        "forræder",
        "landstryker",
        "transe",
        "overtredelse",
        "pynt",
        "feller",
        "søppel",
        "trashy",
        "traumatisk",
        "NO TRANSLATION",
        "parodi",
        "forrædersk",
        "forræderi",
        "forræderi",
        "skjelving",
        "tremor",
        "beven",
        "troløshet",
        "trengsel",
        "tribunal",
        "triks",
        "lureri",
        "bagatell",
        "snubler",
        "troll",
        "plagsom",
        "trompet",
        "tørkes",
        "svulst",
        "svulst",
        "tumult",
        "stormende",
        "turbulens",
        "turbulent",
        "kaos",
        "rykke",
        "tyfon",
        "tyranniske",
        "tyranni",
        "tyrann",
        "stygghet",
        "stygg",
        "magesår",
        "bakenforliggende",
        "ultimatum",
        "ute av stand",
        "uakseptabelt",
        "uforklarlig",
        "ikke godkjent",
        "fristilt",
        "uoppnåelig",
        "uattraktiv",
        "uautorisert",
        "uunngåelig",
        "uvitende",
        "uutholdelig",
        "vantro",
        "ikke til å tro",
        "ufødte",
        "nifst",
        "uncaring",
        "usikker",
        "uforanderlig",
        "urent",
        "ubehagelig",
        "skandaløst",
        "bevisstløs",
        "grunnlovsstridig",
        "ustyrlig",
        "ukontrollert",
        "usikre",
        "undergraves",
        "underbetalt",
        "underdimensjonert",
        "uønsket",
        "uønsket",
        "angre",
        "uro",
        "urolig",
        "uten utdannelse",
        "arbeidsledig",
        "ulik",
        "ujevn",
        "uforklarlig",
        "urettferdig",
        "urettferdighet",
        "utro",
        "ugunstig",
        "uferdig",
        "uforsonlig",
        "uheldig",
        "uvennlig",
        "oppfylt",
        "umøblert",
        "ugudelige",
        "utakknemlig",
        "ulykkelighet",
        "ulykkelig",
        "usunn",
        "uhellig",
        "uviktig",
        "unimpressed",
        "uforbedret",
        "uinformert",
        "uinnvidde",
        "uinspirert",
        "uforståelig",
        "utilsiktet",
        "uinteressert",
        "uinteressant",
        "urettferdig",
        "utilbørlig",
        "grunnløs",
        "uvennlig",
        "ukjent",
        "ulovlig",
        "ulisensiert",
        "uheldig",
        "uhåndterlig",
        "unaturlig",
        "uoffisiell",
        "ubetalt",
        "ubehagelig",
        "upopulær",
        "uforutsigbar",
        "uforberedt",
        "uproduktive",
        "ulønnsom",
        "ubeskyttet",
        "upublisert",
        "upålitelig",
        "gjengjeldt",
        "uregjerlig",
        "usikre",
        "utilfredsstillende",
        "misfornøyd",
        "usmakelig",
        "samvittighetsløs",
        "uoppgjorte",
        "skjemmende",
        "usofistikert",
        "usigelige",
        "ustabil",
        "mislykket",
        "passer ikke",
        "unsung",
        "støttes",
        "unsustainable",
        "usympatiske",
        "utemmet",
        "uholdbar",
        "utenkelig",
        "uryddig",
        "utidige",
        "uten navn",
        "Untold",
        "untoward",
        "utrent",
        "usann",
        "upålitelige",
        "uberettiget",
        "uvaskede",
        "uvel",
        "uvel",
        "uvilje",
        "uklokt",
        "uvitende",
        "uverdig",
        "urokkelig",
        "omveltning",
        "oppstand",
        "opprør",
        "urolig",
        "bolle~~POS=TRUNC",
        "som haster",
        "ubrukelig",
        "tilrive",
        "tilranet",
        "åger",
        "ledighet",
        "vacuous",
        "uklar",
        "vaghet",
        "vainly",
        "vampyr",
        "forsvant",
        "forfengelighet",
        "varicella",
        "varicose",
        "vegetative",
        "heftig",
        "vendetta",
        "hevn",
        "hevngjerrig",
        "giften",
        "giftig",
        "detaljnivå",
        "randen",
        "skadedyr",
        "mot",
        "svimmelhet",
        "veto",
        "vice",
        "ond",
        "offer",
        "utsatt",
        "kriminell, kjeltring",
        "onde",
        "hevngjerrig",
        "brudd",
        "vold",
        "voldelig",
        "voldelig",
        "viper",
        "virulens",
        "virus",
        "visitas",
        "vixen",
        "volatilitet",
        "vulkan",
        "oppkast",
        "voodoo",
        "vulgær",
        "vulgaritet",
        "sårbarhet",
        "gribb",
        "vaffel",
        "jamre",
        "vente",
        "velte seg",
        "NO TRANSLATION",
        "blekne",
        "ønsker",
        "krig",
        "oppsynsmann",
        "ware",
        "krigføring",
        "krigersk",
        "varsle",
        "varp",
        "skjev",
        "vorte",
        "Avfall",
        "drita full",
        "uøkonomisk",
        "sløse",
        "vassen",
        "vakle",
        "svekket",
        "svakt",
        "svakhet",
        "ha på",
        "trett",
        "tretthet",
        "trett",
        "ugress",
        "gråte",
        "merkelig",
        "raring",
        "NO TRANSLATION",
        "wench",
        "knerte",
        "innfall",
        "klynke",
        "piske",
        "virvelvind",
        "whisky",
        "hore",
        "ond",
        "ondskap",
        "vill",
        "undersøkelses",
        "skogbrann",
        "forsettlig",
        "pyse",
        "pysete",
        "krympe",
        "heks",
        "trolldom",
        "ta ut",
        "visne",
        "visnet",
        "ve",
        "sørgelig",
        "sørgelig",
        "ord",
        "mark",
        "slitt",
        "bekymret",
        "bekymre",
        "bekymrings",
        "verre",
        "forverring",
        "verdiløs",
        "sår",
        "krangel",
        "vrede",
        "vrak",
        "vraket",
        "ødelagt",
        "skiftenøkkel",
        "bryting",
        "stakkar",
        "elendig",
        "feil",
        "urett",
        "urettmessig",
        "feil",
        "smidd",
        "skjevt",
        "fremmedfrykt",
        "gjesp",
        "gjesping",
        "hyle",
        "gulfarger",
        "bjeff",
        "glidelås",
    ]
)

_ambivalent = set(
    [
        "overflod",
        "bevæpnet",
        "balsam",
        "skryte",
        "støy",
        "lesehest",
        "buck",
        "kjendis",
        "sjarmert",
        "omgåelse",
        "medvirkning",
        "tilstå",
        "lur",
        "avhengig",
        "mangfoldig",
        "dominere",
        "endeløs",
        "håndheve",
        "erotisk",
        "flukt",
        "følelse",
        "flirt",
        "hagl",
        "hedonisme",
        "høyeste",
        "ydmyk",
        "med en gang",
        "ubevegelig",
        "inntekt",
        "infiltrasjon",
        "innflytelse",
        "intens",
        "uendelig",
        "innblanding",
        "blonder",
        "liberal",
        "lord",
        "mors",
        "jordmor",
        "mor",
        "krus",
        "notoriety",
        "allmakt",
        "utbrudd",
        "fremragende",
        "parade",
        "omskrive",
        "petroleum",
        "present~~POS=TRUNC",
        "fortapte",
        "sitat",
        "rave",
        "regressive",
        "tenne",
        "rester",
        "pensjonering",
        "gjenopplive",
        "revolusjon",
        "fugleskremsel",
        "sølibat",
        "sensuell",
        "opptog",
        "ryggrad",
        "sterling",
        "saftig",
        "overtro",
        "overlegenhet",
        "omgi",
        "synonymt",
        "frist",
        "tenåringer",
        "behandle",
        "ubeseiret",
        "utemmet",
        "uventet",
        "utenkelig",
        "knytte opp",
        "oppoverbakke",
        "stemme",
        "vekt",
        "lengsel",
    ]
)
