_antonyms = {
    "habilitat": "incapacitat",
    "anormal": "normal",
    "abolir": "establir",
    "absència": "presència",
    "absent": "present",
    "futur": "passat",
    "absolut": "familiar",
    "abstenir-se": "actuar",
    "resum": "concret",
    "abundància": "escassetat",
    "abundant": "escàs",
    "acceptar": "rebutjar",
    "admitir": "negar",
    "acceptable": "inacceptable",
    "acceptació": "rebuig",
    "accessible": "inaccessible",
    "precís": "inexacte",
    "reconegut": "desconegut",
    "conegut": "desconegut",
    "actuar": "abstenir-se",
    "acció": "inacció",
    "actiu": "tranquil",
    "existent": "inexistent",
    "sorollós": "tranquil",
    "activitat": "inactivitat",
    "actual": "potencial",
    "afegir": "sostreure",
    "afegit": "resta",
    "adequat": "inadequat",
    "adjectiu": "substantiu",
    "admissible": "inadmissible",
    "adult": "juvenil",
    "avance": "retrocedir",
    "endavant": "invers",
    "front": "darrere",
    "veer": "esquena",
    "avantatge": "desavantatge",
    "afirmació": "reversió",
    "afirmatiu": "negatiu",
    "neutral": "negatiu",
    "popa": "primer pla",
    "edat": "rejovenir",
    "envellit": "jove",
    "agitació": "calma",
    "acordar": "discrepar",
    "agradable": "desagradable",
    "acord": "desacord",
    "alterat": "inalterat",
    "alternatiu": "davant",
    "amateur": "professional",
    "ambigu": "inequívoc",
    "amistós": "hostil",
    "amable": "odiós",
    "amfibis": "terrestre",
    "anal": "oral",
    "anàleg": "homòlegs",
    "anàlisi": "síntesi",
    "analític": "sintètic",
    "avantpassat": "descendent",
    "angular": "arrodonit",
    "animar": "descoratjar",
    "resposta": "pregunta",
    "antagonista": "sinèrgic",
    "antecedent": "posterior",
    "anterior": "posterior",
    "antisèptic": "sèptic",
    "aparença": "desaparició",
    "apreciació": "depreciació",
    "aprovació": "desaprovació",
    "aprovar": "rebutjar",
    "aquàtic": "amfibis",
    "terrestre": "amfibis",
    "aquós": "ígneo",
    "braç": "desarmar",
    "armat": "sense armes",
    "arribar": "sortir",
    "pujar": "conjunt",
    "pujada": "descendència",
    "adormit": "despert",
    "assentiment": "dissidència",
    "asimetria": "simetria",
    "ateisme": "el teisme",
    "adjuntar": "separar",
    "atac": "defensar",
    "perseguir": "defensar",
    "atenció": "desatenció",
    "atracció": "repulsió",
    "audible": "inaudible",
    "augment": "disminució",
    "tia": "oncle",
    "autoritzat": "no autoritzat",
    "automàtic": "manual",
    "evitar": "confrontar",
    "despert": "adormit",
    "esquena": "veer",
    "retrocedir": "avance",
    "darrere": "cap",
    "fons": "superior",
    "cap enrere": "endavant",
    "invers": "anvers",
    "dolent": "bo",
    "maldat": "bondat",
    "equilibrat": "desequilibrats",
    "suportar": "toro",
    "bonic": "lleig",
    "bellesa": "lletjor",
    "començar": "aturar",
    "inici": "mig",
    "aviat": "tard",
    "creença": "incredulitat",
    "doblegar": "redreçar",
    "benigne": "maligne",
    "gran": "petit",
    "naixement": "mort",
    "bisexual": "homosexual",
    "negre": "blanc",
    "beneeixi": "maledicció",
    "beneït": "maleït",
    "sense sang": "sagnant",
    "sagnant": "sense sang",
    "borrós": "enfocament",
    "bullir": "congelar",
    "en negreta": "tímid",
    "audàcia": "timidesa",
    "demanar prestat": "prestar",
    "prestatari": "prestador",
    "lligat": "sense enllaç",
    "noi": "noia",
    "boicot": "patrocinar",
    "trencar": "reparació",
    "trencable": "irrompible",
    "alegre": "trist",
    "alleugerir": "fosc",
    "trencat": "ininterrompudament",
    "germà": "germana",
    "toro": "suportar",
    "ocupada": "desocupats",
    "treballar": "ociós",
    "comprar": "vendre",
    "calma": "agitació",
    "capaç": "incapaç",
    "capacitat": "incapacitat",
    "efectiu": "crèdit",
    "dèbit": "crèdit",
    "centre": "esquerra",
    "cerebral": "emocional",
    "certesa": "incertesa",
    "canviar": "quedar-se",
    "sortir": "arribar",
    "moure's": "quedar-se",
    "canviable": "immutable",
    "ha canviat": "sense canvis",
    "càrrec": "alta",
    "llistar": "alta",
    "barat": "car",
    "alegria": "pena",
    "nen": "pare",
    "civil": "militars",
    "reclamació": "perdut",
    "claredat": "opacitat",
    "prominència": "obscuritat",
    "transparència": "opacitat",
    "net": "brut",
    "clergat": "laics",
    "clergue": "laic",
    "a prop": "obert",
    "tancat": "obert",
    "proximitat": "obertura",
    "litoral": "a l'interior",
    "coherent": "incoherent",
    "fred": "calenta",
    "col · lateral": "lineal",
    "comèdia": "tragèdia",
    "confort": "incomoditat",
    "comú": "poc comú",
    "compatible": "desafiant",
    "competència": "incompetència",
    "competent": "incompetent",
    "competició": "cooperació",
    "queixar-se": "alegria",
    "integritat": "incomplet",
    "complex": "senzill",
    "compost": "senzill",
    "complicar": "simplificar",
    "còncava": "convex",
    "presumitiva": "humilitat",
    "orgull": "humilitat",
    "concentració": "distribució",
    "concèntric": "excèntric",
    "concepció": "equívoca",
    "preocupat": "no preocupat",
    "concret": "resum",
    "confirmat": "no confirmat",
    "confrontar": "evitar",
    "conjuntiva": "disjuntiva",
    "connectar": "desconnectar",
    "connectat": "sense connexió",
    "consciència": "inconsciència",
    "conservador": "liberal",
    "conservar": "malbaratament",
    "considerat": "desconsiderat",
    "consistència": "inconsistència",
    "consonant": "vocal",
    "conspicua": "inconspicu",
    "constitucional": "inconstitucional",
    "consumir": "abstenir-se",
    "contingut": "descontentament",
    "continu": "esporàdic",
    "continuïtat": "discontinuïtat",
    "continueu": "interrompre",
    "contínua": "discontinu",
    "contracte": "ampliar",
    "contractat": "expandit",
    "contracció": "expansió",
    "convenient": "inconvenient",
    "convencional": "poc convencional",
    "convergir": "divergeix",
    "convergència": "divergència",
    "convergent": "divergent",
    "convex": "còncava",
    "convençut": "no convençut",
    "guai": "calenta",
    "cooperació": "competició",
    "cosmopolita": "provincial",
    "valentia": "covardia",
    "portada": "destapar",
    "encoberta": "obert",
    "covardia": "valentia",
    "crèdit": "dèbit",
    "creditor": "deutor",
    "criticar": "lloança",
    "plorar": "riure",
    "curable": "incurable",
    "maledicció": "beneeixi",
    "maleït": "beneït",
    "corb": "recte",
    "tallar": "sense tallar",
    "perill": "seguretat",
    "perillós": "segur",
    "fosc": "alleugerir",
    "foscor": "lleugeresa",
    "pesadesa": "lleugeresa",
    "filla": "fill",
    "dia": "nit",
    "sord": "audició",
    "mort": "naixement",
    "deutor": "creditor",
    "decència": "indecencia",
    "decent": "indecent",
    "caducifoli": "de fulla perenne",
    "decisió": "indecisió",
    "decisiu": "indecís",
    "disminució": "augment",
    "disminuir": "augmentar",
    "derrota": "victòria",
    "defensar": "perseguir",
    "acusat": "demandant",
    "defensa": "enjudiciament",
    "defensiu": "ofensiu",
    "desafiant": "compatible",
    "dèficit": "dirigir",
    "definit": "indefinit",
    "deflació": "inflació",
    "retard": "corren",
    "demora": "corren",
    "demanda": "subministrament",
    "negar": "admitir",
    "rebutjar": "acceptar",
    "depenent": "independent",
    "dipòsit": "retirar",
    "depreciació": "apreciació",
    "depriment": "alegre",
    "baixar": "pujar",
    "descendent": "avantpassat",
    "descendència": "pujada",
    "descriptiu": "prescriptiu",
    "desitjable": "indesitjable",
    "desesperació": "esperança",
    "desesperat": "esperança",
    "destruït": "conservat",
    "separar": "adjuntar",
    "devolució": "evolució",
    "difereixen": "igual",
    "desigual": "igual",
    "diferència": "igual",
    "difícil": "fàcil",
    "incòmode": "fàcil",
    "dificultat": "facilitat",
    "diligent": "negligent",
    "dilució": "concentració",
    "distribució": "concentració",
    "brut": "net",
    "impur": "net",
    "desactivar": "habilitar",
    "desavantatge": "avantatge",
    "discrepar": "acordar",
    "desagradable": "salat",
    "desacord": "acord",
    "desaparició": "aparença",
    "desaprovació": "aprovació",
    "desarmar": "braç",
    "alta": "llistar",
    "renunciar": "reclamació",
    "perdut": "trobat",
    "incomoditat": "confort",
    "desconnectar": "enganxar",
    "descontentament": "contingut",
    "discontinuació": "continuïtat",
    "interrompre": "continueu",
    "discontinuïtat": "continuïtat",
    "discontinu": "contínua",
    "descoratjar": "animar",
    "desànim": "ànim",
    "deshonest": "honesta",
    "deshonestedat": "honestedat",
    "deshonor": "honor",
    "desinfectar": "infectar",
    "es desintegren": "integrar",
    "disjuntiva": "conjuntiva",
    "no m'agrada": "a gust",
    "desallotjar": "allotjament",
    "desobediència": "obediència",
    "desobedient": "obedient",
    "desobeir": "obeir",
    "trastorn": "ordre",
    "desordenat": "ordenat",
    "desorganitzat": "organitzat",
    "sense organitzar": "organitzat",
    "descontent": "satisfet",
    "refutar": "demostrar-ho",
    "descalificar": "qualificar",
    "indescriptible": "reputable",
    "descrèdia": "reputació",
    "falta de respecte": "respecte",
    "irrespectuosa": "respectuós",
    "insatisfacció": "satisfacció",
    "dissidència": "assentiment",
    "disservice": "servei",
    "diferent": "similar",
    "dissonància": "harmonia",
    "dissuadir": "persuadir",
    "distal": "proximal",
    "llunyà": "a prop",
    "obert": "encoberta",
    "distingible": "indistinguible",
    "desconfiança": "confiança",
    "diürn": "nocturn",
    "divergeix": "convergir",
    "divergència": "convergència",
    "divergent": "convergent",
    "dividir": "unir",
    "individualment": "es multipliquen",
    "dividit": "units",
    "divisible": "indivisible",
    "intern": "extern",
    "natiu": "estranger",
    "dominant": "subordinat",
    "inactiu": "sant",
    "extingit": "existent",
    "passiu": "actiu",
    "tranquil": "sorollós",
    "doble": "solter",
    "múltiple": "solter",
    "colom": "falcó",
    "dramàtic": "lírica",
    "sec": "mullat",
    "àcid": "endolceix",
    "vençut": "indegudament",
    "avorrit": "aguditzar",
    "aplanar": "aguditzar",
    "morint": "principiant",
    "terrenal": "celestial",
    "facilitat": "dificultat",
    "fàcil": "incòmode",
    "refreda": "marea",
    "excèntric": "concèntric",
    "educat": "impolite",
    "eficaç": "ineficaç",
    "eficiència": "ineficiència",
    "eficient": "ineficient",
    "egress": "ingress",
    "elàstic": "inelàstic",
    "elegibles": "inelegible",
    "emocional": "cerebral",
    "empíric": "teòric",
    "buit": "sòlid",
    "prim": "espessir",
    "habilitar": "desactivar",
    "ànim": "desànim",
    "final": "inici",
    "acabant": "inici",
    "mig": "aviat",
    "endèmic": "cosmopolita",
    "provincial": "cosmopolita",
    "enèrgic": "letargs",
    "fer complir": "exempt",
    "enganxar": "desconnectar",
    "gaudir": "pateix",
    "entrar": "sortir",
    "igual": "diferència",
    "igualtat": "desigualtat",
    "equatorial": "polar",
    "equitatiu": "inequitativa",
    "equivocal": "inequívoc",
    "esborrar": "registre",
    "establir": "abolir",
    "atroç": "sense incidents",
    "de fulla perenne": "caducifoli",
    "evolució": "devolució",
    "exclusió": "inclusió",
    "exempt": "fer complir",
    "exhalar": "inhalar",
    "ampliar": "estreta",
    "expandit": "contractat",
    "expansió": "contracció",
    "esperat": "inesperat",
    "car": "barat",
    "experimentat": "sense experiència",
    "exportació": "importar",
    "expressar": "local",
    "general": "específic",
    "nacional": "internacional",
    "extensió": "flexió",
    "exterior": "interior",
    "extern": "intern",
    "externament": "internament",
    "extingir": "encendre",
    "extramural": "intramural",
    "extraordinari": "ordinari",
    "extrínsec": "intrínsec",
    "fallant": "passant",
    "corrent": "dempeus",
    "fracàs": "èxit",
    "fira": "injust",
    "fidels": "infidel",
    "caure": "pujar",
    "conjunt": "separat",
    "fallible": "infalible",
    "caient": "pujant",
    "falsedat": "veritat",
    "fama": "infamia",
    "familiar": "absolut",
    "luxós": "plana",
    "greix": "prim",
    "ple": "buit",
    "espés": "prim",
    "espessir": "prim",
    "pare": "nen",
    "fauna": "flora",
    "favorable": "desfavorable",
    "federal": "unitari",
    "femella": "mascle",
    "femení": "neutre",
    "feminitat": "masculinitat",
    "fèrtil": "estèril",
    "fidelitat": "infidelitat",
    "figura": "terra",
    "omplir": "buit",
    "trobar": "perdre",
    "acabar": "començar",
    "aturar": "començar",
    "finit": "infinit",
    "foc": "llogar",
    "flexió": "extensió",
    "surar": "pica",
    "font": "pica",
    "flora": "fauna",
    "enfocament": "borrós",
    "enemic": "amic",
    "plec": "desplegar",
    "seguir": "precedeix",
    "triomfar": "precedeix",
    "seguidor": "líder",
    "bogeria": "saviesa",
    "neci": "prudent",
    "peu": "cap",
    "cua": "cap",
    "prohibir": "permís",
    "primer pla": "fons",
    "estranger": "natiu",
    "oblida't": "recorda",
    "perdonar": "implacable",
    "formalisme": "imitació",
    "afortunat": "mala sort",
    "anvers": "invers",
    "falta": "fira",
    "injust": "fira",
    "trobat": "perdut",
    "fraternal": "idèntic",
    "congelar": "bullir",
    "freqüent": "infreqüent",
    "freqüentment": "amb poca freqüència",
    "amic": "enemic",
    "cap": "cua",
    "plenitud": "buit",
    "funcional": "orgànic",
    "inorgànic": "orgànic",
    "guany": "pèrdua",
    "gasós": "sòlid",
    "reunir": "difusió",
    "generalitat": "particularitat",
    "generós": "taca",
    "noia": "noi",
    "bo": "dolent",
    "bondat": "maldat",
    "gradual": "de sobte",
    "agraït": "ingrat",
    "major": "junior",
    "verd": "madur",
    "terra": "figura",
    "culpa": "innocència",
    "culpable": "innocent",
    "feliçment": "per desgràcia",
    "felicitat": "infelicitat",
    "feliç": "infeliç",
    "duresa": "suavitat",
    "sonoritat": "suavitat",
    "nitidesa": "suavitat",
    "harmonia": "dissonància",
    "odi": "amor",
    "odiós": "amable",
    "falcó": "colom",
    "saludable": "boig",
    "audició": "sord",
    "calenta": "fred",
    "celestial": "terrenal",
    "heterogeneïtat": "homogeneïtat",
    "ocultar": "espectacle",
    "llogar": "foc",
    "colpejar": "senyoreta",
    "sant": "inactiu",
    "homogeneïtat": "heterogeneïtat",
    "homòlegs": "anàleg",
    "homosexual": "bisexual",
    "honesta": "deshonest",
    "honestedat": "deshonestedat",
    "honor": "deshonor",
    "esperança": "desesperació",
    "esperançat": "sense esperança",
    "sense esperança": "esperançat",
    "horitzontal": "vertical",
    "hostil": "amable",
    "humil": "orgullós",
    "humilitat": "orgull",
    "famolenc": "set",
    "idèntic": "fraternal",
    "ociós": "treballar",
    "ígneo": "aquós",
    "encendre": "extingir",
    "ignorar": "avís",
    "il·legal": "lícit",
    "il·legalitat": "legalitat",
    "il·legible": "llegible",
    "il·lògic": "lògic",
    "imitació": "formalisme",
    "immaterial": "material",
    "immaduresa": "maduresa",
    "inconmensurable": "mesurable",
    "immoral": "moral",
    "immoralitat": "moralitat",
    "immortal": "mortal",
    "immortalitat": "mortalitat",
    "immutable": "canviable",
    "imparcialitat": "parcialitat",
    "intransitable": "passable",
    "impaciència": "paciència",
    "impacient": "pacient",
    "imperceptible": "perceptible",
    "imperfecció": "perfecció",
    "impermeable": "permeable",
    "impermissible": "permissible",
    "impersonal": "personal",
    "impolite": "educat",
    "importar": "exportació",
    "important": "no important",
    "impossibilitat": "possibilitat",
    "impotent": "potent",
    "improbable": "probable",
    "millorat": "sense millorar",
    "millora": "disminució",
    "imprudent": "prudent",
    "impuresa": "puresa",
    "incapacitat": "capacitat",
    "inaccessible": "accessible",
    "inexacte": "precís",
    "inacció": "acció",
    "inactivitat": "activitat",
    "inadequat": "adequat",
    "inadmissible": "admissible",
    "inanimat": "animar",
    "desatenció": "atenció",
    "inaudible": "audible",
    "incapaç": "capaç",
    "inclinat": "horitzontal",
    "vertical": "horitzontal",
    "inclusió": "exclusió",
    "incoherent": "coherent",
    "incompatible": "compatible",
    "incompetència": "competència",
    "incompetent": "competent",
    "incomplet": "integritat",
    "desconsiderat": "amable",
    "inconsistència": "consistència",
    "inconspicu": "conspicua",
    "inconvenient": "convenient",
    "augmentar": "disminuir",
    "augmentat": "disminució",
    "increment": "disminució",
    "incurable": "curable",
    "indecencia": "decència",
    "indecent": "decent",
    "indecisió": "decisió",
    "indecís": "decisiu",
    "independent": "depenent",
    "indistinguible": "distingible",
    "indivisible": "divisible",
    "interior": "exterior",
    "ineficaç": "eficaç",
    "ineficiència": "eficiència",
    "ineficient": "eficient",
    "inelàstic": "elàstic",
    "inelegible": "elegibles",
    "desigualtat": "igualtat",
    "inequitativa": "equitatiu",
    "sense experiència": "experimentat",
    "infalible": "fallible",
    "infamia": "fama",
    "infectar": "desinfectar",
    "inferior": "superior",
    "inferioritat": "superioritat",
    "infidelitat": "fidelitat",
    "infinit": "finit",
    "inflació": "deflació",
    "informat": "desinformat",
    "infreqüent": "freqüent",
    "amb poca freqüència": "freqüentment",
    "ingress": "egress",
    "habitat": "deshabitada",
    "inhalar": "exhalar",
    "injustícia": "justícia",
    "a l'interior": "litoral",
    "innocència": "culpa",
    "innocent": "culpable",
    "innocu": "nocius",
    "inoperant": "operatiu",
    "boig": "saludable",
    "la bogeria": "cordura",
    "inseguretat": "seguretat",
    "insignificància": "importància",
    "insignificant": "significatiu",
    "insoluble": "soluble",
    "insolvència": "solvència",
    "insolvent": "dissolvent",
    "inestabilitat": "estabilitat",
    "instrumental": "vocal",
    "insuficiència": "suficiència",
    "insuficient": "prou",
    "integrar": "es desintegren",
    "integració": "segregació",
    "intel·ligència": "estupidesa",
    "intel·ligible": "inintel·ligible",
    "destinat": "no desitjat",
    "intencionalment": "sense intenció",
    "interessat": "sense interès",
    "interessant": "sense interès",
    "intermedi": "terminal",
    "internament": "externament",
    "internacional": "nacional",
    "local": "general",
    "intolerància": "tolerància",
    "intolerant": "tolerant",
    "intractable": "tractable",
    "intramural": "extramural",
    "intrínsec": "extrínsec",
    "invisibilitat": "visibilitat",
    "invisible": "visible",
    "involuntari": "voluntari",
    "irracional": "racional",
    "irregular": "regular",
    "irregularitat": "regularitat",
    "irrelevant": "rellevant",
    "irresponsable": "responsable",
    "irreverent": "reverent",
    "assumpte": "recordar",
    "junior": "major",
    "justícia": "injustícia",
    "juvenil": "adult",
    "kern": "kern",
    "rei": "reina",
    "laics": "clergat",
    "tard": "aviat",
    "riure": "plorar",
    "lícit": "il·legal",
    "laxa": "tens",
    "relaxat": "tens",
    "laic": "clergue",
    "dirigir": "dèficit",
    "líder": "seguidor",
    "esquerra": "centre",
    "legal": "il·legal",
    "legalitat": "il·legalitat",
    "legalitzar": "prohibit",
    "llegible": "il·legible",
    "prestar": "demanar prestat",
    "prestador": "prestatari",
    "allargar": "escurçar",
    "menor": "major",
    "letargs": "enèrgic",
    "nivell": "aixecar",
    "més baix": "aixecar",
    "liberal": "conservador",
    "mentir": "estand",
    "rendiment": "estand",
    "llum": "fosc",
    "lleugeresa": "pesadesa",
    "a gust": "no m'agrada",
    "limitat": "il·limitat",
    "lineal": "col · lateral",
    "líquid": "gasós",
    "sòlid": "buit",
    "específic": "general",
    "ubicació": "estudi",
    "bloqueig": "descobrir",
    "allotjament": "desallotjar",
    "lògic": "il·lògic",
    "llarg": "curt",
    "alt": "curt",
    "afluixar": "estirar",
    "perdre": "cera",
    "pèrdua": "guany",
    "amor": "odi",
    "lírica": "dramàtic",
    "majoria": "minoria",
    "fer": "trencar",
    "reparació": "trencar",
    "mascle": "femella",
    "maligne": "benigne",
    "manual": "automàtic",
    "marcat": "sense marcar",
    "casat": "soltera",
    "masculí": "femení",
    "neutre": "femení",
    "masculinitat": "feminitat",
    "màscara": "desemmascarar",
    "material": "immaterial",
    "maternal": "paterna",
    "maduresa": "immaduresa",
    "màxim": "mínim",
    "mesurable": "inconmensurable",
    "mentals": "físic",
    "misericordiós": "sense pietat",
    "sense pietat": "misericordiós",
    "militars": "civil",
    "ment": "oblida't",
    "recorda": "oblida't",
    "mínim": "màxim",
    "minoria": "majoria",
    "equívoca": "concepció",
    "senyoreta": "colpejar",
    "molar": "molecular",
    "molecular": "molar",
    "moral": "immoral",
    "moralitat": "immoralitat",
    "mortal": "immortal",
    "mortalitat": "immortalitat",
    "mare": "pare",
    "es multipliquen": "individualment",
    "unir": "dividir",
    "mutable": "immutable",
    "nadir": "cenit",
    "estreta": "ampliar",
    "principiant": "morint",
    "negatiu": "neutral",
    "negligent": "diligent",
    "nebot": "neboda",
    "neboda": "nebot",
    "nit": "dia",
    "nocturn": "diürn",
    "nominal": "real",
    "irreal": "real",
    "inexistent": "existent",
    "normal": "anormal",
    "avís": "ignorar",
    "nocius": "innocu",
    "numèric": "verbal",
    "obediència": "desobediència",
    "obedient": "desobedient",
    "obeir": "desobeir",
    "objectiu": "subjectiu",
    "obligatori": "opcional",
    "oblic": "perpendicular",
    "obscuritat": "prominència",
    "opacitat": "transparència",
    "delicte": "defensa",
    "enjudiciament": "defensa",
    "ofensiu": "defensiu",
    "oficial": "no oficial",
    "obertura": "proximitat",
    "operatiu": "inoperant",
    "oposat": "sense oposició",
    "davant": "alternatiu",
    "optimisme": "pessimisme",
    "optimista": "pessimista",
    "opcional": "obligatori",
    "oral": "anal",
    "ordre": "trastorn",
    "ordenat": "desordenat",
    "ordinari": "extraordinari",
    "orgànic": "inorgànic",
    "organitzat": "sense organitzar",
    "ortodox": "poc ortodox",
    "a l'aire lliure": "interior",
    "prohibit": "legalitzar",
    "sobreestimar": "subestimar",
    "sobrecàrrega": "superfície",
    "paquet": "descomprimir",
    "dolorós": "indolor",
    "indolor": "dolorós",
    "paral·lel": "oblic",
    "perpendicular": "oblic",
    "parcialitat": "imparcialitat",
    "particularitat": "generalitat",
    "en part": "completament",
    "passable": "intransitable",
    "passant": "corrent",
    "dempeus": "corrent",
    "passat": "futur",
    "present": "absent",
    "paterna": "maternal",
    "paciència": "impaciència",
    "pacient": "impacient",
    "patrocinar": "boicot",
    "pau": "guerra",
    "penalització": "recompensa",
    "perceptible": "imperceptible",
    "perfecció": "imperfecció",
    "permeable": "impermeable",
    "permissible": "impermissible",
    "permissiu": "preventiva",
    "permís": "prohibir",
    "personal": "impersonal",
    "persuadir": "dissuadir",
    "pessimisme": "optimisme",
    "pessimista": "optimista",
    "físic": "mentals",
    "plana": "luxós",
    "demandant": "acusat",
    "satisfet": "descontent",
    "plural": "singular",
    "polar": "equatorial",
    "popular": "impopular",
    "porositat": "solidesa",
    "possibilitat": "impossibilitat",
    "posterior": "antecedent",
    "potent": "impotent",
    "potencial": "actual",
    "pobresa": "riquesa",
    "lloança": "criticar",
    "precedeix": "triomfar",
    "precedent": "triomfant",
    "prefix": "sufix",
    "preparació": "resolució",
    "preparat": "sense preparació",
    "prescriptiu": "descriptiu",
    "presència": "absència",
    "conservat": "destruït",
    "preventiva": "permissiu",
    "primària": "secundari",
    "privat": "públic",
    "de manera privada": "públicament",
    "probable": "improbable",
    "productiu": "improductiu",
    "profà": "sagrat",
    "professional": "amateur",
    "progrés, progressar": "tornada",
    "progressiu": "regressiu",
    "prospectiu": "retrospectiva",
    "protegit": "sense protecció",
    "orgullós": "humil",
    "demostrar-ho": "refutar",
    "proximal": "distal",
    "proper": "últim",
    "prudent": "neci",
    "públic": "privat",
    "públicament": "de manera privada",
    "publicat": "inèdit",
    "tirar": "empènyer",
    "puntualitat": "tardança",
    "purga": "rehabilitar",
    "puresa": "impuresa",
    "empènyer": "tirar",
    "qualificar": "descalificar",
    "reina": "rei",
    "pregunta": "resposta",
    "qüestionable": "indiscutible",
    "ràpidament": "lentament",
    "aixecar": "més baix",
    "racional": "irracional",
    "real": "irreal",
    "realista": "poc realista",
    "tranquil·litzar": "preocupació",
    "recordar": "assumpte",
    "registre": "esborrar",
    "refuse": "acceptar",
    "tornada": "progrés, progressar",
    "regressiu": "progressiu",
    "regular": "irregular",
    "regularitat": "irregularitat",
    "regulat": "no regulat",
    "rehabilitar": "purga",
    "rebuig": "acceptació",
    "rejovenir": "edat",
    "relacionat": "no relacionat",
    "rellevant": "irrelevant",
    "fiable": "poc fiable",
    "religiosa": "secular",
    "repulsió": "atracció",
    "reputable": "indescriptible",
    "reputació": "descrèdia",
    "resistir": "rendició",
    "resolució": "preparació",
    "respecte": "falta de respecte",
    "respectuós": "irrespectuosa",
    "responsable": "irresponsable",
    "restringit": "sense restriccions",
    "retrospectiva": "prospectiu",
    "reverent": "irreverent",
    "reversió": "afirmació",
    "recompensa": "penalització",
    "passeig": "caminar",
    "madur": "verd",
    "pujant": "caient",
    "rotor": "estator",
    "rugositat": "suavitat",
    "ronda": "quadrat",
    "arrodonit": "angular",
    "rural": "urbà",
    "corren": "demora",
    "sagrat": "profà",
    "per desgràcia": "feliçment",
    "tristesa": "felicitat",
    "infelicitat": "felicitat",
    "segur": "perillós",
    "seguretat": "inseguretat",
    "cordura": "la bogeria",
    "satisfacció": "insatisfacció",
    "salat": "desagradable",
    "escàs": "abundant",
    "escassetat": "abundància",
    "científic": "no científic",
    "escrupolós": "sense escrúpols",
    "secundari": "primària",
    "secular": "religiosa",
    "segregació": "integració",
    "egoista": "desinteressat",
    "vendre": "comprar",
    "separat": "conjunt",
    "separació": "unió",
    "sèptic": "antisèptic",
    "servei": "disservice",
    "es va establir": "inestable",
    "aguditzar": "aplanar",
    "curt": "alt",
    "escurçar": "allargar",
    "crit": "xiuxiueig",
    "espectacle": "ocultar",
    "encongir-se": "estirar",
    "costat": "fons",
    "superior": "inferior",
    "importància": "insignificància",
    "significatiu": "insignificant",
    "similar": "diferent",
    "senzill": "compost",
    "simplificar": "complicar",
    "solter": "múltiple",
    "singular": "plural",
    "pica": "font",
    "germana": "germà",
    "dormir": "estela",
    "lentament": "ràpidament",
    "petit": "gran",
    "suavitat": "nitidesa",
    "solidesa": "porositat",
    "soluble": "insoluble",
    "solvència": "insolvència",
    "dissolvent": "insolvent",
    "fill": "filla",
    "pena": "alegria",
    "trist": "alegre",
    "parlat": "escrit",
    "no escrit": "escrit",
    "esporàdic": "continu",
    "difusió": "reunir",
    "quadrat": "ronda",
    "estabilitat": "inestabilitat",
    "estable": "inestable",
    "estand": "rendiment",
    "estator": "rotor",
    "quedar-se": "moure's",
    "constant": "inestable",
    "empinat": "gradual",
    "de sobte": "gradual",
    "estèril": "fèrtil",
    "estirar": "encongir-se",
    "taca": "generós",
    "tempestuós": "calma",
    "recte": "corb",
    "redreçar": "doblegar",
    "desconegut": "incautà",
    "força": "debilitat",
    "fortament": "feble",
    "estudi": "ubicació",
    "estupidesa": "intel·ligència",
    "subjectiu": "objectiu",
    "subordinat": "dominant",
    "substantiu": "adjectiu",
    "sostreure": "afegir",
    "resta": "afegit",
    "triomfant": "precedent",
    "èxit": "fracàs",
    "reeixit": "sense èxit",
    "sucumbir": "sobreviure",
    "pateix": "gaudir",
    "suficiència": "insuficiència",
    "suficient": "insuficient",
    "prou": "insuficient",
    "sufix": "prefix",
    "alba": "capvespre",
    "capvespre": "alba",
    "superioritat": "inferioritat",
    "subministrament": "demanda",
    "recolzat": "no suportat",
    "superfície": "sobrecàrrega",
    "rendició": "resistir",
    "sobreviure": "sucumbir",
    "dolç": "àcid",
    "mullat": "sec",
    "endolceix": "àcid",
    "simetria": "asimetria",
    "simpàtic": "poc simpàtic",
    "sinèrgic": "antagonista",
    "síntesi": "anàlisi",
    "sintètic": "analític",
    "tardança": "puntualitat",
    "de bon gust": "sense sabor",
    "saborós": "sense sabor",
    "sense sabor": "saborós",
    "tendre": "dur",
    "tens": "relaxat",
    "terminal": "intermedi",
    "el teisme": "ateisme",
    "teòric": "empíric",
    "set": "famolenc",
    "pensatiu": "sense pensar",
    "sense pensar": "pensatiu",
    "estalviador": "inútil",
    "marea": "refreda",
    "corbata": "deslligar",
    "tímid": "en negreta",
    "timidesa": "audàcia",
    "tolerància": "intolerància",
    "tolerant": "intolerant",
    "dentat": "sense dents",
    "sense dents": "dentat",
    "tocat": "intacte",
    "dur": "tendre",
    "tractable": "intractable",
    "tragèdia": "comèdia",
    "entrenat": "sense entrenament",
    "confiança": "desconfiança",
    "veritat": "falsedat",
    "lletjor": "bellesa",
    "lleig": "bonic",
    "últim": "proper",
    "inacceptable": "acceptable",
    "inalterat": "alterat",
    "inequívoc": "equivocal",
    "sense armes": "armat",
    "no autoritzat": "autoritzat",
    "desequilibrats": "equilibrat",
    "incredulitat": "creença",
    "sense enllaç": "lligat",
    "irrompible": "trencable",
    "ininterrompudament": "trencat",
    "incertesa": "certesa",
    "sense canvis": "ha canviat",
    "oncle": "tia",
    "poc comú": "comú",
    "no preocupat": "preocupat",
    "no confirmat": "confirmat",
    "sense connexió": "connectat",
    "inconsciència": "consciència",
    "inconstitucional": "constitucional",
    "poc convencional": "convencional",
    "no convençut": "convençut",
    "destapar": "portada",
    "sense tallar": "tallar",
    "indefinit": "definit",
    "subestimar": "sobreestimar",
    "indesitjable": "desitjable",
    "indegudament": "vençut",
    "sense educació": "educat",
    "sense incidents": "atroç",
    "inesperat": "esperat",
    "infidel": "fidels",
    "desfavorable": "favorable",
    "desplegar": "plec",
    "implacable": "perdonar",
    "desafortunat": "afortunat",
    "ingrat": "agraït",
    "infeliç": "feliç",
    "poc sa": "saludable",
    "no important": "important",
    "sense millorar": "millorat",
    "desinformat": "informat",
    "deshabitada": "habitat",
    "inintel·ligible": "intel·ligible",
    "no desitjat": "destinat",
    "sense intenció": "intencionalment",
    "sense interès": "interessant",
    "unió": "separació",
    "unitari": "federal",
    "units": "dividit",
    "il·limitat": "limitat",
    "descobrir": "bloqueig",
    "mala sort": "afortunat",
    "sense marcar": "marcat",
    "soltera": "casat",
    "desemmascarar": "màscara",
    "desocupats": "ocupada",
    "no oficial": "oficial",
    "sense oposició": "oposat",
    "poc ortodox": "ortodox",
    "descomprimir": "paquet",
    "impopular": "popular",
    "sense preparació": "preparat",
    "improductiu": "productiu",
    "sense protecció": "protegit",
    "inèdit": "publicat",
    "indiscutible": "qüestionable",
    "poc realista": "realista",
    "no regulat": "regulat",
    "no relacionat": "relacionat",
    "poc fiable": "fiable",
    "sense restriccions": "restringit",
    "no científic": "científic",
    "sense escrúpols": "escrupolós",
    "desinteressat": "egoista",
    "inestable": "constant",
    "sense èxit": "reeixit",
    "no suportat": "recolzat",
    "poc simpàtic": "simpàtic",
    "deslligar": "corbata",
    "intacte": "tocat",
    "sense entrenament": "entrenat",
    "inusual": "habitual",
    "esbrinar": "vel",
    "incautà": "desconegut",
    "sense voler": "de bona gana",
    "falta de voluntat": "voluntat",
    "descansar": "vent",
    "indigne": "digne",
    "urbà": "rural",
    "habitual": "inusual",
    "valuós": "sense valor",
    "vel": "esbrinar",
    "verbal": "numèric",
    "victòria": "derrota",
    "virtuós": "malvat",
    "visibilitat": "invisibilitat",
    "visible": "invisible",
    "vocal": "consonant",
    "voluntari": "involuntari",
    "estela": "dormir",
    "caminar": "passeig",
    "guerra": "pau",
    "malbaratament": "conservar",
    "inútil": "estalviador",
    "cera": "perdre",
    "feble": "fortament",
    "debilitat": "força",
    "riquesa": "pobresa",
    "sense pes": "pesant",
    "pesant": "sense pes",
    "xiuxiueig": "crit",
    "blanc": "negre",
    "completament": "en part",
    "malvat": "virtuós",
    "ample": "estreta",
    "de bona gana": "sense voler",
    "voluntat": "falta de voluntat",
    "vent": "descansar",
    "saviesa": "bogeria",
    "retirar": "dipòsit",
    "preocupació": "tranquil·litzar",
    "sense valor": "valuós",
    "digne": "indigne",
    "escrit": "no escrit",
    "jove": "envellit",
    "cenit": "nadir",
}
